{-# LANGUAGE OverloadedStrings #-}
-- | Automatically generated syntax definition for Tcl/Tk.
-- DO NOT EDIT THIS FILE MANUALLY.
-- Instead, modify xml/tcl.xml and 'make bootstrap'.
module Skylighting.Syntax.Tcl (syntax) where

import Skylighting.Types
import Data.Binary

-- | Syntax definition for Tcl/Tk.
syntax :: Syntax
syntax = decode "\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKTcl/Tk\NUL\NUL\NUL\NUL\NUL\NUL\NUL\atcl.xml\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETXTcl\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STX\NUL\NUL\NUL\NUL\NUL\NUL\NUL\bkeywords\NUL\NUL\NUL\NUL\NUL\NUL\NUL\196\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQafter\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKappend\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\vAppleScript\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTargv\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTargc\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQarray\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\nauto_execk\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\vauto_execok\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\vauto_import\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\tauto_load\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\fauto_mkindex\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DLEauto_mkindex_old\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\tauto_path\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\fauto_qualify\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\nauto_reset\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTbeep\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTbell\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKbinary\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTbind\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\bbindtags\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\abgerror\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQbreak\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKbutton\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKcanvas\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTcase\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQcatch\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STXcd\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTchan\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\vcheckbutton\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\tclipboard\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQclock\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQclose\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\bcombobox\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKconcat\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\aconsole\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\bcontinue\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETXdde\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\adestroy\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTdict\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTelse\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKelseif\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\bencoding\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQentry\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETXenv\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETXeof\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQerror\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\terrorCode\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\terrorInfo\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTeval\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQevent\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTexec\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTexit\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTexpr\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\bfblocked\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\nfconfigure\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQfcopy\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTfile\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\tfileevent\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQflush\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQfocus\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTfont\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETXfor\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\aforeach\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKformat\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQframe\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTgets\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTglob\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKglobal\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTgrab\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTgrid\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ahistory\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STXif\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQimage\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTincr\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTinfo\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKinterp\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTjoin\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQlabel\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\nlabelframe\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\alappend\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\alassign\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKlindex\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\alinsert\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTlist\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\alistbox\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\allength\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTload\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQlower\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKlrange\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\alremove\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\alrepeat\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\blreplace\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\blreverse\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\alsearch\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTlset\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQlsort\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTmenu\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\nmenubutton\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\amessage\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\tnamespace\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\bnotebook\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTopen\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKoption\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\aOptProc\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTpack\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\apackage\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\vpanedwindow\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKparray\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETXpid\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQplace\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\vpkg_mkIndex\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTproc\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\vprogressbar\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTputs\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETXpwd\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\vradiobutton\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQraise\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTread\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKregexp\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\bregistry\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKregsub\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKrename\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\bresource\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKreturn\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQscale\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTscan\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\tscrollbar\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTseek\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\tselection\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTsend\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\tseparator\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETXset\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\bsizegrip\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKsocket\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKsource\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\aspinbox\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQsplit\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKstring\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQstyle\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQsubst\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKswitch\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKtclLog\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\rtcl_endOfWord\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SItcl_findLibrary\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\vtcl_library\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOtcl_patchLevel\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ftcl_platform\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\rtcl_precision\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOtcl_rcFileName\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOtcl_rcRsrcName\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC3tcl_startOfNextWord\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETBtcl_startOfPreviousWord\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DLEtcl_traceCompile\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\rtcl_traceExec\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\vtcl_version\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC2tcl_wordBreakAfter\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC3tcl_wordBreakBefore\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTtell\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTtext\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTtime\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STXtk\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\rtkTabToWindow\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKtkwait\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOtk_chooseColor\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC2tk_chooseDirectory\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC3tk_focusFollowMouse\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ftk_focusNext\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ftk_focusPrev\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOtk_getOpenFile\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOtk_getSaveFile\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ntk_library\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SItk_menuSetFocus\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\rtk_messageBox\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\rtk_optionMenu\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\rtk_patchLevel\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\btk_popup\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOtk_strictMotif\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\vtk_textCopy\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ntk_textCut\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ftk_textPaste\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ntk_version\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\btoplevel\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQtrace\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ntraverseTo\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\btreeview\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\aunknown\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKunload\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQunset\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKupdate\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\auplevel\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQupvar\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\bvariable\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQvwait\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQwhile\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQwinfo\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STXwm\NUL\NUL\NUL\NUL\NUL\NUL\NUL\fkeywords-opt\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETXadd\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTargs\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQatime\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\nattributes\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTbody\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\nbytelength\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKcancel\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\bchannels\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKclicks\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\bcmdcount\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\bcommands\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\acompare\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\bcomplete\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\vconvertfrom\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\tconvertto\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTcopy\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\adefault\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKdelete\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\adirname\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQequal\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\nexecutable\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKexists\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\textension\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQfirst\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKforget\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKformat\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\tfunctions\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\aglobals\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\bhostname\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTidle\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\bifneeded\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQindex\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTinfo\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STXis\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\visdirectory\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKisfile\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTjoin\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTlast\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKlength\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQlevel\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\alibrary\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTlink\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKloaded\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKlocals\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQlstat\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETXmap\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQmatch\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQmkdir\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQmtime\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DLEnameofexecutable\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQnames\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\nnativename\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\tnormalize\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKnumber\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQowned\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\npatchlevel\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\bpathtype\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\apresent\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQprocs\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\aprovide\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQrange\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\breadable\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\breadlink\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKremove\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKrename\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKrepeat\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\areplace\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\arequire\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\brootname\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTscan\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKscript\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\aseconds\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\tseparator\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC2sharedlibextension\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTsize\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQsplit\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTstat\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKsystem\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTtail\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ntclversion\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\atolower\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\atotitle\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\atoupper\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTtrim\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\btrimleft\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ttrimright\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTtype\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\aunknown\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\bvariable\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTvars\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\bvcompare\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\avdelete\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\bversions\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQvinfo\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\avolumes\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\nvsatisfies\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\awordend\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\twordstart\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\bwritable\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\bactivate\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKactual\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKaddtag\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKappend\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\aappname\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKaspect\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTatom\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\batomname\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTbbox\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTbind\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\tbroadcast\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\acanvasx\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\acanvasy\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQcaret\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQcells\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTcget\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\bchildren\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQclass\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQclear\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKclient\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQclone\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\fcolormapfull\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SIcolormapwindows\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\acommand\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\tconfigure\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ncontaining\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKcoords\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKcreate\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\acurrent\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\fcurselection\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKdchars\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQdebug\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\tdeiconify\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQdelta\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQdepth\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\bdeselect\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\tdlineinfo\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTdtag\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTdump\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTedit\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\tentrycget\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOentryconfigure\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\bfamilies\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTfind\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQflash\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQfocus\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\nfocusmodel\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\afpixels\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\bfraction\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQframe\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\bgenerate\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\bgeometry\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETXget\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\agettags\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTgrid\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQgroup\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKhandle\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKheight\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOThide\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\niconbitmap\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\aiconify\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\biconmask\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\biconname\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ficonposition\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\niconwindow\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\aicursor\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STXid\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\bidentify\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQimage\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKinsert\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ainterps\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQinuse\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKinvoke\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\bismapped\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\bitemcget\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ritemconfigure\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTkeys\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQlower\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\amanager\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTmark\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\amaxsize\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ameasure\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ametrics\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\aminsize\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTmove\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTname\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\anearest\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DLEoverrideredirect\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETXown\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\bpanecget\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\rpaneconfigure\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQpanes\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKparent\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\bpathname\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKpixels\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\bpointerx\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\tpointerxy\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\bpointery\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\fpositionfrom\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTpost\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\vpostcascade\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\npostscript\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\bprotocol\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQproxy\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQraise\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\arelease\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\treqheight\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\breqwidth\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\tresizable\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETXrgb\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQrootx\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQrooty\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQscale\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ascaling\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKscreen\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\vscreencells\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\vscreendepth\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\fscreenheight\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOscreenmmheight\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\rscreenmmwidth\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\fscreenvisual\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\vscreenwidth\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKsearch\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETXsee\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKselect\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\tselection\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKserver\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETXset\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTshow\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\bsizefrom\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\nstackorder\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQstate\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKstatus\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETXtag\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQtitle\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\btoplevel\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ttransient\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQtypes\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKunpost\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SIuseinputmethods\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\bvalidate\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKvalues\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\bviewable\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKvisual\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\bvisualid\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DLEvisualsavailable\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\vvrootheight\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\nvrootwidth\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKvrootx\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKvrooty\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQwidth\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKwindow\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SIwindowingsystem\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\bwithdraw\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOHx\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQxview\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOHy\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOT\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTBase\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTBase\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKTcl/Tk\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DLE\ACK\NUL\NUL\NUL\NUL\NUL\NUL\NUL\f#\\s*BEGIN.*$\SOH\EM\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACK\NUL\NUL\NUL\NUL\NUL\NUL\NUL\n#\\s*END.*$\SOH\EM\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\a\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\FS\t\n !%&()*+,-./:;<=>?[\\]^{|}~\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\196\NUL\NUL\NUL\NUL\NUL\NUL\NUL\vAppleScript\NUL\NUL\NUL\NUL\NUL\NUL\NUL\aOptProc\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQafter\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKappend\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTargc\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTargv\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQarray\NUL\NUL\NUL\NUL\NUL\NUL\NUL\nauto_execk\NUL\NUL\NUL\NUL\NUL\NUL\NUL\vauto_execok\NUL\NUL\NUL\NUL\NUL\NUL\NUL\vauto_import\NUL\NUL\NUL\NUL\NUL\NUL\NUL\tauto_load\NUL\NUL\NUL\NUL\NUL\NUL\NUL\fauto_mkindex\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DLEauto_mkindex_old\NUL\NUL\NUL\NUL\NUL\NUL\NUL\tauto_path\NUL\NUL\NUL\NUL\NUL\NUL\NUL\fauto_qualify\NUL\NUL\NUL\NUL\NUL\NUL\NUL\nauto_reset\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTbeep\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTbell\NUL\NUL\NUL\NUL\NUL\NUL\NUL\abgerror\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKbinary\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTbind\NUL\NUL\NUL\NUL\NUL\NUL\NUL\bbindtags\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQbreak\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKbutton\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKcanvas\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTcase\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQcatch\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STXcd\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTchan\NUL\NUL\NUL\NUL\NUL\NUL\NUL\vcheckbutton\NUL\NUL\NUL\NUL\NUL\NUL\NUL\tclipboard\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQclock\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQclose\NUL\NUL\NUL\NUL\NUL\NUL\NUL\bcombobox\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKconcat\NUL\NUL\NUL\NUL\NUL\NUL\NUL\aconsole\NUL\NUL\NUL\NUL\NUL\NUL\NUL\bcontinue\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETXdde\NUL\NUL\NUL\NUL\NUL\NUL\NUL\adestroy\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTdict\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTelse\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKelseif\NUL\NUL\NUL\NUL\NUL\NUL\NUL\bencoding\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQentry\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETXenv\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETXeof\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQerror\NUL\NUL\NUL\NUL\NUL\NUL\NUL\terrorCode\NUL\NUL\NUL\NUL\NUL\NUL\NUL\terrorInfo\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTeval\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQevent\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTexec\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTexit\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTexpr\NUL\NUL\NUL\NUL\NUL\NUL\NUL\bfblocked\NUL\NUL\NUL\NUL\NUL\NUL\NUL\nfconfigure\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQfcopy\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTfile\NUL\NUL\NUL\NUL\NUL\NUL\NUL\tfileevent\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQflush\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQfocus\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTfont\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETXfor\NUL\NUL\NUL\NUL\NUL\NUL\NUL\aforeach\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKformat\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQframe\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTgets\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTglob\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKglobal\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTgrab\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTgrid\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ahistory\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STXif\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQimage\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTincr\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTinfo\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKinterp\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTjoin\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQlabel\NUL\NUL\NUL\NUL\NUL\NUL\NUL\nlabelframe\NUL\NUL\NUL\NUL\NUL\NUL\NUL\alappend\NUL\NUL\NUL\NUL\NUL\NUL\NUL\alassign\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKlindex\NUL\NUL\NUL\NUL\NUL\NUL\NUL\alinsert\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTlist\NUL\NUL\NUL\NUL\NUL\NUL\NUL\alistbox\NUL\NUL\NUL\NUL\NUL\NUL\NUL\allength\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTload\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQlower\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKlrange\NUL\NUL\NUL\NUL\NUL\NUL\NUL\alremove\NUL\NUL\NUL\NUL\NUL\NUL\NUL\alrepeat\NUL\NUL\NUL\NUL\NUL\NUL\NUL\blreplace\NUL\NUL\NUL\NUL\NUL\NUL\NUL\blreverse\NUL\NUL\NUL\NUL\NUL\NUL\NUL\alsearch\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTlset\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQlsort\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTmenu\NUL\NUL\NUL\NUL\NUL\NUL\NUL\nmenubutton\NUL\NUL\NUL\NUL\NUL\NUL\NUL\amessage\NUL\NUL\NUL\NUL\NUL\NUL\NUL\tnamespace\NUL\NUL\NUL\NUL\NUL\NUL\NUL\bnotebook\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTopen\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKoption\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTpack\NUL\NUL\NUL\NUL\NUL\NUL\NUL\apackage\NUL\NUL\NUL\NUL\NUL\NUL\NUL\vpanedwindow\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKparray\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETXpid\NUL\NUL\NUL\NUL\NUL\NUL\NUL\vpkg_mkIndex\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQplace\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTproc\NUL\NUL\NUL\NUL\NUL\NUL\NUL\vprogressbar\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTputs\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETXpwd\NUL\NUL\NUL\NUL\NUL\NUL\NUL\vradiobutton\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQraise\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTread\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKregexp\NUL\NUL\NUL\NUL\NUL\NUL\NUL\bregistry\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKregsub\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKrename\NUL\NUL\NUL\NUL\NUL\NUL\NUL\bresource\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKreturn\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQscale\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTscan\NUL\NUL\NUL\NUL\NUL\NUL\NUL\tscrollbar\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTseek\NUL\NUL\NUL\NUL\NUL\NUL\NUL\tselection\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTsend\NUL\NUL\NUL\NUL\NUL\NUL\NUL\tseparator\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETXset\NUL\NUL\NUL\NUL\NUL\NUL\NUL\bsizegrip\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKsocket\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKsource\NUL\NUL\NUL\NUL\NUL\NUL\NUL\aspinbox\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQsplit\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKstring\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQstyle\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQsubst\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKswitch\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKtclLog\NUL\NUL\NUL\NUL\NUL\NUL\NUL\rtcl_endOfWord\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SItcl_findLibrary\NUL\NUL\NUL\NUL\NUL\NUL\NUL\vtcl_library\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOtcl_patchLevel\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ftcl_platform\NUL\NUL\NUL\NUL\NUL\NUL\NUL\rtcl_precision\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOtcl_rcFileName\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOtcl_rcRsrcName\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC3tcl_startOfNextWord\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETBtcl_startOfPreviousWord\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DLEtcl_traceCompile\NUL\NUL\NUL\NUL\NUL\NUL\NUL\rtcl_traceExec\NUL\NUL\NUL\NUL\NUL\NUL\NUL\vtcl_version\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC2tcl_wordBreakAfter\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC3tcl_wordBreakBefore\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTtell\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTtext\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTtime\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STXtk\NUL\NUL\NUL\NUL\NUL\NUL\NUL\rtkTabToWindow\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOtk_chooseColor\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC2tk_chooseDirectory\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC3tk_focusFollowMouse\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ftk_focusNext\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ftk_focusPrev\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOtk_getOpenFile\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOtk_getSaveFile\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ntk_library\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SItk_menuSetFocus\NUL\NUL\NUL\NUL\NUL\NUL\NUL\rtk_messageBox\NUL\NUL\NUL\NUL\NUL\NUL\NUL\rtk_optionMenu\NUL\NUL\NUL\NUL\NUL\NUL\NUL\rtk_patchLevel\NUL\NUL\NUL\NUL\NUL\NUL\NUL\btk_popup\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOtk_strictMotif\NUL\NUL\NUL\NUL\NUL\NUL\NUL\vtk_textCopy\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ntk_textCut\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ftk_textPaste\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ntk_version\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKtkwait\NUL\NUL\NUL\NUL\NUL\NUL\NUL\btoplevel\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQtrace\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ntraverseTo\NUL\NUL\NUL\NUL\NUL\NUL\NUL\btreeview\NUL\NUL\NUL\NUL\NUL\NUL\NUL\aunknown\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKunload\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQunset\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKupdate\NUL\NUL\NUL\NUL\NUL\NUL\NUL\auplevel\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQupvar\NUL\NUL\NUL\NUL\NUL\NUL\NUL\bvariable\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQvwait\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQwhile\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQwinfo\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STXwm\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\a\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\FS\t\n !%&()*+,-./:;<=>?[\\]^{|}~\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\bactivate\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKactual\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETXadd\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKaddtag\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKappend\NUL\NUL\NUL\NUL\NUL\NUL\NUL\aappname\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTargs\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKaspect\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQatime\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTatom\NUL\NUL\NUL\NUL\NUL\NUL\NUL\batomname\NUL\NUL\NUL\NUL\NUL\NUL\NUL\nattributes\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTbbox\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTbind\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTbody\NUL\NUL\NUL\NUL\NUL\NUL\NUL\tbroadcast\NUL\NUL\NUL\NUL\NUL\NUL\NUL\nbytelength\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKcancel\NUL\NUL\NUL\NUL\NUL\NUL\NUL\acanvasx\NUL\NUL\NUL\NUL\NUL\NUL\NUL\acanvasy\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQcaret\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQcells\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTcget\NUL\NUL\NUL\NUL\NUL\NUL\NUL\bchannels\NUL\NUL\NUL\NUL\NUL\NUL\NUL\bchildren\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQclass\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQclear\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKclicks\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKclient\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQclone\NUL\NUL\NUL\NUL\NUL\NUL\NUL\bcmdcount\NUL\NUL\NUL\NUL\NUL\NUL\NUL\fcolormapfull\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SIcolormapwindows\NUL\NUL\NUL\NUL\NUL\NUL\NUL\acommand\NUL\NUL\NUL\NUL\NUL\NUL\NUL\bcommands\NUL\NUL\NUL\NUL\NUL\NUL\NUL\acompare\NUL\NUL\NUL\NUL\NUL\NUL\NUL\bcomplete\NUL\NUL\NUL\NUL\NUL\NUL\NUL\tconfigure\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ncontaining\NUL\NUL\NUL\NUL\NUL\NUL\NUL\vconvertfrom\NUL\NUL\NUL\NUL\NUL\NUL\NUL\tconvertto\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKcoords\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTcopy\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKcreate\NUL\NUL\NUL\NUL\NUL\NUL\NUL\acurrent\NUL\NUL\NUL\NUL\NUL\NUL\NUL\fcurselection\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKdchars\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQdebug\NUL\NUL\NUL\NUL\NUL\NUL\NUL\adefault\NUL\NUL\NUL\NUL\NUL\NUL\NUL\tdeiconify\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKdelete\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQdelta\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQdepth\NUL\NUL\NUL\NUL\NUL\NUL\NUL\bdeselect\NUL\NUL\NUL\NUL\NUL\NUL\NUL\adirname\NUL\NUL\NUL\NUL\NUL\NUL\NUL\tdlineinfo\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTdtag\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTdump\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTedit\NUL\NUL\NUL\NUL\NUL\NUL\NUL\tentrycget\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOentryconfigure\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQequal\NUL\NUL\NUL\NUL\NUL\NUL\NUL\nexecutable\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKexists\NUL\NUL\NUL\NUL\NUL\NUL\NUL\textension\NUL\NUL\NUL\NUL\NUL\NUL\NUL\bfamilies\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTfind\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQfirst\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQflash\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQfocus\NUL\NUL\NUL\NUL\NUL\NUL\NUL\nfocusmodel\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKforget\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKformat\NUL\NUL\NUL\NUL\NUL\NUL\NUL\afpixels\NUL\NUL\NUL\NUL\NUL\NUL\NUL\bfraction\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQframe\NUL\NUL\NUL\NUL\NUL\NUL\NUL\tfunctions\NUL\NUL\NUL\NUL\NUL\NUL\NUL\bgenerate\NUL\NUL\NUL\NUL\NUL\NUL\NUL\bgeometry\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETXget\NUL\NUL\NUL\NUL\NUL\NUL\NUL\agettags\NUL\NUL\NUL\NUL\NUL\NUL\NUL\aglobals\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTgrid\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQgroup\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKhandle\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKheight\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOThide\NUL\NUL\NUL\NUL\NUL\NUL\NUL\bhostname\NUL\NUL\NUL\NUL\NUL\NUL\NUL\niconbitmap\NUL\NUL\NUL\NUL\NUL\NUL\NUL\aiconify\NUL\NUL\NUL\NUL\NUL\NUL\NUL\biconmask\NUL\NUL\NUL\NUL\NUL\NUL\NUL\biconname\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ficonposition\NUL\NUL\NUL\NUL\NUL\NUL\NUL\niconwindow\NUL\NUL\NUL\NUL\NUL\NUL\NUL\aicursor\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STXid\NUL\NUL\NUL\NUL\NUL\NUL\NUL\bidentify\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTidle\NUL\NUL\NUL\NUL\NUL\NUL\NUL\bifneeded\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQimage\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQindex\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTinfo\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKinsert\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ainterps\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQinuse\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKinvoke\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STXis\NUL\NUL\NUL\NUL\NUL\NUL\NUL\visdirectory\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKisfile\NUL\NUL\NUL\NUL\NUL\NUL\NUL\bismapped\NUL\NUL\NUL\NUL\NUL\NUL\NUL\bitemcget\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ritemconfigure\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTjoin\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTkeys\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTlast\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKlength\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQlevel\NUL\NUL\NUL\NUL\NUL\NUL\NUL\alibrary\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTlink\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKloaded\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKlocals\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQlower\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQlstat\NUL\NUL\NUL\NUL\NUL\NUL\NUL\amanager\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETXmap\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTmark\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQmatch\NUL\NUL\NUL\NUL\NUL\NUL\NUL\amaxsize\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ameasure\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ametrics\NUL\NUL\NUL\NUL\NUL\NUL\NUL\aminsize\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQmkdir\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTmove\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQmtime\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTname\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DLEnameofexecutable\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQnames\NUL\NUL\NUL\NUL\NUL\NUL\NUL\nnativename\NUL\NUL\NUL\NUL\NUL\NUL\NUL\anearest\NUL\NUL\NUL\NUL\NUL\NUL\NUL\tnormalize\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKnumber\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DLEoverrideredirect\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETXown\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQowned\NUL\NUL\NUL\NUL\NUL\NUL\NUL\bpanecget\NUL\NUL\NUL\NUL\NUL\NUL\NUL\rpaneconfigure\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQpanes\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKparent\NUL\NUL\NUL\NUL\NUL\NUL\NUL\npatchlevel\NUL\NUL\NUL\NUL\NUL\NUL\NUL\bpathname\NUL\NUL\NUL\NUL\NUL\NUL\NUL\bpathtype\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKpixels\NUL\NUL\NUL\NUL\NUL\NUL\NUL\bpointerx\NUL\NUL\NUL\NUL\NUL\NUL\NUL\tpointerxy\NUL\NUL\NUL\NUL\NUL\NUL\NUL\bpointery\NUL\NUL\NUL\NUL\NUL\NUL\NUL\fpositionfrom\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTpost\NUL\NUL\NUL\NUL\NUL\NUL\NUL\vpostcascade\NUL\NUL\NUL\NUL\NUL\NUL\NUL\npostscript\NUL\NUL\NUL\NUL\NUL\NUL\NUL\apresent\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQprocs\NUL\NUL\NUL\NUL\NUL\NUL\NUL\bprotocol\NUL\NUL\NUL\NUL\NUL\NUL\NUL\aprovide\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQproxy\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQraise\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQrange\NUL\NUL\NUL\NUL\NUL\NUL\NUL\breadable\NUL\NUL\NUL\NUL\NUL\NUL\NUL\breadlink\NUL\NUL\NUL\NUL\NUL\NUL\NUL\arelease\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKremove\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKrename\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKrepeat\NUL\NUL\NUL\NUL\NUL\NUL\NUL\areplace\NUL\NUL\NUL\NUL\NUL\NUL\NUL\treqheight\NUL\NUL\NUL\NUL\NUL\NUL\NUL\arequire\NUL\NUL\NUL\NUL\NUL\NUL\NUL\breqwidth\NUL\NUL\NUL\NUL\NUL\NUL\NUL\tresizable\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETXrgb\NUL\NUL\NUL\NUL\NUL\NUL\NUL\brootname\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQrootx\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQrooty\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQscale\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ascaling\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTscan\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKscreen\NUL\NUL\NUL\NUL\NUL\NUL\NUL\vscreencells\NUL\NUL\NUL\NUL\NUL\NUL\NUL\vscreendepth\NUL\NUL\NUL\NUL\NUL\NUL\NUL\fscreenheight\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOscreenmmheight\NUL\NUL\NUL\NUL\NUL\NUL\NUL\rscreenmmwidth\NUL\NUL\NUL\NUL\NUL\NUL\NUL\fscreenvisual\NUL\NUL\NUL\NUL\NUL\NUL\NUL\vscreenwidth\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKscript\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKsearch\NUL\NUL\NUL\NUL\NUL\NUL\NUL\aseconds\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETXsee\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKselect\NUL\NUL\NUL\NUL\NUL\NUL\NUL\tselection\NUL\NUL\NUL\NUL\NUL\NUL\NUL\tseparator\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKserver\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETXset\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC2sharedlibextension\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTshow\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTsize\NUL\NUL\NUL\NUL\NUL\NUL\NUL\bsizefrom\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQsplit\NUL\NUL\NUL\NUL\NUL\NUL\NUL\nstackorder\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTstat\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQstate\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKstatus\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKsystem\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETXtag\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTtail\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ntclversion\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQtitle\NUL\NUL\NUL\NUL\NUL\NUL\NUL\atolower\NUL\NUL\NUL\NUL\NUL\NUL\NUL\btoplevel\NUL\NUL\NUL\NUL\NUL\NUL\NUL\atotitle\NUL\NUL\NUL\NUL\NUL\NUL\NUL\atoupper\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ttransient\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTtrim\NUL\NUL\NUL\NUL\NUL\NUL\NUL\btrimleft\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ttrimright\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTtype\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQtypes\NUL\NUL\NUL\NUL\NUL\NUL\NUL\aunknown\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKunpost\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SIuseinputmethods\NUL\NUL\NUL\NUL\NUL\NUL\NUL\bvalidate\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKvalues\NUL\NUL\NUL\NUL\NUL\NUL\NUL\bvariable\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTvars\NUL\NUL\NUL\NUL\NUL\NUL\NUL\bvcompare\NUL\NUL\NUL\NUL\NUL\NUL\NUL\avdelete\NUL\NUL\NUL\NUL\NUL\NUL\NUL\bversions\NUL\NUL\NUL\NUL\NUL\NUL\NUL\bviewable\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQvinfo\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKvisual\NUL\NUL\NUL\NUL\NUL\NUL\NUL\bvisualid\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DLEvisualsavailable\NUL\NUL\NUL\NUL\NUL\NUL\NUL\avolumes\NUL\NUL\NUL\NUL\NUL\NUL\NUL\vvrootheight\NUL\NUL\NUL\NUL\NUL\NUL\NUL\nvrootwidth\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKvrootx\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKvrooty\NUL\NUL\NUL\NUL\NUL\NUL\NUL\nvsatisfies\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQwidth\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKwindow\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SIwindowingsystem\NUL\NUL\NUL\NUL\NUL\NUL\NUL\bwithdraw\NUL\NUL\NUL\NUL\NUL\NUL\NUL\awordend\NUL\NUL\NUL\NUL\NUL\NUL\NUL\twordstart\NUL\NUL\NUL\NUL\NUL\NUL\NUL\bwritable\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOHx\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQxview\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOHy\DLE\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\t\EOT\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\b\STX\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACK\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETX\\\\.\SOH\ACK\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACK\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACK\\s-\\w+\SOH\DLE\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACK\NUL\NUL\NUL\NUL\NUL\NUL\NUL\RS\\$\\{([^\\}]|\\\\\\})+\\}|\\$(::|\\w)+\SOH\SOH\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\"\"\b\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\"\b\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKTcl/Tk\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKString\NUL;\RS\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKTcl/Tk\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DLENew command line\NUL#\f\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKTcl/Tk\NUL\NUL\NUL\NUL\NUL\NUL\NUL\aComment\NUL{\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL}\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STX\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STX[]\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\aComment\NUL\NUL\NUL\NUL\NUL\NUL\NUL\aComment\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKTcl/Tk\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STX\DLE\f\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SI\NUL\NUL\NUL\NUL\NUL\NUL\NUL\bComments\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\f\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\f\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DLENew command line\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DLENew command line\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKTcl/Tk\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STX\DLE\RS\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL#\f\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKTcl/Tk\NUL\NUL\NUL\NUL\NUL\NUL\NUL\aComment\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKString\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKString\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKTcl/Tk\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETX\ACK\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETX\\\\.\SOH\ACK\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\"\b\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL$\SOH\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\b\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH8\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETXBSD\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STX\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQ*.tcl\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOT*.tk\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTBase"
