{-# LANGUAGE OverloadedStrings #-}
-- | Automatically generated syntax definition for Elixir.
-- DO NOT EDIT THIS FILE MANUALLY.
-- Instead, modify xml/elixir.xml and 'make bootstrap'.
module Skylighting.Syntax.Elixir (syntax) where

import Skylighting.Types
import Data.Binary

-- | Syntax definition for Elixir.
syntax :: Syntax
syntax = decode "\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKElixir\NUL\NUL\NUL\NUL\NUL\NUL\NUL\nelixir.xml\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKElixir\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQ\NUL\NUL\NUL\NUL\NUL\NUL\NUL\fcontrol-flow\NUL\NUL\NUL\NUL\NUL\NUL\NUL\t\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQcatch\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTcond\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTelse\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STXif\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQraise\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKrescue\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQthrow\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETXtry\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKunless\NUL\NUL\NUL\NUL\NUL\NUL\NUL\vdefinitions\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SO\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\tdefmodule\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETXdef\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTdefp\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\vdefprotocol\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\adefimpl\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\tdefrecord\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\tdefstruct\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\bdefmacro\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\tdefmacrop\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\vdefdelegate\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\vdefcallback\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DLEdefmacrocallback\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\fdefexception\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOdefoverridable\NUL\NUL\NUL\NUL\NUL\NUL\NUL\bkeywords\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC2\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTcase\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STXbc\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STXlc\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETXfor\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\areceive\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTexit\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQafter\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQquote\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\aunquote\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQsuper\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETXand\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETXnot\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STXor\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTwhen\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETXxor\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STXin\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKinlist\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKinbits\NUL\NUL\NUL\NUL\NUL\NUL\NUL\fmixin-macros\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOT\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKimport\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\arequire\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQalias\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETXuse\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DLEpseudo-variables\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETX\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETXnil\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTtrue\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQfalse\NUL\NUL\NUL\NUL\NUL\NUL\NUL\t\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC2Apostrophed String\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC2Apostrophed String\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKElixir\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETX\SOH\\\\\b\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\\'\b\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL'\t\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\t\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\rDocumentation\NUL\NUL\NUL\NUL\NUL\NUL\NUL\rDocumentation\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKElixir\NUL\NUL\NUL\NUL\NUL\NUL\NUL\a\EOT\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETX\"\"\"\DLE\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\ACK\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SO\\s*#+\\s.*[#]?$\SOH\DC1\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACK\NUL\NUL\NUL\NUL\NUL\NUL\NUL\r\\s*[\\*\\+\\-]\\s\SOH\DC1\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACK\NUL\NUL\NUL\NUL\NUL\NUL\NUL\f\\s*[\\d]+\\.\\s\SOH\DC1\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACK\NUL\NUL\NUL\NUL\NUL\NUL\NUL\r\\s*\\`\\`\\`\\s*$\SOH\DC1\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKElixir\NUL\NUL\NUL\NUL\NUL\NUL\NUL\rMarkdown Code\DLE\f\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SI\NUL\NUL\NUL\NUL\NUL\NUL\NUL\bMarkdown\NUL\NUL\NUL\NUL\NUL\NUL\NUL\vNormal Text\f\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\f\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SIGeneral Comment\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SIGeneral Comment\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKElixir\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STX\DLE\f\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SI\NUL\NUL\NUL\NUL\NUL\NUL\NUL\bComments\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\f\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\f\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\rMarkdown Code\NUL\NUL\NUL\NUL\NUL\NUL\NUL\rMarkdown Code\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKElixir\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\ACK\NUL\NUL\NUL\NUL\NUL\NUL\NUL\n\\s*```\\s*$\SOH\DC1\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\DC1\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKNormal\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKNormal\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKElixir\NUL\NUL\NUL\NUL\NUL\NUL\NUL&\ACK\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACK#!\\/.*\SOH\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACK\NUL\NUL\NUL\NUL\NUL\NUL\NUL\v\\bdo\\b(?!:)\SOH\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQ\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STXfn\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQ\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETXend\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL[\DLE\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL]\DLE\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL{\DC1\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL}\DC1\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL(\DC1\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL)\DC1\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\a\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SUB\t\n %&()*+,-./:;<=>[\\]^{|}~\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC2\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQafter\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETXand\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STXbc\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTcase\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTexit\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETXfor\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STXin\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKinbits\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKinlist\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STXlc\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETXnot\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STXor\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQquote\NUL\NUL\NUL\NUL\NUL\NUL\NUL\areceive\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQsuper\NUL\NUL\NUL\NUL\NUL\NUL\NUL\aunquote\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTwhen\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETXxor\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\a\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SUB\t\n %&()*+,-./:;<=>[\\]^{|}~\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\t\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQcatch\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTcond\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTelse\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STXif\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQraise\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKrescue\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQthrow\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETXtry\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKunless\DC3\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\a\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SUB\t\n %&()*+,-./:;<=>[\\]^{|}~\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SO\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETXdef\NUL\NUL\NUL\NUL\NUL\NUL\NUL\vdefcallback\NUL\NUL\NUL\NUL\NUL\NUL\NUL\vdefdelegate\NUL\NUL\NUL\NUL\NUL\NUL\NUL\fdefexception\NUL\NUL\NUL\NUL\NUL\NUL\NUL\adefimpl\NUL\NUL\NUL\NUL\NUL\NUL\NUL\bdefmacro\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DLEdefmacrocallback\NUL\NUL\NUL\NUL\NUL\NUL\NUL\tdefmacrop\NUL\NUL\NUL\NUL\NUL\NUL\NUL\tdefmodule\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOdefoverridable\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTdefp\NUL\NUL\NUL\NUL\NUL\NUL\NUL\vdefprotocol\NUL\NUL\NUL\NUL\NUL\NUL\NUL\tdefrecord\NUL\NUL\NUL\NUL\NUL\NUL\NUL\tdefstruct\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\a\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SUB\t\n %&()*+,-./:;<=>[\\]^{|}~\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETX\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQfalse\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETXnil\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTtrue\ENQ\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\a\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SUB\t\n %&()*+,-./:;<=>[\\]^{|}~\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOT\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQalias\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKimport\NUL\NUL\NUL\NUL\NUL\NUL\NUL\arequire\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETXuse\v\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACK\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NAK\\b[_A-Z]+[A-Z_0-9]+\\b\SOH\ENQ\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACK\NUL\NUL\NUL\NUL\NUL\NUL\NUL(\\b[A-Z]+_*(?:[0-9]|[a-z])[_a-zA-Z0-9]*\\b\SOH\ENQ\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACK\NUL\NUL\NUL\NUL\NUL\NUL\NUL'\\b\\-?0[xX](?:[0-9a-fA-F]|_[0-9a-fA-F])+\SOH\ETX\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACK\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EM\\b\\-?0[bB](?:[01]|_[01])+\SOH\ETX\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACK\NUL\NUL\NUL\NUL\NUL\NUL\NUL\FS\\b\\-?0[1-7](?:[0-7]|_[0-7])*\SOH\ETX\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACK\NUL\NUL\NUL\NUL\NUL\NUL\NULb\\b\\-?[0-9](?:[0-9]|_[0-9])*\\.[0-9](?:[0-9]|_[0-9])*(?:[eE]\\-?[1-9](?:[0-9]|_[0-9])*(?:\\.[0-9]*)?)?\SOH\EOT\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACK\NUL\NUL\NUL\NUL\NUL\NUL\NUL\GS\\b\\-?[1-9](?:[0-9]|_[0-9])*\\b\SOH\STX\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\b\STX\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\r\ACK\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL.\DC4\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH&&\DC4\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH||\DC4\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACK\NUL\NUL\NUL\NUL\NUL\NUL\NUL'\\s[\\?\\:\\%]\\s|[|&<>\\^\\+*~\\-=/]+|\\s!|/=\\s\SOH\DC4\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH%=\DC4\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACK\NUL\NUL\NUL\NUL\NUL\NUL\NULa:(?:@{1,2}|\\$)?[a-zA-Z_][a-zA-Z0-9_]*[=?!]?|\\b(?:@{1,2}|\\$)?[a-zA-Z_][a-zA-Z0-9_]*[=?!]?:|:\\[\\]=?\SOH\DC2\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACK\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NAK@(?:module)?doc\\s+\"\"\"\SOH\DLE\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKElixir\NUL\NUL\NUL\NUL\NUL\NUL\NUL\rDocumentation\EOT\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETX\"\"\"\b\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKElixir\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC4Triple Quoted String\NUL\"\b\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKElixir\NUL\NUL\NUL\NUL\NUL\NUL\NUL\rQuoted String\NUL'\t\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKElixir\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC2Apostrophed String\SOH?#\RS\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL#\f\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKElixir\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SIGeneral Comment\ACK\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SO@[a-zA-Z_0-9]+\SOH\DLE\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC1\RS\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\rQuoted String\NUL\NUL\NUL\NUL\NUL\NUL\NUL\rQuoted String\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKElixir\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQ\SOH\\\\\b\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\\\"\b\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACK\NUL\NUL\NUL\NUL\NUL\NUL\NUL\a#@{1,2}\SOH\DLE\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKElixir\NUL\NUL\NUL\NUL\NUL\NUL\NUL\vShort Subst\SOH#{\DLE\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKElixir\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQSubst\NUL\"\b\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\b\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\vShort Subst\NUL\NUL\NUL\NUL\NUL\NUL\NUL\vShort Subst\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKElixir\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STX\ACK\NUL\NUL\NUL\NUL\NUL\NUL\NUL\a#@{1,2}\SOH\DLE\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACK\NUL\NUL\NUL\NUL\NUL\NUL\NUL\b\\w(?!\\w)\SOH\DLE\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\DLE\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQSubst\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQSubst\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKElixir\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STX\NUL}\DLE\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\SI\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKElixir\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKNormal\RS\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC4Triple Quoted String\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC4Triple Quoted String\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKElixir\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\EOT\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETX\"\"\"\b\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\b\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NULKRub\195\169n Caro (ruben.caro.estevez@gmail.com), Boris Egorov (egorov@linux.com)\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STX15\NUL\NUL\NUL\NUL\NUL\NUL\NUL\aLGPLv2+\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACK\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOT*.ex\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQ*.exs\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQ*.eex\NUL\NUL\NUL\NUL\NUL\NUL\NUL\t*.xml.eex\NUL\NUL\NUL\NUL\NUL\NUL\NUL\b*.js.eex\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACK*.heex\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKNormal"
