{-# LANGUAGE OverloadedStrings #-}
-- | Automatically generated syntax definition for DTD.
-- DO NOT EDIT THIS FILE MANUALLY.
-- Instead, modify xml/dtd.xml and 'make bootstrap'.
module Skylighting.Syntax.Dtd (syntax) where

import Skylighting.Types
import Data.Binary

-- | Syntax definition for DTD.
syntax :: Syntax
syntax = decode "\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETXDTD\NUL\NUL\NUL\NUL\NUL\NUL\NUL\adtd.xml\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETXDtd\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STX\NUL\NUL\NUL\NUL\NUL\NUL\NUL\bCategory\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SO\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQEMPTY\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETXANY\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQCDATA\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STXID\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQIDREF\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKIDREFS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\aNMTOKEN\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\bNMTOKENS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKENTITY\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\bENTITIES\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\bNOTATION\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKPUBLIC\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKSYSTEM\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQNDATA\NUL\NUL\NUL\NUL\NUL\NUL\NUL\bKeywords\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOT\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\a#PCDATA\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\t#REQUIRED\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\b#IMPLIED\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACK#FIXED\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACK\NUL\NUL\NUL\NUL\NUL\NUL\NUL\aComment\NUL\NUL\NUL\NUL\NUL\NUL\NUL\aComment\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETXDTD\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOT\DLE\f\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOT\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETX-->\f\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\SI\NUL\NUL\NUL\NUL\NUL\NUL\NUL\bComments\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\f\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC1\f\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\f\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\vDeclaration\NUL\NUL\NUL\NUL\NUL\NUL\NUL\vDeclaration\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETXDTD\NUL\NUL\NUL\NUL\NUL\NUL\NUL\f\EOT\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOT<!--\f\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETXDTD\NUL\NUL\NUL\NUL\NUL\NUL\NUL\aComment\SOH--\f\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETXDTD\NUL\NUL\NUL\NUL\NUL\NUL\NUL\rInlineComment\NUL>\SOH\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\"\b\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETXDTD\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKString\ACK\NUL\NUL\NUL\NUL\NUL\NUL\NUL\f(-|O)\\s(-|O)\SOH\SOH\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STX\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOT(),|\STX\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACK\NUL\NUL\NUL\NUL\NUL\NUL\NUL/(%|&)(#[0-9]+|#[xX][0-9A-Fa-f]+|[\\-\\w\\d\\.:_]+);\SOH\STX\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STX\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQ&*+-?\EOT\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACK\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETX%\\s\SOH\STX\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\a\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\FS\t\n !%&()*+,-./:;<=>?[\\]^{|}~\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SO\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETXANY\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQCDATA\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQEMPTY\NUL\NUL\NUL\NUL\NUL\NUL\NUL\bENTITIES\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKENTITY\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STXID\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQIDREF\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKIDREFS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQNDATA\NUL\NUL\NUL\NUL\NUL\NUL\NUL\aNMTOKEN\NUL\NUL\NUL\NUL\NUL\NUL\NUL\bNMTOKENS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\bNOTATION\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKPUBLIC\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKSYSTEM\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\a\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\FS\t\n !%&()*+,-./:;<=>?[\\]^{|}~\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOT\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACK#FIXED\NUL\NUL\NUL\NUL\NUL\NUL\NUL\b#IMPLIED\NUL\NUL\NUL\NUL\NUL\NUL\NUL\a#PCDATA\NUL\NUL\NUL\NUL\NUL\NUL\NUL\t#REQUIRED\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACK\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC1\\b[\\-\\w\\d\\.:_]+\\b\SOH\DC1\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\rInlineComment\NUL\NUL\NUL\NUL\NUL\NUL\NUL\rInlineComment\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETXDTD\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOT\DLE\f\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH--\f\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\SI\NUL\NUL\NUL\NUL\NUL\NUL\NUL\bComments\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\f\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC1\f\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\f\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKNormal\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKNormal\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETXDTD\NUL\NUL\NUL\NUL\NUL\NUL\NUL\b\DLE\RS\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOT\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOT<!--\f\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETXDTD\NUL\NUL\NUL\NUL\NUL\NUL\NUL\aComment\EOT\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQ<?xml\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETXDTD\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STXPI\EOT\NUL\NUL\NUL\NUL\NUL\NUL\NUL\t<!ELEMENT\SOH\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETXDTD\NUL\NUL\NUL\NUL\NUL\NUL\NUL\vDeclaration\EOT\NUL\NUL\NUL\NUL\NUL\NUL\NUL\t<!ATTLIST\SOH\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETXDTD\NUL\NUL\NUL\NUL\NUL\NUL\NUL\vDeclaration\EOT\NUL\NUL\NUL\NUL\NUL\NUL\NUL\n<!NOTATION\SOH\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETXDTD\NUL\NUL\NUL\NUL\NUL\NUL\NUL\vDeclaration\EOT\NUL\NUL\NUL\NUL\NUL\NUL\NUL\b<!ENTITY\SOH\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETXDTD\NUL\NUL\NUL\NUL\NUL\NUL\NUL\vDeclaration\DC1\RS\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STXPI\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STXPI\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETXDTD\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\SOH?>\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKString\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKString\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETXDTD\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETX\DLE\b\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\"\b\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\ACK\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SI%[\\-\\w\\d\\.:_]+;\SOH\STX\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\b\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\USAndriy Lesyuk (s-andy@in.if.ua)\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH4\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTLGPL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQ*.dtd\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKNormal"
