{-# LANGUAGE OverloadedStrings #-}
-- | Automatically generated syntax definition for BibTeX.
-- DO NOT EDIT THIS FILE MANUALLY.
-- Instead, modify xml/bibtex.xml and 'make bootstrap'.
module Skylighting.Syntax.Bibtex (syntax) where

import Skylighting.Types
import Data.Binary

-- | Syntax definition for BibTeX.
syntax :: Syntax
syntax = decode "\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKBibTeX\NUL\NUL\NUL\NUL\NUL\NUL\NUL\nbibtex.xml\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKBibtex\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\bkw_entry\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SUB\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\b@article\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQ@book\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\b@booklet\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\v@conference\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\v@collection\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\v@electronic\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\a@inbook\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\r@incollection\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SO@inproceedings\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\a@manual\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SO@mastersthesis\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQ@misc\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\a@online\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\a@patent\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\v@periodical\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\f@proceedings\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\a@report\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\n@phdthesis\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOT@set\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\a@thesis\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\v@techreport\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\f@unpublished\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOT@www\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\a@person\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\b@company\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACK@place\NUL\NUL\NUL\NUL\NUL\NUL\NUL\a\NUL\NUL\NUL\NUL\NUL\NUL\NUL\fCurlyBracket\NUL\NUL\NUL\NUL\NUL\NUL\NUL\fCurlyBracket\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKBibTeX\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOT\NUL{\RS\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKBibTeX\NUL\NUL\NUL\NUL\NUL\NUL\NUL\fCurlyBracket\ACK\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC3\\\\([a-zA-Z@]+|[^ ])\SOH\ACK\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SO\RS\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STX\NUL\NUL\NUL}\RS\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQEntry\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQEntry\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKBibTeX\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOT\NUL{\RS\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACK\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC4[a-zA-Z0-9_@\\\\-\\\\:]+\SOH\DLE\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL,\RS\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKBibTeX\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQField\NUL}\RS\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQField\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQField\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKBibTeX\NUL\NUL\NUL\NUL\NUL\NUL\NUL\n\ACK\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC1[a-zA-Z0-9\\-_\\.]+\SOH\SOH\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DLE\RS\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL=\RS\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL{\RS\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKBibTeX\NUL\NUL\NUL\NUL\NUL\NUL\NUL\fCurlyBracket\NUL}\RS\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\"\RS\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKBibTeX\NUL\NUL\NUL\NUL\NUL\NUL\NUL\nQuotedText\STX\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STX#,\RS\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACK\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACK[0-9]+\SOH\RS\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACK\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SO[a-zA-Z0-9\\-]+\SOH\b\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACK\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH.\SOH\GS\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKNormal\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKNormal\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKBibTeX\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOT\a\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ESC\t\n !%&()*+,-./:;<=>?[]^{|}~\SOH\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SUB\NUL\NUL\NUL\NUL\NUL\NUL\NUL\b@article\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQ@book\NUL\NUL\NUL\NUL\NUL\NUL\NUL\b@booklet\NUL\NUL\NUL\NUL\NUL\NUL\NUL\v@collection\NUL\NUL\NUL\NUL\NUL\NUL\NUL\b@company\NUL\NUL\NUL\NUL\NUL\NUL\NUL\v@conference\NUL\NUL\NUL\NUL\NUL\NUL\NUL\v@electronic\NUL\NUL\NUL\NUL\NUL\NUL\NUL\a@inbook\NUL\NUL\NUL\NUL\NUL\NUL\NUL\r@incollection\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SO@inproceedings\NUL\NUL\NUL\NUL\NUL\NUL\NUL\a@manual\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SO@mastersthesis\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQ@misc\NUL\NUL\NUL\NUL\NUL\NUL\NUL\a@online\NUL\NUL\NUL\NUL\NUL\NUL\NUL\a@patent\NUL\NUL\NUL\NUL\NUL\NUL\NUL\v@periodical\NUL\NUL\NUL\NUL\NUL\NUL\NUL\a@person\NUL\NUL\NUL\NUL\NUL\NUL\NUL\n@phdthesis\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACK@place\NUL\NUL\NUL\NUL\NUL\NUL\NUL\f@proceedings\NUL\NUL\NUL\NUL\NUL\NUL\NUL\a@report\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOT@set\NUL\NUL\NUL\NUL\NUL\NUL\NUL\v@techreport\NUL\NUL\NUL\NUL\NUL\NUL\NUL\a@thesis\NUL\NUL\NUL\NUL\NUL\NUL\NUL\f@unpublished\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOT@www\DC2\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKBibTeX\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQEntry\EOT\NUL\NUL\NUL\NUL\NUL\NUL\NUL\a@string\DC1\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKBibTeX\NUL\NUL\NUL\NUL\NUL\NUL\NUL\rStringCommand\EOT\NUL\NUL\NUL\NUL\NUL\NUL\NUL\t@preamble\DC1\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKBibTeX\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SIPreambleCommand\EOT\NUL\NUL\NUL\NUL\NUL\NUL\NUL\b@comment\f\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\f\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SIPreambleCommand\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SIPreambleCommand\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKBibTeX\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL{\RS\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKBibTeX\NUL\NUL\NUL\NUL\NUL\NUL\NUL\fCurlyBracket\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\nQuotedText\NUL\NUL\NUL\NUL\NUL\NUL\NUL\nQuotedText\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKBibTeX\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STX\NUL\"\RS\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\ACK\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC3\\\\([a-zA-Z@]+|[^ ])\SOH\ACK\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\b\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\rStringCommand\NUL\NUL\NUL\NUL\NUL\NUL\NUL\rStringCommand\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKBibTeX\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STX\NUL{\RS\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKBibTeX\NUL\NUL\NUL\NUL\NUL\NUL\NUL\fCurlyBracket\ACK\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SO[a-zA-Z0-9\\-]+\SOH\b\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKBibTeX\NUL\NUL\NUL\NUL\NUL\NUL\NUL\fCurlyBracket\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL]Jeroen Wijnhout (Jeroen.Wijnhout@kdemail.net)+Thomas Braun (thomas.braun@virtuell-zuhause.de)\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH5\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTLGPL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQ*.bib\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKNormal"
