{-# LANGUAGE OverloadedStrings #-}
-- | Automatically generated syntax definition for ASN.1.
-- DO NOT EDIT THIS FILE MANUALLY.
-- Instead, modify xml/asn1.xml and 'make bootstrap'.
module Skylighting.Syntax.Asn1 (syntax) where

import Skylighting.Types
import Data.Binary

-- | Syntax definition for ASN.1.
syntax :: Syntax
syntax = decode "\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQASN.1\NUL\NUL\NUL\NUL\NUL\NUL\NUL\basn1.xml\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTAsn1\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STX\NUL\NUL\NUL\NUL\NUL\NUL\NUL\bkeywords\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DLE\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\vDEFINITIONS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\aEXPORTS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\aIMPORTS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTFROM\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\vAPPLICATION\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\aPRIVATE\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\tUNIVERSAL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\aDEFAULT\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\bOPTIONAL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQFALSE\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTTRUE\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\tAUTOMATIC\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQCLASS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTWITH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTSIZE\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTTAGS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQtypes\NUL\NUL\NUL\NUL\NUL\NUL\NUL\GS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\aBOOLEAN\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\aINTEGER\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQOCTET\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKSTRING\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTNULL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTREAL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\nENUMERATED\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\bSEQUENCE\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETXSET\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKCHOICE\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STXOF\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQUNION\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\vStringStore\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\rGeneralString\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\tIA5String\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\vISO64String\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\rNumericString\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SIPrintableString\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\tT61String\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\rTeletexString\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SIUniversalString\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\nUTF8String\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOVideotexString\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\rVisibleString\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTDATE\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\tDATE-TIME\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\bDURATION\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SIGeneralizedTime\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\aUTCTime\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOT\NUL\NUL\NUL\NUL\NUL\NUL\NUL\aComment\NUL\NUL\NUL\NUL\NUL\NUL\NUL\aComment\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQASN.1\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\SI\NUL\NUL\NUL\NUL\NUL\NUL\NUL\bComments\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\f\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\f\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC1Multiline Comment\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC1Multiline Comment\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQASN.1\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STX\SOH*/\f\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\SI\NUL\NUL\NUL\NUL\NUL\NUL\NUL\bComments\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\f\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\f\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\vNormal Text\NUL\NUL\NUL\NUL\NUL\NUL\NUL\vNormal Text\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQASN.1\NUL\NUL\NUL\NUL\NUL\NUL\NUL\n\a\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\FS\t\n !%&()*+,-./:;<=>?[\\]^{|}~\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DLE\NUL\NUL\NUL\NUL\NUL\NUL\NUL\vAPPLICATION\NUL\NUL\NUL\NUL\NUL\NUL\NUL\tAUTOMATIC\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQCLASS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\aDEFAULT\NUL\NUL\NUL\NUL\NUL\NUL\NUL\vDEFINITIONS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\aEXPORTS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQFALSE\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTFROM\NUL\NUL\NUL\NUL\NUL\NUL\NUL\aIMPORTS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\bOPTIONAL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\aPRIVATE\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTSIZE\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTTAGS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTTRUE\NUL\NUL\NUL\NUL\NUL\NUL\NUL\tUNIVERSAL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTWITH\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOT\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQBEGIN\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOT\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETXEND\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\a\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\FS\t\n !%&()*+,-./:;<=>?[\\]^{|}~\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\GS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\aBOOLEAN\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKCHOICE\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTDATE\NUL\NUL\NUL\NUL\NUL\NUL\NUL\tDATE-TIME\NUL\NUL\NUL\NUL\NUL\NUL\NUL\bDURATION\NUL\NUL\NUL\NUL\NUL\NUL\NUL\nENUMERATED\NUL\NUL\NUL\NUL\NUL\NUL\NUL\rGeneralString\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SIGeneralizedTime\NUL\NUL\NUL\NUL\NUL\NUL\NUL\tIA5String\NUL\NUL\NUL\NUL\NUL\NUL\NUL\aINTEGER\NUL\NUL\NUL\NUL\NUL\NUL\NUL\vISO64String\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTNULL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\rNumericString\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQOCTET\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STXOF\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SIPrintableString\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTREAL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\bSEQUENCE\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETXSET\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKSTRING\NUL\NUL\NUL\NUL\NUL\NUL\NUL\vStringStore\NUL\NUL\NUL\NUL\NUL\NUL\NUL\tT61String\NUL\NUL\NUL\NUL\NUL\NUL\NUL\rTeletexString\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQUNION\NUL\NUL\NUL\NUL\NUL\NUL\NUL\aUTCTime\NUL\NUL\NUL\NUL\NUL\NUL\NUL\nUTF8String\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SIUniversalString\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOVideotexString\NUL\NUL\NUL\NUL\NUL\NUL\NUL\rVisibleString\SOH\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH--\f\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQASN.1\NUL\NUL\NUL\NUL\NUL\NUL\NUL\aComment\SOH/*\f\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQASN.1\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC1Multiline Comment\NUL{\RS\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL}\RS\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\b\STX\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\"\b\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQASN.1\NUL\NUL\NUL\NUL\NUL\NUL\NUL\tctxString\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\tctxString\NUL\NUL\NUL\NUL\NUL\NUL\NUL\tctxString\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQASN.1\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\"\b\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\b\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DLEPhilippe Rigault\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH6\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETXGPL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STX\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQ*.asn\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACK*.asn1\NUL\NUL\NUL\NUL\NUL\NUL\NUL\vNormal Text"
