{-# LANGUAGE OverloadedStrings #-}
-- | Automatically generated syntax definition for INI Files.
-- DO NOT EDIT THIS FILE MANUALLY.
-- Instead, modify xml/ini.xml and 'make bootstrap'.
module Skylighting.Syntax.Ini (syntax) where

import Skylighting.Types
import Data.Binary

-- | Syntax definition for INI Files.
syntax :: Syntax
syntax = decode "\NUL\NUL\NUL\NUL\NUL\NUL\NUL\tINI Files\NUL\NUL\NUL\NUL\NUL\NUL\NUL\aini.xml\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETXIni\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\bkeywords\NUL\NUL\NUL\NUL\NUL\NUL\NUL\CAN\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STXOn\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETXOff\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\aDefault\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\bDefaults\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\tLocalhost\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTNull\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTTrue\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQFalse\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETXYes\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STXNo\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKNormal\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQE_ALL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\aE_ERROR\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\tE_WARNING\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\aE_PARSE\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\bE_NOTICE\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\bE_STRICT\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\fE_CORE_ERROR\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOE_CORE_WARNING\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SIE_COMPILE_ERROR\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC1E_COMPILE_WARNING\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\fE_USER_ERROR\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOE_USER_WARNING\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\rE_USER_NOTICE\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQ\NUL\NUL\NUL\NUL\NUL\NUL\NUL\aComment\NUL\NUL\NUL\NUL\NUL\NUL\NUL\aComment\NUL\NUL\NUL\NUL\NUL\NUL\NUL\tINI Files\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETX\DLE\f\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SI\NUL\NUL\NUL\NUL\NUL\NUL\NUL\bComments\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\f\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC1\f\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\f\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\vNormalValue\NUL\NUL\NUL\NUL\NUL\NUL\NUL\vNormalValue\NUL\NUL\NUL\NUL\NUL\NUL\NUL\tINI Files\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\b\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\fSpecialValue\NUL\NUL\NUL\NUL\NUL\NUL\NUL\fSpecialValue\NUL\NUL\NUL\NUL\NUL\NUL\NUL\tINI Files\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQ\t\EOT\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\b\STX\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\a\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\FS\t\n !%&()*+,-./:;<=>?[\\]^{|}~\SOH\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\CAN\NUL\NUL\NUL\NUL\NUL\NUL\NUL\adefault\NUL\NUL\NUL\NUL\NUL\NUL\NUL\bdefaults\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQe_all\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SIe_compile_error\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC1e_compile_warning\NUL\NUL\NUL\NUL\NUL\NUL\NUL\fe_core_error\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOe_core_warning\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ae_error\NUL\NUL\NUL\NUL\NUL\NUL\NUL\be_notice\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ae_parse\NUL\NUL\NUL\NUL\NUL\NUL\NUL\be_strict\NUL\NUL\NUL\NUL\NUL\NUL\NUL\fe_user_error\NUL\NUL\NUL\NUL\NUL\NUL\NUL\re_user_notice\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOe_user_warning\NUL\NUL\NUL\NUL\NUL\NUL\NUL\te_warning\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQfalse\NUL\NUL\NUL\NUL\NUL\NUL\NUL\tlocalhost\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STXno\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKnormal\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTnull\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETXoff\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STXon\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTtrue\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETXyes\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL-\STX\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DLE\b\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\b\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQValue\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQValue\NUL\NUL\NUL\NUL\NUL\NUL\NUL\tINI Files\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\ACK\NUL\NUL\NUL\NUL\NUL\NUL\NUL\255\\s*((-?(\\d+(\\.\\d*)?|\\.d+)(e\\d+)?|On|Off|Defaults?|Localhost|Null|True|False|Yes|No|Normal)\\s*$|~?(E_ALL|E_ERROR|E_WARNING|E_PARSE|E_NOTICE|E_STRICT|E_CORE_ERROR|E_CORE_WARNING|E_COMPILE_ERROR|E_COMPILE_WARNING|E_USER_ERROR|E_USER_WARNING|E_USER_NOTICE)\\b)\NUL\b\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STX\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\tINI Files\NUL\NUL\NUL\NUL\NUL\NUL\NUL\fSpecialValue\b\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STX\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\tINI Files\NUL\NUL\NUL\NUL\NUL\NUL\NUL\vNormalValue\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETXini\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETXini\NUL\NUL\NUL\NUL\NUL\NUL\NUL\tINI Files\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQ\ETX[]\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL=\DLE\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\tINI Files\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQValue\STX\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STX#;\f\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\tINI Files\NUL\NUL\NUL\NUL\NUL\NUL\NUL\aComment\DC1\SOH\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DLE\SOH\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\GSJan Janssen (medhefgo@web.de)\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STX12\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTLGPL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\a\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQ*.ini\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQ*.pls\NUL\NUL\NUL\NUL\NUL\NUL\NUL\a*.kcfgc\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SI.gitattributes*\NUL\NUL\NUL\NUL\NUL\NUL\NUL\v.gitconfig*\NUL\NUL\NUL\NUL\NUL\NUL\NUL\f.gitmodules*\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SO.editorconfig*\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETXini"
