{-# LANGUAGE OverloadedStrings #-}
-- | Automatically generated syntax definition for J.
-- DO NOT EDIT THIS FILE MANUALLY.
-- Instead, modify xml/j.xml and 'make bootstrap'.
module Skylighting.Syntax.J (syntax) where

import Skylighting.Types
import Data.Binary

-- | Syntax definition for J.
syntax :: Syntax
syntax = decode "\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOHJ\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQj.xml\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOHJ\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STX\NUL\NUL\NUL\NUL\NUL\NUL\NUL\fcomment line\NUL\NUL\NUL\NUL\NUL\NUL\NUL\fcomment line\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOHJ\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STX\DLE\f\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SI\NUL\NUL\NUL\NUL\NUL\NUL\NUL\bComments\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\f\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\f\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\bsentence\NUL\NUL\NUL\NUL\NUL\NUL\NUL\bsentence\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOHJ\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC1\DLE\RS\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACK\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DLE:\\s*0|\\bdefine\\b\SOH\EM\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SO\EM\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOT\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTNB.(\f\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOT\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTNB.)\f\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOT\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETXNB.\f\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOHJ\NUL\NUL\NUL\NUL\NUL\NUL\NUL\fcomment line\ACK\NUL\NUL\NUL\NUL\NUL\NUL\NUL\f'([^']|'')*'\SOH\b\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACK\NUL\NUL\NUL\NUL\NUL\NUL\NUL)([/\\\\]\\.|\\b[bfMt]\\.|\\bt:|[~/\\\\}])(?![.:])\SOH\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACK\NUL\NUL\NUL\NUL\NUL\NUL\NULl(_?\\d:|p\\.\\.|[ACeEIjLor]\\.|[_/\\\\iqsux]:|\\{::|[=!\\]]|[-<>+*%$|,#\\{][.:]?|[;\\[]:?|[~}\"ip][.:]|[?^]\\.?)(?![.:])\SOH\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACK\NUL\NUL\NUL\NUL\NUL\NUL\NUL\232\\b\\d+b_?[a-z\\d]+(\\.[a-z\\d]+)\\b|\\b_?\\d+x\\b|\\b_?\\d+r_?\\d+\\b|\\b(_?\\d+(\\.\\d+)?(e_?\\d+)?|_?_|_\\.)((j|a[dr])(_?\\d+(\\.\\d+)?(e_?\\d+)?|_?_|_\\.))?([px](_?\\d+(\\.\\d+)?(e_?\\d+)?|_?_|_\\.)((j|a[dr])(_?\\d+(\\.\\d+)?(e_?\\d+)?|_?_|_\\.))?)?(?![a-z\\d_.])\SOH\STX\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STX\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STX()\EM\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACK\NUL\NUL\NUL\NUL\NUL\NUL\NULA(\"|[@&][.:]?|[.:][.:]?|[!D][.:]|&\\.:|[;dHT]\\.|`:?|[LS^]:)(?![.:])\SOH\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACK\NUL\NUL\NUL\NUL\NUL\NUL\NUL\170\\b(assert|break|f?case|catch[dt]?|continue|do|else(if)?|end|for(_[a-zA-Z][a-zA-Z\\d_]*)?|(goto|label)_[a-zA-Z][a-zA-Z\\d_]*|if|return|select|throw|try|whil(e|st))\\.(?![.:])\SOH\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH=:\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH=.\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACK\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC4\\b[nmuvxy](?![\\w:.])\SOH\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACK\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SI\\ba[.:](?![.:])\SOH\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NULBIgor Zhuravlov (zhuravlov.ip@ya.ru), greg heil (gheil.j@gmail.com)\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH5\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETXGPL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOT\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQ*.ijs\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQ*.ijt\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQ*.IJS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQ*.IJT\NUL\NUL\NUL\NUL\NUL\NUL\NUL\bsentence"
