{-# LANGUAGE OverloadedStrings #-}
-- | Automatically generated syntax definition for SPDX-Comments.
-- DO NOT EDIT THIS FILE MANUALLY.
-- Instead, modify xml/spdx-comments.xml and 'make bootstrap'.
module Skylighting.Syntax.SpdxComments (syntax) where

import Skylighting.Types
import Data.Binary

-- | Syntax definition for SPDX-Comments.
syntax :: Syntax
syntax = decode "\NUL\NUL\NUL\NUL\NUL\NUL\NUL\rSPDX-Comments\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC1spdx-comments.xml\NUL\NUL\NUL\NUL\NUL\NUL\NUL\fSpdxComments\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACK\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NAKdeprecated-exceptions\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SYNNokia-Qt-exception-1.1\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC3deprecated-licenses\NUL\NUL\NUL\NUL\NUL\NUL\NUL\CAN\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\aGPL-1.0\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SUBGPL-2.0-with-GCC-exception\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\twxWindows\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQNunit\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\bGFDL-1.1\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\aGPL-2.0\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\bGFDL-1.2\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\bLGPL-2.0\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\USGPL-3.0-with-autoconf-exception\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\bGFDL-1.3\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC3BSD-2-Clause-NetBSD\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\bLGPL-3.0\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL GPL-2.0-with-classpath-exception\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SUBGPL-3.0-with-GCC-exception\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC4BSD-2-Clause-FreeBSD\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\aGPL-3.0\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ESCGPL-2.0-with-font-exception\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\beCos-2.0\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\FSGPL-2.0-with-bison-exception\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\USGPL-2.0-with-autoconf-exception\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\bAGPL-1.0\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\bAGPL-3.0\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\bLGPL-2.1\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\rStandardML-NJ\NUL\NUL\NUL\NUL\NUL\NUL\NUL\nexceptions\NUL\NUL\NUL\NUL\NUL\NUL\NUL(\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\nGPL-CC-1.0\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EMopenvpn-openssl-exception\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETBWxWindows-exception-3.1\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EMGPL-3.0-linking-exception\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SYNi2p-gpl-java-exception\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\RSOpenJDK-assembly-exception-1.0\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\rmif-exception\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC3CLISP-exception-2.0\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SYNfreertos-exception-2.0\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC3Bison-exception-2.2\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC2OCCT-exception-1.0\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SYNAutoconf-exception-2.0\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOLLVM-exception\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC1GCC-exception-3.1\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC2Font-exception-2.0\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC1Libtool-exception\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC4u-boot-exception-2.0\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SISwift-exception\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC2eCos-exception-2.0\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\FSOCaml-LGPL-linking-exception\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC4Qt-GPL-exception-1.0\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC2Linux-syscall-note\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC4Bootloader-exception\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL!PS-or-PDF-font-exception-20170817\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\FSUniversal-FOSS-exception-1.0\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETBClasspath-exception-2.0\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC1Qwt-exception-1.0\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOLZMA-exception\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SYNAutoconf-exception-3.0\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETBDigiRule-FOSS-exception\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\r389-exception\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\aSHL-2.0\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC1GCC-exception-2.0\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL GPL-3.0-linking-source-exception\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NAKQt-LGPL-exception-1.1\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\CANFawkes-Runtime-exception\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SYNgnu-javamail-exception\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOFLTK-exception\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SUBLGPL-3.0-linking-exception\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\aSHL-2.1\NUL\NUL\NUL\NUL\NUL\NUL\NUL\blicenses\NUL\NUL\NUL\NUL\NUL\NUL\SOH\188\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\vbzip2-1.0.6\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\nIntel-ACPI\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQXSkat\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SICC-BY-NC-SA-2.0\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKPlexus\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\bGiftware\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOBitTorrent-1.0\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\bAPSL-1.1\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\aUPL-1.0\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\aCaldera\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\bZend-2.0\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\vCUA-OPL-1.0\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQJPNIC\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKSAX-PD\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\fCC-BY-ND-2.5\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKeGenix\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKLGPLLR\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\vOLDAP-2.2.2\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SICC-BY-ND-3.0-DE\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETXIPA\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTNCSA\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETXW3C\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\nAdobe-2006\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\bNet-SNMP\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\fCC-BY-SA-4.0\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\aYPL-1.0\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKMITNFA\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\bPHP-3.01\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SIBSD-Source-Code\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\fCC-BY-SA-2.5\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\bMotosoto\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\aOSL-1.1\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTNGPL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\fCC-BY-2.5-AU\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\vUnicode-TOU\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\USBSD-3-Clause-No-Nuclear-License\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\tOPUBL-1.0\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC2CC-BY-NC-SA-2.0-UK\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\bNLOD-2.0\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\agnuplot\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQEPICS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\bInfo-ZIP\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\tOLDAP-2.0\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOCERN-OHL-P-2.0\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL BSD-3-Clause-No-Nuclear-Warranty\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETXAML\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\fMulanPSL-1.0\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\aMultics\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\aVSL-1.0\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKRSA-MD\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\aCC-PDDC\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SICC-BY-SA-2.1-JP\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\bLPPL-1.2\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\nSpencer-94\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\tOLDAP-1.2\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\tO-UDA-1.0\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\tOLDAP-2.7\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKGlulxe\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKiMatix\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\fTAPR-OHL-1.0\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\bNBPL-1.0\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\vLiLiQ-R-1.1\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQNoweb\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\aCC0-1.0\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOBSD-Protection\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\fCC-BY-NC-2.5\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTZlib\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\FSGFDL-1.3-invariants-or-later\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\fCC-BY-3.0-AT\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\tLPPL-1.3c\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\aEPL-1.0\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\FSGFDL-1.1-invariants-or-later\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC1ANTLR-PD-fallback\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\tOLDAP-2.4\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\tOLDAP-2.3\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\aZPL-2.1\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\nApache-2.0\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\tSGI-B-2.0\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SIHippocratic-2.1\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SICC-BY-SA-3.0-DE\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SICC-BY-NC-SA-1.0\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC1LGPL-2.1-or-later\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\fCC-BY-3.0-US\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\fTCP-wrappers\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\FSGFDL-1.2-invariants-or-later\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\aEurosym\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\bLPPL-1.0\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\tSGI-B-1.0\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\aAPL-1.0\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\alibtiff\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\aAFL-2.1\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\fCC-BY-NC-1.0\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STXGD\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\aAFL-1.1\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC3CC-BY-NC-ND-3.0-IGO\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DLEUnicode-DFS-2015\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\rGFDL-1.2-only\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\aMPL-1.1\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\fGPL-2.0-only\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\fCC-BY-NC-4.0\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\tFreeImage\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\bSHL-0.51\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\vCNRI-Jython\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\aZPL-1.1\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\bAfmparse\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\tOLDAP-2.1\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQRdisc\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKImlib2\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SYNBSD-4-Clause-Shortened\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\bSendmail\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\tCC-BY-2.5\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETXAAL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\GSMPL-2.0-no-copyleft-exception\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SICC-BY-NC-ND-2.5\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\fCC-BY-3.0-NL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\bLPL-1.02\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\aECL-1.0\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOOFL-1.0-no-RFN\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC2CC-BY-NC-SA-3.0-DE\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\fCC-BY-SA-3.0\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETXNTP\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\aMPL-2.0\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\bAPSL-1.2\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ESCGFDL-1.2-no-invariants-only\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\fArtistic-2.0\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQRSCPL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\tSleepycat\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETXxpp\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DLECDLA-Sharing-1.0\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\nClArtistic\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\rAGPL-1.0-only\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\fCC-BY-3.0-DE\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\aAFL-2.0\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQIntel\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\USGFDL-1.1-no-invariants-or-later\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKAPAFML\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQSISSL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKNaumen\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\bHTMLTIDY\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\tOLDAP-2.8\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\bblessing\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\fCC-BY-ND-2.0\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQOGTSL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC1LGPL-2.0-or-later\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\fParity-7.0.0\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\fCC-BY-ND-1.0\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\advipdfm\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\vCNRI-Python\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SIBSD-4-Clause-UC\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\bNLOD-1.0\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQMS-RL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SICC-BY-NC-SA-4.0\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\rHaskellReport\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\tCC-BY-1.0\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\aUCL-1.0\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETXMup\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQSMPPL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\aPHP-3.0\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQGL2PS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOCrystalStacker\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\fW3C-20150513\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DLENIST-PD-fallback\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\nOGL-UK-1.0\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\aCPL-1.0\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\rLGPL-2.1-only\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\aZPL-2.0\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\rFrameworx-1.0\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\rAGPL-3.0-only\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\aDRL-1.0\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\aEFL-2.0\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\nSpencer-99\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\USCAL-1.0-Combined-Work-Exception\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\CANGFDL-1.1-invariants-only\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETXTCL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\aSHL-0.5\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\vOFL-1.0-RFN\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOCERN-OHL-W-2.0\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQGlide\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKmpich2\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\apsutils\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\aSPL-1.0\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\nApache-1.1\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\fCC-BY-ND-4.0\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\vFreeBSD-DOC\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTSCEA\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\aLatex2e\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DLEArtistic-1.0-cl8\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\tSGI-B-1.1\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETXNRL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETXSWL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETXZed\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\fCERN-OHL-1.1\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\nRHeCos-1.1\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\nJasPer-2.0\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\bSSPL-1.0\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\tOLDAP-1.4\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\nlibpng-2.0\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SUBCNRI-Python-GPL-Compatible\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\aAladdin\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\nCECILL-1.0\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTRuby\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\aNPL-1.1\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\vImageMagick\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTCube\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\rGFDL-1.1-only\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\tCC-BY-2.0\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\aAFL-1.2\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\fCC-BY-SA-2.0\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\nCECILL-2.0\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SIMIT-advertising\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SICC-BY-NC-SA-2.5\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\fArtistic-1.0\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\aOSL-3.0\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETXX11\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKBahyph\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\vOLDAP-2.0.1\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\nEUDatagrid\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTMTLL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\CANGFDL-1.2-invariants-only\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\USGFDL-1.3-no-invariants-or-later\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTcurl\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\aLAL-1.3\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTDSDP\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\fCERN-OHL-1.2\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTTOSL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\tCC-BY-3.0\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQQhull\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ESCGFDL-1.3-no-invariants-only\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\nTORQUE-1.1\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQMS-PL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\nApache-1.0\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC3copyleft-next-0.3.1\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC1GFDL-1.2-or-later\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\fMulanPSL-2.0\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQFSFAP\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQXerox\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\bCDDL-1.0\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\CANGFDL-1.3-invariants-only\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\netalab-2.0\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\vXFree86-1.1\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTSNIA\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\bLPPL-1.1\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\nCATOSL-1.1\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\rTU-Berlin-2.0\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC1GFDL-1.3-or-later\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\aLAL-1.2\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETXICU\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETXFTL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQMirOS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SICC-BY-NC-ND-3.0\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\vOSET-PL-2.1\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SICC-BY-NC-ND-2.0\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\tSISSL-1.2\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKWsuipa\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\nZimbra-1.4\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\fLinux-OpenIB\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\tOLDAP-2.5\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQAMPAS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DLEGPL-1.0-or-later\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\bBUSL-1.1\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\vAdobe-Glyph\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOT0BSD\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\fW3C-19980720\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQFSFUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SICC-BY-NC-SA-3.0\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETXDOC\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQTMate\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOMIT-open-group\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\aAMDPLPA\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\nCondor-1.1\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\FSPolyForm-Noncommercial-1.0.0\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL BSD-3-Clause-No-Military-License\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\tCC-BY-4.0\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOOGL-Canada-2.0\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC3CC-BY-NC-SA-3.0-IGO\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\aEFL-1.0\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\bNewsletr\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC3copyleft-next-0.3.0\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DLEGPL-3.0-or-later\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC3CDLA-Permissive-2.0\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\fCC-BY-ND-3.0\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\tC-UDA-1.0\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTBarr\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETXVim\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOBitTorrent-1.1\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\aCDL-1.0\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\fCC-BY-SA-1.0\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTADSL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\nPostgreSQL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\aOFL-1.1\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\aNPL-1.0\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKxinetd\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\rLGPL-2.0-only\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC4zlib-acknowledgement\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\vOLDAP-2.2.1\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\bAPSL-1.0\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC1BSD-3-Clause-LBNL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKGLWTPL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\rLGPL-3.0-only\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\aOGC-1.0\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\aDotseqn\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\tMakeIndex\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\fGPL-3.0-only\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL$BSD-3-Clause-No-Nuclear-License-2014\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\fGPL-1.0-only\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETXIJG\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC1AGPL-1.0-or-later\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOOFL-1.1-no-RFN\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\aBSL-1.0\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKLibpng\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\fCC-BY-NC-3.0\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\fCC-BY-NC-2.0\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\tUnlicense\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\aLPL-1.0\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\vbzip2-1.0.5\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\aEntessa\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC3BSD-2-Clause-Patent\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\aECL-2.0\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\tCrossword\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SICC-BY-NC-ND-1.0\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\bOCLC-2.0\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\nCECILL-1.1\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\nCECILL-2.1\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SIOGDL-Taiwan-1.0\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\bAbstyles\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOlibselinux-1.0\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\bANTLR-PD\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DLEGPL-2.0-or-later\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\aIPL-1.0\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\bMIT-enna\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\tCPOL-1.02\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SICC-BY-SA-3.0-AT\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\fBSD-1-Clause\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQNTP-0\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOSugarCRM-1.1.3\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETXMIT\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\vOFL-1.1-RFN\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\nWatcom-1.0\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC2CC-BY-NC-SA-2.0-FR\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\bODbL-1.0\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\aFSFULLR\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\tOLDAP-1.3\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\vSSH-OpenSSH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\fBSD-2-Clause\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTHPND\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\nZimbra-1.3\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\aBorceux\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\tOLDAP-1.1\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\aOFL-1.0\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\bNASA-1.3\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\aVOSTROM\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQMIT-0\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETXISC\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DLEUnicode-DFS-2016\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\rBlueOak-1.0.0\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SILiLiQ-Rplus-1.1\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTNOSL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQSMLNJ\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\bCPAL-1.0\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\aPSF-2.0\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\aRPL-1.5\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC2MIT-Modern-Variant\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQNokia\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ESCGFDL-1.1-no-invariants-only\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\bPDDL-1.0\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\bEUPL-1.0\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\bCDDL-1.1\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\rGFDL-1.3-only\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\tOLDAP-2.6\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTJSON\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC1LGPL-3.0-or-later\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTFair\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\aOSL-2.1\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\tLPPL-1.3a\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\nNAIST-2003\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SICC-BY-NC-ND-4.0\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SICC-BY-NC-3.0-DE\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\aOPL-1.0\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC1HPND-sell-variant\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\aQPL-1.0\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\bEUPL-1.2\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\USGFDL-1.2-no-invariants-or-later\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\vNCGL-UK-2.0\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\bBeerware\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NAKBSD-3-Clause-Open-MPI\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\bCECILL-B\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\aEPL-2.0\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\aMIT-feh\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\aRPL-1.1\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC3CDLA-Permissive-1.0\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\nPython-2.0\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\aMPL-1.0\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC1GFDL-1.1-or-later\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\bdiffmark\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\aOpenSSL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\aOSL-1.0\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\fParity-6.0.0\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\aYPL-1.1\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\tSSH-short\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\bIBM-pibs\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTXnet\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\rTU-Berlin-1.0\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\aCAL-1.0\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\aAFL-3.0\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\bCECILL-C\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\nOGL-UK-3.0\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC2BSD-3-Clause-Clear\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EMBSD-3-Clause-Modification\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SICC-BY-SA-2.0-UK\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\aSaxpath\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTNLPL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\tSimPL-2.0\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKpsfrag\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\nSpencer-86\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\aOCCT-PL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOCERN-OHL-S-2.0\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\tErlPL-1.1\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\aMIT-CMU\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\aNIST-PD\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\aOSL-2.0\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\bAPSL-2.0\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\tLeptonica\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\GSPolyForm-Small-Business-1.0.0\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\vLiLiQ-P-1.1\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKNetCDF\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETXOML\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC1AGPL-3.0-or-later\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\tOLDAP-2.2\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\fBSD-3-Clause\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQWTFPL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\nOGL-UK-2.0\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\CANBSD-3-Clause-Attribution\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\bRPSL-1.0\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC2CC-BY-NC-ND-3.0-DE\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\bEUPL-1.1\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\rSendmail-8.23\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\nODC-By-1.0\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\tD-FSL-1.0\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\fBSD-4-Clause\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC2BSD-2-Clause-Views\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC1Artistic-1.0-Perl\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\tNPOSL-3.0\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ngSOAP-1.3b\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\rInterbase-1.0\NUL\NUL\NUL\NUL\NUL\NUL\NUL\toperators\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETX\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETXAND\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STXOR\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTWITH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTtags\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOT\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\CANSPDX-License-Identifier:\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NAKSPDX-FileContributor:\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETBSPDX-FileCopyrightText:\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETBSPDX-LicenseInfoInFile:\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STX\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKNormal\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKNormal\NUL\NUL\NUL\NUL\NUL\NUL\NUL\rSPDX-Comments\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STX\ENQ\NUL\NUL\NUL\NUL\NUL\NUL\NUL\CANSPDX-License-Identifier:\SO\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\rSPDX-Comments\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC2license-expression\a\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EM\t\n !%&()*+,/;<=>?[\\]^{|}~\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOT\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NAKSPDX-FileContributor:\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETBSPDX-FileCopyrightText:\NUL\NUL\NUL\NUL\NUL\NUL\NUL\CANSPDX-License-Identifier:\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETBSPDX-LicenseInfoInFile:\SO\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SO\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC2license-expression\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC2license-expression\NUL\NUL\NUL\NUL\NUL\NUL\NUL\rSPDX-Comments\NUL\NUL\NUL\NUL\NUL\NUL\NUL\b\DLE\SO\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STX\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETX()+\DC4\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\a\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EM\t\n !%&()*+,/;<=>?[\\]^{|}~\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\188\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOT0BSD\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETXAAL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTADSL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\aAFL-1.1\NUL\NUL\NUL\NUL\NUL\NUL\NUL\aAFL-1.2\NUL\NUL\NUL\NUL\NUL\NUL\NUL\aAFL-2.0\NUL\NUL\NUL\NUL\NUL\NUL\NUL\aAFL-2.1\NUL\NUL\NUL\NUL\NUL\NUL\NUL\aAFL-3.0\NUL\NUL\NUL\NUL\NUL\NUL\NUL\rAGPL-1.0-only\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC1AGPL-1.0-or-later\NUL\NUL\NUL\NUL\NUL\NUL\NUL\rAGPL-3.0-only\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC1AGPL-3.0-or-later\NUL\NUL\NUL\NUL\NUL\NUL\NUL\aAMDPLPA\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETXAML\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQAMPAS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\bANTLR-PD\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC1ANTLR-PD-fallback\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKAPAFML\NUL\NUL\NUL\NUL\NUL\NUL\NUL\aAPL-1.0\NUL\NUL\NUL\NUL\NUL\NUL\NUL\bAPSL-1.0\NUL\NUL\NUL\NUL\NUL\NUL\NUL\bAPSL-1.1\NUL\NUL\NUL\NUL\NUL\NUL\NUL\bAPSL-1.2\NUL\NUL\NUL\NUL\NUL\NUL\NUL\bAPSL-2.0\NUL\NUL\NUL\NUL\NUL\NUL\NUL\bAbstyles\NUL\NUL\NUL\NUL\NUL\NUL\NUL\nAdobe-2006\NUL\NUL\NUL\NUL\NUL\NUL\NUL\vAdobe-Glyph\NUL\NUL\NUL\NUL\NUL\NUL\NUL\bAfmparse\NUL\NUL\NUL\NUL\NUL\NUL\NUL\aAladdin\NUL\NUL\NUL\NUL\NUL\NUL\NUL\nApache-1.0\NUL\NUL\NUL\NUL\NUL\NUL\NUL\nApache-1.1\NUL\NUL\NUL\NUL\NUL\NUL\NUL\nApache-2.0\NUL\NUL\NUL\NUL\NUL\NUL\NUL\fArtistic-1.0\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC1Artistic-1.0-Perl\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DLEArtistic-1.0-cl8\NUL\NUL\NUL\NUL\NUL\NUL\NUL\fArtistic-2.0\NUL\NUL\NUL\NUL\NUL\NUL\NUL\fBSD-1-Clause\NUL\NUL\NUL\NUL\NUL\NUL\NUL\fBSD-2-Clause\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC3BSD-2-Clause-Patent\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC2BSD-2-Clause-Views\NUL\NUL\NUL\NUL\NUL\NUL\NUL\fBSD-3-Clause\NUL\NUL\NUL\NUL\NUL\NUL\NUL\CANBSD-3-Clause-Attribution\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC2BSD-3-Clause-Clear\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC1BSD-3-Clause-LBNL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EMBSD-3-Clause-Modification\NUL\NUL\NUL\NUL\NUL\NUL\NUL BSD-3-Clause-No-Military-License\NUL\NUL\NUL\NUL\NUL\NUL\NUL\USBSD-3-Clause-No-Nuclear-License\NUL\NUL\NUL\NUL\NUL\NUL\NUL$BSD-3-Clause-No-Nuclear-License-2014\NUL\NUL\NUL\NUL\NUL\NUL\NUL BSD-3-Clause-No-Nuclear-Warranty\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NAKBSD-3-Clause-Open-MPI\NUL\NUL\NUL\NUL\NUL\NUL\NUL\fBSD-4-Clause\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SYNBSD-4-Clause-Shortened\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SIBSD-4-Clause-UC\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOBSD-Protection\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SIBSD-Source-Code\NUL\NUL\NUL\NUL\NUL\NUL\NUL\aBSL-1.0\NUL\NUL\NUL\NUL\NUL\NUL\NUL\bBUSL-1.1\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKBahyph\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTBarr\NUL\NUL\NUL\NUL\NUL\NUL\NUL\bBeerware\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOBitTorrent-1.0\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOBitTorrent-1.1\NUL\NUL\NUL\NUL\NUL\NUL\NUL\rBlueOak-1.0.0\NUL\NUL\NUL\NUL\NUL\NUL\NUL\aBorceux\NUL\NUL\NUL\NUL\NUL\NUL\NUL\tC-UDA-1.0\NUL\NUL\NUL\NUL\NUL\NUL\NUL\aCAL-1.0\NUL\NUL\NUL\NUL\NUL\NUL\NUL\USCAL-1.0-Combined-Work-Exception\NUL\NUL\NUL\NUL\NUL\NUL\NUL\nCATOSL-1.1\NUL\NUL\NUL\NUL\NUL\NUL\NUL\tCC-BY-1.0\NUL\NUL\NUL\NUL\NUL\NUL\NUL\tCC-BY-2.0\NUL\NUL\NUL\NUL\NUL\NUL\NUL\tCC-BY-2.5\NUL\NUL\NUL\NUL\NUL\NUL\NUL\fCC-BY-2.5-AU\NUL\NUL\NUL\NUL\NUL\NUL\NUL\tCC-BY-3.0\NUL\NUL\NUL\NUL\NUL\NUL\NUL\fCC-BY-3.0-AT\NUL\NUL\NUL\NUL\NUL\NUL\NUL\fCC-BY-3.0-DE\NUL\NUL\NUL\NUL\NUL\NUL\NUL\fCC-BY-3.0-NL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\fCC-BY-3.0-US\NUL\NUL\NUL\NUL\NUL\NUL\NUL\tCC-BY-4.0\NUL\NUL\NUL\NUL\NUL\NUL\NUL\fCC-BY-NC-1.0\NUL\NUL\NUL\NUL\NUL\NUL\NUL\fCC-BY-NC-2.0\NUL\NUL\NUL\NUL\NUL\NUL\NUL\fCC-BY-NC-2.5\NUL\NUL\NUL\NUL\NUL\NUL\NUL\fCC-BY-NC-3.0\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SICC-BY-NC-3.0-DE\NUL\NUL\NUL\NUL\NUL\NUL\NUL\fCC-BY-NC-4.0\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SICC-BY-NC-ND-1.0\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SICC-BY-NC-ND-2.0\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SICC-BY-NC-ND-2.5\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SICC-BY-NC-ND-3.0\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC2CC-BY-NC-ND-3.0-DE\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC3CC-BY-NC-ND-3.0-IGO\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SICC-BY-NC-ND-4.0\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SICC-BY-NC-SA-1.0\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SICC-BY-NC-SA-2.0\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC2CC-BY-NC-SA-2.0-FR\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC2CC-BY-NC-SA-2.0-UK\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SICC-BY-NC-SA-2.5\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SICC-BY-NC-SA-3.0\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC2CC-BY-NC-SA-3.0-DE\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC3CC-BY-NC-SA-3.0-IGO\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SICC-BY-NC-SA-4.0\NUL\NUL\NUL\NUL\NUL\NUL\NUL\fCC-BY-ND-1.0\NUL\NUL\NUL\NUL\NUL\NUL\NUL\fCC-BY-ND-2.0\NUL\NUL\NUL\NUL\NUL\NUL\NUL\fCC-BY-ND-2.5\NUL\NUL\NUL\NUL\NUL\NUL\NUL\fCC-BY-ND-3.0\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SICC-BY-ND-3.0-DE\NUL\NUL\NUL\NUL\NUL\NUL\NUL\fCC-BY-ND-4.0\NUL\NUL\NUL\NUL\NUL\NUL\NUL\fCC-BY-SA-1.0\NUL\NUL\NUL\NUL\NUL\NUL\NUL\fCC-BY-SA-2.0\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SICC-BY-SA-2.0-UK\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SICC-BY-SA-2.1-JP\NUL\NUL\NUL\NUL\NUL\NUL\NUL\fCC-BY-SA-2.5\NUL\NUL\NUL\NUL\NUL\NUL\NUL\fCC-BY-SA-3.0\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SICC-BY-SA-3.0-AT\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SICC-BY-SA-3.0-DE\NUL\NUL\NUL\NUL\NUL\NUL\NUL\fCC-BY-SA-4.0\NUL\NUL\NUL\NUL\NUL\NUL\NUL\aCC-PDDC\NUL\NUL\NUL\NUL\NUL\NUL\NUL\aCC0-1.0\NUL\NUL\NUL\NUL\NUL\NUL\NUL\bCDDL-1.0\NUL\NUL\NUL\NUL\NUL\NUL\NUL\bCDDL-1.1\NUL\NUL\NUL\NUL\NUL\NUL\NUL\aCDL-1.0\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC3CDLA-Permissive-1.0\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC3CDLA-Permissive-2.0\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DLECDLA-Sharing-1.0\NUL\NUL\NUL\NUL\NUL\NUL\NUL\nCECILL-1.0\NUL\NUL\NUL\NUL\NUL\NUL\NUL\nCECILL-1.1\NUL\NUL\NUL\NUL\NUL\NUL\NUL\nCECILL-2.0\NUL\NUL\NUL\NUL\NUL\NUL\NUL\nCECILL-2.1\NUL\NUL\NUL\NUL\NUL\NUL\NUL\bCECILL-B\NUL\NUL\NUL\NUL\NUL\NUL\NUL\bCECILL-C\NUL\NUL\NUL\NUL\NUL\NUL\NUL\fCERN-OHL-1.1\NUL\NUL\NUL\NUL\NUL\NUL\NUL\fCERN-OHL-1.2\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOCERN-OHL-P-2.0\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOCERN-OHL-S-2.0\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOCERN-OHL-W-2.0\NUL\NUL\NUL\NUL\NUL\NUL\NUL\vCNRI-Jython\NUL\NUL\NUL\NUL\NUL\NUL\NUL\vCNRI-Python\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SUBCNRI-Python-GPL-Compatible\NUL\NUL\NUL\NUL\NUL\NUL\NUL\bCPAL-1.0\NUL\NUL\NUL\NUL\NUL\NUL\NUL\aCPL-1.0\NUL\NUL\NUL\NUL\NUL\NUL\NUL\tCPOL-1.02\NUL\NUL\NUL\NUL\NUL\NUL\NUL\vCUA-OPL-1.0\NUL\NUL\NUL\NUL\NUL\NUL\NUL\aCaldera\NUL\NUL\NUL\NUL\NUL\NUL\NUL\nClArtistic\NUL\NUL\NUL\NUL\NUL\NUL\NUL\nCondor-1.1\NUL\NUL\NUL\NUL\NUL\NUL\NUL\tCrossword\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOCrystalStacker\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTCube\NUL\NUL\NUL\NUL\NUL\NUL\NUL\tD-FSL-1.0\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETXDOC\NUL\NUL\NUL\NUL\NUL\NUL\NUL\aDRL-1.0\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTDSDP\NUL\NUL\NUL\NUL\NUL\NUL\NUL\aDotseqn\NUL\NUL\NUL\NUL\NUL\NUL\NUL\aECL-1.0\NUL\NUL\NUL\NUL\NUL\NUL\NUL\aECL-2.0\NUL\NUL\NUL\NUL\NUL\NUL\NUL\aEFL-1.0\NUL\NUL\NUL\NUL\NUL\NUL\NUL\aEFL-2.0\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQEPICS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\aEPL-1.0\NUL\NUL\NUL\NUL\NUL\NUL\NUL\aEPL-2.0\NUL\NUL\NUL\NUL\NUL\NUL\NUL\nEUDatagrid\NUL\NUL\NUL\NUL\NUL\NUL\NUL\bEUPL-1.0\NUL\NUL\NUL\NUL\NUL\NUL\NUL\bEUPL-1.1\NUL\NUL\NUL\NUL\NUL\NUL\NUL\bEUPL-1.2\NUL\NUL\NUL\NUL\NUL\NUL\NUL\aEntessa\NUL\NUL\NUL\NUL\NUL\NUL\NUL\tErlPL-1.1\NUL\NUL\NUL\NUL\NUL\NUL\NUL\aEurosym\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQFSFAP\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQFSFUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\aFSFULLR\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETXFTL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTFair\NUL\NUL\NUL\NUL\NUL\NUL\NUL\rFrameworx-1.0\NUL\NUL\NUL\NUL\NUL\NUL\NUL\vFreeBSD-DOC\NUL\NUL\NUL\NUL\NUL\NUL\NUL\tFreeImage\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STXGD\NUL\NUL\NUL\NUL\NUL\NUL\NUL\CANGFDL-1.1-invariants-only\NUL\NUL\NUL\NUL\NUL\NUL\NUL\FSGFDL-1.1-invariants-or-later\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ESCGFDL-1.1-no-invariants-only\NUL\NUL\NUL\NUL\NUL\NUL\NUL\USGFDL-1.1-no-invariants-or-later\NUL\NUL\NUL\NUL\NUL\NUL\NUL\rGFDL-1.1-only\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC1GFDL-1.1-or-later\NUL\NUL\NUL\NUL\NUL\NUL\NUL\CANGFDL-1.2-invariants-only\NUL\NUL\NUL\NUL\NUL\NUL\NUL\FSGFDL-1.2-invariants-or-later\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ESCGFDL-1.2-no-invariants-only\NUL\NUL\NUL\NUL\NUL\NUL\NUL\USGFDL-1.2-no-invariants-or-later\NUL\NUL\NUL\NUL\NUL\NUL\NUL\rGFDL-1.2-only\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC1GFDL-1.2-or-later\NUL\NUL\NUL\NUL\NUL\NUL\NUL\CANGFDL-1.3-invariants-only\NUL\NUL\NUL\NUL\NUL\NUL\NUL\FSGFDL-1.3-invariants-or-later\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ESCGFDL-1.3-no-invariants-only\NUL\NUL\NUL\NUL\NUL\NUL\NUL\USGFDL-1.3-no-invariants-or-later\NUL\NUL\NUL\NUL\NUL\NUL\NUL\rGFDL-1.3-only\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC1GFDL-1.3-or-later\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQGL2PS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKGLWTPL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\fGPL-1.0-only\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DLEGPL-1.0-or-later\NUL\NUL\NUL\NUL\NUL\NUL\NUL\fGPL-2.0-only\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DLEGPL-2.0-or-later\NUL\NUL\NUL\NUL\NUL\NUL\NUL\fGPL-3.0-only\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DLEGPL-3.0-or-later\NUL\NUL\NUL\NUL\NUL\NUL\NUL\bGiftware\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQGlide\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKGlulxe\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTHPND\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC1HPND-sell-variant\NUL\NUL\NUL\NUL\NUL\NUL\NUL\bHTMLTIDY\NUL\NUL\NUL\NUL\NUL\NUL\NUL\rHaskellReport\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SIHippocratic-2.1\NUL\NUL\NUL\NUL\NUL\NUL\NUL\bIBM-pibs\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETXICU\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETXIJG\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETXIPA\NUL\NUL\NUL\NUL\NUL\NUL\NUL\aIPL-1.0\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETXISC\NUL\NUL\NUL\NUL\NUL\NUL\NUL\vImageMagick\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKImlib2\NUL\NUL\NUL\NUL\NUL\NUL\NUL\bInfo-ZIP\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQIntel\NUL\NUL\NUL\NUL\NUL\NUL\NUL\nIntel-ACPI\NUL\NUL\NUL\NUL\NUL\NUL\NUL\rInterbase-1.0\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQJPNIC\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTJSON\NUL\NUL\NUL\NUL\NUL\NUL\NUL\nJasPer-2.0\NUL\NUL\NUL\NUL\NUL\NUL\NUL\aLAL-1.2\NUL\NUL\NUL\NUL\NUL\NUL\NUL\aLAL-1.3\NUL\NUL\NUL\NUL\NUL\NUL\NUL\rLGPL-2.0-only\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC1LGPL-2.0-or-later\NUL\NUL\NUL\NUL\NUL\NUL\NUL\rLGPL-2.1-only\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC1LGPL-2.1-or-later\NUL\NUL\NUL\NUL\NUL\NUL\NUL\rLGPL-3.0-only\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC1LGPL-3.0-or-later\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKLGPLLR\NUL\NUL\NUL\NUL\NUL\NUL\NUL\aLPL-1.0\NUL\NUL\NUL\NUL\NUL\NUL\NUL\bLPL-1.02\NUL\NUL\NUL\NUL\NUL\NUL\NUL\bLPPL-1.0\NUL\NUL\NUL\NUL\NUL\NUL\NUL\bLPPL-1.1\NUL\NUL\NUL\NUL\NUL\NUL\NUL\bLPPL-1.2\NUL\NUL\NUL\NUL\NUL\NUL\NUL\tLPPL-1.3a\NUL\NUL\NUL\NUL\NUL\NUL\NUL\tLPPL-1.3c\NUL\NUL\NUL\NUL\NUL\NUL\NUL\aLatex2e\NUL\NUL\NUL\NUL\NUL\NUL\NUL\tLeptonica\NUL\NUL\NUL\NUL\NUL\NUL\NUL\vLiLiQ-P-1.1\NUL\NUL\NUL\NUL\NUL\NUL\NUL\vLiLiQ-R-1.1\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SILiLiQ-Rplus-1.1\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKLibpng\NUL\NUL\NUL\NUL\NUL\NUL\NUL\fLinux-OpenIB\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETXMIT\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQMIT-0\NUL\NUL\NUL\NUL\NUL\NUL\NUL\aMIT-CMU\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC2MIT-Modern-Variant\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SIMIT-advertising\NUL\NUL\NUL\NUL\NUL\NUL\NUL\bMIT-enna\NUL\NUL\NUL\NUL\NUL\NUL\NUL\aMIT-feh\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOMIT-open-group\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKMITNFA\NUL\NUL\NUL\NUL\NUL\NUL\NUL\aMPL-1.0\NUL\NUL\NUL\NUL\NUL\NUL\NUL\aMPL-1.1\NUL\NUL\NUL\NUL\NUL\NUL\NUL\aMPL-2.0\NUL\NUL\NUL\NUL\NUL\NUL\NUL\GSMPL-2.0-no-copyleft-exception\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQMS-PL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQMS-RL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTMTLL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\tMakeIndex\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQMirOS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\bMotosoto\NUL\NUL\NUL\NUL\NUL\NUL\NUL\fMulanPSL-1.0\NUL\NUL\NUL\NUL\NUL\NUL\NUL\fMulanPSL-2.0\NUL\NUL\NUL\NUL\NUL\NUL\NUL\aMultics\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETXMup\NUL\NUL\NUL\NUL\NUL\NUL\NUL\nNAIST-2003\NUL\NUL\NUL\NUL\NUL\NUL\NUL\bNASA-1.3\NUL\NUL\NUL\NUL\NUL\NUL\NUL\bNBPL-1.0\NUL\NUL\NUL\NUL\NUL\NUL\NUL\vNCGL-UK-2.0\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTNCSA\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTNGPL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\aNIST-PD\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DLENIST-PD-fallback\NUL\NUL\NUL\NUL\NUL\NUL\NUL\bNLOD-1.0\NUL\NUL\NUL\NUL\NUL\NUL\NUL\bNLOD-2.0\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTNLPL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTNOSL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\aNPL-1.0\NUL\NUL\NUL\NUL\NUL\NUL\NUL\aNPL-1.1\NUL\NUL\NUL\NUL\NUL\NUL\NUL\tNPOSL-3.0\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETXNRL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETXNTP\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQNTP-0\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKNaumen\NUL\NUL\NUL\NUL\NUL\NUL\NUL\bNet-SNMP\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKNetCDF\NUL\NUL\NUL\NUL\NUL\NUL\NUL\bNewsletr\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQNokia\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQNoweb\NUL\NUL\NUL\NUL\NUL\NUL\NUL\tO-UDA-1.0\NUL\NUL\NUL\NUL\NUL\NUL\NUL\aOCCT-PL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\bOCLC-2.0\NUL\NUL\NUL\NUL\NUL\NUL\NUL\nODC-By-1.0\NUL\NUL\NUL\NUL\NUL\NUL\NUL\bODbL-1.0\NUL\NUL\NUL\NUL\NUL\NUL\NUL\aOFL-1.0\NUL\NUL\NUL\NUL\NUL\NUL\NUL\vOFL-1.0-RFN\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOOFL-1.0-no-RFN\NUL\NUL\NUL\NUL\NUL\NUL\NUL\aOFL-1.1\NUL\NUL\NUL\NUL\NUL\NUL\NUL\vOFL-1.1-RFN\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOOFL-1.1-no-RFN\NUL\NUL\NUL\NUL\NUL\NUL\NUL\aOGC-1.0\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SIOGDL-Taiwan-1.0\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOOGL-Canada-2.0\NUL\NUL\NUL\NUL\NUL\NUL\NUL\nOGL-UK-1.0\NUL\NUL\NUL\NUL\NUL\NUL\NUL\nOGL-UK-2.0\NUL\NUL\NUL\NUL\NUL\NUL\NUL\nOGL-UK-3.0\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQOGTSL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\tOLDAP-1.1\NUL\NUL\NUL\NUL\NUL\NUL\NUL\tOLDAP-1.2\NUL\NUL\NUL\NUL\NUL\NUL\NUL\tOLDAP-1.3\NUL\NUL\NUL\NUL\NUL\NUL\NUL\tOLDAP-1.4\NUL\NUL\NUL\NUL\NUL\NUL\NUL\tOLDAP-2.0\NUL\NUL\NUL\NUL\NUL\NUL\NUL\vOLDAP-2.0.1\NUL\NUL\NUL\NUL\NUL\NUL\NUL\tOLDAP-2.1\NUL\NUL\NUL\NUL\NUL\NUL\NUL\tOLDAP-2.2\NUL\NUL\NUL\NUL\NUL\NUL\NUL\vOLDAP-2.2.1\NUL\NUL\NUL\NUL\NUL\NUL\NUL\vOLDAP-2.2.2\NUL\NUL\NUL\NUL\NUL\NUL\NUL\tOLDAP-2.3\NUL\NUL\NUL\NUL\NUL\NUL\NUL\tOLDAP-2.4\NUL\NUL\NUL\NUL\NUL\NUL\NUL\tOLDAP-2.5\NUL\NUL\NUL\NUL\NUL\NUL\NUL\tOLDAP-2.6\NUL\NUL\NUL\NUL\NUL\NUL\NUL\tOLDAP-2.7\NUL\NUL\NUL\NUL\NUL\NUL\NUL\tOLDAP-2.8\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETXOML\NUL\NUL\NUL\NUL\NUL\NUL\NUL\aOPL-1.0\NUL\NUL\NUL\NUL\NUL\NUL\NUL\tOPUBL-1.0\NUL\NUL\NUL\NUL\NUL\NUL\NUL\vOSET-PL-2.1\NUL\NUL\NUL\NUL\NUL\NUL\NUL\aOSL-1.0\NUL\NUL\NUL\NUL\NUL\NUL\NUL\aOSL-1.1\NUL\NUL\NUL\NUL\NUL\NUL\NUL\aOSL-2.0\NUL\NUL\NUL\NUL\NUL\NUL\NUL\aOSL-2.1\NUL\NUL\NUL\NUL\NUL\NUL\NUL\aOSL-3.0\NUL\NUL\NUL\NUL\NUL\NUL\NUL\aOpenSSL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\bPDDL-1.0\NUL\NUL\NUL\NUL\NUL\NUL\NUL\aPHP-3.0\NUL\NUL\NUL\NUL\NUL\NUL\NUL\bPHP-3.01\NUL\NUL\NUL\NUL\NUL\NUL\NUL\aPSF-2.0\NUL\NUL\NUL\NUL\NUL\NUL\NUL\fParity-6.0.0\NUL\NUL\NUL\NUL\NUL\NUL\NUL\fParity-7.0.0\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKPlexus\NUL\NUL\NUL\NUL\NUL\NUL\NUL\FSPolyForm-Noncommercial-1.0.0\NUL\NUL\NUL\NUL\NUL\NUL\NUL\GSPolyForm-Small-Business-1.0.0\NUL\NUL\NUL\NUL\NUL\NUL\NUL\nPostgreSQL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\nPython-2.0\NUL\NUL\NUL\NUL\NUL\NUL\NUL\aQPL-1.0\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQQhull\NUL\NUL\NUL\NUL\NUL\NUL\NUL\nRHeCos-1.1\NUL\NUL\NUL\NUL\NUL\NUL\NUL\aRPL-1.1\NUL\NUL\NUL\NUL\NUL\NUL\NUL\aRPL-1.5\NUL\NUL\NUL\NUL\NUL\NUL\NUL\bRPSL-1.0\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKRSA-MD\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQRSCPL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQRdisc\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTRuby\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKSAX-PD\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTSCEA\NUL\NUL\NUL\NUL\NUL\NUL\NUL\tSGI-B-1.0\NUL\NUL\NUL\NUL\NUL\NUL\NUL\tSGI-B-1.1\NUL\NUL\NUL\NUL\NUL\NUL\NUL\tSGI-B-2.0\NUL\NUL\NUL\NUL\NUL\NUL\NUL\aSHL-0.5\NUL\NUL\NUL\NUL\NUL\NUL\NUL\bSHL-0.51\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQSISSL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\tSISSL-1.2\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQSMLNJ\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQSMPPL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTSNIA\NUL\NUL\NUL\NUL\NUL\NUL\NUL\aSPL-1.0\NUL\NUL\NUL\NUL\NUL\NUL\NUL\vSSH-OpenSSH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\tSSH-short\NUL\NUL\NUL\NUL\NUL\NUL\NUL\bSSPL-1.0\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETXSWL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\aSaxpath\NUL\NUL\NUL\NUL\NUL\NUL\NUL\bSendmail\NUL\NUL\NUL\NUL\NUL\NUL\NUL\rSendmail-8.23\NUL\NUL\NUL\NUL\NUL\NUL\NUL\tSimPL-2.0\NUL\NUL\NUL\NUL\NUL\NUL\NUL\tSleepycat\NUL\NUL\NUL\NUL\NUL\NUL\NUL\nSpencer-86\NUL\NUL\NUL\NUL\NUL\NUL\NUL\nSpencer-94\NUL\NUL\NUL\NUL\NUL\NUL\NUL\nSpencer-99\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOSugarCRM-1.1.3\NUL\NUL\NUL\NUL\NUL\NUL\NUL\fTAPR-OHL-1.0\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETXTCL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\fTCP-wrappers\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQTMate\NUL\NUL\NUL\NUL\NUL\NUL\NUL\nTORQUE-1.1\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTTOSL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\rTU-Berlin-1.0\NUL\NUL\NUL\NUL\NUL\NUL\NUL\rTU-Berlin-2.0\NUL\NUL\NUL\NUL\NUL\NUL\NUL\aUCL-1.0\NUL\NUL\NUL\NUL\NUL\NUL\NUL\aUPL-1.0\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DLEUnicode-DFS-2015\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DLEUnicode-DFS-2016\NUL\NUL\NUL\NUL\NUL\NUL\NUL\vUnicode-TOU\NUL\NUL\NUL\NUL\NUL\NUL\NUL\tUnlicense\NUL\NUL\NUL\NUL\NUL\NUL\NUL\aVOSTROM\NUL\NUL\NUL\NUL\NUL\NUL\NUL\aVSL-1.0\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETXVim\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETXW3C\NUL\NUL\NUL\NUL\NUL\NUL\NUL\fW3C-19980720\NUL\NUL\NUL\NUL\NUL\NUL\NUL\fW3C-20150513\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQWTFPL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\nWatcom-1.0\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKWsuipa\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETXX11\NUL\NUL\NUL\NUL\NUL\NUL\NUL\vXFree86-1.1\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQXSkat\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQXerox\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTXnet\NUL\NUL\NUL\NUL\NUL\NUL\NUL\aYPL-1.0\NUL\NUL\NUL\NUL\NUL\NUL\NUL\aYPL-1.1\NUL\NUL\NUL\NUL\NUL\NUL\NUL\aZPL-1.1\NUL\NUL\NUL\NUL\NUL\NUL\NUL\aZPL-2.0\NUL\NUL\NUL\NUL\NUL\NUL\NUL\aZPL-2.1\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETXZed\NUL\NUL\NUL\NUL\NUL\NUL\NUL\bZend-2.0\NUL\NUL\NUL\NUL\NUL\NUL\NUL\nZimbra-1.3\NUL\NUL\NUL\NUL\NUL\NUL\NUL\nZimbra-1.4\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTZlib\NUL\NUL\NUL\NUL\NUL\NUL\NUL\bblessing\NUL\NUL\NUL\NUL\NUL\NUL\NUL\vbzip2-1.0.5\NUL\NUL\NUL\NUL\NUL\NUL\NUL\vbzip2-1.0.6\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC3copyleft-next-0.3.0\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC3copyleft-next-0.3.1\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTcurl\NUL\NUL\NUL\NUL\NUL\NUL\NUL\bdiffmark\NUL\NUL\NUL\NUL\NUL\NUL\NUL\advipdfm\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKeGenix\NUL\NUL\NUL\NUL\NUL\NUL\NUL\netalab-2.0\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ngSOAP-1.3b\NUL\NUL\NUL\NUL\NUL\NUL\NUL\agnuplot\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKiMatix\NUL\NUL\NUL\NUL\NUL\NUL\NUL\nlibpng-2.0\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOlibselinux-1.0\NUL\NUL\NUL\NUL\NUL\NUL\NUL\alibtiff\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKmpich2\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKpsfrag\NUL\NUL\NUL\NUL\NUL\NUL\NUL\apsutils\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKxinetd\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETXxpp\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC4zlib-acknowledgement\SO\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\a\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EM\t\n !%&()*+,/;<=>?[\\]^{|}~\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\CAN\NUL\NUL\NUL\NUL\NUL\NUL\NUL\bAGPL-1.0\NUL\NUL\NUL\NUL\NUL\NUL\NUL\bAGPL-3.0\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC4BSD-2-Clause-FreeBSD\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC3BSD-2-Clause-NetBSD\NUL\NUL\NUL\NUL\NUL\NUL\NUL\bGFDL-1.1\NUL\NUL\NUL\NUL\NUL\NUL\NUL\bGFDL-1.2\NUL\NUL\NUL\NUL\NUL\NUL\NUL\bGFDL-1.3\NUL\NUL\NUL\NUL\NUL\NUL\NUL\aGPL-1.0\NUL\NUL\NUL\NUL\NUL\NUL\NUL\aGPL-2.0\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SUBGPL-2.0-with-GCC-exception\NUL\NUL\NUL\NUL\NUL\NUL\NUL\USGPL-2.0-with-autoconf-exception\NUL\NUL\NUL\NUL\NUL\NUL\NUL\FSGPL-2.0-with-bison-exception\NUL\NUL\NUL\NUL\NUL\NUL\NUL GPL-2.0-with-classpath-exception\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ESCGPL-2.0-with-font-exception\NUL\NUL\NUL\NUL\NUL\NUL\NUL\aGPL-3.0\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SUBGPL-3.0-with-GCC-exception\NUL\NUL\NUL\NUL\NUL\NUL\NUL\USGPL-3.0-with-autoconf-exception\NUL\NUL\NUL\NUL\NUL\NUL\NUL\bLGPL-2.0\NUL\NUL\NUL\NUL\NUL\NUL\NUL\bLGPL-2.1\NUL\NUL\NUL\NUL\NUL\NUL\NUL\bLGPL-3.0\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQNunit\NUL\NUL\NUL\NUL\NUL\NUL\NUL\rStandardML-NJ\NUL\NUL\NUL\NUL\NUL\NUL\NUL\beCos-2.0\NUL\NUL\NUL\NUL\NUL\NUL\NUL\twxWindows\SO\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\a\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EM\t\n !%&()*+,/;<=>?[\\]^{|}~\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL(\NUL\NUL\NUL\NUL\NUL\NUL\NUL\r389-exception\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SYNAutoconf-exception-2.0\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SYNAutoconf-exception-3.0\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC3Bison-exception-2.2\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC4Bootloader-exception\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC3CLISP-exception-2.0\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETBClasspath-exception-2.0\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETBDigiRule-FOSS-exception\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOFLTK-exception\NUL\NUL\NUL\NUL\NUL\NUL\NUL\CANFawkes-Runtime-exception\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC2Font-exception-2.0\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC1GCC-exception-2.0\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC1GCC-exception-3.1\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EMGPL-3.0-linking-exception\NUL\NUL\NUL\NUL\NUL\NUL\NUL GPL-3.0-linking-source-exception\NUL\NUL\NUL\NUL\NUL\NUL\NUL\nGPL-CC-1.0\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SUBLGPL-3.0-linking-exception\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOLLVM-exception\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOLZMA-exception\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC1Libtool-exception\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC2Linux-syscall-note\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC2OCCT-exception-1.0\NUL\NUL\NUL\NUL\NUL\NUL\NUL\FSOCaml-LGPL-linking-exception\NUL\NUL\NUL\NUL\NUL\NUL\NUL\RSOpenJDK-assembly-exception-1.0\NUL\NUL\NUL\NUL\NUL\NUL\NUL!PS-or-PDF-font-exception-20170817\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC4Qt-GPL-exception-1.0\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NAKQt-LGPL-exception-1.1\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC1Qwt-exception-1.0\NUL\NUL\NUL\NUL\NUL\NUL\NUL\aSHL-2.0\NUL\NUL\NUL\NUL\NUL\NUL\NUL\aSHL-2.1\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SISwift-exception\NUL\NUL\NUL\NUL\NUL\NUL\NUL\FSUniversal-FOSS-exception-1.0\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETBWxWindows-exception-3.1\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC2eCos-exception-2.0\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SYNfreertos-exception-2.0\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SYNgnu-javamail-exception\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SYNi2p-gpl-java-exception\NUL\NUL\NUL\NUL\NUL\NUL\NUL\rmif-exception\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EMopenvpn-openssl-exception\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC4u-boot-exception-2.0\SO\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\a\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EM\t\n !%&()*+,/;<=>?[\\]^{|}~\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SYNNokia-Qt-exception-1.1\SO\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\a\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EM\t\n !%&()*+,/;<=>?[\\]^{|}~\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETX\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETXAND\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STXOR\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTWITH\DC4\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACK\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC3\\bLicenseRef-[^\\s]+\SOH\SO\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SO\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\USAlex Turbov (i.zaufi@gmail.com)\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH6\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETXMIT\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKNormal"
