{-# LANGUAGE OverloadedStrings #-}
-- | Automatically generated syntax definition for Ada.
-- DO NOT EDIT THIS FILE MANUALLY.
-- Instead, modify xml/ada.xml and 'make bootstrap'.
module Skylighting.Syntax.Ada (syntax) where

import Skylighting.Types
import Data.Binary

-- | Syntax definition for Ada.
syntax :: Syntax
syntax = decode "\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETXAda\NUL\NUL\NUL\NUL\NUL\NUL\NUL\aada.xml\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETXAda\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETX\NUL\NUL\NUL\NUL\NUL\NUL\NUL\bkeywords\NUL\NUL\NUL\NUL\NUL\NUL\NULI\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQabort\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETXabs\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\babstract\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKaccept\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKaccess\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\aaliased\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETXall\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETXand\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQarray\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STXat\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQbegin\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTbody\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTcase\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\bconstant\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\adeclare\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQdelay\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQdelta\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKdigits\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STXdo\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTelse\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQelsif\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETXend\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQentry\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\texception\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTexit\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETXfor\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\bfunction\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ageneric\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTgoto\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STXif\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STXin\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\tinterface\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STXis\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\alimited\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTloop\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETXmod\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETXnew\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETXnot\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTnull\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STXof\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STXor\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKothers\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETXout\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\noverriding\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\apackage\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKpragma\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\aprivate\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\tprocedure\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\tprotected\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQraise\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQrange\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKrecord\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETXrem\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\arenames\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\arequeue\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKreturn\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\areverse\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKselect\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\bseparate\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTsome\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\asubtype\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\fsynchronized\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKtagged\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTtask\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\tterminate\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTthen\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTtype\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQuntil\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETXuse\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTwhen\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQwhile\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTwith\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETXxor\NUL\NUL\NUL\NUL\NUL\NUL\NUL\apragmas\NUL\NUL\NUL\NUL\NUL\NUL\NUL1\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DLEall_calls_remote\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKassert\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DLEassertion_policy\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\fasynchronous\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKatomic\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC1atomic_components\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOattach_handler\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ncontrolled\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\nconvention\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SIdetect_blocking\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\rdiscard_names\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\telaborate\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\relaborate_all\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOelaborate_body\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKexport\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKimport\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKinline\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DLEinspection_point\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC1interrupt_handler\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC2interrupt_priority\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOlinker_options\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTlist\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOlocking_policy\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\tno_return\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC1normalize_scalars\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\boptimize\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTpack\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTpage\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\FSpartition_elaboration_policy\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\FSpreelaborable_initialization\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\fpreelaborate\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\bpriority\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\GSpriority_specific_dispatching\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\aprofile\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTpure\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOqueuing_policy\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC1relative_deadline\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NAKremote_call_interface\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\fremote_types\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\frestrictions\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\nreviewable\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOshared_passive\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\fstorage_size\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\bsuppress\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETBtask_dispatching_policy\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SIunchecked_union\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\nunsuppress\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\bvolatile\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC3volatile_components\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQtypes\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SI\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\aboolean\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\tcharacter\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQfloat\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ainteger\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\nlong_float\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\flong_integer\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SIlong_long_float\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC1long_long_integer\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\vshort_float\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\rshort_integer\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKstring\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\vwide_string\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOwide_character\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC3wide_wide_character\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DLEwide_wide_string\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EM\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKBase10\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKBase10\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETXAda\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STX\ACK\NUL\NUL\NUL\NUL\NUL\NUL\NUL&[0-9]++(_?[0-9])*+\\.[0-9]++(_?[0-9])*+\SOH\EOT\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETXAda\NUL\NUL\NUL\NUL\NUL\NUL\NUL\aBaseExp\ACK\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC2[0-9]++(_?[0-9])*+\SOH\STX\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETXAda\NUL\NUL\NUL\NUL\NUL\NUL\NUL\aBaseExp\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STX\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKBase11\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKBase11\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETXAda\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STX\ACK\NUL\NUL\NUL\NUL\NUL\NUL\NUL2[0-9a-a]++(_?[0-9]a-a)*+\\.[0-9a-a]++(_?[0-9]a-a)*+\NUL\EOT\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETXAda\NUL\NUL\NUL\NUL\NUL\NUL\NUL\aBaseExp\ACK\NUL\NUL\NUL\NUL\NUL\NUL\NUL\CAN[0-9a-a]++(_?[0-9]a-a)*+\NUL\STX\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETXAda\NUL\NUL\NUL\NUL\NUL\NUL\NUL\aBaseExp\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STX\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKBase12\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKBase12\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETXAda\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STX\ACK\NUL\NUL\NUL\NUL\NUL\NUL\NUL2[0-9a-b]++(_?[0-9]a-b)*+\\.[0-9a-b]++(_?[0-9]a-b)*+\NUL\EOT\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETXAda\NUL\NUL\NUL\NUL\NUL\NUL\NUL\aBaseExp\ACK\NUL\NUL\NUL\NUL\NUL\NUL\NUL\CAN[0-9a-b]++(_?[0-9]a-b)*+\NUL\STX\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETXAda\NUL\NUL\NUL\NUL\NUL\NUL\NUL\aBaseExp\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STX\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKBase13\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKBase13\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETXAda\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STX\ACK\NUL\NUL\NUL\NUL\NUL\NUL\NUL2[0-9a-c]++(_?[0-9]a-c)*+\\.[0-9a-c]++(_?[0-9]a-c)*+\NUL\EOT\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETXAda\NUL\NUL\NUL\NUL\NUL\NUL\NUL\aBaseExp\ACK\NUL\NUL\NUL\NUL\NUL\NUL\NUL\CAN[0-9a-c]++(_?[0-9]a-c)*+\NUL\STX\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETXAda\NUL\NUL\NUL\NUL\NUL\NUL\NUL\aBaseExp\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STX\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKBase14\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKBase14\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETXAda\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STX\ACK\NUL\NUL\NUL\NUL\NUL\NUL\NUL2[0-9a-d]++(_?[0-9]a-d)*+\\.[0-9a-d]++(_?[0-9]a-d)*+\NUL\EOT\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETXAda\NUL\NUL\NUL\NUL\NUL\NUL\NUL\aBaseExp\ACK\NUL\NUL\NUL\NUL\NUL\NUL\NUL\CAN[0-9a-d]++(_?[0-9]a-d)*+\NUL\STX\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETXAda\NUL\NUL\NUL\NUL\NUL\NUL\NUL\aBaseExp\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STX\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKBase15\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKBase15\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETXAda\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STX\ACK\NUL\NUL\NUL\NUL\NUL\NUL\NUL2[0-9a-e]++(_?[0-9]a-e)*+\\.[0-9a-e]++(_?[0-9]a-e)*+\NUL\EOT\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETXAda\NUL\NUL\NUL\NUL\NUL\NUL\NUL\aBaseExp\ACK\NUL\NUL\NUL\NUL\NUL\NUL\NUL\CAN[0-9a-e]++(_?[0-9]a-e)*+\NUL\STX\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETXAda\NUL\NUL\NUL\NUL\NUL\NUL\NUL\aBaseExp\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STX\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKBase16\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKBase16\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETXAda\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STX\ACK\NUL\NUL\NUL\NUL\NUL\NUL\NUL2[0-9a-f]++(_?[0-9]a-f)*+\\.[0-9a-f]++(_?[0-9]a-f)*+\NUL\EOT\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETXAda\NUL\NUL\NUL\NUL\NUL\NUL\NUL\aBaseExp\ACK\NUL\NUL\NUL\NUL\NUL\NUL\NUL\CAN[0-9a-f]++(_?[0-9]a-f)*+\NUL\STX\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETXAda\NUL\NUL\NUL\NUL\NUL\NUL\NUL\aBaseExp\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STX\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQBase2\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQBase2\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETXAda\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STX\ACK\NUL\NUL\NUL\NUL\NUL\NUL\NUL&[0-1]++(_?[0-1])*+\\.[0-1]++(_?[0-1])*+\SOH\EOT\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETXAda\NUL\NUL\NUL\NUL\NUL\NUL\NUL\aBaseExp\ACK\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC2[0-1]++(_?[0-1])*+\SOH\STX\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETXAda\NUL\NUL\NUL\NUL\NUL\NUL\NUL\aBaseExp\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STX\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQBase3\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQBase3\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETXAda\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STX\ACK\NUL\NUL\NUL\NUL\NUL\NUL\NUL&[0-2]++(_?[0-2])*+\\.[0-2]++(_?[0-2])*+\SOH\EOT\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETXAda\NUL\NUL\NUL\NUL\NUL\NUL\NUL\aBaseExp\ACK\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC2[0-2]++(_?[0-2])*+\SOH\STX\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETXAda\NUL\NUL\NUL\NUL\NUL\NUL\NUL\aBaseExp\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STX\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQBase4\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQBase4\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETXAda\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STX\ACK\NUL\NUL\NUL\NUL\NUL\NUL\NUL&[0-3]++(_?[0-3])*+\\.[0-3]++(_?[0-3])*+\SOH\EOT\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETXAda\NUL\NUL\NUL\NUL\NUL\NUL\NUL\aBaseExp\ACK\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC2[0-3]++(_?[0-3])*+\SOH\STX\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETXAda\NUL\NUL\NUL\NUL\NUL\NUL\NUL\aBaseExp\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STX\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQBase5\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQBase5\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETXAda\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STX\ACK\NUL\NUL\NUL\NUL\NUL\NUL\NUL&[0-4]++(_?[0-4])*+\\.[0-4]++(_?[0-4])*+\SOH\EOT\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETXAda\NUL\NUL\NUL\NUL\NUL\NUL\NUL\aBaseExp\ACK\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC2[0-4]++(_?[0-4])*+\SOH\STX\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETXAda\NUL\NUL\NUL\NUL\NUL\NUL\NUL\aBaseExp\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STX\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQBase6\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQBase6\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETXAda\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STX\ACK\NUL\NUL\NUL\NUL\NUL\NUL\NUL&[0-5]++(_?[0-5])*+\\.[0-5]++(_?[0-5])*+\SOH\EOT\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETXAda\NUL\NUL\NUL\NUL\NUL\NUL\NUL\aBaseExp\ACK\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC2[0-5]++(_?[0-5])*+\SOH\STX\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETXAda\NUL\NUL\NUL\NUL\NUL\NUL\NUL\aBaseExp\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STX\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQBase7\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQBase7\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETXAda\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STX\ACK\NUL\NUL\NUL\NUL\NUL\NUL\NUL&[0-6]++(_?[0-6])*+\\.[0-6]++(_?[0-6])*+\SOH\EOT\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETXAda\NUL\NUL\NUL\NUL\NUL\NUL\NUL\aBaseExp\ACK\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC2[0-6]++(_?[0-6])*+\SOH\STX\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETXAda\NUL\NUL\NUL\NUL\NUL\NUL\NUL\aBaseExp\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STX\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQBase8\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQBase8\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETXAda\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STX\ACK\NUL\NUL\NUL\NUL\NUL\NUL\NUL&[0-7]++(_?[0-7])*+\\.[0-7]++(_?[0-7])*+\SOH\EOT\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETXAda\NUL\NUL\NUL\NUL\NUL\NUL\NUL\aBaseExp\ACK\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC2[0-7]++(_?[0-7])*+\SOH\STX\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETXAda\NUL\NUL\NUL\NUL\NUL\NUL\NUL\aBaseExp\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STX\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQBase9\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQBase9\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETXAda\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STX\ACK\NUL\NUL\NUL\NUL\NUL\NUL\NUL&[0-8]++(_?[0-8])*+\\.[0-8]++(_?[0-8])*+\SOH\EOT\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETXAda\NUL\NUL\NUL\NUL\NUL\NUL\NUL\aBaseExp\ACK\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC2[0-8]++(_?[0-8])*+\SOH\STX\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETXAda\NUL\NUL\NUL\NUL\NUL\NUL\NUL\aBaseExp\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STX\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\aBaseExp\NUL\NUL\NUL\NUL\NUL\NUL\NUL\aBaseExp\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETXAda\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL#\ETX\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETX\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETXAda\NUL\NUL\NUL\NUL\NUL\NUL\NUL\nNumericExp\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETX\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\aComment\NUL\NUL\NUL\NUL\NUL\NUL\NUL\aComment\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETXAda\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETX\DLE\f\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SI\NUL\NUL\NUL\NUL\NUL\NUL\NUL\bComments\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\f\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC1\f\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\f\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\aDefault\NUL\NUL\NUL\NUL\NUL\NUL\NUL\aDefault\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETXAda\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC4\DLE\RS\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOT\NUL\NUL\NUL\NUL\NUL\NUL\NUL\t--  BEGIN\EM\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETXAda\NUL\NUL\NUL\NUL\NUL\NUL\NUL\rRegion Marker\EOT\NUL\NUL\NUL\NUL\NUL\NUL\NUL\a--  END\EM\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETXAda\NUL\NUL\NUL\NUL\NUL\NUL\NUL\rRegion Marker\SOH--\f\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETXAda\NUL\NUL\NUL\NUL\NUL\NUL\NUL\aComment\STX\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DLE!%&()*+,-./:<=>|\DC4\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STX\NUL\NUL\NUL\NUL\NUL\NUL\NUL\n0123456789\RS\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETXAda\NUL\NUL\NUL\NUL\NUL\NUL\NUL\aNumeric\NUL\"\RS\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETXAda\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKString\ENQ\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKrecord\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQ\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTcase\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQ\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STXif\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQ\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTloop\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQ\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKselect\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQ\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQbegin\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQ\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETXend\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETXAda\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETXEnd\ENQ\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTnull\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETXAda\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTNull\a\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\FS\t\n !%&()*+,-./:;<=>?[\\]^{|}~\SOH\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NULI\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQabort\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETXabs\NUL\NUL\NUL\NUL\NUL\NUL\NUL\babstract\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKaccept\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKaccess\NUL\NUL\NUL\NUL\NUL\NUL\NUL\aaliased\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETXall\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETXand\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQarray\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STXat\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQbegin\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTbody\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTcase\NUL\NUL\NUL\NUL\NUL\NUL\NUL\bconstant\NUL\NUL\NUL\NUL\NUL\NUL\NUL\adeclare\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQdelay\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQdelta\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKdigits\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STXdo\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTelse\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQelsif\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETXend\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQentry\NUL\NUL\NUL\NUL\NUL\NUL\NUL\texception\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTexit\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETXfor\NUL\NUL\NUL\NUL\NUL\NUL\NUL\bfunction\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ageneric\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTgoto\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STXif\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STXin\NUL\NUL\NUL\NUL\NUL\NUL\NUL\tinterface\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STXis\NUL\NUL\NUL\NUL\NUL\NUL\NUL\alimited\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTloop\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETXmod\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETXnew\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETXnot\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTnull\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STXof\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STXor\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKothers\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETXout\NUL\NUL\NUL\NUL\NUL\NUL\NUL\noverriding\NUL\NUL\NUL\NUL\NUL\NUL\NUL\apackage\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKpragma\NUL\NUL\NUL\NUL\NUL\NUL\NUL\aprivate\NUL\NUL\NUL\NUL\NUL\NUL\NUL\tprocedure\NUL\NUL\NUL\NUL\NUL\NUL\NUL\tprotected\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQraise\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQrange\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKrecord\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETXrem\NUL\NUL\NUL\NUL\NUL\NUL\NUL\arenames\NUL\NUL\NUL\NUL\NUL\NUL\NUL\arequeue\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKreturn\NUL\NUL\NUL\NUL\NUL\NUL\NUL\areverse\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKselect\NUL\NUL\NUL\NUL\NUL\NUL\NUL\bseparate\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTsome\NUL\NUL\NUL\NUL\NUL\NUL\NUL\asubtype\NUL\NUL\NUL\NUL\NUL\NUL\NUL\fsynchronized\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKtagged\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTtask\NUL\NUL\NUL\NUL\NUL\NUL\NUL\tterminate\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTthen\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTtype\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQuntil\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETXuse\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTwhen\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQwhile\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTwith\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETXxor\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\a\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\FS\t\n !%&()*+,-./:;<=>?[\\]^{|}~\SOH\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL1\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DLEall_calls_remote\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKassert\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DLEassertion_policy\NUL\NUL\NUL\NUL\NUL\NUL\NUL\fasynchronous\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKatomic\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC1atomic_components\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOattach_handler\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ncontrolled\NUL\NUL\NUL\NUL\NUL\NUL\NUL\nconvention\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SIdetect_blocking\NUL\NUL\NUL\NUL\NUL\NUL\NUL\rdiscard_names\NUL\NUL\NUL\NUL\NUL\NUL\NUL\telaborate\NUL\NUL\NUL\NUL\NUL\NUL\NUL\relaborate_all\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOelaborate_body\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKexport\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKimport\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKinline\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DLEinspection_point\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC1interrupt_handler\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC2interrupt_priority\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOlinker_options\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTlist\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOlocking_policy\NUL\NUL\NUL\NUL\NUL\NUL\NUL\tno_return\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC1normalize_scalars\NUL\NUL\NUL\NUL\NUL\NUL\NUL\boptimize\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTpack\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTpage\NUL\NUL\NUL\NUL\NUL\NUL\NUL\FSpartition_elaboration_policy\NUL\NUL\NUL\NUL\NUL\NUL\NUL\FSpreelaborable_initialization\NUL\NUL\NUL\NUL\NUL\NUL\NUL\fpreelaborate\NUL\NUL\NUL\NUL\NUL\NUL\NUL\bpriority\NUL\NUL\NUL\NUL\NUL\NUL\NUL\GSpriority_specific_dispatching\NUL\NUL\NUL\NUL\NUL\NUL\NUL\aprofile\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTpure\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOqueuing_policy\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC1relative_deadline\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NAKremote_call_interface\NUL\NUL\NUL\NUL\NUL\NUL\NUL\fremote_types\NUL\NUL\NUL\NUL\NUL\NUL\NUL\frestrictions\NUL\NUL\NUL\NUL\NUL\NUL\NUL\nreviewable\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOshared_passive\NUL\NUL\NUL\NUL\NUL\NUL\NUL\fstorage_size\NUL\NUL\NUL\NUL\NUL\NUL\NUL\bsuppress\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETBtask_dispatching_policy\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SIunchecked_union\NUL\NUL\NUL\NUL\NUL\NUL\NUL\nunsuppress\NUL\NUL\NUL\NUL\NUL\NUL\NUL\bvolatile\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC3volatile_components\SYN\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\a\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\FS\t\n !%&()*+,-./:;<=>?[\\]^{|}~\SOH\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SI\NUL\NUL\NUL\NUL\NUL\NUL\NUL\aboolean\NUL\NUL\NUL\NUL\NUL\NUL\NUL\tcharacter\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQfloat\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ainteger\NUL\NUL\NUL\NUL\NUL\NUL\NUL\nlong_float\NUL\NUL\NUL\NUL\NUL\NUL\NUL\flong_integer\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SIlong_long_float\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC1long_long_integer\NUL\NUL\NUL\NUL\NUL\NUL\NUL\vshort_float\NUL\NUL\NUL\NUL\NUL\NUL\NUL\rshort_integer\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKstring\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOwide_character\NUL\NUL\NUL\NUL\NUL\NUL\NUL\vwide_string\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC3wide_wide_character\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DLEwide_wide_string\SOH\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC1\RS\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACK\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETX'.'\SOH\ACK\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETXEnd\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETXEnd\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETXAda\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACK\ACK\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOend\\s+record\\b\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\ACK\NUL\NUL\NUL\NUL\NUL\NUL\NUL\fend\\s+case\\b\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\ACK\NUL\NUL\NUL\NUL\NUL\NUL\NUL\nend\\s+if\\b\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\ACK\NUL\NUL\NUL\NUL\NUL\NUL\NUL\fend\\s+loop\\b\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\ACK\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOend\\s+select\\b\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\DC1\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTNull\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTNull\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETXAda\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STX\DLE\RS\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQ\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKrecord\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\aNumeric\NUL\NUL\NUL\NUL\NUL\NUL\NUL\aNumeric\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETXAda\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC1\ACK\NUL\NUL\NUL\NUL\NUL\NUL\NUL(\\b[0-9]++(_?[0-9])*+\\.[0-9]++(_?[0-9])*+\SOH\EOT\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETXAda\NUL\NUL\NUL\NUL\NUL\NUL\NUL\nNumericExp\ACK\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EM\\b[0-9]++(_?[0-9])*+(?!#)\SOH\STX\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETXAda\NUL\NUL\NUL\NUL\NUL\NUL\NUL\nNumericExp\ENQ\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STX2#\ETX\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETXAda\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQBase2\ENQ\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STX3#\ETX\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETXAda\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQBase3\ENQ\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STX4#\ETX\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETXAda\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQBase4\ENQ\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STX5#\ETX\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETXAda\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQBase5\ENQ\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STX6#\ETX\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETXAda\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQBase6\ENQ\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STX7#\ETX\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETXAda\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQBase7\ENQ\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STX8#\ETX\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETXAda\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQBase8\ENQ\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STX9#\ETX\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETXAda\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQBase9\ENQ\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETX10#\ETX\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETXAda\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKBase10\ENQ\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETX11#\ETX\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETXAda\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKBase11\ENQ\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETX12#\ETX\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETXAda\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKBase12\ENQ\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETX13#\ETX\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETXAda\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKBase13\ENQ\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETX14#\ETX\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETXAda\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKBase14\ENQ\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETX15#\ETX\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETXAda\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKBase15\ENQ\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETX16#\ETX\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETXAda\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKBase16\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\nNumericExp\NUL\NUL\NUL\NUL\NUL\NUL\NUL\nNumericExp\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETXAda\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\ACK\NUL\NUL\NUL\NUL\NUL\NUL\NUL\US(?:[eE][-+]?[0-9]++(_?[0-9])*+)\SOH\STX\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STX\NUL\NUL\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STX\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\rPartialString\NUL\NUL\NUL\NUL\NUL\NUL\NUL\rPartialString\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETXAda\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\b\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STX\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\rRegion Marker\NUL\NUL\NUL\NUL\NUL\NUL\NUL\rRegion Marker\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETXAda\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EM\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKString\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKString\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETXAda\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\ETX\"\"\b\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\b\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETXAda\NUL\NUL\NUL\NUL\NUL\NUL\NUL\rPartialString\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH7\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOT\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQ*.adb\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQ*.ads\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQ*.ada\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETX*.a\NUL\NUL\NUL\NUL\NUL\NUL\NUL\aDefault"
