{-# LANGUAGE OverloadedStrings #-}
-- | Automatically generated syntax definition for GNU M4.
-- DO NOT EDIT THIS FILE MANUALLY.
-- Instead, modify xml/m4.xml and 'make bootstrap'.
module Skylighting.Syntax.M4 (syntax) where

import Skylighting.Types
import Data.Binary

-- | Syntax definition for GNU M4.
syntax :: Syntax
syntax = decode "\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKGNU M4\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKm4.xml\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STXM4\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOT\NUL\NUL\NUL\NUL\NUL\NUL\NUL\bbuiltins\NUL\NUL\NUL\NUL\NUL\NUL\NUL-\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\b__file__\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\b__line__\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\v__program__\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\abuiltin\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\tchangecom\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\vchangequote\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\nchangeword\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\tdebugfile\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\tdebugmode\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTdecr\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKdefine\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTdefn\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKdivert\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKdivnum\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETXdnl\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\adumpdef\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\berrprint\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\aesyscmd\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTeval\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKformat\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQifdef\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKifelse\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ainclude\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTincr\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQindex\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQindir\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETXlen\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKm4exit\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKm4wrap\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\bmaketemp\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\amkstemp\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\bpatsubst\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKpopdef\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\apushdef\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKregexp\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQshift\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\bsinclude\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKsubstr\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKsyscmd\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKsysval\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\atraceon\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\btraceoff\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\btranslit\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\bundefine\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\bundivert\NUL\NUL\NUL\NUL\NUL\NUL\NUL\vm4_builtins\NUL\NUL\NUL\NUL\NUL\NUL\NUL-\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\vm4___file__\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\vm4___line__\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOm4___program__\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\nm4_builtin\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\fm4_changecom\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOm4_changequote\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\rm4_changeword\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\fm4_debugfile\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\fm4_debugmode\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\am4_decr\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\tm4_define\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\am4_defn\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\tm4_divert\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\tm4_divnum\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKm4_dnl\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\nm4_dumpdef\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\vm4_errprint\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\nm4_esyscmd\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\am4_eval\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\tm4_format\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\bm4_ifdef\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\tm4_ifelse\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\nm4_include\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\am4_incr\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\bm4_index\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\bm4_indir\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKm4_len\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\tm4_m4exit\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\tm4_m4wrap\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\vm4_maketemp\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\nm4_mkstemp\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\vm4_patsubst\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\tm4_popdef\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\nm4_pushdef\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\tm4_regexp\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\bm4_shift\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\vm4_sinclude\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\tm4_substr\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\tm4_syscmd\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\tm4_sysval\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\nm4_traceon\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\vm4_traceoff\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\vm4_translit\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\vm4_undefine\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\vm4_undivert\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOm4_optbuiltins\NUL\NUL\NUL\NUL\NUL\NUL\NUL\a\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\nm4___gnu__\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\nm4___os2__\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKm4_os2\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\vm4___unix__\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\am4_unix\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOm4___windows__\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\nm4_windows\NUL\NUL\NUL\NUL\NUL\NUL\NUL\voptbuiltins\NUL\NUL\NUL\NUL\NUL\NUL\NUL\a\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\a__gnu__\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\a__os2__\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETXos2\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\b__unix__\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTunix\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\v__windows__\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\awindows\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETX\NUL\NUL\NUL\NUL\NUL\NUL\NUL\aComment\NUL\NUL\NUL\NUL\NUL\NUL\NUL\aComment\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKGNU M4\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STX\DLE\f\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SI\NUL\NUL\NUL\NUL\NUL\NUL\NUL\bComments\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\f\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\f\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\vNormal Text\NUL\NUL\NUL\NUL\NUL\NUL\NUL\vNormal Text\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKGNU M4\NUL\NUL\NUL\NUL\NUL\NUL\NUL\f\a\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\FS\t\n !%&()*+,-./:;<=>?[\\]^{|}~\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL-\NUL\NUL\NUL\NUL\NUL\NUL\NUL\b__file__\NUL\NUL\NUL\NUL\NUL\NUL\NUL\b__line__\NUL\NUL\NUL\NUL\NUL\NUL\NUL\v__program__\NUL\NUL\NUL\NUL\NUL\NUL\NUL\abuiltin\NUL\NUL\NUL\NUL\NUL\NUL\NUL\tchangecom\NUL\NUL\NUL\NUL\NUL\NUL\NUL\vchangequote\NUL\NUL\NUL\NUL\NUL\NUL\NUL\nchangeword\NUL\NUL\NUL\NUL\NUL\NUL\NUL\tdebugfile\NUL\NUL\NUL\NUL\NUL\NUL\NUL\tdebugmode\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTdecr\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKdefine\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTdefn\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKdivert\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKdivnum\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETXdnl\NUL\NUL\NUL\NUL\NUL\NUL\NUL\adumpdef\NUL\NUL\NUL\NUL\NUL\NUL\NUL\berrprint\NUL\NUL\NUL\NUL\NUL\NUL\NUL\aesyscmd\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTeval\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKformat\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQifdef\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKifelse\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ainclude\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTincr\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQindex\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQindir\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETXlen\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKm4exit\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKm4wrap\NUL\NUL\NUL\NUL\NUL\NUL\NUL\bmaketemp\NUL\NUL\NUL\NUL\NUL\NUL\NUL\amkstemp\NUL\NUL\NUL\NUL\NUL\NUL\NUL\bpatsubst\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKpopdef\NUL\NUL\NUL\NUL\NUL\NUL\NUL\apushdef\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKregexp\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQshift\NUL\NUL\NUL\NUL\NUL\NUL\NUL\bsinclude\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKsubstr\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKsyscmd\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKsysval\NUL\NUL\NUL\NUL\NUL\NUL\NUL\btraceoff\NUL\NUL\NUL\NUL\NUL\NUL\NUL\atraceon\NUL\NUL\NUL\NUL\NUL\NUL\NUL\btranslit\NUL\NUL\NUL\NUL\NUL\NUL\NUL\bundefine\NUL\NUL\NUL\NUL\NUL\NUL\NUL\bundivert\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\a\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\FS\t\n !%&()*+,-./:;<=>?[\\]^{|}~\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL-\NUL\NUL\NUL\NUL\NUL\NUL\NUL\vm4___file__\NUL\NUL\NUL\NUL\NUL\NUL\NUL\vm4___line__\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOm4___program__\NUL\NUL\NUL\NUL\NUL\NUL\NUL\nm4_builtin\NUL\NUL\NUL\NUL\NUL\NUL\NUL\fm4_changecom\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOm4_changequote\NUL\NUL\NUL\NUL\NUL\NUL\NUL\rm4_changeword\NUL\NUL\NUL\NUL\NUL\NUL\NUL\fm4_debugfile\NUL\NUL\NUL\NUL\NUL\NUL\NUL\fm4_debugmode\NUL\NUL\NUL\NUL\NUL\NUL\NUL\am4_decr\NUL\NUL\NUL\NUL\NUL\NUL\NUL\tm4_define\NUL\NUL\NUL\NUL\NUL\NUL\NUL\am4_defn\NUL\NUL\NUL\NUL\NUL\NUL\NUL\tm4_divert\NUL\NUL\NUL\NUL\NUL\NUL\NUL\tm4_divnum\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKm4_dnl\NUL\NUL\NUL\NUL\NUL\NUL\NUL\nm4_dumpdef\NUL\NUL\NUL\NUL\NUL\NUL\NUL\vm4_errprint\NUL\NUL\NUL\NUL\NUL\NUL\NUL\nm4_esyscmd\NUL\NUL\NUL\NUL\NUL\NUL\NUL\am4_eval\NUL\NUL\NUL\NUL\NUL\NUL\NUL\tm4_format\NUL\NUL\NUL\NUL\NUL\NUL\NUL\bm4_ifdef\NUL\NUL\NUL\NUL\NUL\NUL\NUL\tm4_ifelse\NUL\NUL\NUL\NUL\NUL\NUL\NUL\nm4_include\NUL\NUL\NUL\NUL\NUL\NUL\NUL\am4_incr\NUL\NUL\NUL\NUL\NUL\NUL\NUL\bm4_index\NUL\NUL\NUL\NUL\NUL\NUL\NUL\bm4_indir\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKm4_len\NUL\NUL\NUL\NUL\NUL\NUL\NUL\tm4_m4exit\NUL\NUL\NUL\NUL\NUL\NUL\NUL\tm4_m4wrap\NUL\NUL\NUL\NUL\NUL\NUL\NUL\vm4_maketemp\NUL\NUL\NUL\NUL\NUL\NUL\NUL\nm4_mkstemp\NUL\NUL\NUL\NUL\NUL\NUL\NUL\vm4_patsubst\NUL\NUL\NUL\NUL\NUL\NUL\NUL\tm4_popdef\NUL\NUL\NUL\NUL\NUL\NUL\NUL\nm4_pushdef\NUL\NUL\NUL\NUL\NUL\NUL\NUL\tm4_regexp\NUL\NUL\NUL\NUL\NUL\NUL\NUL\bm4_shift\NUL\NUL\NUL\NUL\NUL\NUL\NUL\vm4_sinclude\NUL\NUL\NUL\NUL\NUL\NUL\NUL\tm4_substr\NUL\NUL\NUL\NUL\NUL\NUL\NUL\tm4_syscmd\NUL\NUL\NUL\NUL\NUL\NUL\NUL\tm4_sysval\NUL\NUL\NUL\NUL\NUL\NUL\NUL\vm4_traceoff\NUL\NUL\NUL\NUL\NUL\NUL\NUL\nm4_traceon\NUL\NUL\NUL\NUL\NUL\NUL\NUL\vm4_translit\NUL\NUL\NUL\NUL\NUL\NUL\NUL\vm4_undefine\NUL\NUL\NUL\NUL\NUL\NUL\NUL\vm4_undivert\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\a\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\FS\t\n !%&()*+,-./:;<=>?[\\]^{|}~\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\a\NUL\NUL\NUL\NUL\NUL\NUL\NUL\a__gnu__\NUL\NUL\NUL\NUL\NUL\NUL\NUL\a__os2__\NUL\NUL\NUL\NUL\NUL\NUL\NUL\b__unix__\NUL\NUL\NUL\NUL\NUL\NUL\NUL\v__windows__\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETXos2\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTunix\NUL\NUL\NUL\NUL\NUL\NUL\NUL\awindows\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\a\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\FS\t\n !%&()*+,-./:;<=>?[\\]^{|}~\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\a\NUL\NUL\NUL\NUL\NUL\NUL\NUL\nm4___gnu__\NUL\NUL\NUL\NUL\NUL\NUL\NUL\nm4___os2__\NUL\NUL\NUL\NUL\NUL\NUL\NUL\vm4___unix__\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOm4___windows__\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKm4_os2\NUL\NUL\NUL\NUL\NUL\NUL\NUL\am4_unix\NUL\NUL\NUL\NUL\NUL\NUL\NUL\nm4_windows\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACK\NUL\NUL\NUL\NUL\NUL\NUL\NUL\f[a-zA-Z_]\\w+\SOH\RS\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACK\NUL\NUL\NUL\NUL\NUL\NUL\NUL(\\$([1-9]\\d*|0|\\#|\\*|\\@|\\{([1-9]\\d*|0)\\})\SOH\ACK\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACK\NUL\NUL\NUL\NUL\NUL\NUL\NUL!([1-9]\\d*|0|0x[0-9abcdefABCDEF]+)\SOH\STX\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL#\f\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKGNU M4\NUL\NUL\NUL\NUL\NUL\NUL\NUL\aComment\NUL,\ACK\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL(\ACK\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKGNU M4\NUL\NUL\NUL\NUL\NUL\NUL\NUL\rinparenthesis\NUL)\ACK\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\STX\NUL\NUL\NUL\NUL\NUL\NUL\NUL\r!%&*+-/<=>^|~\ACK\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\rinparenthesis\NUL\NUL\NUL\NUL\NUL\NUL\NUL\rinparenthesis\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKGNU M4\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\SI\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKGNU M4\NUL\NUL\NUL\NUL\NUL\NUL\NUL\vNormal Text\RS\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\rJaak Ristioja\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH5\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SINew BSD License\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOT*.m4\NUL\NUL\NUL\NUL\NUL\NUL\NUL\vNormal Text"
