{-# LANGUAGE OverloadedStrings #-}
-- | Automatically generated syntax definition for Haskell.
-- DO NOT EDIT THIS FILE MANUALLY.
-- Instead, modify xml/haskell.xml and 'make bootstrap'.
module Skylighting.Syntax.Haskell (syntax) where

import Skylighting.Types
import Data.Binary

-- | Syntax definition for Haskell.
syntax :: Syntax
syntax = decode "\NUL\NUL\NUL\NUL\NUL\NUL\NUL\aHaskell\NUL\NUL\NUL\NUL\NUL\NUL\NUL\vhaskell.xml\NUL\NUL\NUL\NUL\NUL\NUL\NUL\aHaskell\NUL\NUL\NUL\NUL\NUL\NUL\NUL\t\NUL\NUL\NUL\NUL\NUL\NUL\NUL\rc2hs_keywords\NUL\NUL\NUL\NUL\NUL\NUL\NUL\r\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\tqualified\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETXlib\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKprefix\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STXas\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTwith\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTcall\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTpure\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKunsafe\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETXget\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETXset\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\aforeign\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKstable\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKnocode\NUL\NUL\NUL\NUL\NUL\NUL\NUL\fcpp_keywords\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACK\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\adefined\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STXif\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQifdef\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKifndef\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ainclude\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQundef\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SIimport_keywords\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETX\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STXas\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\tqualified\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKhiding\NUL\NUL\NUL\NUL\NUL\NUL\NUL\bkeywords\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SYN\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTcase\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQclass\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTdata\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\bderiving\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STXdo\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTelse\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKfamily\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKforall\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STXif\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STXin\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKinfixl\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKinfixr\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\binstance\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETXlet\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKmodule\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\anewtype\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STXof\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\apattern\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\tprimitive\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTthen\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTtype\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQwhere\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DLElanguage_pragmas\NUL\NUL\NUL\NUL\NUL\NUL\NULv\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC3AllowAmbiguousTypes\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\rApplicativeDo\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKArrows\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC2AutoDeriveTypeable\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\fBangPatterns\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOBinaryLiterals\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\aCApiFFI\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETXCPP\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETBConstrainedClassMethods\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SIConstraintKinds\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\tDataKinds\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DLEDatatypeContexts\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC1DefaultSignatures\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SODeriveAnyClass\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC2DeriveDataTypeable\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SODeriveFoldable\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\rDeriveFunctor\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\rDeriveGeneric\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\nDeriveLift\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC1DeriveTraversable\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\CANDisambiguateRecordFields\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SIDoAndIfThenElse\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQDoRec\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NAKDuplicateRecordFields\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\tEmptyCase\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOEmptyDataDecls\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EMExistentialQuantification\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOExplicitForAll\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC2ExplicitNamespaces\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC4ExtendedDefaultRules\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC1ExtensibleRecords\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DLEFlexibleContexts\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC1FlexibleInstances\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\CANForeignFunctionInterface\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SYNFunctionalDependencies\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\nGADTSyntax\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQGADTs\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC4GHCForeignImportPrim\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SUBGeneralizedNewtypeDeriving\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\bGenerics\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\rHereDocuments\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOImplicitParams\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SIImplicitPrelude\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC2ImpredicativeTypes\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC3IncoherentInstances\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\fInstanceSigs\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DLEInterruptibleFFI\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\rJavaScriptFFI\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOKindSignatures\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\nLambdaCase\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC3LiberalTypeSynonyms\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\tMagicHash\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC3MonadComprehensions\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC3MonadFailDesugaring\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOMonoLocalBinds\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\fMonoPatBinds\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETBMonomorphismRestriction\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NAKMultiParamTypeClasses\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\nMultiWayIf\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SONPlusKPatterns\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SONamedFieldPuns\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SONamedWildCards\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DLENegativeLiterals\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NAKNewQualifiedOperators\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\CANNondecreasingIndentation\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC2NullaryTypeClasses\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\vNumDecimals\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC4OverlappingInstances\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DLEOverloadedLabels\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SIOverloadedLists\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC1OverloadedStrings\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOPackageImports\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOParallelArrays\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DLEParallelListComp\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NAKPartialTypeSignatures\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\rPatternGuards\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC1PatternSignatures\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SIPatternSynonyms\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\tPolyKinds\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NAKPolymorphicComponents\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DLEPostfixOperators\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\vQuasiQuotes\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\nRank2Types\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\nRankNTypes\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DLERebindableSyntax\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\nRecordPuns\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SIRecordWildCards\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\vRecursiveDo\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SIRegularPatterns\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SORelaxedPolyRec\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SYNRestrictedTypeSynonyms\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SIRoleAnnotations\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTSafe\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\vSafeImports\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC3ScopedTypeVariables\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC2StandaloneDeriving\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOStaticPointers\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKStrict\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\nStrictData\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SITemplateHaskell\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NAKTemplateHaskellQuotes\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETBTraditionalRecordSyntax\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC1TransformListComp\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\vTrustworthy\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\rTupleSections\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DLETypeApplications\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\fTypeFamilies\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\nTypeInType\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\rTypeOperators\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC4TypeSynonymInstances\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\rUnboxedTuples\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC4UndecidableInstances\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETBUndecidableSuperClasses\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\rUnicodeSyntax\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DLEUnliftedFFITypes\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKUnsafe\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\fViewPatterns\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\tXmlSyntax\NUL\NUL\NUL\NUL\NUL\NUL\NUL\rprelude class\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC4\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\vApplicative\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\aBounded\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTEnum\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STXEq\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\bFloating\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\bFoldable\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\nFractional\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\aFunctor\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\bIntegral\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STXIx\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQMonad\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKMonoid\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETXNum\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETXOrd\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTRead\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTReal\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\tRealFloat\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\bRealFrac\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTShow\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\vTraversable\NUL\NUL\NUL\NUL\NUL\NUL\NUL\fprelude data\NUL\NUL\NUL\NUL\NUL\NUL\NUL\t\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQFalse\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTTrue\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTLeft\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQRight\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTJust\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\aNothing\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STXEQ\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STXLT\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STXGT\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DLEprelude function\NUL\NUL\NUL\NUL\NUL\NUL\NUL\225\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETXabs\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTacos\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQacosh\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETXall\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETXand\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETXany\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\nappendFile\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOapproxRational\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\basTypeOf\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTasin\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQasinh\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTatan\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQatan2\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQatanh\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\nbasicIORun\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQbreak\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQcatch\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\aceiling\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETXchr\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\acompare\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKconcat\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\tconcatMap\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQconst\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETXcos\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTcosh\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQcurry\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQcycle\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\vdecodeFloat\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\vdenominator\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ndigitToInt\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETXdiv\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKdivMod\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTdrop\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\tdropWhile\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKeither\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTelem\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\vencodeFloat\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\benumFrom\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\fenumFromThen\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOenumFromThenTo\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\nenumFromTo\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQerror\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTeven\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETXexp\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\bexponent\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTfail\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKfilter\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTflip\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\vfloatDigits\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\nfloatRadix\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\nfloatRange\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQfloor\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTfmap\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQfoldl\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKfoldl1\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\afoldMap\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQfoldr\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKfoldr1\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\nfromDouble\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\bfromEnum\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\afromInt\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\vfromInteger\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ffromIntegral\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ffromRational\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETXfst\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETXgcd\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\agetChar\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\vgetContents\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\agetLine\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQgroup\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOThead\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STXid\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ainRange\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQindex\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTinit\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\nintToDigit\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\binteract\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\aioError\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\aisAlpha\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\nisAlphaNum\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\aisAscii\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\tisControl\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOisDenormalized\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\aisDigit\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\nisHexDigit\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKisIEEE\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\nisInfinite\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\aisLower\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQisNaN\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOisNegativeZero\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\nisOctDigit\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\aisPrint\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\aisSpace\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\aisUpper\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\aiterate\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTlast\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETXlcm\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKlength\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETXlex\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\tlexDigits\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\nlexLitChar\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQlines\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETXlog\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\alogBase\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKlookup\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETXmap\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\amappend\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTmapM\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQmapM_\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETXmax\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\bmaxBound\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\amaximum\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQmaybe\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\amconcat\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKmempty\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETXmin\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\bminBound\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\aminimum\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETXmod\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKnegate\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETXnot\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\anotElem\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTnull\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\tnumerator\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETXodd\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STXor\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETXord\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\totherwise\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTpack\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STXpi\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTpred\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\fprimExitWith\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQprint\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\aproduct\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOproperFraction\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTpure\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\aputChar\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKputStr\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\bputStrLn\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTquot\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\aquotRem\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQrange\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\trangeSize\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTread\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\areadDec\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\breadFile\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\treadFloat\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\areadHex\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKreadIO\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\areadInt\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\breadList\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\vreadLitChar\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKreadLn\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\areadOct\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\treadParen\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\nreadSigned\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQreads\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\treadsPrec\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\nrealToFrac\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQrecip\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETXrem\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKrepeat\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\treplicate\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKreturn\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\areverse\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQround\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\nscaleFloat\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQscanl\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKscanl1\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQscanr\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKscanr1\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETXseq\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\bsequence\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\tsequenceA\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\tsequence_\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTshow\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\bshowChar\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ashowInt\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\bshowList\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\vshowLitChar\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\tshowParen\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\nshowSigned\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\nshowString\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQshows\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\tshowsPrec\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\vsignificand\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKsignum\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETXsin\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTsinh\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETXsnd\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTsort\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTspan\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\asplitAt\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTsqrt\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\bsubtract\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTsucc\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETXsum\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTtail\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTtake\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ttakeWhile\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETXtan\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTtanh\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DLEthreadToIOResult\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKtoEnum\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQtoInt\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ttoInteger\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\atoLower\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ntoRational\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\atoUpper\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\btraverse\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\btruncate\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\auncurry\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\tundefined\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\aunlines\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQuntil\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\aunwords\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQunzip\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKunzip3\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\tuserError\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQwords\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\twriteFile\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETXzip\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTzip3\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\azipWith\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\bzipWith3\NUL\NUL\NUL\NUL\NUL\NUL\NUL\fprelude type\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC3\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTBool\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\nByteString\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTChar\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKDouble\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKEither\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\bFilePath\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQFloat\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETXInt\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\aInteger\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STXIO\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\aIOError\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQMaybe\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\bOrdering\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQRatio\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\bRational\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQReadS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQShowS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKString\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTWord\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SYN\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOC Preprocessor\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOC Preprocessor\NUL\NUL\NUL\NUL\NUL\NUL\NUL\aHaskell\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STX\a\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\FS\t\n !%&()*+,-./:;<=>?[\\]^{|}~\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACK\NUL\NUL\NUL\NUL\NUL\NUL\NUL\adefined\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STXif\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQifdef\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKifndef\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ainclude\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQundef\ETB\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACK\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOT.*>$\SOH\ETB\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETB\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\vFindComment\NUL\NUL\NUL\NUL\NUL\NUL\NUL\vFindComment\NUL\NUL\NUL\NUL\NUL\NUL\NUL\aHaskell\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETX\EOT\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETX{-#\DLE\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\aHaskell\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKpragma\SOH{-\f\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\aHaskell\NUL\NUL\NUL\NUL\NUL\NUL\NUL\bcomments\ACK\NUL\NUL\NUL\NUL\NUL\NUL\NUL%--+(?![\\-!#\\$%&\\*\\+/<=>\\?\\@\\^\\|~\\.:])\SOH\f\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\aHaskell\NUL\NUL\NUL\NUL\NUL\NUL\NUL\acomment\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\aHaddock\NUL\NUL\NUL\NUL\NUL\NUL\NUL\aHaddock\NUL\NUL\NUL\NUL\NUL\NUL\NUL\aHaskell\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOT\ACK\NUL\NUL\NUL\NUL\NUL\NUL\NUL.'([A-Z][a-zA-Z0-9_']*\\.)*[a-z_][a-zA-Z0-9_']*'\SOH\f\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACK\NUL\NUL\NUL\NUL\NUL\NUL\NUL-\"([A-Z][a-zA-Z0-9_']*\\.)*[A-Z][a-zA-Z0-9_']*\"\SOH\f\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETX//\f\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\aHaskell\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SYNStart Haddock Emphasis\ACK\NUL\NUL\NUL\NUL\NUL\NUL\NUL\a__.*?__\SOH\f\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\aHaskell\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC2Start Haddock Bold\f\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\fHaddock Bold\NUL\NUL\NUL\NUL\NUL\NUL\NUL\fHaddock Bold\NUL\NUL\NUL\NUL\NUL\NUL\NUL\aHaskell\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STX\SOH__\f\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STX\NUL\NUL\SI\NUL\NUL\NUL\NUL\NUL\NUL\NUL\aHaskell\NUL\NUL\NUL\NUL\NUL\NUL\NUL\aHaddock\f\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\f\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DLEHaddock Emphasis\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DLEHaddock Emphasis\NUL\NUL\NUL\NUL\NUL\NUL\NUL\aHaskell\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOT\DLE\f\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL/\f\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STX\NUL\NUL\SI\NUL\NUL\NUL\NUL\NUL\NUL\NUL\aHaskell\NUL\NUL\NUL\NUL\NUL\NUL\NUL\aHaddock\f\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC1\f\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\f\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKHamlet\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKHamlet\NUL\NUL\NUL\NUL\NUL\NUL\NUL\aHaskell\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STX\SI\NUL\NUL\NUL\NUL\NUL\NUL\NUL\aHaskell\NUL\NUL\NUL\NUL\NUL\NUL\NUL\nQuasiQuote\RS\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SI\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKHamlet\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\RS\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKJulius\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKJulius\NUL\NUL\NUL\NUL\NUL\NUL\NUL\aHaskell\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STX\SI\NUL\NUL\NUL\NUL\NUL\NUL\NUL\aHaskell\NUL\NUL\NUL\NUL\NUL\NUL\NUL\nQuasiQuote\RS\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SI\NUL\NUL\NUL\NUL\NUL\NUL\NUL\nJavaScript\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKNormal\RS\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\nQuasiQuote\NUL\NUL\NUL\NUL\NUL\NUL\NUL\nQuasiQuote\NUL\NUL\NUL\NUL\NUL\NUL\NUL\aHaskell\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\SOH|]\RS\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC2Start Haddock Bold\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC2Start Haddock Bold\NUL\NUL\NUL\NUL\NUL\NUL\NUL\aHaskell\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\SOH__\f\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\aHaskell\NUL\NUL\NUL\NUL\NUL\NUL\NUL\fHaddock Bold\f\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SYNStart Haddock Emphasis\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SYNStart Haddock Emphasis\NUL\NUL\NUL\NUL\NUL\NUL\NUL\aHaskell\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL/\f\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\aHaskell\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DLEHaddock Emphasis\f\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOc2hs directive\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOc2hs directive\NUL\NUL\NUL\NUL\NUL\NUL\NUL\aHaskell\NUL\NUL\NUL\NUL\NUL\NUL\NUL\v\DLE\b\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH#}\b\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\a\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\FS\t\n !%&()*+,-./:;<=>?[\\]^{|}~\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\r\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STXas\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTcall\NUL\NUL\NUL\NUL\NUL\NUL\NUL\aforeign\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETXget\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETXlib\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKnocode\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKprefix\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTpure\NUL\NUL\NUL\NUL\NUL\NUL\NUL\tqualified\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETXset\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKstable\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKunsafe\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTwith\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOT\NUL\NUL\NUL\NUL\NUL\NUL\NUL\acontext\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOT\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTcall\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOT\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKsizeof\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOT\NUL\NUL\NUL\NUL\NUL\NUL\NUL\aalignof\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOT\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETXfun\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\aHaskell\NUL\NUL\NUL\NUL\NUL\NUL\NUL\bc2hs fun\EOT\NUL\NUL\NUL\NUL\NUL\NUL\NUL\apointer\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\aHaskell\NUL\NUL\NUL\NUL\NUL\NUL\NUL\fc2hs pointer\EOT\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTenum\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\aHaskell\NUL\NUL\NUL\NUL\NUL\NUL\NUL\tc2hs enum\EOT\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKimport\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\aHaskell\NUL\NUL\NUL\NUL\NUL\NUL\NUL\tc2hs enum\b\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\tc2hs enum\NUL\NUL\NUL\NUL\NUL\NUL\NUL\tc2hs enum\NUL\NUL\NUL\NUL\NUL\NUL\NUL\aHaskell\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOT\DLE\b\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACK\NUL\NUL\NUL\NUL\NUL\NUL\NUL+([A-Z][a-zA-Z0-9_']*\\.)*[A-Z][a-zA-Z0-9_']*\SOH\SOH\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH#}\b\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STX\NUL\NUL\DC1\b\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\b\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\bc2hs fun\NUL\NUL\NUL\NUL\NUL\NUL\NUL\bc2hs fun\NUL\NUL\NUL\NUL\NUL\NUL\NUL\aHaskell\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQ\DLE\b\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\a\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\FS\t\n !%&()*+,-./:;<=>?[\\]^{|}~\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\r\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STXas\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTcall\NUL\NUL\NUL\NUL\NUL\NUL\NUL\aforeign\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETXget\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETXlib\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKnocode\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKprefix\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTpure\NUL\NUL\NUL\NUL\NUL\NUL\NUL\tqualified\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETXset\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKstable\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKunsafe\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTwith\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETX`'\SOH\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH#}\b\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STX\NUL\NUL\DC1\b\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\b\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\fc2hs pointer\NUL\NUL\NUL\NUL\NUL\NUL\NUL\fc2hs pointer\NUL\NUL\NUL\NUL\NUL\NUL\NUL\aHaskell\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACK\DLE\b\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\a\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\FS\t\n !%&()*+,-./:;<=>?[\\]^{|}~\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\r\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STXas\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTcall\NUL\NUL\NUL\NUL\NUL\NUL\NUL\aforeign\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETXget\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETXlib\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKnocode\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKprefix\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTpure\NUL\NUL\NUL\NUL\NUL\NUL\NUL\tqualified\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETXset\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKstable\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKunsafe\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTwith\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOT\NUL\NUL\NUL\NUL\NUL\NUL\NUL\anewtype\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACK\NUL\NUL\NUL\NUL\NUL\NUL\NUL+([A-Z][a-zA-Z0-9_']*\\.)*[A-Z][a-zA-Z0-9_']*\SOH\SOH\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH#}\b\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STX\NUL\NUL\DC1\b\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\b\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTchar\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTchar\NUL\NUL\NUL\NUL\NUL\NUL\NUL\aHaskell\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STX\NUL'\ACK\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\ACK\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETX\\\\.\SOH\ACK\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACK\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTcode\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTcode\NUL\NUL\NUL\NUL\NUL\NUL\NUL\aHaskell\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SUB\SI\NUL\NUL\NUL\NUL\NUL\NUL\NUL\aHaskell\NUL\NUL\NUL\NUL\NUL\NUL\NUL\vFindComment\RS\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQ\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKimport\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\aHaskell\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKimport\SOH{#\b\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\aHaskell\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOc2hs directive\NUL#\ETB\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\aHaskell\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOC Preprocessor\a\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\FS\t\n !%&()*+,-./:;<=>?[\\]^{|}~\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SYN\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTcase\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQclass\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTdata\NUL\NUL\NUL\NUL\NUL\NUL\NUL\bderiving\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STXdo\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTelse\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKfamily\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKforall\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STXif\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STXin\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKinfixl\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKinfixr\NUL\NUL\NUL\NUL\NUL\NUL\NUL\binstance\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETXlet\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKmodule\NUL\NUL\NUL\NUL\NUL\NUL\NUL\anewtype\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STXof\NUL\NUL\NUL\NUL\NUL\NUL\NUL\apattern\NUL\NUL\NUL\NUL\NUL\NUL\NUL\tprimitive\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTthen\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTtype\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQwhere\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\a\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\FS\t\n !%&()*+,-./:;<=>?[\\]^{|}~\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\225\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETXabs\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTacos\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQacosh\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETXall\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETXand\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETXany\NUL\NUL\NUL\NUL\NUL\NUL\NUL\nappendFile\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOapproxRational\NUL\NUL\NUL\NUL\NUL\NUL\NUL\basTypeOf\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTasin\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQasinh\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTatan\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQatan2\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQatanh\NUL\NUL\NUL\NUL\NUL\NUL\NUL\nbasicIORun\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQbreak\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQcatch\NUL\NUL\NUL\NUL\NUL\NUL\NUL\aceiling\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETXchr\NUL\NUL\NUL\NUL\NUL\NUL\NUL\acompare\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKconcat\NUL\NUL\NUL\NUL\NUL\NUL\NUL\tconcatMap\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQconst\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETXcos\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTcosh\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQcurry\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQcycle\NUL\NUL\NUL\NUL\NUL\NUL\NUL\vdecodeFloat\NUL\NUL\NUL\NUL\NUL\NUL\NUL\vdenominator\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ndigitToInt\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETXdiv\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKdivMod\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTdrop\NUL\NUL\NUL\NUL\NUL\NUL\NUL\tdropWhile\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKeither\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTelem\NUL\NUL\NUL\NUL\NUL\NUL\NUL\vencodeFloat\NUL\NUL\NUL\NUL\NUL\NUL\NUL\benumFrom\NUL\NUL\NUL\NUL\NUL\NUL\NUL\fenumFromThen\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOenumFromThenTo\NUL\NUL\NUL\NUL\NUL\NUL\NUL\nenumFromTo\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQerror\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTeven\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETXexp\NUL\NUL\NUL\NUL\NUL\NUL\NUL\bexponent\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTfail\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKfilter\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTflip\NUL\NUL\NUL\NUL\NUL\NUL\NUL\vfloatDigits\NUL\NUL\NUL\NUL\NUL\NUL\NUL\nfloatRadix\NUL\NUL\NUL\NUL\NUL\NUL\NUL\nfloatRange\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQfloor\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTfmap\NUL\NUL\NUL\NUL\NUL\NUL\NUL\afoldMap\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQfoldl\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKfoldl1\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQfoldr\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKfoldr1\NUL\NUL\NUL\NUL\NUL\NUL\NUL\nfromDouble\NUL\NUL\NUL\NUL\NUL\NUL\NUL\bfromEnum\NUL\NUL\NUL\NUL\NUL\NUL\NUL\afromInt\NUL\NUL\NUL\NUL\NUL\NUL\NUL\vfromInteger\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ffromIntegral\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ffromRational\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETXfst\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETXgcd\NUL\NUL\NUL\NUL\NUL\NUL\NUL\agetChar\NUL\NUL\NUL\NUL\NUL\NUL\NUL\vgetContents\NUL\NUL\NUL\NUL\NUL\NUL\NUL\agetLine\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQgroup\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOThead\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STXid\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ainRange\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQindex\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTinit\NUL\NUL\NUL\NUL\NUL\NUL\NUL\nintToDigit\NUL\NUL\NUL\NUL\NUL\NUL\NUL\binteract\NUL\NUL\NUL\NUL\NUL\NUL\NUL\aioError\NUL\NUL\NUL\NUL\NUL\NUL\NUL\aisAlpha\NUL\NUL\NUL\NUL\NUL\NUL\NUL\nisAlphaNum\NUL\NUL\NUL\NUL\NUL\NUL\NUL\aisAscii\NUL\NUL\NUL\NUL\NUL\NUL\NUL\tisControl\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOisDenormalized\NUL\NUL\NUL\NUL\NUL\NUL\NUL\aisDigit\NUL\NUL\NUL\NUL\NUL\NUL\NUL\nisHexDigit\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKisIEEE\NUL\NUL\NUL\NUL\NUL\NUL\NUL\nisInfinite\NUL\NUL\NUL\NUL\NUL\NUL\NUL\aisLower\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQisNaN\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOisNegativeZero\NUL\NUL\NUL\NUL\NUL\NUL\NUL\nisOctDigit\NUL\NUL\NUL\NUL\NUL\NUL\NUL\aisPrint\NUL\NUL\NUL\NUL\NUL\NUL\NUL\aisSpace\NUL\NUL\NUL\NUL\NUL\NUL\NUL\aisUpper\NUL\NUL\NUL\NUL\NUL\NUL\NUL\aiterate\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTlast\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETXlcm\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKlength\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETXlex\NUL\NUL\NUL\NUL\NUL\NUL\NUL\tlexDigits\NUL\NUL\NUL\NUL\NUL\NUL\NUL\nlexLitChar\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQlines\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETXlog\NUL\NUL\NUL\NUL\NUL\NUL\NUL\alogBase\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKlookup\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETXmap\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTmapM\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQmapM_\NUL\NUL\NUL\NUL\NUL\NUL\NUL\amappend\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETXmax\NUL\NUL\NUL\NUL\NUL\NUL\NUL\bmaxBound\NUL\NUL\NUL\NUL\NUL\NUL\NUL\amaximum\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQmaybe\NUL\NUL\NUL\NUL\NUL\NUL\NUL\amconcat\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKmempty\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETXmin\NUL\NUL\NUL\NUL\NUL\NUL\NUL\bminBound\NUL\NUL\NUL\NUL\NUL\NUL\NUL\aminimum\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETXmod\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKnegate\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETXnot\NUL\NUL\NUL\NUL\NUL\NUL\NUL\anotElem\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTnull\NUL\NUL\NUL\NUL\NUL\NUL\NUL\tnumerator\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETXodd\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STXor\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETXord\NUL\NUL\NUL\NUL\NUL\NUL\NUL\totherwise\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTpack\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STXpi\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTpred\NUL\NUL\NUL\NUL\NUL\NUL\NUL\fprimExitWith\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQprint\NUL\NUL\NUL\NUL\NUL\NUL\NUL\aproduct\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOproperFraction\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTpure\NUL\NUL\NUL\NUL\NUL\NUL\NUL\aputChar\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKputStr\NUL\NUL\NUL\NUL\NUL\NUL\NUL\bputStrLn\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTquot\NUL\NUL\NUL\NUL\NUL\NUL\NUL\aquotRem\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQrange\NUL\NUL\NUL\NUL\NUL\NUL\NUL\trangeSize\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTread\NUL\NUL\NUL\NUL\NUL\NUL\NUL\areadDec\NUL\NUL\NUL\NUL\NUL\NUL\NUL\breadFile\NUL\NUL\NUL\NUL\NUL\NUL\NUL\treadFloat\NUL\NUL\NUL\NUL\NUL\NUL\NUL\areadHex\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKreadIO\NUL\NUL\NUL\NUL\NUL\NUL\NUL\areadInt\NUL\NUL\NUL\NUL\NUL\NUL\NUL\breadList\NUL\NUL\NUL\NUL\NUL\NUL\NUL\vreadLitChar\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKreadLn\NUL\NUL\NUL\NUL\NUL\NUL\NUL\areadOct\NUL\NUL\NUL\NUL\NUL\NUL\NUL\treadParen\NUL\NUL\NUL\NUL\NUL\NUL\NUL\nreadSigned\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQreads\NUL\NUL\NUL\NUL\NUL\NUL\NUL\treadsPrec\NUL\NUL\NUL\NUL\NUL\NUL\NUL\nrealToFrac\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQrecip\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETXrem\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKrepeat\NUL\NUL\NUL\NUL\NUL\NUL\NUL\treplicate\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKreturn\NUL\NUL\NUL\NUL\NUL\NUL\NUL\areverse\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQround\NUL\NUL\NUL\NUL\NUL\NUL\NUL\nscaleFloat\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQscanl\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKscanl1\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQscanr\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKscanr1\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETXseq\NUL\NUL\NUL\NUL\NUL\NUL\NUL\bsequence\NUL\NUL\NUL\NUL\NUL\NUL\NUL\tsequenceA\NUL\NUL\NUL\NUL\NUL\NUL\NUL\tsequence_\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTshow\NUL\NUL\NUL\NUL\NUL\NUL\NUL\bshowChar\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ashowInt\NUL\NUL\NUL\NUL\NUL\NUL\NUL\bshowList\NUL\NUL\NUL\NUL\NUL\NUL\NUL\vshowLitChar\NUL\NUL\NUL\NUL\NUL\NUL\NUL\tshowParen\NUL\NUL\NUL\NUL\NUL\NUL\NUL\nshowSigned\NUL\NUL\NUL\NUL\NUL\NUL\NUL\nshowString\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQshows\NUL\NUL\NUL\NUL\NUL\NUL\NUL\tshowsPrec\NUL\NUL\NUL\NUL\NUL\NUL\NUL\vsignificand\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKsignum\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETXsin\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTsinh\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETXsnd\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTsort\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTspan\NUL\NUL\NUL\NUL\NUL\NUL\NUL\asplitAt\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTsqrt\NUL\NUL\NUL\NUL\NUL\NUL\NUL\bsubtract\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTsucc\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETXsum\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTtail\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTtake\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ttakeWhile\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETXtan\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTtanh\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DLEthreadToIOResult\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKtoEnum\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQtoInt\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ttoInteger\NUL\NUL\NUL\NUL\NUL\NUL\NUL\atoLower\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ntoRational\NUL\NUL\NUL\NUL\NUL\NUL\NUL\atoUpper\NUL\NUL\NUL\NUL\NUL\NUL\NUL\btraverse\NUL\NUL\NUL\NUL\NUL\NUL\NUL\btruncate\NUL\NUL\NUL\NUL\NUL\NUL\NUL\auncurry\NUL\NUL\NUL\NUL\NUL\NUL\NUL\tundefined\NUL\NUL\NUL\NUL\NUL\NUL\NUL\aunlines\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQuntil\NUL\NUL\NUL\NUL\NUL\NUL\NUL\aunwords\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQunzip\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKunzip3\NUL\NUL\NUL\NUL\NUL\NUL\NUL\tuserError\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQwords\NUL\NUL\NUL\NUL\NUL\NUL\NUL\twriteFile\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETXzip\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTzip3\NUL\NUL\NUL\NUL\NUL\NUL\NUL\azipWith\NUL\NUL\NUL\NUL\NUL\NUL\NUL\bzipWith3\DC1\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\a\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\FS\t\n !%&()*+,-./:;<=>?[\\]^{|}~\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC3\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTBool\NUL\NUL\NUL\NUL\NUL\NUL\NUL\nByteString\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTChar\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKDouble\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKEither\NUL\NUL\NUL\NUL\NUL\NUL\NUL\bFilePath\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQFloat\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STXIO\NUL\NUL\NUL\NUL\NUL\NUL\NUL\aIOError\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETXInt\NUL\NUL\NUL\NUL\NUL\NUL\NUL\aInteger\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQMaybe\NUL\NUL\NUL\NUL\NUL\NUL\NUL\bOrdering\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQRatio\NUL\NUL\NUL\NUL\NUL\NUL\NUL\bRational\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQReadS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQShowS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKString\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTWord\SOH\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\a\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\FS\t\n !%&()*+,-./:;<=>?[\\]^{|}~\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\t\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STXEQ\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQFalse\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STXGT\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTJust\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STXLT\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTLeft\NUL\NUL\NUL\NUL\NUL\NUL\NUL\aNothing\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQRight\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTTrue\SOH\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\a\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\FS\t\n !%&()*+,-./:;<=>?[\\]^{|}~\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC4\NUL\NUL\NUL\NUL\NUL\NUL\NUL\vApplicative\NUL\NUL\NUL\NUL\NUL\NUL\NUL\aBounded\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTEnum\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STXEq\NUL\NUL\NUL\NUL\NUL\NUL\NUL\bFloating\NUL\NUL\NUL\NUL\NUL\NUL\NUL\bFoldable\NUL\NUL\NUL\NUL\NUL\NUL\NUL\nFractional\NUL\NUL\NUL\NUL\NUL\NUL\NUL\aFunctor\NUL\NUL\NUL\NUL\NUL\NUL\NUL\bIntegral\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STXIx\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQMonad\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKMonoid\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETXNum\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETXOrd\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTRead\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTReal\NUL\NUL\NUL\NUL\NUL\NUL\NUL\tRealFloat\NUL\NUL\NUL\NUL\NUL\NUL\NUL\bRealFrac\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTShow\NUL\NUL\NUL\NUL\NUL\NUL\NUL\vTraversable\SOH\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACK\NUL\NUL\NUL\NUL\NUL\NUL\NUL1(::|=>|->|<-|=)(?![\\-!#\\$%&\\*\\+/<=>\\?\\@\\^\\|~\\.:])\SOH\DLE\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACK\NUL\NUL\NUL\NUL\NUL\NUL\NUL\149\\s*[a-z_][a-zA-Z0-9_']*\\s*(?=::([^\\-!#\\$%&\\*\\+/<=>\\?\\@\\^\\|~\\.:]|$))|\\s*(\\([\\-!#\\$%&\\*\\+/<=>\\?\\@\\^\\|~\\.:]*\\))*\\s*(?=::[^\\-!#\\$%&\\*\\+/<=>\\?\\@\\^\\|~\\.:])\SOH\DLE\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACK\NUL\NUL\NUL\NUL\NUL\NUL\NUL,([A-Z][a-zA-Z0-9_']*\\.)*[a-z_][a-zA-Z0-9_']*\SOH\RS\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACK\NUL\NUL\NUL\NUL\NUL\NUL\NUL7([A-Z][a-zA-Z0-9_']*\\.)*[\\-!#\\$%&\\*\\+/<=>\\?\\@\\^\\|~\\.:]+\SOH\DC4\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACK\NUL\NUL\NUL\NUL\NUL\NUL\NULb([A-Z][a-zA-Z0-9_']*\\.)*[A-Z][a-zA-Z0-9_']*|'(?![A-Z]')([A-Z][a-zA-Z0-9_']*\\.)*[A-Z][a-zA-Z0-9_']*\SOH\SOH\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACK\NUL\NUL\NUL\NUL\NUL\NUL\NUL'\\d+\\.\\d+([Ee][+-]?\\d+)?|\\d+[Ee][+-]?\\d+\SOH\EOT\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACK\NUL\NUL\NUL\NUL\NUL\NUL\NUL\v0[Oo][0-7]+\SOH\ETX\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACK\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC10[Xx][0-9A-Fa-f]+\SOH\ETX\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\b\STX\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACK\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETB'(\\\\'|\\\\[^']+|[^\\\\\\n])'\SOH\ACK\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\"\b\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\aHaskell\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKstring\NUL`\DLE\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\aHaskell\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQinfix\SOH..\DLE\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\226\128\165\DLE\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACK\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DLE\\[[wxs]?hamlet\\|\SOH\RS\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\aHaskell\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKHamlet\EOT\NUL\NUL\NUL\NUL\NUL\NUL\NUL\b[julius|\RS\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\aHaskell\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKJulius\ACK\NUL\NUL\NUL\NUL\NUL\NUL\NUL\CAN\\[[a-zA-Z_'](\\w|[_'])*\\|\SOH\RS\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\aHaskell\NUL\NUL\NUL\NUL\NUL\NUL\NUL\nQuasiQuote\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\acomment\NUL\NUL\NUL\NUL\NUL\NUL\NUL\acomment\NUL\NUL\NUL\NUL\NUL\NUL\NUL\aHaskell\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOT\DLE\f\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SI\NUL\NUL\NUL\NUL\NUL\NUL\NUL\aHaskell\NUL\NUL\NUL\NUL\NUL\NUL\NUL\aHaddock\f\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SI\NUL\NUL\NUL\NUL\NUL\NUL\NUL\bComments\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\f\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC1\f\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\f\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\bcomments\NUL\NUL\NUL\NUL\NUL\NUL\NUL\bcomments\NUL\NUL\NUL\NUL\NUL\NUL\NUL\aHaskell\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACK\DLE\f\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH{-\f\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\aHaskell\NUL\NUL\NUL\NUL\NUL\NUL\NUL\bcomments\SOH-}\f\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\SI\NUL\NUL\NUL\NUL\NUL\NUL\NUL\aHaskell\NUL\NUL\NUL\NUL\NUL\NUL\NUL\aHaddock\f\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SI\NUL\NUL\NUL\NUL\NUL\NUL\NUL\bComments\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\f\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC1\f\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\f\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKimport\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKimport\NUL\NUL\NUL\NUL\NUL\NUL\NUL\aHaskell\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQ\DLE\RS\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\a\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\FS\t\n !%&()*+,-./:;<=>?[\\]^{|}~\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETX\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STXas\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKhiding\NUL\NUL\NUL\NUL\NUL\NUL\NUL\tqualified\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACK\NUL\NUL\NUL\NUL\NUL\NUL\NUL+([A-Z][a-zA-Z0-9_']*\\.)*[a-z][a-zA-Z0-9_']*\SOH\RS\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACK\NUL\NUL\NUL\NUL\NUL\NUL\NUL+([A-Z][a-zA-Z0-9_']*\\.)*[A-Z][a-zA-Z0-9_']*\SOH\SOH\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SI\NUL\NUL\NUL\NUL\NUL\NUL\NUL\aHaskell\NUL\NUL\NUL\NUL\NUL\NUL\NUL\vFindComment\RS\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQinfix\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQinfix\NUL\NUL\NUL\NUL\NUL\NUL\NUL\aHaskell\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STX\NUL`\DLE\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\DC1\DLE\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DLE\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKpragma\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKpragma\NUL\NUL\NUL\NUL\NUL\NUL\NUL\aHaskell\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOT\DLE\DLE\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\a\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\FS\t\n !%&()*+,-./:;<=>?[\\]^{|}~\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NULv\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC3AllowAmbiguousTypes\NUL\NUL\NUL\NUL\NUL\NUL\NUL\rApplicativeDo\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKArrows\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC2AutoDeriveTypeable\NUL\NUL\NUL\NUL\NUL\NUL\NUL\fBangPatterns\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOBinaryLiterals\NUL\NUL\NUL\NUL\NUL\NUL\NUL\aCApiFFI\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETXCPP\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETBConstrainedClassMethods\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SIConstraintKinds\NUL\NUL\NUL\NUL\NUL\NUL\NUL\tDataKinds\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DLEDatatypeContexts\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC1DefaultSignatures\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SODeriveAnyClass\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC2DeriveDataTypeable\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SODeriveFoldable\NUL\NUL\NUL\NUL\NUL\NUL\NUL\rDeriveFunctor\NUL\NUL\NUL\NUL\NUL\NUL\NUL\rDeriveGeneric\NUL\NUL\NUL\NUL\NUL\NUL\NUL\nDeriveLift\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC1DeriveTraversable\NUL\NUL\NUL\NUL\NUL\NUL\NUL\CANDisambiguateRecordFields\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SIDoAndIfThenElse\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQDoRec\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NAKDuplicateRecordFields\NUL\NUL\NUL\NUL\NUL\NUL\NUL\tEmptyCase\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOEmptyDataDecls\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EMExistentialQuantification\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOExplicitForAll\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC2ExplicitNamespaces\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC4ExtendedDefaultRules\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC1ExtensibleRecords\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DLEFlexibleContexts\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC1FlexibleInstances\NUL\NUL\NUL\NUL\NUL\NUL\NUL\CANForeignFunctionInterface\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SYNFunctionalDependencies\NUL\NUL\NUL\NUL\NUL\NUL\NUL\nGADTSyntax\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQGADTs\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC4GHCForeignImportPrim\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SUBGeneralizedNewtypeDeriving\NUL\NUL\NUL\NUL\NUL\NUL\NUL\bGenerics\NUL\NUL\NUL\NUL\NUL\NUL\NUL\rHereDocuments\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOImplicitParams\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SIImplicitPrelude\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC2ImpredicativeTypes\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC3IncoherentInstances\NUL\NUL\NUL\NUL\NUL\NUL\NUL\fInstanceSigs\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DLEInterruptibleFFI\NUL\NUL\NUL\NUL\NUL\NUL\NUL\rJavaScriptFFI\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOKindSignatures\NUL\NUL\NUL\NUL\NUL\NUL\NUL\nLambdaCase\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC3LiberalTypeSynonyms\NUL\NUL\NUL\NUL\NUL\NUL\NUL\tMagicHash\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC3MonadComprehensions\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC3MonadFailDesugaring\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOMonoLocalBinds\NUL\NUL\NUL\NUL\NUL\NUL\NUL\fMonoPatBinds\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETBMonomorphismRestriction\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NAKMultiParamTypeClasses\NUL\NUL\NUL\NUL\NUL\NUL\NUL\nMultiWayIf\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SONPlusKPatterns\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SONamedFieldPuns\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SONamedWildCards\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DLENegativeLiterals\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NAKNewQualifiedOperators\NUL\NUL\NUL\NUL\NUL\NUL\NUL\CANNondecreasingIndentation\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC2NullaryTypeClasses\NUL\NUL\NUL\NUL\NUL\NUL\NUL\vNumDecimals\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC4OverlappingInstances\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DLEOverloadedLabels\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SIOverloadedLists\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC1OverloadedStrings\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOPackageImports\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOParallelArrays\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DLEParallelListComp\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NAKPartialTypeSignatures\NUL\NUL\NUL\NUL\NUL\NUL\NUL\rPatternGuards\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC1PatternSignatures\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SIPatternSynonyms\NUL\NUL\NUL\NUL\NUL\NUL\NUL\tPolyKinds\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NAKPolymorphicComponents\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DLEPostfixOperators\NUL\NUL\NUL\NUL\NUL\NUL\NUL\vQuasiQuotes\NUL\NUL\NUL\NUL\NUL\NUL\NUL\nRank2Types\NUL\NUL\NUL\NUL\NUL\NUL\NUL\nRankNTypes\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DLERebindableSyntax\NUL\NUL\NUL\NUL\NUL\NUL\NUL\nRecordPuns\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SIRecordWildCards\NUL\NUL\NUL\NUL\NUL\NUL\NUL\vRecursiveDo\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SIRegularPatterns\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SORelaxedPolyRec\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SYNRestrictedTypeSynonyms\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SIRoleAnnotations\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTSafe\NUL\NUL\NUL\NUL\NUL\NUL\NUL\vSafeImports\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC3ScopedTypeVariables\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC2StandaloneDeriving\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOStaticPointers\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKStrict\NUL\NUL\NUL\NUL\NUL\NUL\NUL\nStrictData\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SITemplateHaskell\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NAKTemplateHaskellQuotes\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETBTraditionalRecordSyntax\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC1TransformListComp\NUL\NUL\NUL\NUL\NUL\NUL\NUL\vTrustworthy\NUL\NUL\NUL\NUL\NUL\NUL\NUL\rTupleSections\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DLETypeApplications\NUL\NUL\NUL\NUL\NUL\NUL\NUL\fTypeFamilies\NUL\NUL\NUL\NUL\NUL\NUL\NUL\nTypeInType\NUL\NUL\NUL\NUL\NUL\NUL\NUL\rTypeOperators\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC4TypeSynonymInstances\NUL\NUL\NUL\NUL\NUL\NUL\NUL\rUnboxedTuples\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC4UndecidableInstances\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETBUndecidableSuperClasses\NUL\NUL\NUL\NUL\NUL\NUL\NUL\rUnicodeSyntax\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DLEUnliftedFFITypes\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKUnsafe\NUL\NUL\NUL\NUL\NUL\NUL\NUL\fViewPatterns\NUL\NUL\NUL\NUL\NUL\NUL\NUL\tXmlSyntax\DLE\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC1\DLE\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOT\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETX#-}\DLE\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\DLE\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKstring\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKstring\NUL\NUL\NUL\NUL\NUL\NUL\NUL\aHaskell\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STX\NUL\"\b\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\ACK\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETX\\\\.\SOH\b\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\b\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\RSNicolas Wu (zenzike@gmail.com)\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STX20\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTLGPL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETX\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOT*.hs\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQ*.chs\NUL\NUL\NUL\NUL\NUL\NUL\NUL\t*.hs-boot\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTcode"
