{-# LANGUAGE OverloadedStrings #-}
-- | Automatically generated syntax definition for Pascal.
-- DO NOT EDIT THIS FILE MANUALLY.
-- Instead, modify xml/pascal.xml and 'make bootstrap'.
module Skylighting.Syntax.Pascal (syntax) where

import Skylighting.Types
import Data.Binary

-- | Syntax definition for Pascal.
syntax :: Syntax
syntax = decode "\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKPascal\NUL\NUL\NUL\NUL\NUL\NUL\NUL\npascal.xml\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKPascal\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETX\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC3ISO/Delphi Extended\NUL\NUL\NUL\NUL\NUL\NUL\NUL!\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\babstract\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STXas\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\bbindable\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\vconstructor\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ndestructor\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKexcept\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKexport\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\afinally\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKimport\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOimplementation\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\tinherited\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKinline\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\tinterface\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STXis\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKmodule\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STXon\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTonly\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\totherwise\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\boverride\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\aprivate\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\bproperty\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\tprotected\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKpublic\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTread\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\tqualified\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQraise\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\nrestricted\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETXshl\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETXshr\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\tthreadvar\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETXtry\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\avirtual\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQwrite\NUL\NUL\NUL\NUL\NUL\NUL\NUL\bkeywords\NUL\NUL\NUL\NUL\NUL\NUL\NUL6\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETXand\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQarray\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETXasm\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTcase\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQconst\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETXdiv\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STXdo\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKdownto\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTelse\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTfile\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETXfor\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\bfunction\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTgoto\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STXif\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STXin\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQlabel\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETXmod\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETXnil\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETXnot\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STXof\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\boperator\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STXor\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKpacked\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\tprocedure\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\aprogram\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKrecord\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKrepeat\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETXset\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTthen\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STXto\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTtype\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTunit\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQuntil\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTuses\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETXvar\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQwhile\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTwith\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETXxor\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STXat\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\tautomated\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQbreak\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\bcontinue\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\rdispinterface\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\adispose\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTexit\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQfalse\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ffinalization\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOinitialization\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\alibrary\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETXnew\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\tpublished\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOresourcestring\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTself\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTtrue\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQtypes\NUL\NUL\NUL\NUL\NUL\NUL\NUL!\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\aInteger\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\bCardinal\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\bShortInt\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\bSmallInt\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\aLongInt\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQInt64\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTByte\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTWord\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\bLongWord\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQDWord\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQQWord\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTChar\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\bAnsiChar\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\bWideChar\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\aBoolean\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\bByteBool\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\bWordBool\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\bLongBool\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKSingle\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKDouble\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\bExtended\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTComp\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\bCurrency\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTReal\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKReal48\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKString\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\vShortString\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\nAnsiString\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\nWideString\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\aPointer\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\aVariant\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTFile\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTText\NUL\NUL\NUL\NUL\NUL\NUL\NUL\n\NUL\NUL\NUL\NUL\NUL\NUL\NUL\aCharNum\NUL\NUL\NUL\NUL\NUL\NUL\NUL\aCharNum\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKPascal\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STX\NUL$\ETX\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKPascal\NUL\NUL\NUL\NUL\NUL\NUL\NUL\nHexCharNum\ACK\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACK[^0-9]\SOH\b\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\b\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\bComment1\NUL\NUL\NUL\NUL\NUL\NUL\NUL\bComment1\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKPascal\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETX\DLE\f\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL}\f\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\SI\NUL\NUL\NUL\NUL\NUL\NUL\NUL\bComments\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\f\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\f\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\bComment2\NUL\NUL\NUL\NUL\NUL\NUL\NUL\bComment2\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKPascal\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETX\DLE\f\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH*)\f\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\SI\NUL\NUL\NUL\NUL\NUL\NUL\NUL\bComments\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\f\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\f\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\bComment3\NUL\NUL\NUL\NUL\NUL\NUL\NUL\bComment3\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKPascal\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STX\DLE\f\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SI\NUL\NUL\NUL\NUL\NUL\NUL\NUL\bComments\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\f\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\f\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETXHex\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETXHex\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKPascal\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\ACK\NUL\NUL\NUL\NUL\NUL\NUL\NUL\f[^a-fA-F0-9]\SOH\ETX\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\ETX\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\nHexCharNum\NUL\NUL\NUL\NUL\NUL\NUL\NUL\nHexCharNum\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKPascal\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\ACK\NUL\NUL\NUL\NUL\NUL\NUL\NUL\f[^a-fA-F0-9]\SOH\ETX\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STX\NUL\NUL\ETX\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKNormal\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKNormal\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKPascal\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DLE\ACK\NUL\NUL\NUL\NUL\NUL\NUL\NULC\\b(begin|case|record)(?=(\\{[^}]*(\\}|$)|\\(\\*.*(\\*\\)|$))*([\\s]|$|//))\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACK\NUL\NUL\NUL\NUL\NUL\NUL\NUL}\\b((object|class)(?=(\\(.*\\))?(\\{[^}]*(\\}|$)|\\(\\*.*(\\*\\)|$))*;?([\\s]|$|//))|try(?=(\\{[^}]*(\\}|$)|\\(\\*.*(\\*\\)|$))*([\\s]|$|//)))\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACK\NUL\NUL\NUL\NUL\NUL\NUL\NUL9\\bend(?=((\\{[^}]*(\\}|$)|\\(\\*.*(\\*\\)|$))*)([.;\\s]|$)|//|$)\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\a\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\FS\t\n !%&()*+,-./:;<=>?[\\]^{|}~\SOH\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL6\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETXand\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQarray\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETXasm\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STXat\NUL\NUL\NUL\NUL\NUL\NUL\NUL\tautomated\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQbreak\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTcase\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQconst\NUL\NUL\NUL\NUL\NUL\NUL\NUL\bcontinue\NUL\NUL\NUL\NUL\NUL\NUL\NUL\rdispinterface\NUL\NUL\NUL\NUL\NUL\NUL\NUL\adispose\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETXdiv\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STXdo\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKdownto\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTelse\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTexit\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQfalse\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTfile\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ffinalization\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETXfor\NUL\NUL\NUL\NUL\NUL\NUL\NUL\bfunction\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTgoto\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STXif\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STXin\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOinitialization\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQlabel\NUL\NUL\NUL\NUL\NUL\NUL\NUL\alibrary\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETXmod\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETXnew\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETXnil\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETXnot\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STXof\NUL\NUL\NUL\NUL\NUL\NUL\NUL\boperator\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STXor\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKpacked\NUL\NUL\NUL\NUL\NUL\NUL\NUL\tprocedure\NUL\NUL\NUL\NUL\NUL\NUL\NUL\aprogram\NUL\NUL\NUL\NUL\NUL\NUL\NUL\tpublished\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKrecord\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKrepeat\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOresourcestring\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTself\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETXset\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTthen\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STXto\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTtrue\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTtype\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTunit\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQuntil\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTuses\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETXvar\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQwhile\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTwith\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETXxor\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\a\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\FS\t\n !%&()*+,-./:;<=>?[\\]^{|}~\SOH\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL!\NUL\NUL\NUL\NUL\NUL\NUL\NUL\babstract\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STXas\NUL\NUL\NUL\NUL\NUL\NUL\NUL\bbindable\NUL\NUL\NUL\NUL\NUL\NUL\NUL\vconstructor\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ndestructor\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKexcept\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKexport\NUL\NUL\NUL\NUL\NUL\NUL\NUL\afinally\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOimplementation\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKimport\NUL\NUL\NUL\NUL\NUL\NUL\NUL\tinherited\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKinline\NUL\NUL\NUL\NUL\NUL\NUL\NUL\tinterface\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STXis\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKmodule\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STXon\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTonly\NUL\NUL\NUL\NUL\NUL\NUL\NUL\totherwise\NUL\NUL\NUL\NUL\NUL\NUL\NUL\boverride\NUL\NUL\NUL\NUL\NUL\NUL\NUL\aprivate\NUL\NUL\NUL\NUL\NUL\NUL\NUL\bproperty\NUL\NUL\NUL\NUL\NUL\NUL\NUL\tprotected\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKpublic\NUL\NUL\NUL\NUL\NUL\NUL\NUL\tqualified\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQraise\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTread\NUL\NUL\NUL\NUL\NUL\NUL\NUL\nrestricted\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETXshl\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETXshr\NUL\NUL\NUL\NUL\NUL\NUL\NUL\tthreadvar\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETXtry\NUL\NUL\NUL\NUL\NUL\NUL\NUL\avirtual\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQwrite\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\a\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\FS\t\n !%&()*+,-./:;<=>?[\\]^{|}~\SOH\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL!\NUL\NUL\NUL\NUL\NUL\NUL\NUL\bansichar\NUL\NUL\NUL\NUL\NUL\NUL\NUL\nansistring\NUL\NUL\NUL\NUL\NUL\NUL\NUL\aboolean\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTbyte\NUL\NUL\NUL\NUL\NUL\NUL\NUL\bbytebool\NUL\NUL\NUL\NUL\NUL\NUL\NUL\bcardinal\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTchar\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTcomp\NUL\NUL\NUL\NUL\NUL\NUL\NUL\bcurrency\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKdouble\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQdword\NUL\NUL\NUL\NUL\NUL\NUL\NUL\bextended\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTfile\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQint64\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ainteger\NUL\NUL\NUL\NUL\NUL\NUL\NUL\blongbool\NUL\NUL\NUL\NUL\NUL\NUL\NUL\alongint\NUL\NUL\NUL\NUL\NUL\NUL\NUL\blongword\NUL\NUL\NUL\NUL\NUL\NUL\NUL\apointer\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQqword\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTreal\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKreal48\NUL\NUL\NUL\NUL\NUL\NUL\NUL\bshortint\NUL\NUL\NUL\NUL\NUL\NUL\NUL\vshortstring\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKsingle\NUL\NUL\NUL\NUL\NUL\NUL\NUL\bsmallint\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKstring\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTtext\NUL\NUL\NUL\NUL\NUL\NUL\NUL\avariant\NUL\NUL\NUL\NUL\NUL\NUL\NUL\bwidechar\NUL\NUL\NUL\NUL\NUL\NUL\NUL\nwidestring\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTword\NUL\NUL\NUL\NUL\NUL\NUL\NUL\bwordbool\SOH\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\t\STX\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\b\STX\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL$\ETX\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKPascal\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETXHex\NUL#\b\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKPascal\NUL\NUL\NUL\NUL\NUL\NUL\NUL\aCharNum\NUL'\b\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKPascal\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKString\EOT\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETX(*$\DLE\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKPascal\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQPrep1\SOH{$\DLE\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKPascal\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQPrep2\NUL{\f\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKPascal\NUL\NUL\NUL\NUL\NUL\NUL\NUL\bComment1\SOH(*\f\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKPascal\NUL\NUL\NUL\NUL\NUL\NUL\NUL\bComment2\SOH//\f\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKPascal\NUL\NUL\NUL\NUL\NUL\NUL\NUL\bComment3\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQPrep1\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQPrep1\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKPascal\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\SOH*)\DLE\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\DLE\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQPrep2\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQPrep2\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKPascal\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL}\DLE\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\DLE\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKString\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKString\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKPascal\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL'\b\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\b\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL2Unnamed people and Liu Sizhuang(oldherl@gmail.com)\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH4\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETX\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETX*.p\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQ*.pas\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOT*.pp\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKNormal"
