{-# LANGUAGE OverloadedStrings #-}
-- | Automatically generated syntax definition for PureBasic.
-- DO NOT EDIT THIS FILE MANUALLY.
-- Instead, modify xml/purebasic.xml and 'make bootstrap'.
module Skylighting.Syntax.Purebasic (syntax) where

import Skylighting.Types
import Data.Binary

-- | Syntax definition for PureBasic.
syntax :: Syntax
syntax = decode "\NUL\NUL\NUL\NUL\NUL\NUL\NUL\tPureBasic\NUL\NUL\NUL\NUL\NUL\NUL\NUL\rpurebasic.xml\NUL\NUL\NUL\NUL\NUL\NUL\NUL\tPurebasic\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOT\NUL\NUL\NUL\NUL\NUL\NUL\NUL\bcompiler\NUL\NUL\NUL\NUL\NUL\NUL\NUL\a\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\nCompilerIf\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\fCompilerElse\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\rCompilerEndIf\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOCompilerSelect\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\fCompilerCase\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SICompilerDefault\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC1CompilerEndSelect\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQdebug\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STX\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\fCallDebugger\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQDebug\NUL\NUL\NUL\NUL\NUL\NUL\NUL\tfunctions\NUL\NUL\NUL\NUL\NUL\NUL\ACK9\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTACos\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQACosH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\nAESDecoder\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\nAESEncoder\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTASin\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQASinH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTATan\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQATan2\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQATanH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\fAbortFTPFile\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETXAbs\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\fAdd3DArchive\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\fAddBillboard\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SIAddCipherBuffer\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\aAddDate\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\nAddElement\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SYNAddEntityAnimationTime\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SIAddGadgetColumn\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\rAddGadgetItem\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SIAddGadgetItem3D\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOAddJSONElement\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\rAddJSONMember\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC3AddKeyboardShortcut\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC1AddMailAttachment\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NAKAddMailAttachmentData\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DLEAddMailRecipient\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\rAddMapElement\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DLEAddMaterialLayer\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC4AddNodeAnimationTime\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\vAddPackFile\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\rAddPackMemory\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOAddSplinePoint\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETBAddStaticGeometryEntity\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC1AddStatusBarField\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\nAddSubMesh\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOAddSysTrayIcon\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC1AddTerrainTexture\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SYNAddVertexPoseReference\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOAddWindowTimer\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC4AffectedDatabaseRows\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOAllocateMemory\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC1AllocateStructure\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQAlpha\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\nAlphaBlend\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\fAmbientColor\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DLEAntialiasingMode\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DLEApplyEntityForce\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC2ApplyEntityImpulse\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\tArraySize\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETXAsc\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC2AttachEntityObject\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DLEAttachNodeObject\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC2AttachRibbonEffect\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\rAudioCDLength\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\vAudioCDName\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\rAudioCDStatus\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC2AudioCDTrackLength\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC3AudioCDTrackSeconds\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\rAudioCDTracks\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SYNAvailableProgramOutput\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NAKAvailableScreenMemory\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\CANAvailableSerialPortInput\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EMAvailableSerialPortOutput\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\tBackColor\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\rBase64Decoder\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\rBase64Encoder\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\GSBillboardGroupCommonDirection\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\FSBillboardGroupCommonUpVector\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DLEBillboardGroupID\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SYNBillboardGroupMaterial\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SIBillboardGroupX\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SIBillboardGroupY\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SIBillboardGroupZ\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SIBillboardHeight\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SIBillboardLocate\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOBillboardWidth\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\nBillboardX\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\nBillboardY\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\nBillboardZ\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETXBin\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\tBindEvent\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SIBindGadgetEvent\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\rBindMenuEvent\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTBlue\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETXBox\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\rBoxedGradient\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NAKBuildMeshShadowVolume\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC1BuildMeshTangents\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC3BuildStaticGeometry\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\fBuildTerrain\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\fButtonGadget\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOButtonGadget3D\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC1ButtonImageGadget\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\aCPUName\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC4CRC32FileFingerprint\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DLECRC32Fingerprint\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOCalendarGadget\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\rCallCFunction\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC1CallCFunctionFast\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\fCallFunction\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DLECallFunctionFast\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SICameraBackColor\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SICameraDirection\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DLECameraDirectionX\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DLECameraDirectionY\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DLECameraDirectionZ\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\tCameraFOV\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC2CameraFixedYawAxis\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\fCameraFollow\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\bCameraID\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\fCameraLookAt\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\vCameraPitch\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC4CameraProjectionMode\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC1CameraProjectionX\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC1CameraProjectionY\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\vCameraRange\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DLECameraRenderMode\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\nCameraRoll\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DLECameraViewHeight\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SICameraViewWidth\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\vCameraViewX\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\vCameraViewY\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\aCameraX\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\aCameraY\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\tCameraYaw\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\aCameraZ\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\fCanvasGadget\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\fCanvasOutput\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\nCatchImage\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\tCatchJSON\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\nCatchMusic\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\nCatchSound\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\vCatchSprite\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\bCatchXML\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC4ChangeCurrentElement\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\vChangeGamma\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ESCChangeListIconGadgetDisplay\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC1ChangeSysTrayIcon\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOCheckBoxGadget\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DLECheckBoxGadget3D\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC1CheckDatabaseNull\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC2CheckFTPConnection\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\rCheckFilename\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NAKCheckObjectVisibility\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\fChildXMLNode\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETXChr\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKCircle\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DLECircularGradient\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SIClearBillboards\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOClearClipboard\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\fClearConsole\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DLEClearDebugOutput\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC3ClearGadgetItemList\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DLEClearGadgetItems\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC2ClearGadgetItems3D\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC1ClearJSONElements\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DLEClearJSONMembers\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\tClearList\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\bClearMap\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\vClearScreen\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\vClearSpline\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\nClipOutput\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\nClipSprite\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\fCloseConsole\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DLECloseCryptRandom\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\rCloseDatabase\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\bCloseFTP\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\tCloseFile\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SICloseGadgetList\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC1CloseGadgetList3D\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\tCloseHelp\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\fCloseLibrary\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SYNCloseNetworkConnection\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC2CloseNetworkServer\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\tClosePack\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DLEClosePreferences\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\fCloseProgram\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\vCloseScreen\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SICloseSerialPort\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\fCloseSubMenu\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\vCloseWindow\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\rCloseWindow3D\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\fCocoaMessage\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOColorRequester\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOComboBoxGadget\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DLEComboBoxGadget3D\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\rCompareMemory\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC3CompareMemoryString\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\vComposeJSON\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\nComposeXML\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EMCompositorEffectParameter\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOCompressMemory\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\rComputeSpline\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\fComputerName\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOConeTwistJoint\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SIConicalGradient\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\fConnectionID\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\fConsoleColor\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\rConsoleCursor\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\fConsoleError\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\rConsoleLocate\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\fConsoleTitle\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SIContainerGadget\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC1ContainerGadget3D\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ESCConvertLocalToWorldPosition\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ESCConvertWorldToLocalPosition\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\tCopyArray\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\rCopyDirectory\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\nCopyEntity\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\bCopyFile\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\tCopyImage\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\tCopyLight\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\bCopyList\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\aCopyMap\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\fCopyMaterial\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\nCopyMemory\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DLECopyMemoryString\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\bCopyMesh\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\nCopySprite\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\vCopyTexture\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\vCopyXMLNode\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETXCos\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTCosH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SICountBillboards\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\tCountCPUs\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DLECountGadgetItems\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC2CountGadgetItems3D\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NAKCountLibraryFunctions\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\tCountList\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC3CountMaterialLayers\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SYNCountProgramParameters\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\FSCountRegularExpressionGroups\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC1CountSplinePoints\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\vCountString\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC4CreateBillboardGroup\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\fCreateCamera\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SYNCreateCompositorEffect\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\nCreateCube\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC4CreateCubeMapTexture\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOCreateCylinder\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\fCreateDialog\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SICreateDirectory\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\fCreateEntity\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC2CreateFTPDirectory\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\nCreateFile\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DLECreateGadgetList\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\vCreateImage\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SICreateImageMenu\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\nCreateJSON\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NAKCreateLensFlareEffect\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\vCreateLight\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\fCreateLine3D\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\nCreateMail\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOCreateMaterial\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\nCreateMenu\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\nCreateMesh\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\vCreateMutex\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC3CreateNetworkServer\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\nCreateNode\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC3CreateNodeAnimation\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ESCCreateNodeAnimationKeyFrame\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\nCreatePack\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NAKCreateParticleEmitter\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\vCreatePlane\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC4CreatePopupImageMenu\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SICreatePopupMenu\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC1CreatePreferences\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETBCreateRegularExpression\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC3CreateRenderTexture\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC2CreateRibbonEffect\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SICreateSemaphore\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\fCreateSphere\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\fCreateSpline\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\fCreateSprite\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC4CreateStaticGeometry\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SICreateStatusBar\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\rCreateTerrain\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\fCreateText3D\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\rCreateTexture\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\fCreateThread\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\rCreateToolBar\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NAKCreateVertexAnimation\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\CANCreateVertexPoseKeyFrame\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC1CreateVertexTrack\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\vCreateWater\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\tCreateXML\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\rCreateXMLNode\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\vCryptRandom\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SICryptRandomData\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC4CustomFilterCallback\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOCustomGradient\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SODESFingerprint\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC3DatabaseColumnIndex\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC2DatabaseColumnName\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC2DatabaseColumnSize\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC2DatabaseColumnType\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SIDatabaseColumns\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EMDatabaseDriverDescription\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC2DatabaseDriverName\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\rDatabaseError\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\nDatabaseID\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\rDatabaseQuery\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SODatabaseUpdate\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTDate\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\nDateGadget\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETXDay\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\tDayOfWeek\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\tDayOfYear\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SODefaultPrinter\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC1DefineTerrainTile\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKDegree\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQDelay\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SIDeleteDirectory\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\rDeleteElement\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC2DeleteFTPDirectory\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\rDeleteFTPFile\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\nDeleteFile\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DLEDeleteMapElement\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\rDeleteXMLNode\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\fDesktopDepth\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DLEDesktopFrequency\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\rDesktopHeight\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\rDesktopMouseX\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\rDesktopMouseY\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\vDesktopName\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\fDesktopWidth\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\bDesktopX\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\bDesktopY\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC2DetachEntityObject\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DLEDetachNodeObject\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC2DetachRibbonEffect\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\vDialogError\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\fDialogGadget\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\bDialogID\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\fDialogWindow\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\CANDirectoryEntryAttributes\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC2DirectoryEntryDate\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC2DirectoryEntryName\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC2DirectoryEntrySize\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC2DirectoryEntryType\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC1DisableEntityBody\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\rDisableGadget\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SIDisableGadget3D\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC3DisableLightShadows\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETBDisableMaterialLighting\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SIDisableMenuItem\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SYNDisableParticleEmitter\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC4DisableToolBarButton\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\rDisableWindow\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SIDisableWindow3D\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DLEDisplayPopupMenu\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\rDisplaySprite\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\CANDisplayTransparentSprite\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SIDoubleClickTime\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\tDragFiles\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\tDragImage\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\rDragOSFormats\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\vDragPrivate\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\bDragText\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SODrawAlphaImage\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\tDrawImage\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SIDrawRotatedText\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\bDrawText\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\rDrawingBuffer\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC2DrawingBufferPitch\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\CANDrawingBufferPixelFormat\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\vDrawingFont\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\vDrawingMode\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\fEditorGadget\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOEditorGadget3D\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\fEjectAudioCD\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC3ElapsedMilliseconds\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\aEllipse\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC2EllipticalGradient\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DLEEnableGadgetDrop\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SYNEnableGraphicalConsole\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\FSEnableHingeJointAngularMotor\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\GSEnableManualEntityBoneControl\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DLEEnableWindowDrop\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NAKEnableWorldCollisions\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC2EnableWorldPhysics\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\vEncodeImage\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOEngine3DStatus\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC3EntityAngularFactor\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\CANEntityAnimationBlendMode\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NAKEntityAnimationStatus\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SIEntityBonePitch\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOEntityBoneRoll\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\vEntityBoneX\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\vEntityBoneY\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\rEntityBoneYaw\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\vEntityBoneZ\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC1EntityBoundingBox\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\rEntityCollide\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC4EntityCubeMapTexture\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NAKEntityCustomParameter\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC2EntityFixedYawAxis\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\bEntityID\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC2EntityLinearFactor\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\fEntityLookAt\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DLEEntityParentNode\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DLEEntityPhysicBody\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\vEntityPitch\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DLEEntityRenderMode\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\nEntityRoll\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOEntityVelocity\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\aEntityX\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\aEntityY\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\tEntityYaw\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\aEntityZ\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETBEnvironmentVariableName\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\CANEnvironmentVariableValue\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETXEof\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\fErrorAddress\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\tErrorCode\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\tErrorFile\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\tErrorLine\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\fErrorMessage\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\rErrorRegister\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC2ErrorTargetAddress\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\vEventClient\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\tEventData\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SIEventDropAction\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SIEventDropBuffer\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOEventDropFiles\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOEventDropImage\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DLEEventDropPrivate\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\rEventDropSize\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\rEventDropText\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\rEventDropType\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\nEventDropX\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\nEventDropY\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\vEventGadget\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\rEventGadget3D\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\tEventMenu\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\vEventServer\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\nEventTimer\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\tEventType\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\vEventType3D\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\vEventWindow\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\rEventWindow3D\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\vEventlParam\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\vEventwParam\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SIExamineAssembly\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SYNExamineDatabaseDrivers\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SIExamineDesktops\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DLEExamineDirectory\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ESCExamineEnvironmentVariables\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC3ExamineFTPDirectory\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC2ExamineIPAddresses\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC2ExamineJSONMembers\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SIExamineJoystick\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SIExamineKeyboard\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETBExamineLibraryFunctions\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NAKExamineMD5Fingerprint\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\fExamineMouse\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\vExaminePack\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETBExaminePreferenceGroups\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NAKExaminePreferenceKeys\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\CANExamineRegularExpression\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SYNExamineSHA1Fingerprint\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC2ExamineScreenModes\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SYNExamineWorldCollisions\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC4ExamineXMLAttributes\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETXExp\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC3ExplorerComboGadget\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC2ExplorerListGadget\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC2ExplorerTreeGadget\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\nExportJSON\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOExportJSONSize\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\tExportXML\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\rExportXMLSize\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DLEExtractJSONArray\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SIExtractJSONList\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOExtractJSONMap\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC4ExtractJSONStructure\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\CANExtractRegularExpression\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SIExtractXMLArray\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOExtractXMLList\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\rExtractXMLMap\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC3ExtractXMLStructure\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ESCFTPDirectoryEntryAttributes\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NAKFTPDirectoryEntryDate\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NAKFTPDirectoryEntryName\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC4FTPDirectoryEntryRaw\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NAKFTPDirectoryEntrySize\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NAKFTPDirectoryEntryType\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\vFTPProgress\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC3FetchEntityMaterial\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DLEFetchOrientation\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SIFileBuffersSize\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKFileID\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\bFileSeek\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\bFileSize\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\bFillArea\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\nFillMemory\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOFindMapElement\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\nFindString\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\fFinishCipher\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC3FinishDatabaseQuery\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SIFinishDirectory\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC2FinishFTPDirectory\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC1FinishFingerprint\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\nFinishMesh\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DLEFirstDatabaseRow\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\fFirstElement\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EMFirstWorldCollisionEntity\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\vFlipBuffers\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DLEFlushFileBuffers\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETXFog\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKFontID\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\rFontRequester\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\nFormatDate\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\tFormatXML\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\vFrameGadget\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\rFrameGadget3D\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\tFreeArray\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC2FreeBillboardGroup\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\nFreeCamera\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\nFreeDialog\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\nFreeEffect\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\nFreeEntity\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DLEFreeEntityJoints\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\bFreeFont\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\nFreeGadget\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\fFreeGadget3D\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKFreeIP\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\tFreeImage\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\bFreeJSON\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\tFreeJoint\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\tFreeLight\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\bFreeList\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\bFreeMail\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\aFreeMap\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\fFreeMaterial\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\nFreeMemory\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\bFreeMenu\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\bFreeMesh\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\tFreeMovie\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\tFreeMusic\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\tFreeMutex\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\bFreeNode\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC1FreeNodeAnimation\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC3FreeParticleEmitter\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NAKFreeRegularExpression\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\rFreeSemaphore\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\tFreeSound\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\vFreeSound3D\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\nFreeSpline\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\nFreeSprite\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC2FreeStaticGeometry\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\rFreeStatusBar\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\rFreeStructure\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\vFreeTerrain\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\nFreeText3D\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\vFreeTexture\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\vFreeToolBar\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\tFreeWater\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\aFreeXML\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\nFrontColor\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\fGadgetHeight\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOGadgetHeight3D\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\bGadgetID\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\nGadgetID3D\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\fGadgetItemID\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\rGadgetToolTip\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SIGadgetToolTip3D\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\nGadgetType\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\fGadgetType3D\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\vGadgetWidth\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\rGadgetWidth3D\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\aGadgetX\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\tGadgetX3D\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\aGadgetY\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\tGadgetY3D\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SIGetActiveGadget\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC1GetActiveGadget3D\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SIGetActiveWindow\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC1GetActiveWindow3D\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\vGetClientIP\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\rGetClientPort\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC1GetClipboardImage\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DLEGetClipboardText\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC3GetCurrentDirectory\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SIGetDatabaseBlob\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC1GetDatabaseDouble\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DLEGetDatabaseFloat\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SIGetDatabaseLong\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SIGetDatabaseQuad\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC1GetDatabaseString\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\CANGetEntityAnimationLength\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SYNGetEntityAnimationTime\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\CANGetEntityAnimationWeight\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC2GetEntityAttribute\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETBGetEntityCollisionGroup\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SYNGetEntityCollisionMask\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SYNGetEnvironmentVariable\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DLEGetExtensionPart\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SIGetFTPDirectory\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC1GetFileAttributes\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\vGetFileDate\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\vGetFilePart\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\vGetFunction\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DLEGetFunctionEntry\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC2GetGadgetAttribute\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC4GetGadgetAttribute3D\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOGetGadgetColor\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\rGetGadgetData\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SIGetGadgetData3D\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\rGetGadgetFont\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SYNGetGadgetItemAttribute\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC2GetGadgetItemColor\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC1GetGadgetItemData\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC3GetGadgetItemData3D\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC2GetGadgetItemState\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC4GetGadgetItemState3D\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC1GetGadgetItemText\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC3GetGadgetItemText3D\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOGetGadgetState\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DLEGetGadgetState3D\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\rGetGadgetText\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SIGetGadgetText3D\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\rGetHTTPHeader\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DLEGetHomeDirectory\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOGetJSONBoolean\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\rGetJSONDouble\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOGetJSONElement\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\fGetJSONFloat\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOGetJSONInteger\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\rGetJSONMember\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\vGetJSONQuad\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\rGetJSONString\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC1GetJointAttribute\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\rGetLightColor\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DLEGetMailAttribute\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\vGetMailBody\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC4GetMaterialAttribute\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DLEGetMaterialColor\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DLEGetMenuItemState\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SIGetMenuItemText\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DLEGetMenuTitleText\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\vGetMeshData\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DLEGetMusicPosition\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\vGetMusicRow\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\FSGetNodeAnimationKeyFrameTime\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SYNGetNodeAnimationLength\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC4GetNodeAnimationTime\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SYNGetNodeAnimationWeight\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\nGetOriginX\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\nGetOriginY\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\vGetPathPart\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DLEGetRuntimeDouble\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC1GetRuntimeInteger\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DLEGetRuntimeString\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC1GetScriptMaterial\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\CANGetScriptParticleEmitter\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DLEGetScriptTexture\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC3GetSerialPortStatus\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC1GetSoundFrequency\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DLEGetSoundPosition\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NAKGetTemporaryDirectory\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ESCGetTerrainTileHeightAtPoint\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\CANGetTerrainTileLayerBlend\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NAKGetToolBarButtonState\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\nGetURLPart\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTGetW\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOGetWindowColor\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\rGetWindowData\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOGetWindowState\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOGetWindowTitle\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DLEGetWindowTitle3D\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTGetX\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SIGetXMLAttribute\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOGetXMLEncoding\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOGetXMLNodeName\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DLEGetXMLNodeOffset\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOGetXMLNodeText\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DLEGetXMLStandalone\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTGetY\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTGetZ\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DLEGrabDrawingImage\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\tGrabImage\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\nGrabSprite\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\rGradientColor\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQGreen\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETXHex\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC2HideBillboardGroup\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\nHideEffect\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\nHideEntity\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\nHideGadget\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\fHideGadget3D\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\tHideLight\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\bHideMenu\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC3HideParticleEmitter\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\nHideWindow\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\fHideWindow3D\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\nHingeJoint\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NAKHingeJointMotorTarget\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\bHostName\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTHour\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SIHyperLinkGadget\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOIPAddressField\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SIIPAddressGadget\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\bIPString\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\nImageDepth\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\vImageFormat\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\vImageGadget\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\rImageGadget3D\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\vImageHeight\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\aImageID\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\vImageOutput\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\nImageWidth\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\bInfinity\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\vInitAudioCD\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\fInitEngine3D\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\fInitJoystick\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\fInitKeyboard\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\tInitMouse\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\tInitMovie\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\vInitNetwork\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\rInitScintilla\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\tInitSound\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\nInitSprite\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQInkey\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQInput\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\fInputEvent3D\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOInputRequester\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\rInsertElement\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SIInsertJSONArray\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOInsertJSONList\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\rInsertJSONMap\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC3InsertJSONStructure\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\fInsertString\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOInsertXMLArray\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\rInsertXMLList\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\fInsertXMLMap\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC2InsertXMLStructure\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC2InstructionAddress\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC1InstructionString\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETXInt\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTIntQ\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DLEIsBillboardGroup\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\bIsCamera\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\nIsDatabase\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\bIsDialog\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\vIsDirectory\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\bIsEffect\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\bIsEntity\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKIsFile\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\rIsFingerprint\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKIsFont\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQIsFtp\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\bIsGadget\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\nIsGadget3D\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\aIsImage\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\nIsInfinity\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKIsJSON\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\tIsLibrary\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\aIsLight\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKIsMail\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\nIsMaterial\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKIsMenu\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKIsMesh\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\aIsMovie\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\aIsMusic\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQIsNaN\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKIsNode\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC1IsParticleEmitter\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\tIsProgram\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC3IsRegularExpression\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\tIsRuntime\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOIsScreenActive\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\fIsSerialPort\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\aIsSound\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\tIsSound3D\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\bIsSprite\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DLEIsStaticGeometry\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\vIsStatusBar\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\rIsSysTrayIcon\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\bIsText3D\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\tIsTexture\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\bIsThread\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\tIsToolBar\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\bIsWindow\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\nIsWindow3D\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQIsXML\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\rJSONArraySize\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\rJSONErrorLine\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DLEJSONErrorMessage\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC1JSONErrorPosition\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\rJSONMemberKey\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SIJSONMemberValue\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOJSONObjectSize\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\bJSONType\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\tJSONValue\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\rJoystickAxisX\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\rJoystickAxisY\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\rJoystickAxisZ\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOJoystickButton\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\fJoystickName\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\rKeyboardInkey\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\fKeyboardMode\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOKeyboardPushed\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DLEKeyboardReleased\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\vKillProgram\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\nKillThread\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQLCase\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTLSet\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQLTrim\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\vLastElement\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTLeft\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETXLen\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC4LensFlareEffectColor\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SYNLibraryFunctionAddress\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC3LibraryFunctionName\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\tLibraryID\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DLELightAttenuation\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOLightDirection\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SILightDirectionX\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SILightDirectionY\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SILightDirectionZ\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\aLightID\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\vLightLookAt\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\nLightPitch\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\tLightRoll\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKLightX\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKLightY\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\bLightYaw\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKLightZ\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTLine\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKLineXY\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOLinearGradient\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOListIconGadget\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\tListIndex\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\bListSize\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOListViewGadget\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DLEListViewGadget3D\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\bLoadFont\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\tLoadImage\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\bLoadJSON\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\bLoadMesh\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\tLoadMovie\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\tLoadMusic\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\tLoadSound\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\vLoadSound3D\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\nLoadSprite\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\vLoadTexture\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\tLoadWorld\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\aLoadXML\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETXLoc\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\tLockMutex\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETXLof\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETXLog\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQLog10\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC2MD5FileFingerprint\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOMD5Fingerprint\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\tMDIGadget\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\fMailProgress\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\vMainXMLNode\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\rMakeIPAddress\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKMapKey\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\aMapSize\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SYNMatchRegularExpression\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC4MaterialBlendingMode\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC3MaterialCullingMode\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NAKMaterialFilteringMode\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\vMaterialFog\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\nMaterialID\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC3MaterialShadingMode\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC1MaterialShininess\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\nMemorySize\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\fMemoryStatus\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC2MemoryStringLength\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\aMenuBar\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\nMenuHeight\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKMenuID\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\bMenuItem\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\tMenuTitle\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\nMergeLists\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\bMeshFace\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKMeshID\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\tMeshIndex\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOMeshIndexCount\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\rMeshPoseCount\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\fMeshPoseName\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\nMeshRadius\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SIMeshVertexColor\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SIMeshVertexCount\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DLEMeshVertexNormal\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC2MeshVertexPosition\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC1MeshVertexTangent\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ESCMeshVertexTextureCoordinate\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DLEMessageRequester\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETXMid\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKMinute\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETXMod\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQMonth\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\vMouseButton\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\vMouseDeltaX\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\vMouseDeltaY\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\vMouseLocate\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\tMousePick\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\fMouseRayCast\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\nMouseWheel\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKMouseX\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKMouseY\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\rMoveBillboard\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC2MoveBillboardGroup\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\nMoveCamera\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\vMoveElement\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\nMoveEntity\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOMoveEntityBone\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\tMoveLight\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\nMoveMemory\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\bMoveNode\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC3MoveParticleEmitter\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\nMoveText3D\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\vMoveXMLNode\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\nMovieAudio\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\vMovieHeight\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\tMovieInfo\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\vMovieLength\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\tMovieSeek\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\vMovieStatus\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\nMovieWidth\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\vMusicVolume\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETXNaN\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC2NetworkClientEvent\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC2NetworkServerEvent\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SONewPrinterPage\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC2NextDatabaseDriver\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SINextDatabaseRow\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC2NextDirectoryEntry\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\vNextElement\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETBNextEnvironmentVariable\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NAKNextFTPDirectoryEntry\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SINextFingerprint\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\rNextIPAddress\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SINextInstruction\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SONextJSONMember\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC3NextLibraryFunction\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SONextMapElement\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\rNextPackEntry\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC3NextPreferenceGroup\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC1NextPreferenceKey\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SUBNextRegularExpressionMatch\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SONextScreenMode\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC4NextSelectedFilename\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC2NextWorldCollision\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DLENextXMLAttribute\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\vNextXMLNode\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SUBNodeAnimationKeyFramePitch\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EMNodeAnimationKeyFrameRoll\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SYNNodeAnimationKeyFrameX\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SYNNodeAnimationKeyFrameY\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\CANNodeAnimationKeyFrameYaw\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SYNNodeAnimationKeyFrameZ\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC3NodeAnimationStatus\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DLENodeFixedYawAxis\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKNodeID\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\nNodeLookAt\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\tNodePitch\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\bNodeRoll\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQNodeX\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQNodeY\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\aNodeYaw\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQNodeZ\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\aNormalX\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\aNormalY\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\aNormalZ\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\rNormalizeMesh\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\tOSVersion\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\vOnErrorCall\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOOnErrorDefault\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\vOnErrorExit\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\vOnErrorGoto\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\vOpenConsole\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SIOpenCryptRandom\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\fOpenDatabase\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NAKOpenDatabaseRequester\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\aOpenFTP\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\bOpenFile\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC1OpenFileRequester\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\fOpenGLGadget\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOOpenGadgetList\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DLEOpenGadgetList3D\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\bOpenHelp\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\vOpenLibrary\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NAKOpenNetworkConnection\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\bOpenPack\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SIOpenPreferences\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\nOpenScreen\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOOpenSerialPort\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\vOpenSubMenu\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\nOpenWindow\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\fOpenWindow3D\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC2OpenWindowedScreen\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\rOpenXMLDialog\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\fOptionGadget\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOOptionGadget3D\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\vOutputDepth\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\fOutputHeight\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\vOutputWidth\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\rPackEntryName\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\rPackEntrySize\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\rPackEntryType\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\vPanelGadget\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\rPanelGadget3D\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\rParentXMLNode\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOParse3DScripts\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\tParseDate\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\tParseJSON\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\bParseXML\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC2ParticleColorFader\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC2ParticleColorRange\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC4ParticleEmissionRate\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\CANParticleEmitterDirection\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC1ParticleEmitterID\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DLEParticleEmitterX\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DLEParticleEmitterY\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DLEParticleEmitterZ\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DLEParticleMaterial\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\fParticleSize\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC3ParticleSpeedFactor\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC2ParticleTimeToLive\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DLEParticleVelocity\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\rPathRequester\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\fPauseAudioCD\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\nPauseMovie\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\nPauseSound\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\vPauseThread\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQPeekA\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQPeekB\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQPeekC\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQPeekD\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQPeekF\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQPeekI\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQPeekL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQPeekQ\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQPeekS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQPeekU\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQPeekW\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQPickX\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQPickY\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQPickZ\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQPitch\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\vPlayAudioCD\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\tPlayMovie\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\tPlayMusic\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\tPlaySound\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\vPlaySound3D\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTPlot\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQPoint\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\nPointJoint\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\tPointPick\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQPokeA\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQPokeB\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQPokeC\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQPokeD\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQPokeF\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQPokeI\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQPokeL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQPokeQ\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQPokeS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQPokeU\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQPokeW\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SIPopListPosition\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOPopMapPosition\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\tPostEvent\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETXPow\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC1PreferenceComment\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SIPreferenceGroup\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC3PreferenceGroupName\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC1PreferenceKeyName\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC2PreferenceKeyValue\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC3PreviousDatabaseRow\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SIPreviousElement\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SIPreviousXMLNode\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQPrint\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKPrintN\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOPrintRequester\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\rPrinterOutput\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC1PrinterPageHeight\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DLEPrinterPageWidth\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SIProgramExitCode\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SIProgramFilename\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\tProgramID\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DLEProgramParameter\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOProgramRunning\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC1ProgressBarGadget\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC3ProgressBarGadget3D\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC3PurifierGranularity\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DLEPushListPosition\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SIPushMapPosition\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETXRGB\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTRGBA\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTRSet\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQRTrim\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKRadian\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\nRaiseError\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKRandom\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\nRandomData\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\nRandomSeed\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SORandomizeArray\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\rRandomizeList\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKRawKey\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\aRayCast\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\nRayCollide\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\aRayPick\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DLEReAllocateMemory\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC2ReadAsciiCharacter\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\bReadByte\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\rReadCharacter\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SIReadConsoleData\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\bReadData\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\nReadDouble\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\bReadFile\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\tReadFloat\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\vReadInteger\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\bReadLong\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC4ReadPreferenceDouble\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC3ReadPreferenceFloat\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NAKReadPreferenceInteger\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC2ReadPreferenceLong\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC2ReadPreferenceQuad\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC4ReadPreferenceString\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SIReadProgramData\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DLEReadProgramError\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC1ReadProgramString\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\bReadQuad\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC2ReadSerialPortData\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\nReadString\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DLEReadStringFormat\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC4ReadUnicodeCharacter\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\bReadWord\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOReceiveFTPFile\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SIReceiveHTTPFile\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC2ReceiveNetworkData\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETXRed\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SYNRegularExpressionError\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SYNRegularExpressionGroup\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\FSRegularExpressionGroupLength\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\RSRegularExpressionGroupPosition\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\FSRegularExpressionMatchLength\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\RSRegularExpressionMatchPosition\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\FSRegularExpressionMatchString\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ESCRegularExpressionNamedGroup\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL!RegularExpressionNamedGroupLength\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL#RegularExpressionNamedGroupPosition\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\fReleaseMouse\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOReloadMaterial\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SIRemoveBillboard\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EMRemoveEnvironmentVariable\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC2RemoveGadgetColumn\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DLERemoveGadgetItem\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC2RemoveGadgetItem3D\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC1RemoveJSONElement\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DLERemoveJSONMember\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SYNRemoveKeyboardShortcut\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC3RemoveMailRecipient\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC3RemoveMaterialLayer\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SORemovePackFile\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NAKRemovePreferenceGroup\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC3RemovePreferenceKey\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\fRemoveString\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC1RemoveSysTrayIcon\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC1RemoveWindowTimer\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC2RemoveXMLAttribute\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\rRenameFTPFile\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\nRenameFile\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\vRenderWorld\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\CANReplaceRegularExpression\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\rReplaceString\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC3ResetGradientColors\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\tResetList\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\bResetMap\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\rResetMaterial\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\rResetProfiler\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SIResizeBillboard\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\fResizeGadget\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOResizeGadget3D\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\vResizeImage\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC2ResizeJSONElements\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\vResizeMovie\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NAKResizeParticleEmitter\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\fResizeWindow\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOResizeWindow3D\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETBResolveXMLAttributeName\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC2ResolveXMLNodeName\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\rResumeAudioCD\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\vResumeMovie\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\vResumeSound\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\fResumeThread\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\rReverseString\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC1RibbonEffectColor\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC1RibbonEffectWidth\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQRight\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTRoll\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\vRootXMLNode\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC4RotateBillboardGroup\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\fRotateCamera\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\fRotateEntity\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DLERotateEntityBone\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\vRotateLight\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SORotateMaterial\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\nRotateNode\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\fRotateSprite\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQRound\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\bRoundBox\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\nRunProgram\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC3SHA1FileFingerprint\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SISHA1Fingerprint\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SISaveDebugOutput\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC1SaveFileRequester\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\tSaveImage\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\bSaveJSON\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\bSaveMesh\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC1SaveRenderTexture\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\nSaveSprite\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\vSaveTerrain\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\aSaveXML\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\vScaleEntity\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\rScaleMaterial\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\tScaleNode\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\vScaleText3D\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SIScintillaGadget\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC4ScintillaSendMessage\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\vScreenDepth\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\fScreenHeight\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\bScreenID\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SIScreenModeDepth\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DLEScreenModeHeight\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NAKScreenModeRefreshRate\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SIScreenModeWidth\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\fScreenOutput\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\vScreenWidth\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DLEScrollAreaGadget\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC2ScrollAreaGadget3D\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SIScrollBarGadget\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC1ScrollBarGadget3D\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOScrollMaterial\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKSecond\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SUBSecondWorldCollisionEntity\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\rSelectElement\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC3SelectedFilePattern\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC1SelectedFontColor\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DLESelectedFontName\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DLESelectedFontSize\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC1SelectedFontStyle\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\vSendFTPFile\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\bSendMail\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SISendNetworkData\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC1SendNetworkString\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SISerialPortError\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\fSerialPortID\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC2SerialPortTimeouts\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\bServerID\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SISetActiveGadget\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC1SetActiveGadget3D\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SISetActiveWindow\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC1SetActiveWindow3D\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC1SetClipboardImage\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DLESetClipboardText\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC3SetCurrentDirectory\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SISetDatabaseBlob\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SISetDragCallback\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SISetDropCallback\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\CANSetEntityAnimationLength\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SYNSetEntityAnimationTime\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\CANSetEntityAnimationWeight\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC2SetEntityAttribute\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\CANSetEntityCollisionFilter\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC1SetEntityMaterial\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SYNSetEnvironmentVariable\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SISetFTPDirectory\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC1SetFileAttributes\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\vSetFileDate\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\fSetFrameRate\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\rSetGUITheme3D\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC2SetGadgetAttribute\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC4SetGadgetAttribute3D\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOSetGadgetColor\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\rSetGadgetData\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SISetGadgetData3D\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\rSetGadgetFont\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SYNSetGadgetItemAttribute\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC2SetGadgetItemColor\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC1SetGadgetItemData\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC3SetGadgetItemData3D\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC2SetGadgetItemImage\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC2SetGadgetItemState\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC4SetGadgetItemState3D\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC1SetGadgetItemText\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC3SetGadgetItemText3D\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOSetGadgetState\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DLESetGadgetState3D\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\rSetGadgetText\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SISetGadgetText3D\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\fSetJSONArray\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOSetJSONBoolean\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\rSetJSONDouble\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\fSetJSONFloat\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOSetJSONInteger\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\vSetJSONNull\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\rSetJSONObject\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\vSetJSONQuad\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\rSetJSONString\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC1SetJointAttribute\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\rSetLightColor\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DLESetMailAttribute\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\vSetMailBody\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC4SetMaterialAttribute\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DLESetMaterialColor\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DLESetMenuItemState\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SISetMenuItemText\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DLESetMenuTitleText\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\vSetMeshData\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SISetMeshMaterial\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DLESetMusicPosition\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL SetNodeAnimationKeyFramePosition\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL SetNodeAnimationKeyFrameRotation\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\GSSetNodeAnimationKeyFrameScale\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SYNSetNodeAnimationLength\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC4SetNodeAnimationTime\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SYNSetNodeAnimationWeight\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOSetOrientation\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\tSetOrigin\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOSetRenderQueue\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DLESetRuntimeDouble\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC1SetRuntimeInteger\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DLESetRuntimeString\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC3SetSerialPortStatus\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC1SetSoundFrequency\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DLESetSoundPosition\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ESCSetTerrainTileHeightAtPoint\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\CANSetTerrainTileLayerBlend\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NAKSetToolBarButtonState\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\nSetURLPart\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC1SetWindowCallback\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOSetWindowColor\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\rSetWindowData\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOSetWindowState\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOSetWindowTitle\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DLESetWindowTitle3D\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SISetXMLAttribute\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOSetXMLEncoding\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOSetXMLNodeName\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DLESetXMLNodeOffset\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOSetXMLNodeText\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DLESetXMLStandalone\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\rSetupTerrains\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOShortcutGadget\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC2ShowAssemblyViewer\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\rShowCallstack\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SIShowDebugOutput\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\aShowGUI\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC1ShowLibraryViewer\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DLEShowMemoryViewer\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\fShowProfiler\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC2ShowVariableViewer\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\rShowWatchlist\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTSign\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SISignalSemaphore\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETXSin\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTSinH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKSkyBox\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\aSkyDome\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\vSliderJoint\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC2SmartWindowRefresh\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\tSortArray\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\bSortList\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC3SortStructuredArray\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC2SortStructuredList\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\vSoundCone3D\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\tSoundID3D\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\vSoundLength\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC3SoundListenerLocate\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\bSoundPan\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\fSoundRange3D\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\vSoundStatus\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\vSoundVolume\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\rSoundVolume3D\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQSpace\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\nSpinGadget\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\fSpinGadget3D\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\fSplinePointX\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\fSplinePointY\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\fSplinePointZ\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\aSplineX\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\aSplineY\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\aSplineZ\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\tSplitList\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOSplitterGadget\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOSpotLightRange\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC2SpriteBlendingMode\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SISpriteCollision\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\vSpriteDepth\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\fSpriteHeight\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\bSpriteID\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\fSpriteOutput\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC4SpritePixelCollision\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\rSpriteQuality\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\vSpriteWidth\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETXSqr\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOStartAESCipher\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\fStartDrawing\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC4StartEntityAnimation\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC2StartNodeAnimation\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\rStartPrinting\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\rStartProfiler\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SIStatusBarHeight\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\vStatusBarID\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOStatusBarImage\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC1StatusBarProgress\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\rStatusBarText\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\fStickyWindow\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\vStopAudioCD\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\vStopDrawing\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC3StopEntityAnimation\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\tStopMovie\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\tStopMusic\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC1StopNodeAnimation\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\fStopPrinting\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\fStopProfiler\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\tStopSound\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\vStopSound3D\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETXStr\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTStrD\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTStrF\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTStrU\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DLEStringByteLength\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\vStringField\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\fStringGadget\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOStringGadget3D\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\fSubMeshCount\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETXSun\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\fSwapElements\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\fSwitchCamera\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC2SysTrayIconToolTip\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETXTan\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTTanH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\rTerrainHeight\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\rTerrainLocate\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DLETerrainMousePick\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC1TerrainPhysicBody\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC1TerrainRenderMode\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ESCTerrainTileHeightAtPosition\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETBTerrainTileLayerMapSize\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC1TerrainTilePointX\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC1TerrainTilePointY\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SITerrainTileSize\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SIText3DAlignment\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\rText3DCaption\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\vText3DColor\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\bText3DID\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\nTextGadget\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\fTextGadget3D\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\nTextHeight\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\tTextWidth\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\rTextureHeight\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\tTextureID\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\rTextureOutput\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\fTextureWidth\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\bThreadID\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOThreadPriority\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\rToolBarHeight\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\tToolBarID\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC2ToolBarImageButton\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DLEToolBarSeparator\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NAKToolBarStandardButton\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOToolBarToolTip\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOTrackBarGadget\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\rTransformMesh\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SITransformSprite\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SYNTransparentSpriteColor\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\nTreeGadget\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTTrim\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\fTruncateFile\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\fTryLockMutex\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\fTrySemaphore\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQUCase\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\nURLDecoder\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\nURLEncoder\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\vUnbindEvent\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC1UnbindGadgetEvent\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SIUnbindMenuEvent\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\fUnclipOutput\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DLEUncompressMemory\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC2UncompressPackFile\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC4UncompressPackMemory\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\vUnlockMutex\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NAKUpdateEntityAnimation\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\nUpdateMesh\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NAKUpdateMeshBoundingBox\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC3UpdateRenderTexture\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC1UpdateSplinePoint\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\rUpdateTerrain\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ESCUpdateTerrainTileLayerBlend\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EMUpdateVertexPoseReference\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\nUseAudioCD\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DLEUseBriefLZPacker\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC3UseFLACSoundDecoder\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\rUseGadgetList\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SIUseJCALG1Packer\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETBUseJPEG2000ImageDecoder\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETBUseJPEG2000ImageEncoder\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC3UseJPEGImageDecoder\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC3UseJPEGImageEncoder\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\rUseLZMAPacker\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SIUseODBCDatabase\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC2UseOGGSoundDecoder\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC2UsePNGImageDecoder\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC2UsePNGImageEncoder\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NAKUsePostgreSQLDatabase\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC1UseSQLiteDatabase\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC2UseTGAImageDecoder\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC3UseTIFFImageDecoder\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\fUseZipPacker\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\bUserName\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETXVal\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTValD\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTValF\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\CANVertexPoseReferenceCount\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\vWaitProgram\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\rWaitSemaphore\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\nWaitThread\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SIWaitWindowEvent\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\nWaterColor\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\vWaterHeight\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\tWebGadget\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\rWebGadgetPath\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\fWindowBounds\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\vWindowEvent\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\rWindowEvent3D\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\fWindowHeight\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOWindowHeight3D\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\bWindowID\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\nWindowID3D\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\fWindowMouseX\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\fWindowMouseY\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\fWindowOutput\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\vWindowWidth\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\rWindowWidth3D\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\aWindowX\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\tWindowX3D\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\aWindowY\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\tWindowY3D\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\FSWorldCollisionAppliedImpulse\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NAKWorldCollisionContact\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC4WorldCollisionNormal\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\nWorldDebug\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\fWorldGravity\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\fWorldShadows\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC3WriteAsciiCharacter\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\tWriteByte\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOWriteCharacter\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DLEWriteConsoleData\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\tWriteData\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\vWriteDouble\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\nWriteFloat\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\fWriteInteger\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\tWriteLong\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NAKWritePreferenceDouble\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC4WritePreferenceFloat\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SYNWritePreferenceInteger\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC3WritePreferenceLong\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC3WritePreferenceQuad\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NAKWritePreferenceString\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DLEWriteProgramData\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC2WriteProgramString\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC3WriteProgramStringN\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\tWriteQuad\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC3WriteSerialPortData\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NAKWriteSerialPortString\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\vWriteString\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC1WriteStringFormat\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\fWriteStringN\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NAKWriteUnicodeCharacter\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\tWriteWord\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DLEXMLAttributeName\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC1XMLAttributeValue\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\rXMLChildCount\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\bXMLError\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\fXMLErrorLine\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DLEXMLErrorPosition\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\rXMLNodeFromID\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SIXMLNodeFromPath\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\vXMLNodePath\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\vXMLNodeType\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\tXMLStatus\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETXYaw\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTYear\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\nZoomSprite\NUL\NUL\NUL\NUL\NUL\NUL\NUL\bkeywords\NUL\NUL\NUL\NUL\NUL\NUL\NUL;\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQBreak\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\bContinue\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETXFor\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\aForEach\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STXTo\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTStep\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTNext\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQGosub\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKReturn\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\nFakeReturn\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STXIf\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTElse\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKElseIf\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQEndIf\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKRepeat\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQUntil\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKSelect\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTCase\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\aDefault\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\tEndSelect\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQWhile\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTWend\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETXEnd\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\tStructure\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\fEndStructure\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\tInterface\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\fEndInterface\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\aExtends\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\aDefType\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETXDim\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\vEnumeration\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOEndEnumeration\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKGlobal\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\tProcedure\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\fEndProcedure\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SIProcedureReturn\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKShared\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\tProtected\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKStatic\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\aDeclare\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\vDataSection\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOEndDataSection\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTData\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\aRestore\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTRead\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\vIncludeFile\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\fXIncludeFile\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\rIncludeBinary\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\vIncludePath\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\fProcedureDLL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\aNewList\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTGoto\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTWith\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\rDeclareModule\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DLEEndDeclareModule\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKModule\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\tEndModule\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\tUseModule\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\vUnuseModule\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETX\NUL\NUL\NUL\NUL\NUL\NUL\NUL\bComment1\NUL\NUL\NUL\NUL\NUL\NUL\NUL\bComment1\NUL\NUL\NUL\NUL\NUL\NUL\NUL\tPureBasic\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STX\DLE\f\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SI\NUL\NUL\NUL\NUL\NUL\NUL\NUL\bComments\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\f\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\f\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKNormal\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKNormal\NUL\NUL\NUL\NUL\NUL\NUL\NUL\tPureBasic\NUL\NUL\NUL\NUL\NUL\NUL\NUL%\STX\NUL\NUL\NUL\NUL\NUL\NUL\NUL\r!%&*+-/<=>^|~\DC4\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STX\NUL\NUL\NUL\NUL\NUL\NUL\NUL\b(),.:[\\]\RS\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACK\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SO\\b(if)([\\s]|$)\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACK\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC1\\b(endif)([\\s]|$)\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACK\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC1\\b(while)([\\s]|$)\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACK\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DLE\\b(wend)([\\s]|$)\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACK\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC2\\b(repeat)([\\s]|$)\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACK\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC1\\b(until)([\\s]|$)\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACK\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC2\\b(select)([\\s]|$)\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACK\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NAK\\b(endselect)([\\s]|$)\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACK\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETB\\b(for|foreach)([\\s]|$)\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACK\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DLE\\b(next)([\\s]|$)\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACK\NUL\NUL\NUL\NUL\NUL\NUL\NUL#\\b(procedure|proceduredll)([.\\s]|$)\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACK\NUL\NUL\NUL\NUL\NUL\NUL\NUL\CAN\\b(endprocedure)([\\s]|$)\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACK\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NAK\\b(structure)([\\s]|$)\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACK\NUL\NUL\NUL\NUL\NUL\NUL\NUL\CAN\\b(endstructure)([\\s]|$)\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACK\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NAK\\b(interface)([\\s]|$)\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACK\NUL\NUL\NUL\NUL\NUL\NUL\NUL\CAN\\b(endinterface)([\\s]|$)\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACK\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETB\\b(enumeration)([\\s]|$)\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACK\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SUB\\b(endenumeration)([\\s]|$)\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACK\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETB\\b(datasection)([\\s]|$)\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACK\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SUB\\b(enddatasection)([\\s]|$)\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\a\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\FS\t\n !%&()*+,-./:;<=>?[\\]^{|}~\SOH\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL;\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQbreak\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTcase\NUL\NUL\NUL\NUL\NUL\NUL\NUL\bcontinue\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTdata\NUL\NUL\NUL\NUL\NUL\NUL\NUL\vdatasection\NUL\NUL\NUL\NUL\NUL\NUL\NUL\adeclare\NUL\NUL\NUL\NUL\NUL\NUL\NUL\rdeclaremodule\NUL\NUL\NUL\NUL\NUL\NUL\NUL\adefault\NUL\NUL\NUL\NUL\NUL\NUL\NUL\adeftype\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETXdim\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTelse\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKelseif\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETXend\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOenddatasection\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DLEenddeclaremodule\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOendenumeration\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQendif\NUL\NUL\NUL\NUL\NUL\NUL\NUL\fendinterface\NUL\NUL\NUL\NUL\NUL\NUL\NUL\tendmodule\NUL\NUL\NUL\NUL\NUL\NUL\NUL\fendprocedure\NUL\NUL\NUL\NUL\NUL\NUL\NUL\tendselect\NUL\NUL\NUL\NUL\NUL\NUL\NUL\fendstructure\NUL\NUL\NUL\NUL\NUL\NUL\NUL\venumeration\NUL\NUL\NUL\NUL\NUL\NUL\NUL\aextends\NUL\NUL\NUL\NUL\NUL\NUL\NUL\nfakereturn\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETXfor\NUL\NUL\NUL\NUL\NUL\NUL\NUL\aforeach\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKglobal\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQgosub\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTgoto\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STXif\NUL\NUL\NUL\NUL\NUL\NUL\NUL\rincludebinary\NUL\NUL\NUL\NUL\NUL\NUL\NUL\vincludefile\NUL\NUL\NUL\NUL\NUL\NUL\NUL\vincludepath\NUL\NUL\NUL\NUL\NUL\NUL\NUL\tinterface\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKmodule\NUL\NUL\NUL\NUL\NUL\NUL\NUL\anewlist\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTnext\NUL\NUL\NUL\NUL\NUL\NUL\NUL\tprocedure\NUL\NUL\NUL\NUL\NUL\NUL\NUL\fproceduredll\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SIprocedurereturn\NUL\NUL\NUL\NUL\NUL\NUL\NUL\tprotected\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTread\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKrepeat\NUL\NUL\NUL\NUL\NUL\NUL\NUL\arestore\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKreturn\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKselect\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKshared\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKstatic\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTstep\NUL\NUL\NUL\NUL\NUL\NUL\NUL\tstructure\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STXto\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQuntil\NUL\NUL\NUL\NUL\NUL\NUL\NUL\vunusemodule\NUL\NUL\NUL\NUL\NUL\NUL\NUL\tusemodule\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTwend\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQwhile\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTwith\NUL\NUL\NUL\NUL\NUL\NUL\NUL\fxincludefile\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACK\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SYN\\b(compilerif)([\\s]|$)\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACK\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EM\\b(compilerendif)([\\s]|$)\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACK\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SUB\\b(compilerselect)([\\s]|$)\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACK\NUL\NUL\NUL\NUL\NUL\NUL\NUL\GS\\b(compilerendselect)([\\s]|$)\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\a\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\FS\t\n !%&()*+,-./:;<=>?[\\]^{|}~\SOH\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\a\NUL\NUL\NUL\NUL\NUL\NUL\NUL\fcompilercase\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SIcompilerdefault\NUL\NUL\NUL\NUL\NUL\NUL\NUL\fcompilerelse\NUL\NUL\NUL\NUL\NUL\NUL\NUL\rcompilerendif\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC1compilerendselect\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ncompilerif\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOcompilerselect\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\a\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\FS\t\n !%&()*+,-./:;<=>?[\\]^{|}~\SOH\SOH\NUL\NUL\NUL\NUL\NUL\NUL\ACK9\NUL\NUL\NUL\NUL\NUL\NUL\NUL\fabortftpfile\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETXabs\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTacos\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQacosh\NUL\NUL\NUL\NUL\NUL\NUL\NUL\fadd3darchive\NUL\NUL\NUL\NUL\NUL\NUL\NUL\faddbillboard\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SIaddcipherbuffer\NUL\NUL\NUL\NUL\NUL\NUL\NUL\aadddate\NUL\NUL\NUL\NUL\NUL\NUL\NUL\naddelement\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SYNaddentityanimationtime\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SIaddgadgetcolumn\NUL\NUL\NUL\NUL\NUL\NUL\NUL\raddgadgetitem\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SIaddgadgetitem3d\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOaddjsonelement\NUL\NUL\NUL\NUL\NUL\NUL\NUL\raddjsonmember\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC3addkeyboardshortcut\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC1addmailattachment\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NAKaddmailattachmentdata\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DLEaddmailrecipient\NUL\NUL\NUL\NUL\NUL\NUL\NUL\raddmapelement\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DLEaddmateriallayer\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC4addnodeanimationtime\NUL\NUL\NUL\NUL\NUL\NUL\NUL\vaddpackfile\NUL\NUL\NUL\NUL\NUL\NUL\NUL\raddpackmemory\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOaddsplinepoint\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETBaddstaticgeometryentity\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC1addstatusbarfield\NUL\NUL\NUL\NUL\NUL\NUL\NUL\naddsubmesh\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOaddsystrayicon\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC1addterraintexture\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SYNaddvertexposereference\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOaddwindowtimer\NUL\NUL\NUL\NUL\NUL\NUL\NUL\naesdecoder\NUL\NUL\NUL\NUL\NUL\NUL\NUL\naesencoder\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC4affecteddatabaserows\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOallocatememory\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC1allocatestructure\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQalpha\NUL\NUL\NUL\NUL\NUL\NUL\NUL\nalphablend\NUL\NUL\NUL\NUL\NUL\NUL\NUL\fambientcolor\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DLEantialiasingmode\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DLEapplyentityforce\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC2applyentityimpulse\NUL\NUL\NUL\NUL\NUL\NUL\NUL\tarraysize\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETXasc\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTasin\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQasinh\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTatan\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQatan2\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQatanh\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC2attachentityobject\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DLEattachnodeobject\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC2attachribboneffect\NUL\NUL\NUL\NUL\NUL\NUL\NUL\raudiocdlength\NUL\NUL\NUL\NUL\NUL\NUL\NUL\vaudiocdname\NUL\NUL\NUL\NUL\NUL\NUL\NUL\raudiocdstatus\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC2audiocdtracklength\NUL\NUL\NUL\NUL\NUL\NUL\NUL\raudiocdtracks\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC3audiocdtrackseconds\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SYNavailableprogramoutput\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NAKavailablescreenmemory\NUL\NUL\NUL\NUL\NUL\NUL\NUL\CANavailableserialportinput\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EMavailableserialportoutput\NUL\NUL\NUL\NUL\NUL\NUL\NUL\tbackcolor\NUL\NUL\NUL\NUL\NUL\NUL\NUL\rbase64decoder\NUL\NUL\NUL\NUL\NUL\NUL\NUL\rbase64encoder\NUL\NUL\NUL\NUL\NUL\NUL\NUL\GSbillboardgroupcommondirection\NUL\NUL\NUL\NUL\NUL\NUL\NUL\FSbillboardgroupcommonupvector\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DLEbillboardgroupid\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SYNbillboardgroupmaterial\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SIbillboardgroupx\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SIbillboardgroupy\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SIbillboardgroupz\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SIbillboardheight\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SIbillboardlocate\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SObillboardwidth\NUL\NUL\NUL\NUL\NUL\NUL\NUL\nbillboardx\NUL\NUL\NUL\NUL\NUL\NUL\NUL\nbillboardy\NUL\NUL\NUL\NUL\NUL\NUL\NUL\nbillboardz\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETXbin\NUL\NUL\NUL\NUL\NUL\NUL\NUL\tbindevent\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SIbindgadgetevent\NUL\NUL\NUL\NUL\NUL\NUL\NUL\rbindmenuevent\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTblue\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETXbox\NUL\NUL\NUL\NUL\NUL\NUL\NUL\rboxedgradient\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NAKbuildmeshshadowvolume\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC1buildmeshtangents\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC3buildstaticgeometry\NUL\NUL\NUL\NUL\NUL\NUL\NUL\fbuildterrain\NUL\NUL\NUL\NUL\NUL\NUL\NUL\fbuttongadget\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SObuttongadget3d\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC1buttonimagegadget\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOcalendargadget\NUL\NUL\NUL\NUL\NUL\NUL\NUL\rcallcfunction\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC1callcfunctionfast\NUL\NUL\NUL\NUL\NUL\NUL\NUL\fcallfunction\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DLEcallfunctionfast\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SIcamerabackcolor\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SIcameradirection\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DLEcameradirectionx\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DLEcameradirectiony\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DLEcameradirectionz\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC2camerafixedyawaxis\NUL\NUL\NUL\NUL\NUL\NUL\NUL\fcamerafollow\NUL\NUL\NUL\NUL\NUL\NUL\NUL\tcamerafov\NUL\NUL\NUL\NUL\NUL\NUL\NUL\bcameraid\NUL\NUL\NUL\NUL\NUL\NUL\NUL\fcameralookat\NUL\NUL\NUL\NUL\NUL\NUL\NUL\vcamerapitch\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC4cameraprojectionmode\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC1cameraprojectionx\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC1cameraprojectiony\NUL\NUL\NUL\NUL\NUL\NUL\NUL\vcamerarange\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DLEcamerarendermode\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ncameraroll\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DLEcameraviewheight\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SIcameraviewwidth\NUL\NUL\NUL\NUL\NUL\NUL\NUL\vcameraviewx\NUL\NUL\NUL\NUL\NUL\NUL\NUL\vcameraviewy\NUL\NUL\NUL\NUL\NUL\NUL\NUL\acamerax\NUL\NUL\NUL\NUL\NUL\NUL\NUL\acameray\NUL\NUL\NUL\NUL\NUL\NUL\NUL\tcamerayaw\NUL\NUL\NUL\NUL\NUL\NUL\NUL\acameraz\NUL\NUL\NUL\NUL\NUL\NUL\NUL\fcanvasgadget\NUL\NUL\NUL\NUL\NUL\NUL\NUL\fcanvasoutput\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ncatchimage\NUL\NUL\NUL\NUL\NUL\NUL\NUL\tcatchjson\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ncatchmusic\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ncatchsound\NUL\NUL\NUL\NUL\NUL\NUL\NUL\vcatchsprite\NUL\NUL\NUL\NUL\NUL\NUL\NUL\bcatchxml\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC4changecurrentelement\NUL\NUL\NUL\NUL\NUL\NUL\NUL\vchangegamma\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ESCchangelisticongadgetdisplay\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC1changesystrayicon\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOcheckboxgadget\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DLEcheckboxgadget3d\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC1checkdatabasenull\NUL\NUL\NUL\NUL\NUL\NUL\NUL\rcheckfilename\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC2checkftpconnection\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NAKcheckobjectvisibility\NUL\NUL\NUL\NUL\NUL\NUL\NUL\fchildxmlnode\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETXchr\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKcircle\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DLEcirculargradient\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SIclearbillboards\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOclearclipboard\NUL\NUL\NUL\NUL\NUL\NUL\NUL\fclearconsole\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DLEcleardebugoutput\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC3cleargadgetitemlist\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DLEcleargadgetitems\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC2cleargadgetitems3d\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC1clearjsonelements\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DLEclearjsonmembers\NUL\NUL\NUL\NUL\NUL\NUL\NUL\tclearlist\NUL\NUL\NUL\NUL\NUL\NUL\NUL\bclearmap\NUL\NUL\NUL\NUL\NUL\NUL\NUL\vclearscreen\NUL\NUL\NUL\NUL\NUL\NUL\NUL\vclearspline\NUL\NUL\NUL\NUL\NUL\NUL\NUL\nclipoutput\NUL\NUL\NUL\NUL\NUL\NUL\NUL\nclipsprite\NUL\NUL\NUL\NUL\NUL\NUL\NUL\fcloseconsole\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DLEclosecryptrandom\NUL\NUL\NUL\NUL\NUL\NUL\NUL\rclosedatabase\NUL\NUL\NUL\NUL\NUL\NUL\NUL\tclosefile\NUL\NUL\NUL\NUL\NUL\NUL\NUL\bcloseftp\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SIclosegadgetlist\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC1closegadgetlist3d\NUL\NUL\NUL\NUL\NUL\NUL\NUL\tclosehelp\NUL\NUL\NUL\NUL\NUL\NUL\NUL\fcloselibrary\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SYNclosenetworkconnection\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC2closenetworkserver\NUL\NUL\NUL\NUL\NUL\NUL\NUL\tclosepack\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DLEclosepreferences\NUL\NUL\NUL\NUL\NUL\NUL\NUL\fcloseprogram\NUL\NUL\NUL\NUL\NUL\NUL\NUL\vclosescreen\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SIcloseserialport\NUL\NUL\NUL\NUL\NUL\NUL\NUL\fclosesubmenu\NUL\NUL\NUL\NUL\NUL\NUL\NUL\vclosewindow\NUL\NUL\NUL\NUL\NUL\NUL\NUL\rclosewindow3d\NUL\NUL\NUL\NUL\NUL\NUL\NUL\fcocoamessage\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOcolorrequester\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOcomboboxgadget\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DLEcomboboxgadget3d\NUL\NUL\NUL\NUL\NUL\NUL\NUL\rcomparememory\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC3comparememorystring\NUL\NUL\NUL\NUL\NUL\NUL\NUL\vcomposejson\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ncomposexml\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EMcompositoreffectparameter\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOcompressmemory\NUL\NUL\NUL\NUL\NUL\NUL\NUL\fcomputername\NUL\NUL\NUL\NUL\NUL\NUL\NUL\rcomputespline\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOconetwistjoint\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SIconicalgradient\NUL\NUL\NUL\NUL\NUL\NUL\NUL\fconnectionid\NUL\NUL\NUL\NUL\NUL\NUL\NUL\fconsolecolor\NUL\NUL\NUL\NUL\NUL\NUL\NUL\rconsolecursor\NUL\NUL\NUL\NUL\NUL\NUL\NUL\fconsoleerror\NUL\NUL\NUL\NUL\NUL\NUL\NUL\rconsolelocate\NUL\NUL\NUL\NUL\NUL\NUL\NUL\fconsoletitle\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SIcontainergadget\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC1containergadget3d\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ESCconvertlocaltoworldposition\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ESCconvertworldtolocalposition\NUL\NUL\NUL\NUL\NUL\NUL\NUL\tcopyarray\NUL\NUL\NUL\NUL\NUL\NUL\NUL\rcopydirectory\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ncopyentity\NUL\NUL\NUL\NUL\NUL\NUL\NUL\bcopyfile\NUL\NUL\NUL\NUL\NUL\NUL\NUL\tcopyimage\NUL\NUL\NUL\NUL\NUL\NUL\NUL\tcopylight\NUL\NUL\NUL\NUL\NUL\NUL\NUL\bcopylist\NUL\NUL\NUL\NUL\NUL\NUL\NUL\acopymap\NUL\NUL\NUL\NUL\NUL\NUL\NUL\fcopymaterial\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ncopymemory\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DLEcopymemorystring\NUL\NUL\NUL\NUL\NUL\NUL\NUL\bcopymesh\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ncopysprite\NUL\NUL\NUL\NUL\NUL\NUL\NUL\vcopytexture\NUL\NUL\NUL\NUL\NUL\NUL\NUL\vcopyxmlnode\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETXcos\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTcosh\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SIcountbillboards\NUL\NUL\NUL\NUL\NUL\NUL\NUL\tcountcpus\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DLEcountgadgetitems\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC2countgadgetitems3d\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NAKcountlibraryfunctions\NUL\NUL\NUL\NUL\NUL\NUL\NUL\tcountlist\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC3countmateriallayers\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SYNcountprogramparameters\NUL\NUL\NUL\NUL\NUL\NUL\NUL\FScountregularexpressiongroups\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC1countsplinepoints\NUL\NUL\NUL\NUL\NUL\NUL\NUL\vcountstring\NUL\NUL\NUL\NUL\NUL\NUL\NUL\acpuname\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC4crc32filefingerprint\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DLEcrc32fingerprint\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC4createbillboardgroup\NUL\NUL\NUL\NUL\NUL\NUL\NUL\fcreatecamera\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SYNcreatecompositoreffect\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ncreatecube\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC4createcubemaptexture\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOcreatecylinder\NUL\NUL\NUL\NUL\NUL\NUL\NUL\fcreatedialog\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SIcreatedirectory\NUL\NUL\NUL\NUL\NUL\NUL\NUL\fcreateentity\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ncreatefile\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC2createftpdirectory\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DLEcreategadgetlist\NUL\NUL\NUL\NUL\NUL\NUL\NUL\vcreateimage\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SIcreateimagemenu\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ncreatejson\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NAKcreatelensflareeffect\NUL\NUL\NUL\NUL\NUL\NUL\NUL\vcreatelight\NUL\NUL\NUL\NUL\NUL\NUL\NUL\fcreateline3d\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ncreatemail\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOcreatematerial\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ncreatemenu\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ncreatemesh\NUL\NUL\NUL\NUL\NUL\NUL\NUL\vcreatemutex\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC3createnetworkserver\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ncreatenode\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC3createnodeanimation\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ESCcreatenodeanimationkeyframe\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ncreatepack\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NAKcreateparticleemitter\NUL\NUL\NUL\NUL\NUL\NUL\NUL\vcreateplane\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC4createpopupimagemenu\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SIcreatepopupmenu\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC1createpreferences\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETBcreateregularexpression\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC3createrendertexture\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC2createribboneffect\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SIcreatesemaphore\NUL\NUL\NUL\NUL\NUL\NUL\NUL\fcreatesphere\NUL\NUL\NUL\NUL\NUL\NUL\NUL\fcreatespline\NUL\NUL\NUL\NUL\NUL\NUL\NUL\fcreatesprite\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC4createstaticgeometry\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SIcreatestatusbar\NUL\NUL\NUL\NUL\NUL\NUL\NUL\rcreateterrain\NUL\NUL\NUL\NUL\NUL\NUL\NUL\fcreatetext3d\NUL\NUL\NUL\NUL\NUL\NUL\NUL\rcreatetexture\NUL\NUL\NUL\NUL\NUL\NUL\NUL\fcreatethread\NUL\NUL\NUL\NUL\NUL\NUL\NUL\rcreatetoolbar\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NAKcreatevertexanimation\NUL\NUL\NUL\NUL\NUL\NUL\NUL\CANcreatevertexposekeyframe\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC1createvertextrack\NUL\NUL\NUL\NUL\NUL\NUL\NUL\vcreatewater\NUL\NUL\NUL\NUL\NUL\NUL\NUL\tcreatexml\NUL\NUL\NUL\NUL\NUL\NUL\NUL\rcreatexmlnode\NUL\NUL\NUL\NUL\NUL\NUL\NUL\vcryptrandom\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SIcryptrandomdata\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC4customfiltercallback\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOcustomgradient\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC3databasecolumnindex\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC2databasecolumnname\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SIdatabasecolumns\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC2databasecolumnsize\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC2databasecolumntype\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EMdatabasedriverdescription\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC2databasedrivername\NUL\NUL\NUL\NUL\NUL\NUL\NUL\rdatabaseerror\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ndatabaseid\NUL\NUL\NUL\NUL\NUL\NUL\NUL\rdatabasequery\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOdatabaseupdate\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTdate\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ndategadget\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETXday\NUL\NUL\NUL\NUL\NUL\NUL\NUL\tdayofweek\NUL\NUL\NUL\NUL\NUL\NUL\NUL\tdayofyear\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOdefaultprinter\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC1defineterraintile\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKdegree\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQdelay\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SIdeletedirectory\NUL\NUL\NUL\NUL\NUL\NUL\NUL\rdeleteelement\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ndeletefile\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC2deleteftpdirectory\NUL\NUL\NUL\NUL\NUL\NUL\NUL\rdeleteftpfile\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DLEdeletemapelement\NUL\NUL\NUL\NUL\NUL\NUL\NUL\rdeletexmlnode\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOdesfingerprint\NUL\NUL\NUL\NUL\NUL\NUL\NUL\fdesktopdepth\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DLEdesktopfrequency\NUL\NUL\NUL\NUL\NUL\NUL\NUL\rdesktopheight\NUL\NUL\NUL\NUL\NUL\NUL\NUL\rdesktopmousex\NUL\NUL\NUL\NUL\NUL\NUL\NUL\rdesktopmousey\NUL\NUL\NUL\NUL\NUL\NUL\NUL\vdesktopname\NUL\NUL\NUL\NUL\NUL\NUL\NUL\fdesktopwidth\NUL\NUL\NUL\NUL\NUL\NUL\NUL\bdesktopx\NUL\NUL\NUL\NUL\NUL\NUL\NUL\bdesktopy\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC2detachentityobject\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DLEdetachnodeobject\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC2detachribboneffect\NUL\NUL\NUL\NUL\NUL\NUL\NUL\vdialogerror\NUL\NUL\NUL\NUL\NUL\NUL\NUL\fdialoggadget\NUL\NUL\NUL\NUL\NUL\NUL\NUL\bdialogid\NUL\NUL\NUL\NUL\NUL\NUL\NUL\fdialogwindow\NUL\NUL\NUL\NUL\NUL\NUL\NUL\CANdirectoryentryattributes\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC2directoryentrydate\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC2directoryentryname\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC2directoryentrysize\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC2directoryentrytype\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC1disableentitybody\NUL\NUL\NUL\NUL\NUL\NUL\NUL\rdisablegadget\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SIdisablegadget3d\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC3disablelightshadows\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETBdisablemateriallighting\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SIdisablemenuitem\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SYNdisableparticleemitter\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC4disabletoolbarbutton\NUL\NUL\NUL\NUL\NUL\NUL\NUL\rdisablewindow\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SIdisablewindow3d\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DLEdisplaypopupmenu\NUL\NUL\NUL\NUL\NUL\NUL\NUL\rdisplaysprite\NUL\NUL\NUL\NUL\NUL\NUL\NUL\CANdisplaytransparentsprite\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SIdoubleclicktime\NUL\NUL\NUL\NUL\NUL\NUL\NUL\tdragfiles\NUL\NUL\NUL\NUL\NUL\NUL\NUL\tdragimage\NUL\NUL\NUL\NUL\NUL\NUL\NUL\rdragosformats\NUL\NUL\NUL\NUL\NUL\NUL\NUL\vdragprivate\NUL\NUL\NUL\NUL\NUL\NUL\NUL\bdragtext\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOdrawalphaimage\NUL\NUL\NUL\NUL\NUL\NUL\NUL\tdrawimage\NUL\NUL\NUL\NUL\NUL\NUL\NUL\rdrawingbuffer\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC2drawingbufferpitch\NUL\NUL\NUL\NUL\NUL\NUL\NUL\CANdrawingbufferpixelformat\NUL\NUL\NUL\NUL\NUL\NUL\NUL\vdrawingfont\NUL\NUL\NUL\NUL\NUL\NUL\NUL\vdrawingmode\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SIdrawrotatedtext\NUL\NUL\NUL\NUL\NUL\NUL\NUL\bdrawtext\NUL\NUL\NUL\NUL\NUL\NUL\NUL\feditorgadget\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOeditorgadget3d\NUL\NUL\NUL\NUL\NUL\NUL\NUL\fejectaudiocd\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC3elapsedmilliseconds\NUL\NUL\NUL\NUL\NUL\NUL\NUL\aellipse\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC2ellipticalgradient\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DLEenablegadgetdrop\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SYNenablegraphicalconsole\NUL\NUL\NUL\NUL\NUL\NUL\NUL\FSenablehingejointangularmotor\NUL\NUL\NUL\NUL\NUL\NUL\NUL\GSenablemanualentitybonecontrol\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DLEenablewindowdrop\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NAKenableworldcollisions\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC2enableworldphysics\NUL\NUL\NUL\NUL\NUL\NUL\NUL\vencodeimage\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOengine3dstatus\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC3entityangularfactor\NUL\NUL\NUL\NUL\NUL\NUL\NUL\CANentityanimationblendmode\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NAKentityanimationstatus\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SIentitybonepitch\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOentityboneroll\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ventitybonex\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ventityboney\NUL\NUL\NUL\NUL\NUL\NUL\NUL\rentityboneyaw\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ventitybonez\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC1entityboundingbox\NUL\NUL\NUL\NUL\NUL\NUL\NUL\rentitycollide\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC4entitycubemaptexture\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NAKentitycustomparameter\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC2entityfixedyawaxis\NUL\NUL\NUL\NUL\NUL\NUL\NUL\bentityid\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC2entitylinearfactor\NUL\NUL\NUL\NUL\NUL\NUL\NUL\fentitylookat\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DLEentityparentnode\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DLEentityphysicbody\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ventitypitch\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DLEentityrendermode\NUL\NUL\NUL\NUL\NUL\NUL\NUL\nentityroll\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOentityvelocity\NUL\NUL\NUL\NUL\NUL\NUL\NUL\aentityx\NUL\NUL\NUL\NUL\NUL\NUL\NUL\aentityy\NUL\NUL\NUL\NUL\NUL\NUL\NUL\tentityyaw\NUL\NUL\NUL\NUL\NUL\NUL\NUL\aentityz\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETBenvironmentvariablename\NUL\NUL\NUL\NUL\NUL\NUL\NUL\CANenvironmentvariablevalue\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETXeof\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ferroraddress\NUL\NUL\NUL\NUL\NUL\NUL\NUL\terrorcode\NUL\NUL\NUL\NUL\NUL\NUL\NUL\terrorfile\NUL\NUL\NUL\NUL\NUL\NUL\NUL\terrorline\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ferrormessage\NUL\NUL\NUL\NUL\NUL\NUL\NUL\rerrorregister\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC2errortargetaddress\NUL\NUL\NUL\NUL\NUL\NUL\NUL\veventclient\NUL\NUL\NUL\NUL\NUL\NUL\NUL\teventdata\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SIeventdropaction\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SIeventdropbuffer\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOeventdropfiles\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOeventdropimage\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DLEeventdropprivate\NUL\NUL\NUL\NUL\NUL\NUL\NUL\reventdropsize\NUL\NUL\NUL\NUL\NUL\NUL\NUL\reventdroptext\NUL\NUL\NUL\NUL\NUL\NUL\NUL\reventdroptype\NUL\NUL\NUL\NUL\NUL\NUL\NUL\neventdropx\NUL\NUL\NUL\NUL\NUL\NUL\NUL\neventdropy\NUL\NUL\NUL\NUL\NUL\NUL\NUL\veventgadget\NUL\NUL\NUL\NUL\NUL\NUL\NUL\reventgadget3d\NUL\NUL\NUL\NUL\NUL\NUL\NUL\veventlparam\NUL\NUL\NUL\NUL\NUL\NUL\NUL\teventmenu\NUL\NUL\NUL\NUL\NUL\NUL\NUL\veventserver\NUL\NUL\NUL\NUL\NUL\NUL\NUL\neventtimer\NUL\NUL\NUL\NUL\NUL\NUL\NUL\teventtype\NUL\NUL\NUL\NUL\NUL\NUL\NUL\veventtype3d\NUL\NUL\NUL\NUL\NUL\NUL\NUL\veventwindow\NUL\NUL\NUL\NUL\NUL\NUL\NUL\reventwindow3d\NUL\NUL\NUL\NUL\NUL\NUL\NUL\veventwparam\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SIexamineassembly\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SYNexaminedatabasedrivers\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SIexaminedesktops\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DLEexaminedirectory\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ESCexamineenvironmentvariables\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC3examineftpdirectory\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC2examineipaddresses\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SIexaminejoystick\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC2examinejsonmembers\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SIexaminekeyboard\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETBexaminelibraryfunctions\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NAKexaminemd5fingerprint\NUL\NUL\NUL\NUL\NUL\NUL\NUL\fexaminemouse\NUL\NUL\NUL\NUL\NUL\NUL\NUL\vexaminepack\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETBexaminepreferencegroups\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NAKexaminepreferencekeys\NUL\NUL\NUL\NUL\NUL\NUL\NUL\CANexamineregularexpression\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC2examinescreenmodes\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SYNexaminesha1fingerprint\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SYNexamineworldcollisions\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC4examinexmlattributes\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETXexp\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC3explorercombogadget\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC2explorerlistgadget\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC2explorertreegadget\NUL\NUL\NUL\NUL\NUL\NUL\NUL\nexportjson\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOexportjsonsize\NUL\NUL\NUL\NUL\NUL\NUL\NUL\texportxml\NUL\NUL\NUL\NUL\NUL\NUL\NUL\rexportxmlsize\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DLEextractjsonarray\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SIextractjsonlist\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOextractjsonmap\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC4extractjsonstructure\NUL\NUL\NUL\NUL\NUL\NUL\NUL\CANextractregularexpression\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SIextractxmlarray\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOextractxmllist\NUL\NUL\NUL\NUL\NUL\NUL\NUL\rextractxmlmap\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC3extractxmlstructure\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC3fetchentitymaterial\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DLEfetchorientation\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SIfilebufferssize\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKfileid\NUL\NUL\NUL\NUL\NUL\NUL\NUL\bfileseek\NUL\NUL\NUL\NUL\NUL\NUL\NUL\bfilesize\NUL\NUL\NUL\NUL\NUL\NUL\NUL\bfillarea\NUL\NUL\NUL\NUL\NUL\NUL\NUL\nfillmemory\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOfindmapelement\NUL\NUL\NUL\NUL\NUL\NUL\NUL\nfindstring\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ffinishcipher\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC3finishdatabasequery\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SIfinishdirectory\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC1finishfingerprint\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC2finishftpdirectory\NUL\NUL\NUL\NUL\NUL\NUL\NUL\nfinishmesh\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DLEfirstdatabaserow\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ffirstelement\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EMfirstworldcollisionentity\NUL\NUL\NUL\NUL\NUL\NUL\NUL\vflipbuffers\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DLEflushfilebuffers\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETXfog\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKfontid\NUL\NUL\NUL\NUL\NUL\NUL\NUL\rfontrequester\NUL\NUL\NUL\NUL\NUL\NUL\NUL\nformatdate\NUL\NUL\NUL\NUL\NUL\NUL\NUL\tformatxml\NUL\NUL\NUL\NUL\NUL\NUL\NUL\vframegadget\NUL\NUL\NUL\NUL\NUL\NUL\NUL\rframegadget3d\NUL\NUL\NUL\NUL\NUL\NUL\NUL\tfreearray\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC2freebillboardgroup\NUL\NUL\NUL\NUL\NUL\NUL\NUL\nfreecamera\NUL\NUL\NUL\NUL\NUL\NUL\NUL\nfreedialog\NUL\NUL\NUL\NUL\NUL\NUL\NUL\nfreeeffect\NUL\NUL\NUL\NUL\NUL\NUL\NUL\nfreeentity\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DLEfreeentityjoints\NUL\NUL\NUL\NUL\NUL\NUL\NUL\bfreefont\NUL\NUL\NUL\NUL\NUL\NUL\NUL\nfreegadget\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ffreegadget3d\NUL\NUL\NUL\NUL\NUL\NUL\NUL\tfreeimage\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKfreeip\NUL\NUL\NUL\NUL\NUL\NUL\NUL\tfreejoint\NUL\NUL\NUL\NUL\NUL\NUL\NUL\bfreejson\NUL\NUL\NUL\NUL\NUL\NUL\NUL\tfreelight\NUL\NUL\NUL\NUL\NUL\NUL\NUL\bfreelist\NUL\NUL\NUL\NUL\NUL\NUL\NUL\bfreemail\NUL\NUL\NUL\NUL\NUL\NUL\NUL\afreemap\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ffreematerial\NUL\NUL\NUL\NUL\NUL\NUL\NUL\nfreememory\NUL\NUL\NUL\NUL\NUL\NUL\NUL\bfreemenu\NUL\NUL\NUL\NUL\NUL\NUL\NUL\bfreemesh\NUL\NUL\NUL\NUL\NUL\NUL\NUL\tfreemovie\NUL\NUL\NUL\NUL\NUL\NUL\NUL\tfreemusic\NUL\NUL\NUL\NUL\NUL\NUL\NUL\tfreemutex\NUL\NUL\NUL\NUL\NUL\NUL\NUL\bfreenode\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC1freenodeanimation\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC3freeparticleemitter\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NAKfreeregularexpression\NUL\NUL\NUL\NUL\NUL\NUL\NUL\rfreesemaphore\NUL\NUL\NUL\NUL\NUL\NUL\NUL\tfreesound\NUL\NUL\NUL\NUL\NUL\NUL\NUL\vfreesound3d\NUL\NUL\NUL\NUL\NUL\NUL\NUL\nfreespline\NUL\NUL\NUL\NUL\NUL\NUL\NUL\nfreesprite\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC2freestaticgeometry\NUL\NUL\NUL\NUL\NUL\NUL\NUL\rfreestatusbar\NUL\NUL\NUL\NUL\NUL\NUL\NUL\rfreestructure\NUL\NUL\NUL\NUL\NUL\NUL\NUL\vfreeterrain\NUL\NUL\NUL\NUL\NUL\NUL\NUL\nfreetext3d\NUL\NUL\NUL\NUL\NUL\NUL\NUL\vfreetexture\NUL\NUL\NUL\NUL\NUL\NUL\NUL\vfreetoolbar\NUL\NUL\NUL\NUL\NUL\NUL\NUL\tfreewater\NUL\NUL\NUL\NUL\NUL\NUL\NUL\afreexml\NUL\NUL\NUL\NUL\NUL\NUL\NUL\nfrontcolor\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ESCftpdirectoryentryattributes\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NAKftpdirectoryentrydate\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NAKftpdirectoryentryname\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC4ftpdirectoryentryraw\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NAKftpdirectoryentrysize\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NAKftpdirectoryentrytype\NUL\NUL\NUL\NUL\NUL\NUL\NUL\vftpprogress\NUL\NUL\NUL\NUL\NUL\NUL\NUL\fgadgetheight\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOgadgetheight3d\NUL\NUL\NUL\NUL\NUL\NUL\NUL\bgadgetid\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ngadgetid3d\NUL\NUL\NUL\NUL\NUL\NUL\NUL\fgadgetitemid\NUL\NUL\NUL\NUL\NUL\NUL\NUL\rgadgettooltip\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SIgadgettooltip3d\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ngadgettype\NUL\NUL\NUL\NUL\NUL\NUL\NUL\fgadgettype3d\NUL\NUL\NUL\NUL\NUL\NUL\NUL\vgadgetwidth\NUL\NUL\NUL\NUL\NUL\NUL\NUL\rgadgetwidth3d\NUL\NUL\NUL\NUL\NUL\NUL\NUL\agadgetx\NUL\NUL\NUL\NUL\NUL\NUL\NUL\tgadgetx3d\NUL\NUL\NUL\NUL\NUL\NUL\NUL\agadgety\NUL\NUL\NUL\NUL\NUL\NUL\NUL\tgadgety3d\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SIgetactivegadget\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC1getactivegadget3d\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SIgetactivewindow\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC1getactivewindow3d\NUL\NUL\NUL\NUL\NUL\NUL\NUL\vgetclientip\NUL\NUL\NUL\NUL\NUL\NUL\NUL\rgetclientport\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC1getclipboardimage\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DLEgetclipboardtext\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC3getcurrentdirectory\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SIgetdatabaseblob\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC1getdatabasedouble\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DLEgetdatabasefloat\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SIgetdatabaselong\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SIgetdatabasequad\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC1getdatabasestring\NUL\NUL\NUL\NUL\NUL\NUL\NUL\CANgetentityanimationlength\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SYNgetentityanimationtime\NUL\NUL\NUL\NUL\NUL\NUL\NUL\CANgetentityanimationweight\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC2getentityattribute\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETBgetentitycollisiongroup\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SYNgetentitycollisionmask\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SYNgetenvironmentvariable\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DLEgetextensionpart\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC1getfileattributes\NUL\NUL\NUL\NUL\NUL\NUL\NUL\vgetfiledate\NUL\NUL\NUL\NUL\NUL\NUL\NUL\vgetfilepart\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SIgetftpdirectory\NUL\NUL\NUL\NUL\NUL\NUL\NUL\vgetfunction\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DLEgetfunctionentry\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC2getgadgetattribute\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC4getgadgetattribute3d\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOgetgadgetcolor\NUL\NUL\NUL\NUL\NUL\NUL\NUL\rgetgadgetdata\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SIgetgadgetdata3d\NUL\NUL\NUL\NUL\NUL\NUL\NUL\rgetgadgetfont\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SYNgetgadgetitemattribute\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC2getgadgetitemcolor\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC1getgadgetitemdata\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC3getgadgetitemdata3d\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC2getgadgetitemstate\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC4getgadgetitemstate3d\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC1getgadgetitemtext\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC3getgadgetitemtext3d\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOgetgadgetstate\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DLEgetgadgetstate3d\NUL\NUL\NUL\NUL\NUL\NUL\NUL\rgetgadgettext\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SIgetgadgettext3d\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DLEgethomedirectory\NUL\NUL\NUL\NUL\NUL\NUL\NUL\rgethttpheader\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC1getjointattribute\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOgetjsonboolean\NUL\NUL\NUL\NUL\NUL\NUL\NUL\rgetjsondouble\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOgetjsonelement\NUL\NUL\NUL\NUL\NUL\NUL\NUL\fgetjsonfloat\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOgetjsoninteger\NUL\NUL\NUL\NUL\NUL\NUL\NUL\rgetjsonmember\NUL\NUL\NUL\NUL\NUL\NUL\NUL\vgetjsonquad\NUL\NUL\NUL\NUL\NUL\NUL\NUL\rgetjsonstring\NUL\NUL\NUL\NUL\NUL\NUL\NUL\rgetlightcolor\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DLEgetmailattribute\NUL\NUL\NUL\NUL\NUL\NUL\NUL\vgetmailbody\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC4getmaterialattribute\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DLEgetmaterialcolor\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DLEgetmenuitemstate\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SIgetmenuitemtext\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DLEgetmenutitletext\NUL\NUL\NUL\NUL\NUL\NUL\NUL\vgetmeshdata\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DLEgetmusicposition\NUL\NUL\NUL\NUL\NUL\NUL\NUL\vgetmusicrow\NUL\NUL\NUL\NUL\NUL\NUL\NUL\FSgetnodeanimationkeyframetime\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SYNgetnodeanimationlength\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC4getnodeanimationtime\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SYNgetnodeanimationweight\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ngetoriginx\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ngetoriginy\NUL\NUL\NUL\NUL\NUL\NUL\NUL\vgetpathpart\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DLEgetruntimedouble\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC1getruntimeinteger\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DLEgetruntimestring\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC1getscriptmaterial\NUL\NUL\NUL\NUL\NUL\NUL\NUL\CANgetscriptparticleemitter\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DLEgetscripttexture\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC3getserialportstatus\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC1getsoundfrequency\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DLEgetsoundposition\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NAKgettemporarydirectory\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ESCgetterraintileheightatpoint\NUL\NUL\NUL\NUL\NUL\NUL\NUL\CANgetterraintilelayerblend\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NAKgettoolbarbuttonstate\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ngeturlpart\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTgetw\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOgetwindowcolor\NUL\NUL\NUL\NUL\NUL\NUL\NUL\rgetwindowdata\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOgetwindowstate\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOgetwindowtitle\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DLEgetwindowtitle3d\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTgetx\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SIgetxmlattribute\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOgetxmlencoding\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOgetxmlnodename\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DLEgetxmlnodeoffset\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOgetxmlnodetext\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DLEgetxmlstandalone\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTgety\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTgetz\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DLEgrabdrawingimage\NUL\NUL\NUL\NUL\NUL\NUL\NUL\tgrabimage\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ngrabsprite\NUL\NUL\NUL\NUL\NUL\NUL\NUL\rgradientcolor\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQgreen\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETXhex\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC2hidebillboardgroup\NUL\NUL\NUL\NUL\NUL\NUL\NUL\nhideeffect\NUL\NUL\NUL\NUL\NUL\NUL\NUL\nhideentity\NUL\NUL\NUL\NUL\NUL\NUL\NUL\nhidegadget\NUL\NUL\NUL\NUL\NUL\NUL\NUL\fhidegadget3d\NUL\NUL\NUL\NUL\NUL\NUL\NUL\thidelight\NUL\NUL\NUL\NUL\NUL\NUL\NUL\bhidemenu\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC3hideparticleemitter\NUL\NUL\NUL\NUL\NUL\NUL\NUL\nhidewindow\NUL\NUL\NUL\NUL\NUL\NUL\NUL\fhidewindow3d\NUL\NUL\NUL\NUL\NUL\NUL\NUL\nhingejoint\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NAKhingejointmotortarget\NUL\NUL\NUL\NUL\NUL\NUL\NUL\bhostname\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOThour\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SIhyperlinkgadget\NUL\NUL\NUL\NUL\NUL\NUL\NUL\nimagedepth\NUL\NUL\NUL\NUL\NUL\NUL\NUL\vimageformat\NUL\NUL\NUL\NUL\NUL\NUL\NUL\vimagegadget\NUL\NUL\NUL\NUL\NUL\NUL\NUL\rimagegadget3d\NUL\NUL\NUL\NUL\NUL\NUL\NUL\vimageheight\NUL\NUL\NUL\NUL\NUL\NUL\NUL\aimageid\NUL\NUL\NUL\NUL\NUL\NUL\NUL\vimageoutput\NUL\NUL\NUL\NUL\NUL\NUL\NUL\nimagewidth\NUL\NUL\NUL\NUL\NUL\NUL\NUL\binfinity\NUL\NUL\NUL\NUL\NUL\NUL\NUL\vinitaudiocd\NUL\NUL\NUL\NUL\NUL\NUL\NUL\finitengine3d\NUL\NUL\NUL\NUL\NUL\NUL\NUL\finitjoystick\NUL\NUL\NUL\NUL\NUL\NUL\NUL\finitkeyboard\NUL\NUL\NUL\NUL\NUL\NUL\NUL\tinitmouse\NUL\NUL\NUL\NUL\NUL\NUL\NUL\tinitmovie\NUL\NUL\NUL\NUL\NUL\NUL\NUL\vinitnetwork\NUL\NUL\NUL\NUL\NUL\NUL\NUL\rinitscintilla\NUL\NUL\NUL\NUL\NUL\NUL\NUL\tinitsound\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ninitsprite\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQinkey\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQinput\NUL\NUL\NUL\NUL\NUL\NUL\NUL\finputevent3d\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOinputrequester\NUL\NUL\NUL\NUL\NUL\NUL\NUL\rinsertelement\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SIinsertjsonarray\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOinsertjsonlist\NUL\NUL\NUL\NUL\NUL\NUL\NUL\rinsertjsonmap\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC3insertjsonstructure\NUL\NUL\NUL\NUL\NUL\NUL\NUL\finsertstring\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOinsertxmlarray\NUL\NUL\NUL\NUL\NUL\NUL\NUL\rinsertxmllist\NUL\NUL\NUL\NUL\NUL\NUL\NUL\finsertxmlmap\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC2insertxmlstructure\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC2instructionaddress\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC1instructionstring\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETXint\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTintq\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOipaddressfield\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SIipaddressgadget\NUL\NUL\NUL\NUL\NUL\NUL\NUL\bipstring\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DLEisbillboardgroup\NUL\NUL\NUL\NUL\NUL\NUL\NUL\biscamera\NUL\NUL\NUL\NUL\NUL\NUL\NUL\nisdatabase\NUL\NUL\NUL\NUL\NUL\NUL\NUL\bisdialog\NUL\NUL\NUL\NUL\NUL\NUL\NUL\visdirectory\NUL\NUL\NUL\NUL\NUL\NUL\NUL\biseffect\NUL\NUL\NUL\NUL\NUL\NUL\NUL\bisentity\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKisfile\NUL\NUL\NUL\NUL\NUL\NUL\NUL\risfingerprint\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKisfont\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQisftp\NUL\NUL\NUL\NUL\NUL\NUL\NUL\bisgadget\NUL\NUL\NUL\NUL\NUL\NUL\NUL\nisgadget3d\NUL\NUL\NUL\NUL\NUL\NUL\NUL\aisimage\NUL\NUL\NUL\NUL\NUL\NUL\NUL\nisinfinity\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKisjson\NUL\NUL\NUL\NUL\NUL\NUL\NUL\tislibrary\NUL\NUL\NUL\NUL\NUL\NUL\NUL\aislight\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKismail\NUL\NUL\NUL\NUL\NUL\NUL\NUL\nismaterial\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKismenu\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKismesh\NUL\NUL\NUL\NUL\NUL\NUL\NUL\aismovie\NUL\NUL\NUL\NUL\NUL\NUL\NUL\aismusic\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQisnan\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKisnode\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC1isparticleemitter\NUL\NUL\NUL\NUL\NUL\NUL\NUL\tisprogram\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC3isregularexpression\NUL\NUL\NUL\NUL\NUL\NUL\NUL\tisruntime\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOisscreenactive\NUL\NUL\NUL\NUL\NUL\NUL\NUL\fisserialport\NUL\NUL\NUL\NUL\NUL\NUL\NUL\aissound\NUL\NUL\NUL\NUL\NUL\NUL\NUL\tissound3d\NUL\NUL\NUL\NUL\NUL\NUL\NUL\bissprite\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DLEisstaticgeometry\NUL\NUL\NUL\NUL\NUL\NUL\NUL\visstatusbar\NUL\NUL\NUL\NUL\NUL\NUL\NUL\rissystrayicon\NUL\NUL\NUL\NUL\NUL\NUL\NUL\bistext3d\NUL\NUL\NUL\NUL\NUL\NUL\NUL\tistexture\NUL\NUL\NUL\NUL\NUL\NUL\NUL\bisthread\NUL\NUL\NUL\NUL\NUL\NUL\NUL\tistoolbar\NUL\NUL\NUL\NUL\NUL\NUL\NUL\biswindow\NUL\NUL\NUL\NUL\NUL\NUL\NUL\niswindow3d\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQisxml\NUL\NUL\NUL\NUL\NUL\NUL\NUL\rjoystickaxisx\NUL\NUL\NUL\NUL\NUL\NUL\NUL\rjoystickaxisy\NUL\NUL\NUL\NUL\NUL\NUL\NUL\rjoystickaxisz\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOjoystickbutton\NUL\NUL\NUL\NUL\NUL\NUL\NUL\fjoystickname\NUL\NUL\NUL\NUL\NUL\NUL\NUL\rjsonarraysize\NUL\NUL\NUL\NUL\NUL\NUL\NUL\rjsonerrorline\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DLEjsonerrormessage\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC1jsonerrorposition\NUL\NUL\NUL\NUL\NUL\NUL\NUL\rjsonmemberkey\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SIjsonmembervalue\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOjsonobjectsize\NUL\NUL\NUL\NUL\NUL\NUL\NUL\bjsontype\NUL\NUL\NUL\NUL\NUL\NUL\NUL\tjsonvalue\NUL\NUL\NUL\NUL\NUL\NUL\NUL\rkeyboardinkey\NUL\NUL\NUL\NUL\NUL\NUL\NUL\fkeyboardmode\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOkeyboardpushed\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DLEkeyboardreleased\NUL\NUL\NUL\NUL\NUL\NUL\NUL\vkillprogram\NUL\NUL\NUL\NUL\NUL\NUL\NUL\nkillthread\NUL\NUL\NUL\NUL\NUL\NUL\NUL\vlastelement\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQlcase\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTleft\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETXlen\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC4lensflareeffectcolor\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SYNlibraryfunctionaddress\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC3libraryfunctionname\NUL\NUL\NUL\NUL\NUL\NUL\NUL\tlibraryid\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DLElightattenuation\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOlightdirection\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SIlightdirectionx\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SIlightdirectiony\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SIlightdirectionz\NUL\NUL\NUL\NUL\NUL\NUL\NUL\alightid\NUL\NUL\NUL\NUL\NUL\NUL\NUL\vlightlookat\NUL\NUL\NUL\NUL\NUL\NUL\NUL\nlightpitch\NUL\NUL\NUL\NUL\NUL\NUL\NUL\tlightroll\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKlightx\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKlighty\NUL\NUL\NUL\NUL\NUL\NUL\NUL\blightyaw\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKlightz\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTline\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOlineargradient\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKlinexy\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOlisticongadget\NUL\NUL\NUL\NUL\NUL\NUL\NUL\tlistindex\NUL\NUL\NUL\NUL\NUL\NUL\NUL\blistsize\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOlistviewgadget\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DLElistviewgadget3d\NUL\NUL\NUL\NUL\NUL\NUL\NUL\bloadfont\NUL\NUL\NUL\NUL\NUL\NUL\NUL\tloadimage\NUL\NUL\NUL\NUL\NUL\NUL\NUL\bloadjson\NUL\NUL\NUL\NUL\NUL\NUL\NUL\bloadmesh\NUL\NUL\NUL\NUL\NUL\NUL\NUL\tloadmovie\NUL\NUL\NUL\NUL\NUL\NUL\NUL\tloadmusic\NUL\NUL\NUL\NUL\NUL\NUL\NUL\tloadsound\NUL\NUL\NUL\NUL\NUL\NUL\NUL\vloadsound3d\NUL\NUL\NUL\NUL\NUL\NUL\NUL\nloadsprite\NUL\NUL\NUL\NUL\NUL\NUL\NUL\vloadtexture\NUL\NUL\NUL\NUL\NUL\NUL\NUL\tloadworld\NUL\NUL\NUL\NUL\NUL\NUL\NUL\aloadxml\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETXloc\NUL\NUL\NUL\NUL\NUL\NUL\NUL\tlockmutex\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETXlof\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETXlog\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQlog10\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTlset\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQltrim\NUL\NUL\NUL\NUL\NUL\NUL\NUL\fmailprogress\NUL\NUL\NUL\NUL\NUL\NUL\NUL\vmainxmlnode\NUL\NUL\NUL\NUL\NUL\NUL\NUL\rmakeipaddress\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKmapkey\NUL\NUL\NUL\NUL\NUL\NUL\NUL\amapsize\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SYNmatchregularexpression\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC4materialblendingmode\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC3materialcullingmode\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NAKmaterialfilteringmode\NUL\NUL\NUL\NUL\NUL\NUL\NUL\vmaterialfog\NUL\NUL\NUL\NUL\NUL\NUL\NUL\nmaterialid\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC3materialshadingmode\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC1materialshininess\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC2md5filefingerprint\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOmd5fingerprint\NUL\NUL\NUL\NUL\NUL\NUL\NUL\tmdigadget\NUL\NUL\NUL\NUL\NUL\NUL\NUL\nmemorysize\NUL\NUL\NUL\NUL\NUL\NUL\NUL\fmemorystatus\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC2memorystringlength\NUL\NUL\NUL\NUL\NUL\NUL\NUL\amenubar\NUL\NUL\NUL\NUL\NUL\NUL\NUL\nmenuheight\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKmenuid\NUL\NUL\NUL\NUL\NUL\NUL\NUL\bmenuitem\NUL\NUL\NUL\NUL\NUL\NUL\NUL\tmenutitle\NUL\NUL\NUL\NUL\NUL\NUL\NUL\nmergelists\NUL\NUL\NUL\NUL\NUL\NUL\NUL\bmeshface\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKmeshid\NUL\NUL\NUL\NUL\NUL\NUL\NUL\tmeshindex\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOmeshindexcount\NUL\NUL\NUL\NUL\NUL\NUL\NUL\rmeshposecount\NUL\NUL\NUL\NUL\NUL\NUL\NUL\fmeshposename\NUL\NUL\NUL\NUL\NUL\NUL\NUL\nmeshradius\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SImeshvertexcolor\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SImeshvertexcount\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DLEmeshvertexnormal\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC2meshvertexposition\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC1meshvertextangent\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ESCmeshvertextexturecoordinate\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DLEmessagerequester\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETXmid\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKminute\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETXmod\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQmonth\NUL\NUL\NUL\NUL\NUL\NUL\NUL\vmousebutton\NUL\NUL\NUL\NUL\NUL\NUL\NUL\vmousedeltax\NUL\NUL\NUL\NUL\NUL\NUL\NUL\vmousedeltay\NUL\NUL\NUL\NUL\NUL\NUL\NUL\vmouselocate\NUL\NUL\NUL\NUL\NUL\NUL\NUL\tmousepick\NUL\NUL\NUL\NUL\NUL\NUL\NUL\fmouseraycast\NUL\NUL\NUL\NUL\NUL\NUL\NUL\nmousewheel\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKmousex\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKmousey\NUL\NUL\NUL\NUL\NUL\NUL\NUL\rmovebillboard\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC2movebillboardgroup\NUL\NUL\NUL\NUL\NUL\NUL\NUL\nmovecamera\NUL\NUL\NUL\NUL\NUL\NUL\NUL\vmoveelement\NUL\NUL\NUL\NUL\NUL\NUL\NUL\nmoveentity\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOmoveentitybone\NUL\NUL\NUL\NUL\NUL\NUL\NUL\tmovelight\NUL\NUL\NUL\NUL\NUL\NUL\NUL\nmovememory\NUL\NUL\NUL\NUL\NUL\NUL\NUL\bmovenode\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC3moveparticleemitter\NUL\NUL\NUL\NUL\NUL\NUL\NUL\nmovetext3d\NUL\NUL\NUL\NUL\NUL\NUL\NUL\vmovexmlnode\NUL\NUL\NUL\NUL\NUL\NUL\NUL\nmovieaudio\NUL\NUL\NUL\NUL\NUL\NUL\NUL\vmovieheight\NUL\NUL\NUL\NUL\NUL\NUL\NUL\tmovieinfo\NUL\NUL\NUL\NUL\NUL\NUL\NUL\vmovielength\NUL\NUL\NUL\NUL\NUL\NUL\NUL\tmovieseek\NUL\NUL\NUL\NUL\NUL\NUL\NUL\vmoviestatus\NUL\NUL\NUL\NUL\NUL\NUL\NUL\nmoviewidth\NUL\NUL\NUL\NUL\NUL\NUL\NUL\vmusicvolume\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETXnan\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC2networkclientevent\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC2networkserverevent\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOnewprinterpage\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC2nextdatabasedriver\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SInextdatabaserow\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC2nextdirectoryentry\NUL\NUL\NUL\NUL\NUL\NUL\NUL\vnextelement\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETBnextenvironmentvariable\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SInextfingerprint\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NAKnextftpdirectoryentry\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SInextinstruction\NUL\NUL\NUL\NUL\NUL\NUL\NUL\rnextipaddress\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOnextjsonmember\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC3nextlibraryfunction\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOnextmapelement\NUL\NUL\NUL\NUL\NUL\NUL\NUL\rnextpackentry\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC3nextpreferencegroup\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC1nextpreferencekey\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SUBnextregularexpressionmatch\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOnextscreenmode\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC4nextselectedfilename\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC2nextworldcollision\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DLEnextxmlattribute\NUL\NUL\NUL\NUL\NUL\NUL\NUL\vnextxmlnode\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SUBnodeanimationkeyframepitch\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EMnodeanimationkeyframeroll\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SYNnodeanimationkeyframex\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SYNnodeanimationkeyframey\NUL\NUL\NUL\NUL\NUL\NUL\NUL\CANnodeanimationkeyframeyaw\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SYNnodeanimationkeyframez\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC3nodeanimationstatus\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DLEnodefixedyawaxis\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKnodeid\NUL\NUL\NUL\NUL\NUL\NUL\NUL\nnodelookat\NUL\NUL\NUL\NUL\NUL\NUL\NUL\tnodepitch\NUL\NUL\NUL\NUL\NUL\NUL\NUL\bnoderoll\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQnodex\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQnodey\NUL\NUL\NUL\NUL\NUL\NUL\NUL\anodeyaw\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQnodez\NUL\NUL\NUL\NUL\NUL\NUL\NUL\rnormalizemesh\NUL\NUL\NUL\NUL\NUL\NUL\NUL\anormalx\NUL\NUL\NUL\NUL\NUL\NUL\NUL\anormaly\NUL\NUL\NUL\NUL\NUL\NUL\NUL\anormalz\NUL\NUL\NUL\NUL\NUL\NUL\NUL\vonerrorcall\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOonerrordefault\NUL\NUL\NUL\NUL\NUL\NUL\NUL\vonerrorexit\NUL\NUL\NUL\NUL\NUL\NUL\NUL\vonerrorgoto\NUL\NUL\NUL\NUL\NUL\NUL\NUL\vopenconsole\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SIopencryptrandom\NUL\NUL\NUL\NUL\NUL\NUL\NUL\fopendatabase\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NAKopendatabaserequester\NUL\NUL\NUL\NUL\NUL\NUL\NUL\bopenfile\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC1openfilerequester\NUL\NUL\NUL\NUL\NUL\NUL\NUL\aopenftp\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOopengadgetlist\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DLEopengadgetlist3d\NUL\NUL\NUL\NUL\NUL\NUL\NUL\fopenglgadget\NUL\NUL\NUL\NUL\NUL\NUL\NUL\bopenhelp\NUL\NUL\NUL\NUL\NUL\NUL\NUL\vopenlibrary\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NAKopennetworkconnection\NUL\NUL\NUL\NUL\NUL\NUL\NUL\bopenpack\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SIopenpreferences\NUL\NUL\NUL\NUL\NUL\NUL\NUL\nopenscreen\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOopenserialport\NUL\NUL\NUL\NUL\NUL\NUL\NUL\vopensubmenu\NUL\NUL\NUL\NUL\NUL\NUL\NUL\nopenwindow\NUL\NUL\NUL\NUL\NUL\NUL\NUL\fopenwindow3d\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC2openwindowedscreen\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ropenxmldialog\NUL\NUL\NUL\NUL\NUL\NUL\NUL\foptiongadget\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOoptiongadget3d\NUL\NUL\NUL\NUL\NUL\NUL\NUL\tosversion\NUL\NUL\NUL\NUL\NUL\NUL\NUL\voutputdepth\NUL\NUL\NUL\NUL\NUL\NUL\NUL\foutputheight\NUL\NUL\NUL\NUL\NUL\NUL\NUL\voutputwidth\NUL\NUL\NUL\NUL\NUL\NUL\NUL\rpackentryname\NUL\NUL\NUL\NUL\NUL\NUL\NUL\rpackentrysize\NUL\NUL\NUL\NUL\NUL\NUL\NUL\rpackentrytype\NUL\NUL\NUL\NUL\NUL\NUL\NUL\vpanelgadget\NUL\NUL\NUL\NUL\NUL\NUL\NUL\rpanelgadget3d\NUL\NUL\NUL\NUL\NUL\NUL\NUL\rparentxmlnode\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOparse3dscripts\NUL\NUL\NUL\NUL\NUL\NUL\NUL\tparsedate\NUL\NUL\NUL\NUL\NUL\NUL\NUL\tparsejson\NUL\NUL\NUL\NUL\NUL\NUL\NUL\bparsexml\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC2particlecolorfader\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC2particlecolorrange\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC4particleemissionrate\NUL\NUL\NUL\NUL\NUL\NUL\NUL\CANparticleemitterdirection\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC1particleemitterid\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DLEparticleemitterx\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DLEparticleemittery\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DLEparticleemitterz\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DLEparticlematerial\NUL\NUL\NUL\NUL\NUL\NUL\NUL\fparticlesize\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC3particlespeedfactor\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC2particletimetolive\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DLEparticlevelocity\NUL\NUL\NUL\NUL\NUL\NUL\NUL\rpathrequester\NUL\NUL\NUL\NUL\NUL\NUL\NUL\fpauseaudiocd\NUL\NUL\NUL\NUL\NUL\NUL\NUL\npausemovie\NUL\NUL\NUL\NUL\NUL\NUL\NUL\npausesound\NUL\NUL\NUL\NUL\NUL\NUL\NUL\vpausethread\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQpeeka\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQpeekb\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQpeekc\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQpeekd\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQpeekf\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQpeeki\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQpeekl\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQpeekq\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQpeeks\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQpeeku\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQpeekw\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQpickx\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQpicky\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQpickz\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQpitch\NUL\NUL\NUL\NUL\NUL\NUL\NUL\vplayaudiocd\NUL\NUL\NUL\NUL\NUL\NUL\NUL\tplaymovie\NUL\NUL\NUL\NUL\NUL\NUL\NUL\tplaymusic\NUL\NUL\NUL\NUL\NUL\NUL\NUL\tplaysound\NUL\NUL\NUL\NUL\NUL\NUL\NUL\vplaysound3d\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTplot\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQpoint\NUL\NUL\NUL\NUL\NUL\NUL\NUL\npointjoint\NUL\NUL\NUL\NUL\NUL\NUL\NUL\tpointpick\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQpokea\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQpokeb\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQpokec\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQpoked\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQpokef\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQpokei\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQpokel\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQpokeq\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQpokes\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQpokeu\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQpokew\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SIpoplistposition\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOpopmapposition\NUL\NUL\NUL\NUL\NUL\NUL\NUL\tpostevent\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETXpow\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC1preferencecomment\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SIpreferencegroup\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC3preferencegroupname\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC1preferencekeyname\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC2preferencekeyvalue\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC3previousdatabaserow\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SIpreviouselement\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SIpreviousxmlnode\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQprint\NUL\NUL\NUL\NUL\NUL\NUL\NUL\rprinteroutput\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC1printerpageheight\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DLEprinterpagewidth\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKprintn\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOprintrequester\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SIprogramexitcode\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SIprogramfilename\NUL\NUL\NUL\NUL\NUL\NUL\NUL\tprogramid\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DLEprogramparameter\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOprogramrunning\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC1progressbargadget\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC3progressbargadget3d\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC3purifiergranularity\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DLEpushlistposition\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SIpushmapposition\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKradian\NUL\NUL\NUL\NUL\NUL\NUL\NUL\nraiseerror\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKrandom\NUL\NUL\NUL\NUL\NUL\NUL\NUL\nrandomdata\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOrandomizearray\NUL\NUL\NUL\NUL\NUL\NUL\NUL\rrandomizelist\NUL\NUL\NUL\NUL\NUL\NUL\NUL\nrandomseed\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKrawkey\NUL\NUL\NUL\NUL\NUL\NUL\NUL\araycast\NUL\NUL\NUL\NUL\NUL\NUL\NUL\nraycollide\NUL\NUL\NUL\NUL\NUL\NUL\NUL\araypick\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC2readasciicharacter\NUL\NUL\NUL\NUL\NUL\NUL\NUL\breadbyte\NUL\NUL\NUL\NUL\NUL\NUL\NUL\rreadcharacter\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SIreadconsoledata\NUL\NUL\NUL\NUL\NUL\NUL\NUL\breaddata\NUL\NUL\NUL\NUL\NUL\NUL\NUL\nreaddouble\NUL\NUL\NUL\NUL\NUL\NUL\NUL\breadfile\NUL\NUL\NUL\NUL\NUL\NUL\NUL\treadfloat\NUL\NUL\NUL\NUL\NUL\NUL\NUL\vreadinteger\NUL\NUL\NUL\NUL\NUL\NUL\NUL\breadlong\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC4readpreferencedouble\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC3readpreferencefloat\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NAKreadpreferenceinteger\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC2readpreferencelong\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC2readpreferencequad\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC4readpreferencestring\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SIreadprogramdata\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DLEreadprogramerror\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC1readprogramstring\NUL\NUL\NUL\NUL\NUL\NUL\NUL\breadquad\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC2readserialportdata\NUL\NUL\NUL\NUL\NUL\NUL\NUL\nreadstring\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DLEreadstringformat\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC4readunicodecharacter\NUL\NUL\NUL\NUL\NUL\NUL\NUL\breadword\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DLEreallocatememory\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOreceiveftpfile\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SIreceivehttpfile\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC2receivenetworkdata\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETXred\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SYNregularexpressionerror\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SYNregularexpressiongroup\NUL\NUL\NUL\NUL\NUL\NUL\NUL\FSregularexpressiongrouplength\NUL\NUL\NUL\NUL\NUL\NUL\NUL\RSregularexpressiongroupposition\NUL\NUL\NUL\NUL\NUL\NUL\NUL\FSregularexpressionmatchlength\NUL\NUL\NUL\NUL\NUL\NUL\NUL\RSregularexpressionmatchposition\NUL\NUL\NUL\NUL\NUL\NUL\NUL\FSregularexpressionmatchstring\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ESCregularexpressionnamedgroup\NUL\NUL\NUL\NUL\NUL\NUL\NUL!regularexpressionnamedgrouplength\NUL\NUL\NUL\NUL\NUL\NUL\NUL#regularexpressionnamedgroupposition\NUL\NUL\NUL\NUL\NUL\NUL\NUL\freleasemouse\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOreloadmaterial\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SIremovebillboard\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EMremoveenvironmentvariable\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC2removegadgetcolumn\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DLEremovegadgetitem\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC2removegadgetitem3d\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC1removejsonelement\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DLEremovejsonmember\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SYNremovekeyboardshortcut\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC3removemailrecipient\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC3removemateriallayer\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOremovepackfile\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NAKremovepreferencegroup\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC3removepreferencekey\NUL\NUL\NUL\NUL\NUL\NUL\NUL\fremovestring\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC1removesystrayicon\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC1removewindowtimer\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC2removexmlattribute\NUL\NUL\NUL\NUL\NUL\NUL\NUL\nrenamefile\NUL\NUL\NUL\NUL\NUL\NUL\NUL\rrenameftpfile\NUL\NUL\NUL\NUL\NUL\NUL\NUL\vrenderworld\NUL\NUL\NUL\NUL\NUL\NUL\NUL\CANreplaceregularexpression\NUL\NUL\NUL\NUL\NUL\NUL\NUL\rreplacestring\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC3resetgradientcolors\NUL\NUL\NUL\NUL\NUL\NUL\NUL\tresetlist\NUL\NUL\NUL\NUL\NUL\NUL\NUL\bresetmap\NUL\NUL\NUL\NUL\NUL\NUL\NUL\rresetmaterial\NUL\NUL\NUL\NUL\NUL\NUL\NUL\rresetprofiler\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SIresizebillboard\NUL\NUL\NUL\NUL\NUL\NUL\NUL\fresizegadget\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOresizegadget3d\NUL\NUL\NUL\NUL\NUL\NUL\NUL\vresizeimage\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC2resizejsonelements\NUL\NUL\NUL\NUL\NUL\NUL\NUL\vresizemovie\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NAKresizeparticleemitter\NUL\NUL\NUL\NUL\NUL\NUL\NUL\fresizewindow\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOresizewindow3d\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETBresolvexmlattributename\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC2resolvexmlnodename\NUL\NUL\NUL\NUL\NUL\NUL\NUL\rresumeaudiocd\NUL\NUL\NUL\NUL\NUL\NUL\NUL\vresumemovie\NUL\NUL\NUL\NUL\NUL\NUL\NUL\vresumesound\NUL\NUL\NUL\NUL\NUL\NUL\NUL\fresumethread\NUL\NUL\NUL\NUL\NUL\NUL\NUL\rreversestring\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETXrgb\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTrgba\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC1ribboneffectcolor\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC1ribboneffectwidth\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQright\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTroll\NUL\NUL\NUL\NUL\NUL\NUL\NUL\vrootxmlnode\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC4rotatebillboardgroup\NUL\NUL\NUL\NUL\NUL\NUL\NUL\frotatecamera\NUL\NUL\NUL\NUL\NUL\NUL\NUL\frotateentity\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DLErotateentitybone\NUL\NUL\NUL\NUL\NUL\NUL\NUL\vrotatelight\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOrotatematerial\NUL\NUL\NUL\NUL\NUL\NUL\NUL\nrotatenode\NUL\NUL\NUL\NUL\NUL\NUL\NUL\frotatesprite\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQround\NUL\NUL\NUL\NUL\NUL\NUL\NUL\broundbox\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTrset\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQrtrim\NUL\NUL\NUL\NUL\NUL\NUL\NUL\nrunprogram\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SIsavedebugoutput\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC1savefilerequester\NUL\NUL\NUL\NUL\NUL\NUL\NUL\tsaveimage\NUL\NUL\NUL\NUL\NUL\NUL\NUL\bsavejson\NUL\NUL\NUL\NUL\NUL\NUL\NUL\bsavemesh\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC1saverendertexture\NUL\NUL\NUL\NUL\NUL\NUL\NUL\nsavesprite\NUL\NUL\NUL\NUL\NUL\NUL\NUL\vsaveterrain\NUL\NUL\NUL\NUL\NUL\NUL\NUL\asavexml\NUL\NUL\NUL\NUL\NUL\NUL\NUL\vscaleentity\NUL\NUL\NUL\NUL\NUL\NUL\NUL\rscalematerial\NUL\NUL\NUL\NUL\NUL\NUL\NUL\tscalenode\NUL\NUL\NUL\NUL\NUL\NUL\NUL\vscaletext3d\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SIscintillagadget\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC4scintillasendmessage\NUL\NUL\NUL\NUL\NUL\NUL\NUL\vscreendepth\NUL\NUL\NUL\NUL\NUL\NUL\NUL\fscreenheight\NUL\NUL\NUL\NUL\NUL\NUL\NUL\bscreenid\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SIscreenmodedepth\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DLEscreenmodeheight\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NAKscreenmoderefreshrate\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SIscreenmodewidth\NUL\NUL\NUL\NUL\NUL\NUL\NUL\fscreenoutput\NUL\NUL\NUL\NUL\NUL\NUL\NUL\vscreenwidth\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DLEscrollareagadget\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC2scrollareagadget3d\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SIscrollbargadget\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC1scrollbargadget3d\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOscrollmaterial\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKsecond\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SUBsecondworldcollisionentity\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC3selectedfilepattern\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC1selectedfontcolor\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DLEselectedfontname\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DLEselectedfontsize\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC1selectedfontstyle\NUL\NUL\NUL\NUL\NUL\NUL\NUL\rselectelement\NUL\NUL\NUL\NUL\NUL\NUL\NUL\vsendftpfile\NUL\NUL\NUL\NUL\NUL\NUL\NUL\bsendmail\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SIsendnetworkdata\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC1sendnetworkstring\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SIserialporterror\NUL\NUL\NUL\NUL\NUL\NUL\NUL\fserialportid\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC2serialporttimeouts\NUL\NUL\NUL\NUL\NUL\NUL\NUL\bserverid\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SIsetactivegadget\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC1setactivegadget3d\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SIsetactivewindow\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC1setactivewindow3d\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC1setclipboardimage\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DLEsetclipboardtext\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC3setcurrentdirectory\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SIsetdatabaseblob\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SIsetdragcallback\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SIsetdropcallback\NUL\NUL\NUL\NUL\NUL\NUL\NUL\CANsetentityanimationlength\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SYNsetentityanimationtime\NUL\NUL\NUL\NUL\NUL\NUL\NUL\CANsetentityanimationweight\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC2setentityattribute\NUL\NUL\NUL\NUL\NUL\NUL\NUL\CANsetentitycollisionfilter\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC1setentitymaterial\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SYNsetenvironmentvariable\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC1setfileattributes\NUL\NUL\NUL\NUL\NUL\NUL\NUL\vsetfiledate\NUL\NUL\NUL\NUL\NUL\NUL\NUL\fsetframerate\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SIsetftpdirectory\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC2setgadgetattribute\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC4setgadgetattribute3d\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOsetgadgetcolor\NUL\NUL\NUL\NUL\NUL\NUL\NUL\rsetgadgetdata\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SIsetgadgetdata3d\NUL\NUL\NUL\NUL\NUL\NUL\NUL\rsetgadgetfont\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SYNsetgadgetitemattribute\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC2setgadgetitemcolor\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC1setgadgetitemdata\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC3setgadgetitemdata3d\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC2setgadgetitemimage\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC2setgadgetitemstate\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC4setgadgetitemstate3d\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC1setgadgetitemtext\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC3setgadgetitemtext3d\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOsetgadgetstate\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DLEsetgadgetstate3d\NUL\NUL\NUL\NUL\NUL\NUL\NUL\rsetgadgettext\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SIsetgadgettext3d\NUL\NUL\NUL\NUL\NUL\NUL\NUL\rsetguitheme3d\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC1setjointattribute\NUL\NUL\NUL\NUL\NUL\NUL\NUL\fsetjsonarray\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOsetjsonboolean\NUL\NUL\NUL\NUL\NUL\NUL\NUL\rsetjsondouble\NUL\NUL\NUL\NUL\NUL\NUL\NUL\fsetjsonfloat\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOsetjsoninteger\NUL\NUL\NUL\NUL\NUL\NUL\NUL\vsetjsonnull\NUL\NUL\NUL\NUL\NUL\NUL\NUL\rsetjsonobject\NUL\NUL\NUL\NUL\NUL\NUL\NUL\vsetjsonquad\NUL\NUL\NUL\NUL\NUL\NUL\NUL\rsetjsonstring\NUL\NUL\NUL\NUL\NUL\NUL\NUL\rsetlightcolor\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DLEsetmailattribute\NUL\NUL\NUL\NUL\NUL\NUL\NUL\vsetmailbody\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC4setmaterialattribute\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DLEsetmaterialcolor\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DLEsetmenuitemstate\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SIsetmenuitemtext\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DLEsetmenutitletext\NUL\NUL\NUL\NUL\NUL\NUL\NUL\vsetmeshdata\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SIsetmeshmaterial\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DLEsetmusicposition\NUL\NUL\NUL\NUL\NUL\NUL\NUL setnodeanimationkeyframeposition\NUL\NUL\NUL\NUL\NUL\NUL\NUL setnodeanimationkeyframerotation\NUL\NUL\NUL\NUL\NUL\NUL\NUL\GSsetnodeanimationkeyframescale\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SYNsetnodeanimationlength\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC4setnodeanimationtime\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SYNsetnodeanimationweight\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOsetorientation\NUL\NUL\NUL\NUL\NUL\NUL\NUL\tsetorigin\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOsetrenderqueue\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DLEsetruntimedouble\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC1setruntimeinteger\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DLEsetruntimestring\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC3setserialportstatus\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC1setsoundfrequency\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DLEsetsoundposition\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ESCsetterraintileheightatpoint\NUL\NUL\NUL\NUL\NUL\NUL\NUL\CANsetterraintilelayerblend\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NAKsettoolbarbuttonstate\NUL\NUL\NUL\NUL\NUL\NUL\NUL\rsetupterrains\NUL\NUL\NUL\NUL\NUL\NUL\NUL\nseturlpart\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC1setwindowcallback\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOsetwindowcolor\NUL\NUL\NUL\NUL\NUL\NUL\NUL\rsetwindowdata\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOsetwindowstate\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOsetwindowtitle\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DLEsetwindowtitle3d\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SIsetxmlattribute\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOsetxmlencoding\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOsetxmlnodename\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DLEsetxmlnodeoffset\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOsetxmlnodetext\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DLEsetxmlstandalone\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC3sha1filefingerprint\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SIsha1fingerprint\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOshortcutgadget\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC2showassemblyviewer\NUL\NUL\NUL\NUL\NUL\NUL\NUL\rshowcallstack\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SIshowdebugoutput\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ashowgui\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC1showlibraryviewer\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DLEshowmemoryviewer\NUL\NUL\NUL\NUL\NUL\NUL\NUL\fshowprofiler\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC2showvariableviewer\NUL\NUL\NUL\NUL\NUL\NUL\NUL\rshowwatchlist\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTsign\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SIsignalsemaphore\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETXsin\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTsinh\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKskybox\NUL\NUL\NUL\NUL\NUL\NUL\NUL\askydome\NUL\NUL\NUL\NUL\NUL\NUL\NUL\vsliderjoint\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC2smartwindowrefresh\NUL\NUL\NUL\NUL\NUL\NUL\NUL\tsortarray\NUL\NUL\NUL\NUL\NUL\NUL\NUL\bsortlist\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC3sortstructuredarray\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC2sortstructuredlist\NUL\NUL\NUL\NUL\NUL\NUL\NUL\vsoundcone3d\NUL\NUL\NUL\NUL\NUL\NUL\NUL\tsoundid3d\NUL\NUL\NUL\NUL\NUL\NUL\NUL\vsoundlength\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC3soundlistenerlocate\NUL\NUL\NUL\NUL\NUL\NUL\NUL\bsoundpan\NUL\NUL\NUL\NUL\NUL\NUL\NUL\fsoundrange3d\NUL\NUL\NUL\NUL\NUL\NUL\NUL\vsoundstatus\NUL\NUL\NUL\NUL\NUL\NUL\NUL\vsoundvolume\NUL\NUL\NUL\NUL\NUL\NUL\NUL\rsoundvolume3d\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQspace\NUL\NUL\NUL\NUL\NUL\NUL\NUL\nspingadget\NUL\NUL\NUL\NUL\NUL\NUL\NUL\fspingadget3d\NUL\NUL\NUL\NUL\NUL\NUL\NUL\fsplinepointx\NUL\NUL\NUL\NUL\NUL\NUL\NUL\fsplinepointy\NUL\NUL\NUL\NUL\NUL\NUL\NUL\fsplinepointz\NUL\NUL\NUL\NUL\NUL\NUL\NUL\asplinex\NUL\NUL\NUL\NUL\NUL\NUL\NUL\aspliney\NUL\NUL\NUL\NUL\NUL\NUL\NUL\asplinez\NUL\NUL\NUL\NUL\NUL\NUL\NUL\tsplitlist\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOsplittergadget\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOspotlightrange\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC2spriteblendingmode\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SIspritecollision\NUL\NUL\NUL\NUL\NUL\NUL\NUL\vspritedepth\NUL\NUL\NUL\NUL\NUL\NUL\NUL\fspriteheight\NUL\NUL\NUL\NUL\NUL\NUL\NUL\bspriteid\NUL\NUL\NUL\NUL\NUL\NUL\NUL\fspriteoutput\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC4spritepixelcollision\NUL\NUL\NUL\NUL\NUL\NUL\NUL\rspritequality\NUL\NUL\NUL\NUL\NUL\NUL\NUL\vspritewidth\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETXsqr\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOstartaescipher\NUL\NUL\NUL\NUL\NUL\NUL\NUL\fstartdrawing\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC4startentityanimation\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC2startnodeanimation\NUL\NUL\NUL\NUL\NUL\NUL\NUL\rstartprinting\NUL\NUL\NUL\NUL\NUL\NUL\NUL\rstartprofiler\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SIstatusbarheight\NUL\NUL\NUL\NUL\NUL\NUL\NUL\vstatusbarid\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOstatusbarimage\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC1statusbarprogress\NUL\NUL\NUL\NUL\NUL\NUL\NUL\rstatusbartext\NUL\NUL\NUL\NUL\NUL\NUL\NUL\fstickywindow\NUL\NUL\NUL\NUL\NUL\NUL\NUL\vstopaudiocd\NUL\NUL\NUL\NUL\NUL\NUL\NUL\vstopdrawing\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC3stopentityanimation\NUL\NUL\NUL\NUL\NUL\NUL\NUL\tstopmovie\NUL\NUL\NUL\NUL\NUL\NUL\NUL\tstopmusic\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC1stopnodeanimation\NUL\NUL\NUL\NUL\NUL\NUL\NUL\fstopprinting\NUL\NUL\NUL\NUL\NUL\NUL\NUL\fstopprofiler\NUL\NUL\NUL\NUL\NUL\NUL\NUL\tstopsound\NUL\NUL\NUL\NUL\NUL\NUL\NUL\vstopsound3d\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETXstr\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTstrd\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTstrf\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DLEstringbytelength\NUL\NUL\NUL\NUL\NUL\NUL\NUL\vstringfield\NUL\NUL\NUL\NUL\NUL\NUL\NUL\fstringgadget\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOstringgadget3d\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTstru\NUL\NUL\NUL\NUL\NUL\NUL\NUL\fsubmeshcount\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETXsun\NUL\NUL\NUL\NUL\NUL\NUL\NUL\fswapelements\NUL\NUL\NUL\NUL\NUL\NUL\NUL\fswitchcamera\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC2systrayicontooltip\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETXtan\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTtanh\NUL\NUL\NUL\NUL\NUL\NUL\NUL\rterrainheight\NUL\NUL\NUL\NUL\NUL\NUL\NUL\rterrainlocate\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DLEterrainmousepick\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC1terrainphysicbody\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC1terrainrendermode\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ESCterraintileheightatposition\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETBterraintilelayermapsize\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC1terraintilepointx\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC1terraintilepointy\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SIterraintilesize\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SItext3dalignment\NUL\NUL\NUL\NUL\NUL\NUL\NUL\rtext3dcaption\NUL\NUL\NUL\NUL\NUL\NUL\NUL\vtext3dcolor\NUL\NUL\NUL\NUL\NUL\NUL\NUL\btext3did\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ntextgadget\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ftextgadget3d\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ntextheight\NUL\NUL\NUL\NUL\NUL\NUL\NUL\rtextureheight\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ttextureid\NUL\NUL\NUL\NUL\NUL\NUL\NUL\rtextureoutput\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ftexturewidth\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ttextwidth\NUL\NUL\NUL\NUL\NUL\NUL\NUL\bthreadid\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOthreadpriority\NUL\NUL\NUL\NUL\NUL\NUL\NUL\rtoolbarheight\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ttoolbarid\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC2toolbarimagebutton\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DLEtoolbarseparator\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NAKtoolbarstandardbutton\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOtoolbartooltip\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOtrackbargadget\NUL\NUL\NUL\NUL\NUL\NUL\NUL\rtransformmesh\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SItransformsprite\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SYNtransparentspritecolor\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ntreegadget\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTtrim\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ftruncatefile\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ftrylockmutex\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ftrysemaphore\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQucase\NUL\NUL\NUL\NUL\NUL\NUL\NUL\vunbindevent\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC1unbindgadgetevent\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SIunbindmenuevent\NUL\NUL\NUL\NUL\NUL\NUL\NUL\funclipoutput\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DLEuncompressmemory\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC2uncompresspackfile\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC4uncompresspackmemory\NUL\NUL\NUL\NUL\NUL\NUL\NUL\vunlockmutex\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NAKupdateentityanimation\NUL\NUL\NUL\NUL\NUL\NUL\NUL\nupdatemesh\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NAKupdatemeshboundingbox\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC3updaterendertexture\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC1updatesplinepoint\NUL\NUL\NUL\NUL\NUL\NUL\NUL\rupdateterrain\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ESCupdateterraintilelayerblend\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EMupdatevertexposereference\NUL\NUL\NUL\NUL\NUL\NUL\NUL\nurldecoder\NUL\NUL\NUL\NUL\NUL\NUL\NUL\nurlencoder\NUL\NUL\NUL\NUL\NUL\NUL\NUL\nuseaudiocd\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DLEusebrieflzpacker\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC3useflacsounddecoder\NUL\NUL\NUL\NUL\NUL\NUL\NUL\rusegadgetlist\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SIusejcalg1packer\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETBusejpeg2000imagedecoder\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETBusejpeg2000imageencoder\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC3usejpegimagedecoder\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC3usejpegimageencoder\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ruselzmapacker\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SIuseodbcdatabase\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC2useoggsounddecoder\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC2usepngimagedecoder\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC2usepngimageencoder\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NAKusepostgresqldatabase\NUL\NUL\NUL\NUL\NUL\NUL\NUL\busername\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC1usesqlitedatabase\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC2usetgaimagedecoder\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC3usetiffimagedecoder\NUL\NUL\NUL\NUL\NUL\NUL\NUL\fusezippacker\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETXval\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTvald\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTvalf\NUL\NUL\NUL\NUL\NUL\NUL\NUL\CANvertexposereferencecount\NUL\NUL\NUL\NUL\NUL\NUL\NUL\vwaitprogram\NUL\NUL\NUL\NUL\NUL\NUL\NUL\rwaitsemaphore\NUL\NUL\NUL\NUL\NUL\NUL\NUL\nwaitthread\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SIwaitwindowevent\NUL\NUL\NUL\NUL\NUL\NUL\NUL\nwatercolor\NUL\NUL\NUL\NUL\NUL\NUL\NUL\vwaterheight\NUL\NUL\NUL\NUL\NUL\NUL\NUL\twebgadget\NUL\NUL\NUL\NUL\NUL\NUL\NUL\rwebgadgetpath\NUL\NUL\NUL\NUL\NUL\NUL\NUL\fwindowbounds\NUL\NUL\NUL\NUL\NUL\NUL\NUL\vwindowevent\NUL\NUL\NUL\NUL\NUL\NUL\NUL\rwindowevent3d\NUL\NUL\NUL\NUL\NUL\NUL\NUL\fwindowheight\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOwindowheight3d\NUL\NUL\NUL\NUL\NUL\NUL\NUL\bwindowid\NUL\NUL\NUL\NUL\NUL\NUL\NUL\nwindowid3d\NUL\NUL\NUL\NUL\NUL\NUL\NUL\fwindowmousex\NUL\NUL\NUL\NUL\NUL\NUL\NUL\fwindowmousey\NUL\NUL\NUL\NUL\NUL\NUL\NUL\fwindowoutput\NUL\NUL\NUL\NUL\NUL\NUL\NUL\vwindowwidth\NUL\NUL\NUL\NUL\NUL\NUL\NUL\rwindowwidth3d\NUL\NUL\NUL\NUL\NUL\NUL\NUL\awindowx\NUL\NUL\NUL\NUL\NUL\NUL\NUL\twindowx3d\NUL\NUL\NUL\NUL\NUL\NUL\NUL\awindowy\NUL\NUL\NUL\NUL\NUL\NUL\NUL\twindowy3d\NUL\NUL\NUL\NUL\NUL\NUL\NUL\FSworldcollisionappliedimpulse\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NAKworldcollisioncontact\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC4worldcollisionnormal\NUL\NUL\NUL\NUL\NUL\NUL\NUL\nworlddebug\NUL\NUL\NUL\NUL\NUL\NUL\NUL\fworldgravity\NUL\NUL\NUL\NUL\NUL\NUL\NUL\fworldshadows\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC3writeasciicharacter\NUL\NUL\NUL\NUL\NUL\NUL\NUL\twritebyte\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOwritecharacter\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DLEwriteconsoledata\NUL\NUL\NUL\NUL\NUL\NUL\NUL\twritedata\NUL\NUL\NUL\NUL\NUL\NUL\NUL\vwritedouble\NUL\NUL\NUL\NUL\NUL\NUL\NUL\nwritefloat\NUL\NUL\NUL\NUL\NUL\NUL\NUL\fwriteinteger\NUL\NUL\NUL\NUL\NUL\NUL\NUL\twritelong\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NAKwritepreferencedouble\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC4writepreferencefloat\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SYNwritepreferenceinteger\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC3writepreferencelong\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC3writepreferencequad\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NAKwritepreferencestring\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DLEwriteprogramdata\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC2writeprogramstring\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC3writeprogramstringn\NUL\NUL\NUL\NUL\NUL\NUL\NUL\twritequad\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC3writeserialportdata\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NAKwriteserialportstring\NUL\NUL\NUL\NUL\NUL\NUL\NUL\vwritestring\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC1writestringformat\NUL\NUL\NUL\NUL\NUL\NUL\NUL\fwritestringn\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NAKwriteunicodecharacter\NUL\NUL\NUL\NUL\NUL\NUL\NUL\twriteword\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DLExmlattributename\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC1xmlattributevalue\NUL\NUL\NUL\NUL\NUL\NUL\NUL\rxmlchildcount\NUL\NUL\NUL\NUL\NUL\NUL\NUL\bxmlerror\NUL\NUL\NUL\NUL\NUL\NUL\NUL\fxmlerrorline\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DLExmlerrorposition\NUL\NUL\NUL\NUL\NUL\NUL\NUL\rxmlnodefromid\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SIxmlnodefrompath\NUL\NUL\NUL\NUL\NUL\NUL\NUL\vxmlnodepath\NUL\NUL\NUL\NUL\NUL\NUL\NUL\vxmlnodetype\NUL\NUL\NUL\NUL\NUL\NUL\NUL\txmlstatus\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETXyaw\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTyear\NUL\NUL\NUL\NUL\NUL\NUL\NUL\nzoomsprite\DC1\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\a\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\FS\t\n !%&()*+,-./:;<=>?[\\]^{|}~\SOH\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STX\NUL\NUL\NUL\NUL\NUL\NUL\NUL\fcalldebugger\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQdebug\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACK\NUL\NUL\NUL\NUL\NUL\NUL\NUL+\\#+[a-zA-Z_\\x7f-\\xff][a-zA-Z0-9_\\x7f-\\xff]*\SOH\SOH\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\t\STX\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\b\STX\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\"\b\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\tPureBasic\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKString\ACK\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DLE\\s*;+\\s*BEGIN.*$\SOH\EM\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACK\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SO\\s*;+\\s*END.*$\SOH\EM\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL;\f\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\tPureBasic\NUL\NUL\NUL\NUL\NUL\NUL\NUL\bComment1\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKString\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKString\NUL\NUL\NUL\NUL\NUL\NUL\NUL\tPureBasic\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\"\b\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\b\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NULKAlexander Clay (Tuireann@EpicBasic.org);Sven Langenkamp (ace@kylixforum.de)\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STX10\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTLGPL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STX\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOT*.pb\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQ*.pbi\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKNormal"
