{-# LANGUAGE OverloadedStrings #-}
-- | Automatically generated syntax definition for Intel x86 (FASM).
-- DO NOT EDIT THIS FILE MANUALLY.
-- Instead, modify xml/fasm.xml and 'make bootstrap'.
module Skylighting.Syntax.Fasm (syntax) where

import Skylighting.Types
import Data.Binary

-- | Syntax definition for Intel x86 (FASM).
syntax :: Syntax
syntax = decode "\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DLEIntel x86 (FASM)\NUL\NUL\NUL\NUL\NUL\NUL\NUL\bfasm.xml\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTFasm\NUL\NUL\NUL\NUL\NUL\NUL\NUL\b\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTData\NUL\NUL\NUL\NUL\NUL\NUL\NUL\US\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STXdb\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STXdw\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STXdu\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STXdd\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STXdp\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STXdf\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STXdq\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STXdt\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STXrb\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STXrw\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STXrd\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STXrp\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STXrf\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STXrq\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STXrt\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTfile\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTbyte\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTword\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQdword\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQfword\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQpword\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQqword\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQtbyte\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQtword\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKdqword\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQxword\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKqqword\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQyword\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\adqqword\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQzword\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETXptr\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EMInstruction-like Keywords\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC4\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQalign\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQentry\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQextrn\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKformat\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ainclude\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKinvoke\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTdata\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTload\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTfrom\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTheap\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETXorg\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTproc\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKpublic\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\asection\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\asegment\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQstack\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQstore\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQuse16\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQuse32\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQuse64\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NAKPreprocessor Keywords\NUL\NUL\NUL\NUL\NUL\NUL\NUL!\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKassert\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKappend\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STXat\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQbreak\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SIcalminstruction\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKcommon\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\adisplay\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTelse\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETXend\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETXequ\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETXerr\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETXfix\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKfoward\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STXif\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\aiterate\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETXirp\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTirps\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQlabel\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQlocal\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQmatch\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQmacro\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\bpostpone\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQpurge\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKrepeat\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTrept\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\areverse\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\arestore\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\arestruc\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQstruc\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQtimes\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQwhile\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\avirtual\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\tnamespace\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC3branch instructions\NUL\NUL\NUL\NUL\NUL\NUL\NULJ\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTcall\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STXja\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETXjae\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STXjb\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETXjbe\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STXjc\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STXje\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STXjg\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETXjge\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STXjl\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETXjle\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETXjmp\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETXjna\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTjnae\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETXjnb\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTjnbe\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETXjnc\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETXjne\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETXjng\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTjnge\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETXjnl\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTjnle\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETXjno\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETXjnp\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETXjns\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETXjnz\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STXjo\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STXjp\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETXjpe\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETXjpo\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STXjs\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STXjz\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTjcxz\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQjecxz\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTloop\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQloopd\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQloope\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKlooped\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKloopew\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKloopne\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\aloopned\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\aloopnew\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKloopnz\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\aloopnzd\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\aloopnzw\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQloopw\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQloopz\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKloopzd\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKloopzw\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKloopnz\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\aloopnzd\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\aloopnzw\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQloopz\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKloopzw\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETXret\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTretd\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTretf\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQretfd\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQretfw\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTretn\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQretnd\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQretnw\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTretw\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTiret\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQiretd\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQiretq\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQiretw\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETXrsm\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\asyscall\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\bsysenter\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\asysexit\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKsysret\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\bsyscallq\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\asysretq\NUL\NUL\NUL\NUL\NUL\NUL\NUL\finstructions\NUL\NUL\NUL\NUL\NUL\NUL\EOT\240\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETXaaa\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETXaad\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETXaam\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETXaas\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETXadc\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETXadd\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQaddpd\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQaddps\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQaddsd\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQaddss\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\baddsubpd\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\baddsubps\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKaesdec\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\naesdeclast\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKaesenc\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\naesenclast\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKaesimc\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SIaeskeygenassist\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETXand\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTandn\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKandnpd\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKandnps\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQandpd\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQandps\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTarpl\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQbextr\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ablcfill\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTblci\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQblcic\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKblcmsk\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTblcs\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ablendpd\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ablendps\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\bblendvpd\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\bblendvps\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ablsfill\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTblsi\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQblsic\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKblsmsk\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTblsr\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKbndldx\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQbndmk\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKbndstx\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQbound\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETXbsf\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETXbsr\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQbswap\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STXbt\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETXbtc\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETXbtr\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETXbts\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTbzhi\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETXcbw\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETXcdq\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTcdqe\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETXclc\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETXcld\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\aclflush\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTclgi\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETXcli\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTclts\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETXcmc\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTcmov\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQcmova\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKcmovae\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQcmovb\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKcmovbe\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQcmovc\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQcmove\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQcmovg\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKcmovge\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQcmovl\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKcmovle\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKcmovna\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\acmovnae\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKcmovnb\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\acmovnbe\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKcmovnc\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKcmovne\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKcmovng\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\acmovnge\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKcmovnl\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\acmovnle\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKcmovno\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKcmovnp\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKcmovns\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKcmovnz\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQcmovo\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQcmovp\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKcmovpe\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKcmovpo\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQcmovs\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQcmovz\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETXcmp\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQcmpeq\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\acmpeqpd\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\acmpeqps\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\acmpeqsd\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\acmpeqss\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQcmple\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\acmplepd\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\acmpleps\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\acmplesd\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\acmpless\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQcmplt\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\acmpltpd\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\acmpltps\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\acmpltsd\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\acmpltss\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKcmpneq\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\bcmpneqpd\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\bcmpneqps\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\bcmpneqsd\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\bcmpneqss\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKcmpnle\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\bcmpnlepd\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\bcmpnleps\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\bcmpnlesd\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\bcmpnless\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKcmpnlt\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\bcmpnltpd\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\bcmpnltps\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\bcmpnltsd\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\bcmpnltss\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKcmpord\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\bcmpordpd\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\bcmpordps\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\bcmpordsd\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\bcmpordss\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQcmppd\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQcmpps\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTcmps\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQcmpsb\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQcmpsd\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQcmpsq\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQcmpss\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQcmpsw\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\bcmpunord\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ncmpunordpd\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ncmpunordps\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ncmpunordsd\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ncmpunordss\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ncmpxchg16b\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ncmpxchg486\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\tcmpxchg8b\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\acmpxchg\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKcomisd\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKcomiss\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\acompare\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQcpuid\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETXcqo\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQcrc32\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\bcvtdq2pd\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\bcvtdq2ps\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\bcvtpd2dq\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\bcvtpd2pi\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\bcvtpd2ps\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\bcvtpi2pd\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\bcvtpi2ps\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\bcvtps2dq\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\bcvtps2pd\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\bcvtps2pi\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\bcvtsd2si\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\bcvtsd2ss\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\bcvtsi2sd\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\bcvtsi2ss\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\bcvtss2sd\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\bcvtss2si\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\tcvttpd2dq\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\tcvttpd2pi\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\tcvttps2dq\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\tcvttps2pi\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\tcvttsd2si\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\tcvttss2si\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETXcwd\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTcwde\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETXdaa\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETXdas\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETXdec\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETXdiv\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQdivpd\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQdivps\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQdivsd\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQdivss\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTdppd\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTdpps\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTemms\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQenter\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\textractps\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQextrq\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQf2xm1\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTfabs\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTfadd\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQfaddp\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTfbld\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQfbstp\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTfchs\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQfclex\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKfcmovb\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\afcmovbe\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKfcmove\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\afcmovnb\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\bfcmovnbe\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\afcmovne\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\afcmovnu\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKfcmovu\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTfcom\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQfcomi\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKfcomip\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQfcomp\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKfcompp\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTfcos\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\afdecstp\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQfdisi\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTfdiv\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQfdivp\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQfdivr\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKfdivrp\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQfemms\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTfeni\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQffree\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKffreep\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQfiadd\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQficom\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKficomp\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQfidiv\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKfidivr\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTfild\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQfimul\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\afincstp\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQfinit\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTfist\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQfistp\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKfisttp\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQfisub\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKfisubr\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTfld1\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETXfld\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQfldcw\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKfldenv\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\afldenvd\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\afldenvw\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKfldl2e\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKfldl2t\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKfldlg2\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKfldln2\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQfldpi\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTfldz\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTfmul\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQfmulp\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKfnclex\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKfndisi\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQfneni\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKfninit\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTfnop\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKfnsave\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\afnsaved\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\afnsavew\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKfnstcw\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\afnstenv\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\bfnstenvd\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\bfnstenvw\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKfnstsw\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKfnwait\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKfpatan\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKfprem1\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQfprem\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQfptan\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\afrndint\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKfrstor\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\afrstord\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\afrstorw\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQfsave\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKfsaved\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKfsavew\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKfscale\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKfsetpm\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTfsin\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\afsincos\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQfsqrt\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETXfst\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQfstcw\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKfstenv\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\afstenvd\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\afstenvw\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTfstp\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQfstsw\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTfsub\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQfsubp\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQfsubr\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKfsubrp\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTftst\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQfucom\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKfucomi\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\afucomip\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKfucomp\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\afucompp\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQfwait\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTfxam\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTfxch\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\tfxrstor64\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\afxrstor\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\bfxsave64\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKfxsave\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\afxtract\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQfyl2x\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\afyl2xp1\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKgetsec\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKhaddpd\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKhaddps\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETXhlt\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKhsubpd\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKhsubps\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTibts\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTidiv\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTimul\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STXin\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETXinc\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETXins\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTinsb\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTinsd\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\binsertps\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ainsertq\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTinsw\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTint1\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTint3\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETXint\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTinto\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTinvd\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKinvept\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKinvlpg\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ainvlpga\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ainvpcid\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ainvvpid\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTlahf\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETXlar\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQlddqu\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\aldmxcsr\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETXlds\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETXlea\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQleave\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETXles\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKlfence\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETXlfs\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTlgdt\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETXlgs\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTlidt\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTlldt\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTlmsw\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\nloadall286\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\aloadall\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTlock\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTlods\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQlodsb\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQlodsd\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQlodsq\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQlodsw\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETXlsl\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETXlss\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETXltr\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQlzcnt\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\nmaskmovdqu\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\bmaskmovq\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQmaxpd\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQmaxps\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQmaxsd\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQmaxss\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKmfence\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQminpd\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQminps\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQminsd\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQminss\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\amonitor\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETXmov\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKmovapd\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKmovaps\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQmovbe\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTmovd\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\amovddup\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\amovdq2q\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKmovdqa\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKmovdqu\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\amovhlps\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKmovhpd\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKmovhps\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\amovlhps\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKmovlpd\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKmovlps\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\bmovmskpd\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\bmovmskps\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\amovntdq\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\bmovntdqa\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKmovnti\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\amovntpd\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\amovntps\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKmovntq\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\amovntsd\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\amovntss\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\amovq2dq\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTmovq\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTmovs\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQmovsb\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQmovsd\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\bmovshdup\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\bmovsldup\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQmovsq\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQmovss\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQmovsw\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQmovsx\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKmovsxd\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKmovupd\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKmovups\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQmovzx\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ampsadbw\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETXmul\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQmulpd\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQmulps\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQmulsd\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQmulss\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTmulx\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQmwait\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETXneg\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETXnop\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETXnot\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STXor\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTorpd\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTorps\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETXout\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTouts\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQoutsb\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQoutsd\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQoutsw\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQpabsb\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQpabsd\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQpabsw\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\bpackssdw\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\bpacksswb\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\bpackusdw\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\bpackuswb\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQpaddb\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQpaddd\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQpaddq\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKpaddsb\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKpaddsw\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\apaddusb\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\apaddusw\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQpaddw\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\apalignr\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTpand\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQpandn\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQpause\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQpavgb\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\apavgusb\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQpavgw\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\bpblendvb\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\apblendw\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\tpclmulqdq\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\apcmpeqb\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\apcmpeqd\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\apcmpeqq\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\apcmpeqw\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\tpcmpestri\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\tpcmpestrm\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\apcmpgtb\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\apcmpgtd\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\apcmpgtq\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\apcmpgtw\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\tpcmpistri\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\tpcmpistrm\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTpdep\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\apdistib\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTpext\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKpextrb\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKpextrd\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKpextrq\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKpextrw\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQpf2id\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQpf2iw\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQpfacc\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQpfadd\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\apfcmpeq\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\apfcmpge\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\apfcmpgt\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQpfmax\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQpfmin\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQpfmul\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKpfnacc\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\apfpnacc\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQpfrcp\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\bpfrcpit1\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\bpfrcpit2\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\bpfrsqit1\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\apfrsqrt\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQpfsub\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKpfsubr\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKphaddd\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\aphaddsw\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKphaddw\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\nphminposuw\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKphsubd\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\aphsubsw\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKphsubw\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQpi2fd\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQpi2fw\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKpinsrb\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKpinsrd\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKpinsrq\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKpinsrw\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\bpmachriw\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\tpmaddubsw\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\apmaddwd\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQpmagw\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKpmaxsb\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKpmaxsd\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKpmaxsw\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKpmaxub\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKpmaxud\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKpmaxuw\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKpminsb\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKpminsd\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKpminsw\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKpminub\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKpminud\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKpminuw\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\bpmovmskb\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\bpmovsxbd\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\bpmovsxbq\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\bpmovsxbw\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\bpmovsxdq\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\bpmovsxwd\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\bpmovsxwq\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\bpmovzxbd\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\bpmovzxbq\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\bpmovzxbw\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\bpmovzxdq\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\bpmovzxwd\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\bpmovzxwq\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKpmuldq\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\bpmulhrsw\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\apmulhrw\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\apmulhuw\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKpmulhw\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKpmulld\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKpmullw\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\apmuludq\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\apmvgezb\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKpmvlzb\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKpmvnzb\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQpmvzb\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETXpop\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTpopa\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQpopad\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQpopaw\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKpopcnt\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTpopd\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTpopf\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQpopfd\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQpopfq\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQpopfw\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTpopw\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETXpor\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\bprefetch\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\vprefetchnta\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\nprefetcht0\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\nprefetcht1\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\nprefetcht2\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\tprefetchw\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKpsadbw\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKpshufb\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKpshufd\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\apshufhw\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\apshuflw\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKpshufw\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKpsignb\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKpsignd\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKpsignw\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQpslld\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKpslldq\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQpsllq\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQpsllw\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQpsrad\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQpsraw\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQpsrld\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKpsrldq\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQpsrlq\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQpsrlw\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQpsubb\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQpsubd\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQpsubq\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKpsubsb\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\apsubsiw\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKpsubsw\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\apsubusb\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\apsubusw\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQpsubw\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKpswapd\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQptest\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\tpunpckhbw\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\tpunpckhdq\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\npunpckhqdq\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\tpunpckhwd\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\tpunpcklbw\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\tpunpckldq\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\npunpcklqdq\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\tpunpcklwd\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTpush\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQpusha\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKpushad\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKpushaw\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQpushd\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQpushf\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKpushfd\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKpushfq\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKpushfw\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQpushw\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTpxor\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETXrcl\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQrcpps\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQrcpss\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETXrcr\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\brdfsbase\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\brdgsbase\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQrdmsr\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKrdmsrq\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQrdpmc\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKrdrand\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQrdshr\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQrdtsc\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKrdtscp\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETXrol\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETXror\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTrorx\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\aroundpd\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\aroundps\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\aroundsd\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\aroundss\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTrsdc\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQrsldt\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETXrsm\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\arsqrtps\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\arsqrtss\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTrsts\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTsahf\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETXsal\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTsalc\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETXsar\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTsarx\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETXsbb\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTscas\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQscasb\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQscasd\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQscasq\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQscasw\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETXset\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTseta\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQsetae\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTsetb\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQsetbe\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTsetc\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTsete\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTsetg\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQsetge\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTsetl\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQsetle\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQsetna\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKsetnae\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQsetnb\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKsetnbe\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQsetnc\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQsetne\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQsetng\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKsetnge\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQsetnl\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKsetnle\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQsetno\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQsetnp\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQsetns\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQsetnz\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTseto\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTsetp\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQsetpe\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQsetpo\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTsets\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTsetz\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKsfence\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTsgdt\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETXshl\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTshld\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTshlx\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETXshr\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTshrd\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTshrx\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKshufpd\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKshufps\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTsidt\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKskinit\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTsldt\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETXsmi\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQsmint\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\bsmintold\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTsmsw\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKsqrtpd\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKsqrtps\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKsqrtsd\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKsqrtss\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETXstc\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETXstd\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTstgi\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETXsti\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\astmxcsr\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTstos\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQstosb\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQstosd\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQstosq\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQstosw\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETXstr\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETXsub\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQsubpd\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQsubps\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQsubsd\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQsubss\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTsvdc\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQsvldt\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTsvts\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKswapgs\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKt1mskc\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTtest\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQtzcnt\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQtzmsk\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\aucomisd\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\aucomiss\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETXud0\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETXud1\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETXud2\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTumov\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\bunpckhpd\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\bunpckhps\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\bunpcklpd\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\bunpcklps\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\avaesenc\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\vvaesenclast\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\avaesimc\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\tvblendvpd\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\tvblendvps\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOvbroadcastf128\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOvbroadcasti128\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\fvbroadcastsd\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\fvbroadcastss\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\avcomisd\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\avcomiss\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\tvcvtdq2pd\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\tvcvtdq2ps\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\tvcvtpd2dq\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\tvcvtpd2ps\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\tvcvtph2ps\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\tvcvtps2dq\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\tvcvtps2pd\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\tvcvtps2ph\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\tvcvtsd2si\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\tvcvtsd2ss\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\tvcvtsi2sd\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\tvcvtsi2ss\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\tvcvtss2sd\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\tvcvtss2si\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\nvcvttpd2dq\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\nvcvttps2dq\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\nvcvttsd2si\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\nvcvttss2si\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQvdppd\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTverr\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTverw\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\fvextractf128\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\fvextracti128\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\nvextractps\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\bvfm132pd\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\bvfm132ps\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\bvfm132sd\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\bvfm132ss\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\bvfm213pd\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\bvfm213ps\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\bvfm213sd\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\bvfm213ss\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\bvfm231pd\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\bvfm231ps\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\bvfm231sd\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\bvfm231ss\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\bvfmaddpd\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOvfmaddsub132pd\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOvfmaddsub132ps\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOvfmaddsub213pd\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOvfmaddsub213ps\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOvfmaddsub231pd\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOvfmaddsub231ps\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOvfmsubadd132pd\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOvfmsubadd132ps\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOvfmsubadd213pd\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOvfmsubadd213ps\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOvfmsubadd231pd\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOvfmsubadd231ps\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\bvfmsubss\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\tvfnm132pd\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\tvfnm132ps\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\tvfnm132sd\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\tvfnm132ss\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\tvfnm213pd\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\tvfnm213ps\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\tvfnm213sd\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\tvfnm213ss\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\tvfnm231pd\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\tvfnm231ps\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\tvfnm231sd\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\tvfnm231ss\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\avfrczpd\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\avfrczps\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\avfrczsd\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\avfrczss\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\nvgatherdpd\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\nvgatherdps\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\nvgatherqpd\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\nvgatherqps\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\vvinsertf128\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\vvinserti128\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\tvinsertps\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKvlddqu\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\bvldmxcsr\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\vvmaskmovdqu\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\nvmaskmovpd\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\nvmaskmovps\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKvmcall\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\avmclear\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\bvmlaunch\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKvmload\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\avmmcall\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\avmovapd\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\avmovaps\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQvmovd\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\bvmovddup\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\avmovdqa\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\avmovdqu\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\bvmovhlps\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\avmovhpd\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\avmovhps\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\bvmovlhps\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\avmovlpd\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\avmovlps\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\tvmovmskpd\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\tvmovmskps\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\bvmovntdq\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\tvmovntdqa\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\bvmovntpd\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\bvmovntps\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQvmovq\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKvmovsd\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\tvmovshdup\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\tvmovsldup\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKvmovss\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\avmovupd\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\avmovups\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\avmptrld\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\avmptrst\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKvmread\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\bvmresume\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQvmrun\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKvmsave\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\avmwrite\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKvmxoff\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQvmxon\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKvpabsb\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKvpabsd\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKvpabsw\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\tvpackssdw\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\tvpacksswb\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\tvpackusdw\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\tvpackuswb\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKvpaddb\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKvpaddd\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKvpaddq\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\avpaddsb\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\avpaddsw\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\bvpaddusb\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\bvpaddusw\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKvpaddw\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\bvpalignr\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQvpand\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKvpandn\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKvpause\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKvpavgb\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\bvpavgusb\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKvpavgw\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\tvpblendvb\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\bvpblendw\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\fvpbroadcastb\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\fvpbroadcastd\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\fvpbroadcastq\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\fvpbroadcastw\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\nvpclmulqdq\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKvpcmov\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\bvpcmpeqb\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\bvpcmpeqd\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\bvpcmpeqq\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\bvpcmpeqw\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\nvpcmpestri\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\nvpcmpestrm\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\bvpcmpgtb\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\bvpcmpgtd\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\bvpcmpgtq\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\bvpcmpgtw\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\nvpcmpistri\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\nvpcmpistrm\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKvpcomb\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKvpcomd\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\vvfmadd132ps\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\fvfnmadd132ps\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\vvfmsub132ps\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\fvfnmsub132ps\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\vvfmadd213ps\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\fvfnmadd213ps\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\vvfmsub213ps\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\fvfnmsub213ps\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\vvfmadd231ps\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\fvfnmadd231ps\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\vvfmsub231ps\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\fvfnmsub231ps\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\vvfmadd132pd\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\fvfnmadd132pd\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\vvfmsub132pd\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\fvfnmsub132pd\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\vvfmadd213pd\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\fvfnmadd213pd\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\vvfmsub213pd\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\fvfnmsub213pd\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\vvfmadd231pd\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\fvfnmadd231pd\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\vvfmsub231pd\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\fvfnmsub231pd\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\vvfmadd132ss\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\fvfnmadd132ss\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\vvfmsub132ss\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\fvfnmsub132ss\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\vvfmadd213ss\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\fvfnmadd213ss\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\vvfmsub213ss\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\fvfnmsub213ss\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\vvfmadd231ss\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\fvfnmadd231ss\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\vvfmsub231ss\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\fvfnmsub231ss\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\vvfmadd132sd\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\fvfnmadd132sd\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\vvfmsub132sd\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\fvfnmsub132sd\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\vvfmadd213sd\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\fvfnmadd213sd\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\vvfmsub213sd\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\fvfnmsub213sd\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\vvfmadd231sd\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\fvfnmadd231sd\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\vvfmsub231sd\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\fvfnmsub231sd\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\bvpcomeqb\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\bvpcomeqd\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\bvpcomeqq\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\tvpcomequb\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\tvpcomequd\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\tvpcomequq\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\tvpcomequw\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\bvpcomeqw\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\vvpcomfalseb\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\vvpcomfalsed\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\vvpcomfalseq\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\fvpcomfalseub\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\fvpcomfalseud\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\fvpcomfalseuq\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\fvpcomfalseuw\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\vvpcomfalsew\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\bvpcomgeb\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\bvpcomged\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\bvpcomgeq\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\tvpcomgeub\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\tvpcomgeud\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\tvpcomgeuq\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\tvpcomgeuw\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\bvpcomgew\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\bvpcomgtb\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\bvpcomgtd\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\bvpcomgtq\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\tvpcomgtub\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\tvpcomgtud\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\tvpcomgtuq\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\tvpcomgtuw\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\bvpcomgtw\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\bvpcomleb\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\bvpcomled\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\bvpcomleq\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\tvpcomleub\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\tvpcomleud\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\tvpcomleuq\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\tvpcomleuw\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\bvpcomlew\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\bvpcomltb\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\bvpcomltd\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\bvpcomltq\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\tvpcomltub\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\tvpcomltud\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\tvpcomltuq\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\tvpcomltuw\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\bvpcomltw\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\tvpcomneqb\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\tvpcomneqd\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\tvpcomneqq\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\nvpcomnequb\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\nvpcomnequd\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\nvpcomnequq\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\nvpcomnequw\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\tvpcomneqw\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKvpcomq\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\nvpcomtrueb\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\nvpcomtrued\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\nvpcomtrueq\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\vvpcomtrueub\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\vvpcomtrueud\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\vvpcomtrueuq\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\vvpcomtrueuw\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\nvpcomtruew\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\avpcomub\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\avpcomud\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\avpcomuq\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\avpcomuw\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKvpcomw\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQvpdep\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\bvpdistib\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\nvperm2f128\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\nvperm2i128\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKvpermd\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\nvpermil2pd\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\nvpermil2ps\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\tvpermilpd\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\tvpermilps\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\avpermpd\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\avpermps\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKvpermq\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQvpext\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\avpextrb\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\avpextrd\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\avpextrq\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\avpextrw\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKvpf2id\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKvpf2iw\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKvpfacc\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKvpfadd\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\bvpfcmpeq\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\bvpfcmpge\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\bvpfcmpgt\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKvpfmax\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKvpfmin\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKvpfmul\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\avpfnacc\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\bvpfpnacc\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKvpfrcp\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\tvpfrcpit1\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\tvpfrcpit2\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\tvpfrsqit1\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\bvpfrsqrt\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKvpfsub\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\avpfsubr\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\nvpgatherdd\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\vvscatterdpd\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\vvscatterdps\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\vvscatterqpd\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\vvscatterqps\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\vvpscatterdd\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\vvpscatterdq\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\vvpscatterqd\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\vvpscatterqq\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\nvpgatherdq\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\nvpgatherqd\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\nvpgatherqq\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\bvphaddbd\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\bvphaddbq\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\bvphaddbw\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\avphaddd\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\bvphadddq\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\bvphaddsw\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\tvphaddubd\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\tvphaddubq\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\tvphaddubw\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\tvphaddudq\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\tvphadduwd\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\tvphadduwq\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\avphaddw\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\bvphaddwd\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\bvphaddwq\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\vvphminposuw\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\bvphsubbw\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\avphsubd\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\bvphsubdq\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\bvphsubsw\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\avphsubw\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\bvphsubwd\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKvpi2fd\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKvpi2fw\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\avpinsrb\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\avpinsrd\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\avpinsrq\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\avpinsrw\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\tvpmachriw\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\bvpmacsdd\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\tvpmacsdqh\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\tvpmacsdql\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\tvpmacssdd\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\nvpmacssdqh\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\nvpmacssdql\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\tvpmacsswd\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\tvpmacssww\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\bvpmacswd\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\bvpmacsww\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\nvpmadcsswd\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\tvpmadcswd\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\nvpmaddubsw\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\bvpmaddwd\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKvpmagw\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\nvpmaskmovd\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\nvpmaskmovq\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\avpmaxsb\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\avpmaxsd\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\avpmaxsw\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\avpmaxub\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\avpmaxud\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\avpmaxuw\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\avpminsb\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\avpminsd\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\avpminsw\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\avpminub\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\avpminud\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\avpminuw\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\tvpmovmskb\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\tvpmovsxbd\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\tvpmovsxbq\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\tvpmovsxbw\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\tvpmovsxdq\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\tvpmovsxwd\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\tvpmovsxwq\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\tvpmovzxbd\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\tvpmovzxbq\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\tvpmovzxbw\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\tvpmovzxdq\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\tvpmovzxwd\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\tvpmovzxwq\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\avpmuldq\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\tvpmulhrsw\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\bvpmulhrw\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\bvpmulhuw\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\avpmulhw\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\avpmulld\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\avpmullw\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\bvpmuludq\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\bvpmvgezb\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\avpmvlzb\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\avpmvnzb\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKvpmvzb\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTvpor\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKvpperm\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\tvprefetch\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\fvprefetchnta\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\vvprefetcht0\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\vvprefetcht1\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\vvprefetcht2\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\nvprefetchw\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKvprotb\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKvprotd\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKvprotq\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKvprotw\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\avpsadbw\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKvpshab\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKvpshad\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKvpshaq\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKvpshaw\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKvpshlb\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKvpshld\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKvpshlq\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKvpshlw\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\avpshufb\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\avpshufd\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\bvpshufhw\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\bvpshuflw\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\avpshufw\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\avpsignb\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\avpsignd\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\avpsignw\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKvpslld\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\avpslldq\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKvpsllq\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\avpsllvd\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\avpsllvq\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKvpsllw\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKvpsrad\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\avpsravd\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKvpsraw\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKvpsrld\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\avpsrldq\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKvpsrlq\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\avpsrlvd\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\avpsrlvq\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKvpsrlw\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKvpsubb\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKvpsubd\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKvpsubq\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\avpsubsb\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\bvpsubsiw\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\avpsubsw\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\bvpsubusb\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\bvpsubusw\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKvpsubw\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\avpswapd\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKvptest\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\nvpunpckhbw\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\nvpunpckhdq\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\vvpunpckhqdq\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\nvpunpckhwd\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\nvpunpcklbw\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\nvpunpckldq\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\vvpunpcklqdq\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\nvpunpcklwd\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQvpxor\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKvrcpps\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\bvroundpd\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\bvroundps\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\bvrsqrtps\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\avsqrtpd\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\avsqrtps\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\bvstmxcsr\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\avtestpd\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\avtestps\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\bvzeroall\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\nvzeroupper\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTwait\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKwbinvd\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\bwrfsbase\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\bwrgsbase\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQwrmsr\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKwrmsrq\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQwrshr\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKxabort\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\bxacquire\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTxadd\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKxbegin\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTxbts\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTxchg\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTxend\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKxgetbv\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTxlat\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQxlatb\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETXxor\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQxorpd\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQxorps\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\bxrelease\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\bxrstor64\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKxrstor\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\axsave64\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQxsave\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\nxsaveopt64\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\bxsaveopt\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKxsetbv\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQxtest\NUL\NUL\NUL\NUL\NUL\NUL\NUL\toperators\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DLE\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTused\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\adefined\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETXmod\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETXand\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STXor\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETXxor\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETXnot\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETXshl\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETXshr\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETXbsf\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETXbsr\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETXrva\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETXplt\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETXfar\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTnear\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQshort\NUL\NUL\NUL\NUL\NUL\NUL\NUL\tregisters\NUL\NUL\NUL\NUL\NUL\NUL\NULl\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETXrax\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETXeax\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STXax\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STXah\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STXal\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETXrbx\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETXebx\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STXbx\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STXbh\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STXbl\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETXrcx\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETXecx\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STXcx\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STXch\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STXcl\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETXrdx\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETXedx\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STXdx\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STXdh\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STXdl\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETXrbp\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETXebp\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STXbp\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETXrsi\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETXesi\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STXsi\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETXrdi\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETXedi\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STXdi\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETXrsp\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETXesp\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STXsp\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STXr8\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STXr9\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETXr10\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETXr11\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETXr12\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETXr13\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETXr14\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETXr15\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STXcs\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STXds\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STXes\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STXfs\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STXgs\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STXss\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETXcr0\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETXcr2\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETXcr3\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETXcr4\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETXdr0\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETXdr1\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETXdr2\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETXdr3\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETXdr6\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETXdr7\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETXst0\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETXst1\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETXst2\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETXst3\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETXst4\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETXst5\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETXst6\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETXst7\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETXmm0\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETXmm1\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETXmm2\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETXmm3\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETXmm4\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETXmm5\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETXmm6\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETXmm7\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTxmm0\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTxmm1\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTxmm2\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTxmm3\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTxmm4\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTxmm5\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTxmm6\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTxmm7\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTymm0\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTymm1\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTymm2\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTymm3\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTymm4\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTymm5\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTymm6\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTymm7\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTzmm0\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTzmm1\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTzmm2\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTzmm3\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTzmm4\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTzmm5\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTzmm6\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTzmm7\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STXk0\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STXk1\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STXk2\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STXk3\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STXk4\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STXk5\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STXk6\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STXk7\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTbnd0\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTbnd1\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTbnd2\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTbnd3\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SIrepeat prefixes\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQ\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETXrep\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTrepe\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTrepz\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQrepne\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQrepnz\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC3\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOT$Hex\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOT$Hex\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DLEIntel x86 (FASM)\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\ACK\NUL\NUL\NUL\NUL\NUL\NUL\NUL\r[0-9a-fA-F_]*\SOH\ETX\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STX\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DLEIntel x86 (FASM)\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC1CheckNumberSuffix\ETX\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACK@Label\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACK@Label\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DLEIntel x86 (FASM)\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STX\STX\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETXbfr\DC1\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\ACK\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH.\SOH\GS\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\DC1\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\nBaseSuffix\NUL\NUL\NUL\NUL\NUL\NUL\NUL\nBaseSuffix\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DLEIntel x86 (FASM)\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\STX\NUL\NUL\NUL\NUL\NUL\NUL\NUL\nBHOQYbhoqy\ETX\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STX\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DLEIntel x86 (FASM)\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC1CheckNumberSuffix\ETX\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STX\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DLEIntel x86 (FASM)\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC1CheckNumberSuffix\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC1CheckNumberSuffix\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC1CheckNumberSuffix\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DLEIntel x86 (FASM)\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETX\DLE\RS\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\STX\NUL\NUL\NUL\NUL\NUL\NUL\NUL\CAN!#%&()*+,-./:<=>?[]`{|}~\DC4\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\ACK\NUL\NUL\NUL\NUL\NUL\NUL\NUL\a[\\d\\w]+\SOH\GS\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\STX\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\aComment\NUL\NUL\NUL\NUL\NUL\NUL\NUL\aComment\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DLEIntel x86 (FASM)\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETX\DLE\f\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SI\NUL\NUL\NUL\NUL\NUL\NUL\NUL\bComments\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\f\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC1\f\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\f\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\bDQString\NUL\NUL\NUL\NUL\NUL\NUL\NUL\bDQString\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DLEIntel x86 (FASM)\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STX\SO\DC4\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\"\b\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\b\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKDollar\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKDollar\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DLEIntel x86 (FASM)\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STX\STX\NUL\NUL\NUL\NUL\NUL\NUL\NUL\n0123456789\ETX\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STX\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DLEIntel x86 (FASM)\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOT$Hex\STX\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETX$%@\DC4\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\DC4\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\vFloatSuffix\NUL\NUL\NUL\NUL\NUL\NUL\NUL\vFloatSuffix\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DLEIntel x86 (FASM)\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\STX\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STXFf\ETX\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STX\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DLEIntel x86 (FASM)\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC1CheckNumberSuffix\EOT\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STX\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DLEIntel x86 (FASM)\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC1CheckNumberSuffix\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\vInstruction\NUL\NUL\NUL\NUL\NUL\NUL\NUL\vInstruction\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DLEIntel x86 (FASM)\NUL\NUL\NUL\NUL\NUL\NUL\NUL\v\DLE\RS\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL;\f\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STX\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DLEIntel x86 (FASM)\NUL\NUL\NUL\NUL\NUL\NUL\NUL\aComment\a\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\FS\t\n !%&()*+,-./:;<=>?[\\]^{|}~\SOH\SOH\NUL\NUL\NUL\NUL\NUL\NUL\EOT\240\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETXaaa\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETXaad\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETXaam\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETXaas\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETXadc\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETXadd\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQaddpd\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQaddps\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQaddsd\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQaddss\NUL\NUL\NUL\NUL\NUL\NUL\NUL\baddsubpd\NUL\NUL\NUL\NUL\NUL\NUL\NUL\baddsubps\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKaesdec\NUL\NUL\NUL\NUL\NUL\NUL\NUL\naesdeclast\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKaesenc\NUL\NUL\NUL\NUL\NUL\NUL\NUL\naesenclast\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKaesimc\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SIaeskeygenassist\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETXand\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTandn\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKandnpd\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKandnps\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQandpd\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQandps\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTarpl\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQbextr\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ablcfill\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTblci\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQblcic\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKblcmsk\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTblcs\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ablendpd\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ablendps\NUL\NUL\NUL\NUL\NUL\NUL\NUL\bblendvpd\NUL\NUL\NUL\NUL\NUL\NUL\NUL\bblendvps\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ablsfill\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTblsi\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQblsic\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKblsmsk\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTblsr\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKbndldx\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQbndmk\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKbndstx\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQbound\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETXbsf\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETXbsr\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQbswap\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STXbt\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETXbtc\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETXbtr\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETXbts\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTbzhi\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETXcbw\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETXcdq\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTcdqe\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETXclc\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETXcld\NUL\NUL\NUL\NUL\NUL\NUL\NUL\aclflush\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTclgi\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETXcli\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTclts\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETXcmc\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTcmov\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQcmova\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKcmovae\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQcmovb\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKcmovbe\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQcmovc\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQcmove\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQcmovg\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKcmovge\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQcmovl\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKcmovle\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKcmovna\NUL\NUL\NUL\NUL\NUL\NUL\NUL\acmovnae\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKcmovnb\NUL\NUL\NUL\NUL\NUL\NUL\NUL\acmovnbe\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKcmovnc\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKcmovne\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKcmovng\NUL\NUL\NUL\NUL\NUL\NUL\NUL\acmovnge\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKcmovnl\NUL\NUL\NUL\NUL\NUL\NUL\NUL\acmovnle\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKcmovno\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKcmovnp\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKcmovns\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKcmovnz\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQcmovo\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQcmovp\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKcmovpe\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKcmovpo\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQcmovs\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQcmovz\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETXcmp\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQcmpeq\NUL\NUL\NUL\NUL\NUL\NUL\NUL\acmpeqpd\NUL\NUL\NUL\NUL\NUL\NUL\NUL\acmpeqps\NUL\NUL\NUL\NUL\NUL\NUL\NUL\acmpeqsd\NUL\NUL\NUL\NUL\NUL\NUL\NUL\acmpeqss\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQcmple\NUL\NUL\NUL\NUL\NUL\NUL\NUL\acmplepd\NUL\NUL\NUL\NUL\NUL\NUL\NUL\acmpleps\NUL\NUL\NUL\NUL\NUL\NUL\NUL\acmplesd\NUL\NUL\NUL\NUL\NUL\NUL\NUL\acmpless\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQcmplt\NUL\NUL\NUL\NUL\NUL\NUL\NUL\acmpltpd\NUL\NUL\NUL\NUL\NUL\NUL\NUL\acmpltps\NUL\NUL\NUL\NUL\NUL\NUL\NUL\acmpltsd\NUL\NUL\NUL\NUL\NUL\NUL\NUL\acmpltss\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKcmpneq\NUL\NUL\NUL\NUL\NUL\NUL\NUL\bcmpneqpd\NUL\NUL\NUL\NUL\NUL\NUL\NUL\bcmpneqps\NUL\NUL\NUL\NUL\NUL\NUL\NUL\bcmpneqsd\NUL\NUL\NUL\NUL\NUL\NUL\NUL\bcmpneqss\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKcmpnle\NUL\NUL\NUL\NUL\NUL\NUL\NUL\bcmpnlepd\NUL\NUL\NUL\NUL\NUL\NUL\NUL\bcmpnleps\NUL\NUL\NUL\NUL\NUL\NUL\NUL\bcmpnlesd\NUL\NUL\NUL\NUL\NUL\NUL\NUL\bcmpnless\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKcmpnlt\NUL\NUL\NUL\NUL\NUL\NUL\NUL\bcmpnltpd\NUL\NUL\NUL\NUL\NUL\NUL\NUL\bcmpnltps\NUL\NUL\NUL\NUL\NUL\NUL\NUL\bcmpnltsd\NUL\NUL\NUL\NUL\NUL\NUL\NUL\bcmpnltss\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKcmpord\NUL\NUL\NUL\NUL\NUL\NUL\NUL\bcmpordpd\NUL\NUL\NUL\NUL\NUL\NUL\NUL\bcmpordps\NUL\NUL\NUL\NUL\NUL\NUL\NUL\bcmpordsd\NUL\NUL\NUL\NUL\NUL\NUL\NUL\bcmpordss\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQcmppd\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQcmpps\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTcmps\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQcmpsb\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQcmpsd\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQcmpsq\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQcmpss\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQcmpsw\NUL\NUL\NUL\NUL\NUL\NUL\NUL\bcmpunord\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ncmpunordpd\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ncmpunordps\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ncmpunordsd\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ncmpunordss\NUL\NUL\NUL\NUL\NUL\NUL\NUL\acmpxchg\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ncmpxchg16b\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ncmpxchg486\NUL\NUL\NUL\NUL\NUL\NUL\NUL\tcmpxchg8b\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKcomisd\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKcomiss\NUL\NUL\NUL\NUL\NUL\NUL\NUL\acompare\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQcpuid\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETXcqo\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQcrc32\NUL\NUL\NUL\NUL\NUL\NUL\NUL\bcvtdq2pd\NUL\NUL\NUL\NUL\NUL\NUL\NUL\bcvtdq2ps\NUL\NUL\NUL\NUL\NUL\NUL\NUL\bcvtpd2dq\NUL\NUL\NUL\NUL\NUL\NUL\NUL\bcvtpd2pi\NUL\NUL\NUL\NUL\NUL\NUL\NUL\bcvtpd2ps\NUL\NUL\NUL\NUL\NUL\NUL\NUL\bcvtpi2pd\NUL\NUL\NUL\NUL\NUL\NUL\NUL\bcvtpi2ps\NUL\NUL\NUL\NUL\NUL\NUL\NUL\bcvtps2dq\NUL\NUL\NUL\NUL\NUL\NUL\NUL\bcvtps2pd\NUL\NUL\NUL\NUL\NUL\NUL\NUL\bcvtps2pi\NUL\NUL\NUL\NUL\NUL\NUL\NUL\bcvtsd2si\NUL\NUL\NUL\NUL\NUL\NUL\NUL\bcvtsd2ss\NUL\NUL\NUL\NUL\NUL\NUL\NUL\bcvtsi2sd\NUL\NUL\NUL\NUL\NUL\NUL\NUL\bcvtsi2ss\NUL\NUL\NUL\NUL\NUL\NUL\NUL\bcvtss2sd\NUL\NUL\NUL\NUL\NUL\NUL\NUL\bcvtss2si\NUL\NUL\NUL\NUL\NUL\NUL\NUL\tcvttpd2dq\NUL\NUL\NUL\NUL\NUL\NUL\NUL\tcvttpd2pi\NUL\NUL\NUL\NUL\NUL\NUL\NUL\tcvttps2dq\NUL\NUL\NUL\NUL\NUL\NUL\NUL\tcvttps2pi\NUL\NUL\NUL\NUL\NUL\NUL\NUL\tcvttsd2si\NUL\NUL\NUL\NUL\NUL\NUL\NUL\tcvttss2si\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETXcwd\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTcwde\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETXdaa\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETXdas\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETXdec\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETXdiv\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQdivpd\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQdivps\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQdivsd\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQdivss\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTdppd\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTdpps\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTemms\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQenter\NUL\NUL\NUL\NUL\NUL\NUL\NUL\textractps\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQextrq\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQf2xm1\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTfabs\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTfadd\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQfaddp\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTfbld\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQfbstp\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTfchs\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQfclex\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKfcmovb\NUL\NUL\NUL\NUL\NUL\NUL\NUL\afcmovbe\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKfcmove\NUL\NUL\NUL\NUL\NUL\NUL\NUL\afcmovnb\NUL\NUL\NUL\NUL\NUL\NUL\NUL\bfcmovnbe\NUL\NUL\NUL\NUL\NUL\NUL\NUL\afcmovne\NUL\NUL\NUL\NUL\NUL\NUL\NUL\afcmovnu\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKfcmovu\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTfcom\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQfcomi\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKfcomip\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQfcomp\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKfcompp\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTfcos\NUL\NUL\NUL\NUL\NUL\NUL\NUL\afdecstp\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQfdisi\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTfdiv\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQfdivp\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQfdivr\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKfdivrp\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQfemms\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTfeni\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQffree\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKffreep\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQfiadd\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQficom\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKficomp\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQfidiv\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKfidivr\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTfild\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQfimul\NUL\NUL\NUL\NUL\NUL\NUL\NUL\afincstp\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQfinit\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTfist\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQfistp\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKfisttp\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQfisub\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKfisubr\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETXfld\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTfld1\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQfldcw\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKfldenv\NUL\NUL\NUL\NUL\NUL\NUL\NUL\afldenvd\NUL\NUL\NUL\NUL\NUL\NUL\NUL\afldenvw\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKfldl2e\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKfldl2t\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKfldlg2\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKfldln2\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQfldpi\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTfldz\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTfmul\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQfmulp\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKfnclex\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKfndisi\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQfneni\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKfninit\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTfnop\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKfnsave\NUL\NUL\NUL\NUL\NUL\NUL\NUL\afnsaved\NUL\NUL\NUL\NUL\NUL\NUL\NUL\afnsavew\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKfnstcw\NUL\NUL\NUL\NUL\NUL\NUL\NUL\afnstenv\NUL\NUL\NUL\NUL\NUL\NUL\NUL\bfnstenvd\NUL\NUL\NUL\NUL\NUL\NUL\NUL\bfnstenvw\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKfnstsw\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKfnwait\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKfpatan\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQfprem\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKfprem1\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQfptan\NUL\NUL\NUL\NUL\NUL\NUL\NUL\afrndint\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKfrstor\NUL\NUL\NUL\NUL\NUL\NUL\NUL\afrstord\NUL\NUL\NUL\NUL\NUL\NUL\NUL\afrstorw\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQfsave\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKfsaved\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKfsavew\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKfscale\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKfsetpm\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTfsin\NUL\NUL\NUL\NUL\NUL\NUL\NUL\afsincos\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQfsqrt\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETXfst\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQfstcw\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKfstenv\NUL\NUL\NUL\NUL\NUL\NUL\NUL\afstenvd\NUL\NUL\NUL\NUL\NUL\NUL\NUL\afstenvw\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTfstp\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQfstsw\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTfsub\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQfsubp\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQfsubr\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKfsubrp\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTftst\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQfucom\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKfucomi\NUL\NUL\NUL\NUL\NUL\NUL\NUL\afucomip\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKfucomp\NUL\NUL\NUL\NUL\NUL\NUL\NUL\afucompp\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQfwait\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTfxam\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTfxch\NUL\NUL\NUL\NUL\NUL\NUL\NUL\afxrstor\NUL\NUL\NUL\NUL\NUL\NUL\NUL\tfxrstor64\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKfxsave\NUL\NUL\NUL\NUL\NUL\NUL\NUL\bfxsave64\NUL\NUL\NUL\NUL\NUL\NUL\NUL\afxtract\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQfyl2x\NUL\NUL\NUL\NUL\NUL\NUL\NUL\afyl2xp1\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKgetsec\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKhaddpd\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKhaddps\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETXhlt\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKhsubpd\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKhsubps\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTibts\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTidiv\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTimul\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STXin\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETXinc\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETXins\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTinsb\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTinsd\NUL\NUL\NUL\NUL\NUL\NUL\NUL\binsertps\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ainsertq\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTinsw\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETXint\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTint1\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTint3\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTinto\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTinvd\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKinvept\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKinvlpg\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ainvlpga\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ainvpcid\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ainvvpid\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTlahf\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETXlar\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQlddqu\NUL\NUL\NUL\NUL\NUL\NUL\NUL\aldmxcsr\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETXlds\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETXlea\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQleave\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETXles\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKlfence\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETXlfs\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTlgdt\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETXlgs\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTlidt\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTlldt\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTlmsw\NUL\NUL\NUL\NUL\NUL\NUL\NUL\aloadall\NUL\NUL\NUL\NUL\NUL\NUL\NUL\nloadall286\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTlock\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTlods\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQlodsb\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQlodsd\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQlodsq\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQlodsw\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETXlsl\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETXlss\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETXltr\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQlzcnt\NUL\NUL\NUL\NUL\NUL\NUL\NUL\nmaskmovdqu\NUL\NUL\NUL\NUL\NUL\NUL\NUL\bmaskmovq\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQmaxpd\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQmaxps\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQmaxsd\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQmaxss\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKmfence\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQminpd\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQminps\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQminsd\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQminss\NUL\NUL\NUL\NUL\NUL\NUL\NUL\amonitor\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETXmov\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKmovapd\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKmovaps\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQmovbe\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTmovd\NUL\NUL\NUL\NUL\NUL\NUL\NUL\amovddup\NUL\NUL\NUL\NUL\NUL\NUL\NUL\amovdq2q\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKmovdqa\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKmovdqu\NUL\NUL\NUL\NUL\NUL\NUL\NUL\amovhlps\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKmovhpd\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKmovhps\NUL\NUL\NUL\NUL\NUL\NUL\NUL\amovlhps\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKmovlpd\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKmovlps\NUL\NUL\NUL\NUL\NUL\NUL\NUL\bmovmskpd\NUL\NUL\NUL\NUL\NUL\NUL\NUL\bmovmskps\NUL\NUL\NUL\NUL\NUL\NUL\NUL\amovntdq\NUL\NUL\NUL\NUL\NUL\NUL\NUL\bmovntdqa\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKmovnti\NUL\NUL\NUL\NUL\NUL\NUL\NUL\amovntpd\NUL\NUL\NUL\NUL\NUL\NUL\NUL\amovntps\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKmovntq\NUL\NUL\NUL\NUL\NUL\NUL\NUL\amovntsd\NUL\NUL\NUL\NUL\NUL\NUL\NUL\amovntss\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTmovq\NUL\NUL\NUL\NUL\NUL\NUL\NUL\amovq2dq\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTmovs\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQmovsb\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQmovsd\NUL\NUL\NUL\NUL\NUL\NUL\NUL\bmovshdup\NUL\NUL\NUL\NUL\NUL\NUL\NUL\bmovsldup\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQmovsq\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQmovss\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQmovsw\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQmovsx\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKmovsxd\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKmovupd\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKmovups\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQmovzx\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ampsadbw\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETXmul\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQmulpd\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQmulps\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQmulsd\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQmulss\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTmulx\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQmwait\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETXneg\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETXnop\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETXnot\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STXor\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTorpd\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTorps\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETXout\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTouts\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQoutsb\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQoutsd\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQoutsw\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQpabsb\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQpabsd\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQpabsw\NUL\NUL\NUL\NUL\NUL\NUL\NUL\bpackssdw\NUL\NUL\NUL\NUL\NUL\NUL\NUL\bpacksswb\NUL\NUL\NUL\NUL\NUL\NUL\NUL\bpackusdw\NUL\NUL\NUL\NUL\NUL\NUL\NUL\bpackuswb\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQpaddb\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQpaddd\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQpaddq\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKpaddsb\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKpaddsw\NUL\NUL\NUL\NUL\NUL\NUL\NUL\apaddusb\NUL\NUL\NUL\NUL\NUL\NUL\NUL\apaddusw\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQpaddw\NUL\NUL\NUL\NUL\NUL\NUL\NUL\apalignr\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTpand\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQpandn\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQpause\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQpavgb\NUL\NUL\NUL\NUL\NUL\NUL\NUL\apavgusb\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQpavgw\NUL\NUL\NUL\NUL\NUL\NUL\NUL\bpblendvb\NUL\NUL\NUL\NUL\NUL\NUL\NUL\apblendw\NUL\NUL\NUL\NUL\NUL\NUL\NUL\tpclmulqdq\NUL\NUL\NUL\NUL\NUL\NUL\NUL\apcmpeqb\NUL\NUL\NUL\NUL\NUL\NUL\NUL\apcmpeqd\NUL\NUL\NUL\NUL\NUL\NUL\NUL\apcmpeqq\NUL\NUL\NUL\NUL\NUL\NUL\NUL\apcmpeqw\NUL\NUL\NUL\NUL\NUL\NUL\NUL\tpcmpestri\NUL\NUL\NUL\NUL\NUL\NUL\NUL\tpcmpestrm\NUL\NUL\NUL\NUL\NUL\NUL\NUL\apcmpgtb\NUL\NUL\NUL\NUL\NUL\NUL\NUL\apcmpgtd\NUL\NUL\NUL\NUL\NUL\NUL\NUL\apcmpgtq\NUL\NUL\NUL\NUL\NUL\NUL\NUL\apcmpgtw\NUL\NUL\NUL\NUL\NUL\NUL\NUL\tpcmpistri\NUL\NUL\NUL\NUL\NUL\NUL\NUL\tpcmpistrm\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTpdep\NUL\NUL\NUL\NUL\NUL\NUL\NUL\apdistib\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTpext\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKpextrb\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKpextrd\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKpextrq\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKpextrw\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQpf2id\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQpf2iw\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQpfacc\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQpfadd\NUL\NUL\NUL\NUL\NUL\NUL\NUL\apfcmpeq\NUL\NUL\NUL\NUL\NUL\NUL\NUL\apfcmpge\NUL\NUL\NUL\NUL\NUL\NUL\NUL\apfcmpgt\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQpfmax\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQpfmin\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQpfmul\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKpfnacc\NUL\NUL\NUL\NUL\NUL\NUL\NUL\apfpnacc\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQpfrcp\NUL\NUL\NUL\NUL\NUL\NUL\NUL\bpfrcpit1\NUL\NUL\NUL\NUL\NUL\NUL\NUL\bpfrcpit2\NUL\NUL\NUL\NUL\NUL\NUL\NUL\bpfrsqit1\NUL\NUL\NUL\NUL\NUL\NUL\NUL\apfrsqrt\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQpfsub\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKpfsubr\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKphaddd\NUL\NUL\NUL\NUL\NUL\NUL\NUL\aphaddsw\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKphaddw\NUL\NUL\NUL\NUL\NUL\NUL\NUL\nphminposuw\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKphsubd\NUL\NUL\NUL\NUL\NUL\NUL\NUL\aphsubsw\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKphsubw\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQpi2fd\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQpi2fw\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKpinsrb\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKpinsrd\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKpinsrq\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKpinsrw\NUL\NUL\NUL\NUL\NUL\NUL\NUL\bpmachriw\NUL\NUL\NUL\NUL\NUL\NUL\NUL\tpmaddubsw\NUL\NUL\NUL\NUL\NUL\NUL\NUL\apmaddwd\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQpmagw\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKpmaxsb\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKpmaxsd\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKpmaxsw\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKpmaxub\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKpmaxud\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKpmaxuw\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKpminsb\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKpminsd\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKpminsw\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKpminub\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKpminud\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKpminuw\NUL\NUL\NUL\NUL\NUL\NUL\NUL\bpmovmskb\NUL\NUL\NUL\NUL\NUL\NUL\NUL\bpmovsxbd\NUL\NUL\NUL\NUL\NUL\NUL\NUL\bpmovsxbq\NUL\NUL\NUL\NUL\NUL\NUL\NUL\bpmovsxbw\NUL\NUL\NUL\NUL\NUL\NUL\NUL\bpmovsxdq\NUL\NUL\NUL\NUL\NUL\NUL\NUL\bpmovsxwd\NUL\NUL\NUL\NUL\NUL\NUL\NUL\bpmovsxwq\NUL\NUL\NUL\NUL\NUL\NUL\NUL\bpmovzxbd\NUL\NUL\NUL\NUL\NUL\NUL\NUL\bpmovzxbq\NUL\NUL\NUL\NUL\NUL\NUL\NUL\bpmovzxbw\NUL\NUL\NUL\NUL\NUL\NUL\NUL\bpmovzxdq\NUL\NUL\NUL\NUL\NUL\NUL\NUL\bpmovzxwd\NUL\NUL\NUL\NUL\NUL\NUL\NUL\bpmovzxwq\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKpmuldq\NUL\NUL\NUL\NUL\NUL\NUL\NUL\bpmulhrsw\NUL\NUL\NUL\NUL\NUL\NUL\NUL\apmulhrw\NUL\NUL\NUL\NUL\NUL\NUL\NUL\apmulhuw\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKpmulhw\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKpmulld\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKpmullw\NUL\NUL\NUL\NUL\NUL\NUL\NUL\apmuludq\NUL\NUL\NUL\NUL\NUL\NUL\NUL\apmvgezb\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKpmvlzb\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKpmvnzb\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQpmvzb\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETXpop\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTpopa\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQpopad\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQpopaw\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKpopcnt\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTpopd\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTpopf\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQpopfd\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQpopfq\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQpopfw\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTpopw\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETXpor\NUL\NUL\NUL\NUL\NUL\NUL\NUL\bprefetch\NUL\NUL\NUL\NUL\NUL\NUL\NUL\vprefetchnta\NUL\NUL\NUL\NUL\NUL\NUL\NUL\nprefetcht0\NUL\NUL\NUL\NUL\NUL\NUL\NUL\nprefetcht1\NUL\NUL\NUL\NUL\NUL\NUL\NUL\nprefetcht2\NUL\NUL\NUL\NUL\NUL\NUL\NUL\tprefetchw\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKpsadbw\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKpshufb\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKpshufd\NUL\NUL\NUL\NUL\NUL\NUL\NUL\apshufhw\NUL\NUL\NUL\NUL\NUL\NUL\NUL\apshuflw\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKpshufw\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKpsignb\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKpsignd\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKpsignw\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQpslld\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKpslldq\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQpsllq\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQpsllw\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQpsrad\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQpsraw\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQpsrld\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKpsrldq\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQpsrlq\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQpsrlw\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQpsubb\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQpsubd\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQpsubq\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKpsubsb\NUL\NUL\NUL\NUL\NUL\NUL\NUL\apsubsiw\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKpsubsw\NUL\NUL\NUL\NUL\NUL\NUL\NUL\apsubusb\NUL\NUL\NUL\NUL\NUL\NUL\NUL\apsubusw\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQpsubw\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKpswapd\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQptest\NUL\NUL\NUL\NUL\NUL\NUL\NUL\tpunpckhbw\NUL\NUL\NUL\NUL\NUL\NUL\NUL\tpunpckhdq\NUL\NUL\NUL\NUL\NUL\NUL\NUL\npunpckhqdq\NUL\NUL\NUL\NUL\NUL\NUL\NUL\tpunpckhwd\NUL\NUL\NUL\NUL\NUL\NUL\NUL\tpunpcklbw\NUL\NUL\NUL\NUL\NUL\NUL\NUL\tpunpckldq\NUL\NUL\NUL\NUL\NUL\NUL\NUL\npunpcklqdq\NUL\NUL\NUL\NUL\NUL\NUL\NUL\tpunpcklwd\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTpush\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQpusha\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKpushad\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKpushaw\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQpushd\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQpushf\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKpushfd\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKpushfq\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKpushfw\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQpushw\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTpxor\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETXrcl\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQrcpps\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQrcpss\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETXrcr\NUL\NUL\NUL\NUL\NUL\NUL\NUL\brdfsbase\NUL\NUL\NUL\NUL\NUL\NUL\NUL\brdgsbase\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQrdmsr\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKrdmsrq\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQrdpmc\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKrdrand\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQrdshr\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQrdtsc\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKrdtscp\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETXrol\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETXror\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTrorx\NUL\NUL\NUL\NUL\NUL\NUL\NUL\aroundpd\NUL\NUL\NUL\NUL\NUL\NUL\NUL\aroundps\NUL\NUL\NUL\NUL\NUL\NUL\NUL\aroundsd\NUL\NUL\NUL\NUL\NUL\NUL\NUL\aroundss\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTrsdc\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQrsldt\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETXrsm\NUL\NUL\NUL\NUL\NUL\NUL\NUL\arsqrtps\NUL\NUL\NUL\NUL\NUL\NUL\NUL\arsqrtss\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTrsts\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTsahf\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETXsal\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTsalc\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETXsar\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTsarx\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETXsbb\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTscas\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQscasb\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQscasd\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQscasq\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQscasw\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETXset\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTseta\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQsetae\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTsetb\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQsetbe\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTsetc\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTsete\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTsetg\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQsetge\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTsetl\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQsetle\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQsetna\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKsetnae\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQsetnb\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKsetnbe\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQsetnc\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQsetne\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQsetng\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKsetnge\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQsetnl\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKsetnle\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQsetno\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQsetnp\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQsetns\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQsetnz\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTseto\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTsetp\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQsetpe\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQsetpo\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTsets\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTsetz\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKsfence\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTsgdt\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETXshl\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTshld\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTshlx\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETXshr\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTshrd\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTshrx\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKshufpd\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKshufps\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTsidt\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKskinit\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTsldt\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETXsmi\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQsmint\NUL\NUL\NUL\NUL\NUL\NUL\NUL\bsmintold\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTsmsw\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKsqrtpd\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKsqrtps\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKsqrtsd\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKsqrtss\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETXstc\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETXstd\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTstgi\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETXsti\NUL\NUL\NUL\NUL\NUL\NUL\NUL\astmxcsr\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTstos\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQstosb\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQstosd\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQstosq\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQstosw\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETXstr\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETXsub\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQsubpd\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQsubps\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQsubsd\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQsubss\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTsvdc\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQsvldt\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTsvts\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKswapgs\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKt1mskc\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTtest\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQtzcnt\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQtzmsk\NUL\NUL\NUL\NUL\NUL\NUL\NUL\aucomisd\NUL\NUL\NUL\NUL\NUL\NUL\NUL\aucomiss\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETXud0\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETXud1\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETXud2\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTumov\NUL\NUL\NUL\NUL\NUL\NUL\NUL\bunpckhpd\NUL\NUL\NUL\NUL\NUL\NUL\NUL\bunpckhps\NUL\NUL\NUL\NUL\NUL\NUL\NUL\bunpcklpd\NUL\NUL\NUL\NUL\NUL\NUL\NUL\bunpcklps\NUL\NUL\NUL\NUL\NUL\NUL\NUL\avaesenc\NUL\NUL\NUL\NUL\NUL\NUL\NUL\vvaesenclast\NUL\NUL\NUL\NUL\NUL\NUL\NUL\avaesimc\NUL\NUL\NUL\NUL\NUL\NUL\NUL\tvblendvpd\NUL\NUL\NUL\NUL\NUL\NUL\NUL\tvblendvps\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOvbroadcastf128\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOvbroadcasti128\NUL\NUL\NUL\NUL\NUL\NUL\NUL\fvbroadcastsd\NUL\NUL\NUL\NUL\NUL\NUL\NUL\fvbroadcastss\NUL\NUL\NUL\NUL\NUL\NUL\NUL\avcomisd\NUL\NUL\NUL\NUL\NUL\NUL\NUL\avcomiss\NUL\NUL\NUL\NUL\NUL\NUL\NUL\tvcvtdq2pd\NUL\NUL\NUL\NUL\NUL\NUL\NUL\tvcvtdq2ps\NUL\NUL\NUL\NUL\NUL\NUL\NUL\tvcvtpd2dq\NUL\NUL\NUL\NUL\NUL\NUL\NUL\tvcvtpd2ps\NUL\NUL\NUL\NUL\NUL\NUL\NUL\tvcvtph2ps\NUL\NUL\NUL\NUL\NUL\NUL\NUL\tvcvtps2dq\NUL\NUL\NUL\NUL\NUL\NUL\NUL\tvcvtps2pd\NUL\NUL\NUL\NUL\NUL\NUL\NUL\tvcvtps2ph\NUL\NUL\NUL\NUL\NUL\NUL\NUL\tvcvtsd2si\NUL\NUL\NUL\NUL\NUL\NUL\NUL\tvcvtsd2ss\NUL\NUL\NUL\NUL\NUL\NUL\NUL\tvcvtsi2sd\NUL\NUL\NUL\NUL\NUL\NUL\NUL\tvcvtsi2ss\NUL\NUL\NUL\NUL\NUL\NUL\NUL\tvcvtss2sd\NUL\NUL\NUL\NUL\NUL\NUL\NUL\tvcvtss2si\NUL\NUL\NUL\NUL\NUL\NUL\NUL\nvcvttpd2dq\NUL\NUL\NUL\NUL\NUL\NUL\NUL\nvcvttps2dq\NUL\NUL\NUL\NUL\NUL\NUL\NUL\nvcvttsd2si\NUL\NUL\NUL\NUL\NUL\NUL\NUL\nvcvttss2si\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQvdppd\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTverr\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTverw\NUL\NUL\NUL\NUL\NUL\NUL\NUL\fvextractf128\NUL\NUL\NUL\NUL\NUL\NUL\NUL\fvextracti128\NUL\NUL\NUL\NUL\NUL\NUL\NUL\nvextractps\NUL\NUL\NUL\NUL\NUL\NUL\NUL\bvfm132pd\NUL\NUL\NUL\NUL\NUL\NUL\NUL\bvfm132ps\NUL\NUL\NUL\NUL\NUL\NUL\NUL\bvfm132sd\NUL\NUL\NUL\NUL\NUL\NUL\NUL\bvfm132ss\NUL\NUL\NUL\NUL\NUL\NUL\NUL\bvfm213pd\NUL\NUL\NUL\NUL\NUL\NUL\NUL\bvfm213ps\NUL\NUL\NUL\NUL\NUL\NUL\NUL\bvfm213sd\NUL\NUL\NUL\NUL\NUL\NUL\NUL\bvfm213ss\NUL\NUL\NUL\NUL\NUL\NUL\NUL\bvfm231pd\NUL\NUL\NUL\NUL\NUL\NUL\NUL\bvfm231ps\NUL\NUL\NUL\NUL\NUL\NUL\NUL\bvfm231sd\NUL\NUL\NUL\NUL\NUL\NUL\NUL\bvfm231ss\NUL\NUL\NUL\NUL\NUL\NUL\NUL\vvfmadd132pd\NUL\NUL\NUL\NUL\NUL\NUL\NUL\vvfmadd132ps\NUL\NUL\NUL\NUL\NUL\NUL\NUL\vvfmadd132sd\NUL\NUL\NUL\NUL\NUL\NUL\NUL\vvfmadd132ss\NUL\NUL\NUL\NUL\NUL\NUL\NUL\vvfmadd213pd\NUL\NUL\NUL\NUL\NUL\NUL\NUL\vvfmadd213ps\NUL\NUL\NUL\NUL\NUL\NUL\NUL\vvfmadd213sd\NUL\NUL\NUL\NUL\NUL\NUL\NUL\vvfmadd213ss\NUL\NUL\NUL\NUL\NUL\NUL\NUL\vvfmadd231pd\NUL\NUL\NUL\NUL\NUL\NUL\NUL\vvfmadd231ps\NUL\NUL\NUL\NUL\NUL\NUL\NUL\vvfmadd231sd\NUL\NUL\NUL\NUL\NUL\NUL\NUL\vvfmadd231ss\NUL\NUL\NUL\NUL\NUL\NUL\NUL\bvfmaddpd\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOvfmaddsub132pd\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOvfmaddsub132ps\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOvfmaddsub213pd\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOvfmaddsub213ps\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOvfmaddsub231pd\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOvfmaddsub231ps\NUL\NUL\NUL\NUL\NUL\NUL\NUL\vvfmsub132pd\NUL\NUL\NUL\NUL\NUL\NUL\NUL\vvfmsub132ps\NUL\NUL\NUL\NUL\NUL\NUL\NUL\vvfmsub132sd\NUL\NUL\NUL\NUL\NUL\NUL\NUL\vvfmsub132ss\NUL\NUL\NUL\NUL\NUL\NUL\NUL\vvfmsub213pd\NUL\NUL\NUL\NUL\NUL\NUL\NUL\vvfmsub213ps\NUL\NUL\NUL\NUL\NUL\NUL\NUL\vvfmsub213sd\NUL\NUL\NUL\NUL\NUL\NUL\NUL\vvfmsub213ss\NUL\NUL\NUL\NUL\NUL\NUL\NUL\vvfmsub231pd\NUL\NUL\NUL\NUL\NUL\NUL\NUL\vvfmsub231ps\NUL\NUL\NUL\NUL\NUL\NUL\NUL\vvfmsub231sd\NUL\NUL\NUL\NUL\NUL\NUL\NUL\vvfmsub231ss\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOvfmsubadd132pd\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOvfmsubadd132ps\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOvfmsubadd213pd\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOvfmsubadd213ps\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOvfmsubadd231pd\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOvfmsubadd231ps\NUL\NUL\NUL\NUL\NUL\NUL\NUL\bvfmsubss\NUL\NUL\NUL\NUL\NUL\NUL\NUL\tvfnm132pd\NUL\NUL\NUL\NUL\NUL\NUL\NUL\tvfnm132ps\NUL\NUL\NUL\NUL\NUL\NUL\NUL\tvfnm132sd\NUL\NUL\NUL\NUL\NUL\NUL\NUL\tvfnm132ss\NUL\NUL\NUL\NUL\NUL\NUL\NUL\tvfnm213pd\NUL\NUL\NUL\NUL\NUL\NUL\NUL\tvfnm213ps\NUL\NUL\NUL\NUL\NUL\NUL\NUL\tvfnm213sd\NUL\NUL\NUL\NUL\NUL\NUL\NUL\tvfnm213ss\NUL\NUL\NUL\NUL\NUL\NUL\NUL\tvfnm231pd\NUL\NUL\NUL\NUL\NUL\NUL\NUL\tvfnm231ps\NUL\NUL\NUL\NUL\NUL\NUL\NUL\tvfnm231sd\NUL\NUL\NUL\NUL\NUL\NUL\NUL\tvfnm231ss\NUL\NUL\NUL\NUL\NUL\NUL\NUL\fvfnmadd132pd\NUL\NUL\NUL\NUL\NUL\NUL\NUL\fvfnmadd132ps\NUL\NUL\NUL\NUL\NUL\NUL\NUL\fvfnmadd132sd\NUL\NUL\NUL\NUL\NUL\NUL\NUL\fvfnmadd132ss\NUL\NUL\NUL\NUL\NUL\NUL\NUL\fvfnmadd213pd\NUL\NUL\NUL\NUL\NUL\NUL\NUL\fvfnmadd213ps\NUL\NUL\NUL\NUL\NUL\NUL\NUL\fvfnmadd213sd\NUL\NUL\NUL\NUL\NUL\NUL\NUL\fvfnmadd213ss\NUL\NUL\NUL\NUL\NUL\NUL\NUL\fvfnmadd231pd\NUL\NUL\NUL\NUL\NUL\NUL\NUL\fvfnmadd231ps\NUL\NUL\NUL\NUL\NUL\NUL\NUL\fvfnmadd231sd\NUL\NUL\NUL\NUL\NUL\NUL\NUL\fvfnmadd231ss\NUL\NUL\NUL\NUL\NUL\NUL\NUL\fvfnmsub132pd\NUL\NUL\NUL\NUL\NUL\NUL\NUL\fvfnmsub132ps\NUL\NUL\NUL\NUL\NUL\NUL\NUL\fvfnmsub132sd\NUL\NUL\NUL\NUL\NUL\NUL\NUL\fvfnmsub132ss\NUL\NUL\NUL\NUL\NUL\NUL\NUL\fvfnmsub213pd\NUL\NUL\NUL\NUL\NUL\NUL\NUL\fvfnmsub213ps\NUL\NUL\NUL\NUL\NUL\NUL\NUL\fvfnmsub213sd\NUL\NUL\NUL\NUL\NUL\NUL\NUL\fvfnmsub213ss\NUL\NUL\NUL\NUL\NUL\NUL\NUL\fvfnmsub231pd\NUL\NUL\NUL\NUL\NUL\NUL\NUL\fvfnmsub231ps\NUL\NUL\NUL\NUL\NUL\NUL\NUL\fvfnmsub231sd\NUL\NUL\NUL\NUL\NUL\NUL\NUL\fvfnmsub231ss\NUL\NUL\NUL\NUL\NUL\NUL\NUL\avfrczpd\NUL\NUL\NUL\NUL\NUL\NUL\NUL\avfrczps\NUL\NUL\NUL\NUL\NUL\NUL\NUL\avfrczsd\NUL\NUL\NUL\NUL\NUL\NUL\NUL\avfrczss\NUL\NUL\NUL\NUL\NUL\NUL\NUL\nvgatherdpd\NUL\NUL\NUL\NUL\NUL\NUL\NUL\nvgatherdps\NUL\NUL\NUL\NUL\NUL\NUL\NUL\nvgatherqpd\NUL\NUL\NUL\NUL\NUL\NUL\NUL\nvgatherqps\NUL\NUL\NUL\NUL\NUL\NUL\NUL\vvinsertf128\NUL\NUL\NUL\NUL\NUL\NUL\NUL\vvinserti128\NUL\NUL\NUL\NUL\NUL\NUL\NUL\tvinsertps\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKvlddqu\NUL\NUL\NUL\NUL\NUL\NUL\NUL\bvldmxcsr\NUL\NUL\NUL\NUL\NUL\NUL\NUL\vvmaskmovdqu\NUL\NUL\NUL\NUL\NUL\NUL\NUL\nvmaskmovpd\NUL\NUL\NUL\NUL\NUL\NUL\NUL\nvmaskmovps\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKvmcall\NUL\NUL\NUL\NUL\NUL\NUL\NUL\avmclear\NUL\NUL\NUL\NUL\NUL\NUL\NUL\bvmlaunch\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKvmload\NUL\NUL\NUL\NUL\NUL\NUL\NUL\avmmcall\NUL\NUL\NUL\NUL\NUL\NUL\NUL\avmovapd\NUL\NUL\NUL\NUL\NUL\NUL\NUL\avmovaps\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQvmovd\NUL\NUL\NUL\NUL\NUL\NUL\NUL\bvmovddup\NUL\NUL\NUL\NUL\NUL\NUL\NUL\avmovdqa\NUL\NUL\NUL\NUL\NUL\NUL\NUL\avmovdqu\NUL\NUL\NUL\NUL\NUL\NUL\NUL\bvmovhlps\NUL\NUL\NUL\NUL\NUL\NUL\NUL\avmovhpd\NUL\NUL\NUL\NUL\NUL\NUL\NUL\avmovhps\NUL\NUL\NUL\NUL\NUL\NUL\NUL\bvmovlhps\NUL\NUL\NUL\NUL\NUL\NUL\NUL\avmovlpd\NUL\NUL\NUL\NUL\NUL\NUL\NUL\avmovlps\NUL\NUL\NUL\NUL\NUL\NUL\NUL\tvmovmskpd\NUL\NUL\NUL\NUL\NUL\NUL\NUL\tvmovmskps\NUL\NUL\NUL\NUL\NUL\NUL\NUL\bvmovntdq\NUL\NUL\NUL\NUL\NUL\NUL\NUL\tvmovntdqa\NUL\NUL\NUL\NUL\NUL\NUL\NUL\bvmovntpd\NUL\NUL\NUL\NUL\NUL\NUL\NUL\bvmovntps\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQvmovq\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKvmovsd\NUL\NUL\NUL\NUL\NUL\NUL\NUL\tvmovshdup\NUL\NUL\NUL\NUL\NUL\NUL\NUL\tvmovsldup\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKvmovss\NUL\NUL\NUL\NUL\NUL\NUL\NUL\avmovupd\NUL\NUL\NUL\NUL\NUL\NUL\NUL\avmovups\NUL\NUL\NUL\NUL\NUL\NUL\NUL\avmptrld\NUL\NUL\NUL\NUL\NUL\NUL\NUL\avmptrst\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKvmread\NUL\NUL\NUL\NUL\NUL\NUL\NUL\bvmresume\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQvmrun\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKvmsave\NUL\NUL\NUL\NUL\NUL\NUL\NUL\avmwrite\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKvmxoff\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQvmxon\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKvpabsb\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKvpabsd\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKvpabsw\NUL\NUL\NUL\NUL\NUL\NUL\NUL\tvpackssdw\NUL\NUL\NUL\NUL\NUL\NUL\NUL\tvpacksswb\NUL\NUL\NUL\NUL\NUL\NUL\NUL\tvpackusdw\NUL\NUL\NUL\NUL\NUL\NUL\NUL\tvpackuswb\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKvpaddb\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKvpaddd\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKvpaddq\NUL\NUL\NUL\NUL\NUL\NUL\NUL\avpaddsb\NUL\NUL\NUL\NUL\NUL\NUL\NUL\avpaddsw\NUL\NUL\NUL\NUL\NUL\NUL\NUL\bvpaddusb\NUL\NUL\NUL\NUL\NUL\NUL\NUL\bvpaddusw\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKvpaddw\NUL\NUL\NUL\NUL\NUL\NUL\NUL\bvpalignr\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQvpand\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKvpandn\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKvpause\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKvpavgb\NUL\NUL\NUL\NUL\NUL\NUL\NUL\bvpavgusb\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKvpavgw\NUL\NUL\NUL\NUL\NUL\NUL\NUL\tvpblendvb\NUL\NUL\NUL\NUL\NUL\NUL\NUL\bvpblendw\NUL\NUL\NUL\NUL\NUL\NUL\NUL\fvpbroadcastb\NUL\NUL\NUL\NUL\NUL\NUL\NUL\fvpbroadcastd\NUL\NUL\NUL\NUL\NUL\NUL\NUL\fvpbroadcastq\NUL\NUL\NUL\NUL\NUL\NUL\NUL\fvpbroadcastw\NUL\NUL\NUL\NUL\NUL\NUL\NUL\nvpclmulqdq\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKvpcmov\NUL\NUL\NUL\NUL\NUL\NUL\NUL\bvpcmpeqb\NUL\NUL\NUL\NUL\NUL\NUL\NUL\bvpcmpeqd\NUL\NUL\NUL\NUL\NUL\NUL\NUL\bvpcmpeqq\NUL\NUL\NUL\NUL\NUL\NUL\NUL\bvpcmpeqw\NUL\NUL\NUL\NUL\NUL\NUL\NUL\nvpcmpestri\NUL\NUL\NUL\NUL\NUL\NUL\NUL\nvpcmpestrm\NUL\NUL\NUL\NUL\NUL\NUL\NUL\bvpcmpgtb\NUL\NUL\NUL\NUL\NUL\NUL\NUL\bvpcmpgtd\NUL\NUL\NUL\NUL\NUL\NUL\NUL\bvpcmpgtq\NUL\NUL\NUL\NUL\NUL\NUL\NUL\bvpcmpgtw\NUL\NUL\NUL\NUL\NUL\NUL\NUL\nvpcmpistri\NUL\NUL\NUL\NUL\NUL\NUL\NUL\nvpcmpistrm\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKvpcomb\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKvpcomd\NUL\NUL\NUL\NUL\NUL\NUL\NUL\bvpcomeqb\NUL\NUL\NUL\NUL\NUL\NUL\NUL\bvpcomeqd\NUL\NUL\NUL\NUL\NUL\NUL\NUL\bvpcomeqq\NUL\NUL\NUL\NUL\NUL\NUL\NUL\tvpcomequb\NUL\NUL\NUL\NUL\NUL\NUL\NUL\tvpcomequd\NUL\NUL\NUL\NUL\NUL\NUL\NUL\tvpcomequq\NUL\NUL\NUL\NUL\NUL\NUL\NUL\tvpcomequw\NUL\NUL\NUL\NUL\NUL\NUL\NUL\bvpcomeqw\NUL\NUL\NUL\NUL\NUL\NUL\NUL\vvpcomfalseb\NUL\NUL\NUL\NUL\NUL\NUL\NUL\vvpcomfalsed\NUL\NUL\NUL\NUL\NUL\NUL\NUL\vvpcomfalseq\NUL\NUL\NUL\NUL\NUL\NUL\NUL\fvpcomfalseub\NUL\NUL\NUL\NUL\NUL\NUL\NUL\fvpcomfalseud\NUL\NUL\NUL\NUL\NUL\NUL\NUL\fvpcomfalseuq\NUL\NUL\NUL\NUL\NUL\NUL\NUL\fvpcomfalseuw\NUL\NUL\NUL\NUL\NUL\NUL\NUL\vvpcomfalsew\NUL\NUL\NUL\NUL\NUL\NUL\NUL\bvpcomgeb\NUL\NUL\NUL\NUL\NUL\NUL\NUL\bvpcomged\NUL\NUL\NUL\NUL\NUL\NUL\NUL\bvpcomgeq\NUL\NUL\NUL\NUL\NUL\NUL\NUL\tvpcomgeub\NUL\NUL\NUL\NUL\NUL\NUL\NUL\tvpcomgeud\NUL\NUL\NUL\NUL\NUL\NUL\NUL\tvpcomgeuq\NUL\NUL\NUL\NUL\NUL\NUL\NUL\tvpcomgeuw\NUL\NUL\NUL\NUL\NUL\NUL\NUL\bvpcomgew\NUL\NUL\NUL\NUL\NUL\NUL\NUL\bvpcomgtb\NUL\NUL\NUL\NUL\NUL\NUL\NUL\bvpcomgtd\NUL\NUL\NUL\NUL\NUL\NUL\NUL\bvpcomgtq\NUL\NUL\NUL\NUL\NUL\NUL\NUL\tvpcomgtub\NUL\NUL\NUL\NUL\NUL\NUL\NUL\tvpcomgtud\NUL\NUL\NUL\NUL\NUL\NUL\NUL\tvpcomgtuq\NUL\NUL\NUL\NUL\NUL\NUL\NUL\tvpcomgtuw\NUL\NUL\NUL\NUL\NUL\NUL\NUL\bvpcomgtw\NUL\NUL\NUL\NUL\NUL\NUL\NUL\bvpcomleb\NUL\NUL\NUL\NUL\NUL\NUL\NUL\bvpcomled\NUL\NUL\NUL\NUL\NUL\NUL\NUL\bvpcomleq\NUL\NUL\NUL\NUL\NUL\NUL\NUL\tvpcomleub\NUL\NUL\NUL\NUL\NUL\NUL\NUL\tvpcomleud\NUL\NUL\NUL\NUL\NUL\NUL\NUL\tvpcomleuq\NUL\NUL\NUL\NUL\NUL\NUL\NUL\tvpcomleuw\NUL\NUL\NUL\NUL\NUL\NUL\NUL\bvpcomlew\NUL\NUL\NUL\NUL\NUL\NUL\NUL\bvpcomltb\NUL\NUL\NUL\NUL\NUL\NUL\NUL\bvpcomltd\NUL\NUL\NUL\NUL\NUL\NUL\NUL\bvpcomltq\NUL\NUL\NUL\NUL\NUL\NUL\NUL\tvpcomltub\NUL\NUL\NUL\NUL\NUL\NUL\NUL\tvpcomltud\NUL\NUL\NUL\NUL\NUL\NUL\NUL\tvpcomltuq\NUL\NUL\NUL\NUL\NUL\NUL\NUL\tvpcomltuw\NUL\NUL\NUL\NUL\NUL\NUL\NUL\bvpcomltw\NUL\NUL\NUL\NUL\NUL\NUL\NUL\tvpcomneqb\NUL\NUL\NUL\NUL\NUL\NUL\NUL\tvpcomneqd\NUL\NUL\NUL\NUL\NUL\NUL\NUL\tvpcomneqq\NUL\NUL\NUL\NUL\NUL\NUL\NUL\nvpcomnequb\NUL\NUL\NUL\NUL\NUL\NUL\NUL\nvpcomnequd\NUL\NUL\NUL\NUL\NUL\NUL\NUL\nvpcomnequq\NUL\NUL\NUL\NUL\NUL\NUL\NUL\nvpcomnequw\NUL\NUL\NUL\NUL\NUL\NUL\NUL\tvpcomneqw\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKvpcomq\NUL\NUL\NUL\NUL\NUL\NUL\NUL\nvpcomtrueb\NUL\NUL\NUL\NUL\NUL\NUL\NUL\nvpcomtrued\NUL\NUL\NUL\NUL\NUL\NUL\NUL\nvpcomtrueq\NUL\NUL\NUL\NUL\NUL\NUL\NUL\vvpcomtrueub\NUL\NUL\NUL\NUL\NUL\NUL\NUL\vvpcomtrueud\NUL\NUL\NUL\NUL\NUL\NUL\NUL\vvpcomtrueuq\NUL\NUL\NUL\NUL\NUL\NUL\NUL\vvpcomtrueuw\NUL\NUL\NUL\NUL\NUL\NUL\NUL\nvpcomtruew\NUL\NUL\NUL\NUL\NUL\NUL\NUL\avpcomub\NUL\NUL\NUL\NUL\NUL\NUL\NUL\avpcomud\NUL\NUL\NUL\NUL\NUL\NUL\NUL\avpcomuq\NUL\NUL\NUL\NUL\NUL\NUL\NUL\avpcomuw\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKvpcomw\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQvpdep\NUL\NUL\NUL\NUL\NUL\NUL\NUL\bvpdistib\NUL\NUL\NUL\NUL\NUL\NUL\NUL\nvperm2f128\NUL\NUL\NUL\NUL\NUL\NUL\NUL\nvperm2i128\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKvpermd\NUL\NUL\NUL\NUL\NUL\NUL\NUL\nvpermil2pd\NUL\NUL\NUL\NUL\NUL\NUL\NUL\nvpermil2ps\NUL\NUL\NUL\NUL\NUL\NUL\NUL\tvpermilpd\NUL\NUL\NUL\NUL\NUL\NUL\NUL\tvpermilps\NUL\NUL\NUL\NUL\NUL\NUL\NUL\avpermpd\NUL\NUL\NUL\NUL\NUL\NUL\NUL\avpermps\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKvpermq\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQvpext\NUL\NUL\NUL\NUL\NUL\NUL\NUL\avpextrb\NUL\NUL\NUL\NUL\NUL\NUL\NUL\avpextrd\NUL\NUL\NUL\NUL\NUL\NUL\NUL\avpextrq\NUL\NUL\NUL\NUL\NUL\NUL\NUL\avpextrw\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKvpf2id\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKvpf2iw\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKvpfacc\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKvpfadd\NUL\NUL\NUL\NUL\NUL\NUL\NUL\bvpfcmpeq\NUL\NUL\NUL\NUL\NUL\NUL\NUL\bvpfcmpge\NUL\NUL\NUL\NUL\NUL\NUL\NUL\bvpfcmpgt\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKvpfmax\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKvpfmin\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKvpfmul\NUL\NUL\NUL\NUL\NUL\NUL\NUL\avpfnacc\NUL\NUL\NUL\NUL\NUL\NUL\NUL\bvpfpnacc\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKvpfrcp\NUL\NUL\NUL\NUL\NUL\NUL\NUL\tvpfrcpit1\NUL\NUL\NUL\NUL\NUL\NUL\NUL\tvpfrcpit2\NUL\NUL\NUL\NUL\NUL\NUL\NUL\tvpfrsqit1\NUL\NUL\NUL\NUL\NUL\NUL\NUL\bvpfrsqrt\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKvpfsub\NUL\NUL\NUL\NUL\NUL\NUL\NUL\avpfsubr\NUL\NUL\NUL\NUL\NUL\NUL\NUL\nvpgatherdd\NUL\NUL\NUL\NUL\NUL\NUL\NUL\nvpgatherdq\NUL\NUL\NUL\NUL\NUL\NUL\NUL\nvpgatherqd\NUL\NUL\NUL\NUL\NUL\NUL\NUL\nvpgatherqq\NUL\NUL\NUL\NUL\NUL\NUL\NUL\bvphaddbd\NUL\NUL\NUL\NUL\NUL\NUL\NUL\bvphaddbq\NUL\NUL\NUL\NUL\NUL\NUL\NUL\bvphaddbw\NUL\NUL\NUL\NUL\NUL\NUL\NUL\avphaddd\NUL\NUL\NUL\NUL\NUL\NUL\NUL\bvphadddq\NUL\NUL\NUL\NUL\NUL\NUL\NUL\bvphaddsw\NUL\NUL\NUL\NUL\NUL\NUL\NUL\tvphaddubd\NUL\NUL\NUL\NUL\NUL\NUL\NUL\tvphaddubq\NUL\NUL\NUL\NUL\NUL\NUL\NUL\tvphaddubw\NUL\NUL\NUL\NUL\NUL\NUL\NUL\tvphaddudq\NUL\NUL\NUL\NUL\NUL\NUL\NUL\tvphadduwd\NUL\NUL\NUL\NUL\NUL\NUL\NUL\tvphadduwq\NUL\NUL\NUL\NUL\NUL\NUL\NUL\avphaddw\NUL\NUL\NUL\NUL\NUL\NUL\NUL\bvphaddwd\NUL\NUL\NUL\NUL\NUL\NUL\NUL\bvphaddwq\NUL\NUL\NUL\NUL\NUL\NUL\NUL\vvphminposuw\NUL\NUL\NUL\NUL\NUL\NUL\NUL\bvphsubbw\NUL\NUL\NUL\NUL\NUL\NUL\NUL\avphsubd\NUL\NUL\NUL\NUL\NUL\NUL\NUL\bvphsubdq\NUL\NUL\NUL\NUL\NUL\NUL\NUL\bvphsubsw\NUL\NUL\NUL\NUL\NUL\NUL\NUL\avphsubw\NUL\NUL\NUL\NUL\NUL\NUL\NUL\bvphsubwd\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKvpi2fd\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKvpi2fw\NUL\NUL\NUL\NUL\NUL\NUL\NUL\avpinsrb\NUL\NUL\NUL\NUL\NUL\NUL\NUL\avpinsrd\NUL\NUL\NUL\NUL\NUL\NUL\NUL\avpinsrq\NUL\NUL\NUL\NUL\NUL\NUL\NUL\avpinsrw\NUL\NUL\NUL\NUL\NUL\NUL\NUL\tvpmachriw\NUL\NUL\NUL\NUL\NUL\NUL\NUL\bvpmacsdd\NUL\NUL\NUL\NUL\NUL\NUL\NUL\tvpmacsdqh\NUL\NUL\NUL\NUL\NUL\NUL\NUL\tvpmacsdql\NUL\NUL\NUL\NUL\NUL\NUL\NUL\tvpmacssdd\NUL\NUL\NUL\NUL\NUL\NUL\NUL\nvpmacssdqh\NUL\NUL\NUL\NUL\NUL\NUL\NUL\nvpmacssdql\NUL\NUL\NUL\NUL\NUL\NUL\NUL\tvpmacsswd\NUL\NUL\NUL\NUL\NUL\NUL\NUL\tvpmacssww\NUL\NUL\NUL\NUL\NUL\NUL\NUL\bvpmacswd\NUL\NUL\NUL\NUL\NUL\NUL\NUL\bvpmacsww\NUL\NUL\NUL\NUL\NUL\NUL\NUL\nvpmadcsswd\NUL\NUL\NUL\NUL\NUL\NUL\NUL\tvpmadcswd\NUL\NUL\NUL\NUL\NUL\NUL\NUL\nvpmaddubsw\NUL\NUL\NUL\NUL\NUL\NUL\NUL\bvpmaddwd\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKvpmagw\NUL\NUL\NUL\NUL\NUL\NUL\NUL\nvpmaskmovd\NUL\NUL\NUL\NUL\NUL\NUL\NUL\nvpmaskmovq\NUL\NUL\NUL\NUL\NUL\NUL\NUL\avpmaxsb\NUL\NUL\NUL\NUL\NUL\NUL\NUL\avpmaxsd\NUL\NUL\NUL\NUL\NUL\NUL\NUL\avpmaxsw\NUL\NUL\NUL\NUL\NUL\NUL\NUL\avpmaxub\NUL\NUL\NUL\NUL\NUL\NUL\NUL\avpmaxud\NUL\NUL\NUL\NUL\NUL\NUL\NUL\avpmaxuw\NUL\NUL\NUL\NUL\NUL\NUL\NUL\avpminsb\NUL\NUL\NUL\NUL\NUL\NUL\NUL\avpminsd\NUL\NUL\NUL\NUL\NUL\NUL\NUL\avpminsw\NUL\NUL\NUL\NUL\NUL\NUL\NUL\avpminub\NUL\NUL\NUL\NUL\NUL\NUL\NUL\avpminud\NUL\NUL\NUL\NUL\NUL\NUL\NUL\avpminuw\NUL\NUL\NUL\NUL\NUL\NUL\NUL\tvpmovmskb\NUL\NUL\NUL\NUL\NUL\NUL\NUL\tvpmovsxbd\NUL\NUL\NUL\NUL\NUL\NUL\NUL\tvpmovsxbq\NUL\NUL\NUL\NUL\NUL\NUL\NUL\tvpmovsxbw\NUL\NUL\NUL\NUL\NUL\NUL\NUL\tvpmovsxdq\NUL\NUL\NUL\NUL\NUL\NUL\NUL\tvpmovsxwd\NUL\NUL\NUL\NUL\NUL\NUL\NUL\tvpmovsxwq\NUL\NUL\NUL\NUL\NUL\NUL\NUL\tvpmovzxbd\NUL\NUL\NUL\NUL\NUL\NUL\NUL\tvpmovzxbq\NUL\NUL\NUL\NUL\NUL\NUL\NUL\tvpmovzxbw\NUL\NUL\NUL\NUL\NUL\NUL\NUL\tvpmovzxdq\NUL\NUL\NUL\NUL\NUL\NUL\NUL\tvpmovzxwd\NUL\NUL\NUL\NUL\NUL\NUL\NUL\tvpmovzxwq\NUL\NUL\NUL\NUL\NUL\NUL\NUL\avpmuldq\NUL\NUL\NUL\NUL\NUL\NUL\NUL\tvpmulhrsw\NUL\NUL\NUL\NUL\NUL\NUL\NUL\bvpmulhrw\NUL\NUL\NUL\NUL\NUL\NUL\NUL\bvpmulhuw\NUL\NUL\NUL\NUL\NUL\NUL\NUL\avpmulhw\NUL\NUL\NUL\NUL\NUL\NUL\NUL\avpmulld\NUL\NUL\NUL\NUL\NUL\NUL\NUL\avpmullw\NUL\NUL\NUL\NUL\NUL\NUL\NUL\bvpmuludq\NUL\NUL\NUL\NUL\NUL\NUL\NUL\bvpmvgezb\NUL\NUL\NUL\NUL\NUL\NUL\NUL\avpmvlzb\NUL\NUL\NUL\NUL\NUL\NUL\NUL\avpmvnzb\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKvpmvzb\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTvpor\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKvpperm\NUL\NUL\NUL\NUL\NUL\NUL\NUL\tvprefetch\NUL\NUL\NUL\NUL\NUL\NUL\NUL\fvprefetchnta\NUL\NUL\NUL\NUL\NUL\NUL\NUL\vvprefetcht0\NUL\NUL\NUL\NUL\NUL\NUL\NUL\vvprefetcht1\NUL\NUL\NUL\NUL\NUL\NUL\NUL\vvprefetcht2\NUL\NUL\NUL\NUL\NUL\NUL\NUL\nvprefetchw\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKvprotb\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKvprotd\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKvprotq\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKvprotw\NUL\NUL\NUL\NUL\NUL\NUL\NUL\avpsadbw\NUL\NUL\NUL\NUL\NUL\NUL\NUL\vvpscatterdd\NUL\NUL\NUL\NUL\NUL\NUL\NUL\vvpscatterdq\NUL\NUL\NUL\NUL\NUL\NUL\NUL\vvpscatterqd\NUL\NUL\NUL\NUL\NUL\NUL\NUL\vvpscatterqq\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKvpshab\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKvpshad\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKvpshaq\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKvpshaw\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKvpshlb\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKvpshld\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKvpshlq\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKvpshlw\NUL\NUL\NUL\NUL\NUL\NUL\NUL\avpshufb\NUL\NUL\NUL\NUL\NUL\NUL\NUL\avpshufd\NUL\NUL\NUL\NUL\NUL\NUL\NUL\bvpshufhw\NUL\NUL\NUL\NUL\NUL\NUL\NUL\bvpshuflw\NUL\NUL\NUL\NUL\NUL\NUL\NUL\avpshufw\NUL\NUL\NUL\NUL\NUL\NUL\NUL\avpsignb\NUL\NUL\NUL\NUL\NUL\NUL\NUL\avpsignd\NUL\NUL\NUL\NUL\NUL\NUL\NUL\avpsignw\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKvpslld\NUL\NUL\NUL\NUL\NUL\NUL\NUL\avpslldq\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKvpsllq\NUL\NUL\NUL\NUL\NUL\NUL\NUL\avpsllvd\NUL\NUL\NUL\NUL\NUL\NUL\NUL\avpsllvq\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKvpsllw\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKvpsrad\NUL\NUL\NUL\NUL\NUL\NUL\NUL\avpsravd\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKvpsraw\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKvpsrld\NUL\NUL\NUL\NUL\NUL\NUL\NUL\avpsrldq\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKvpsrlq\NUL\NUL\NUL\NUL\NUL\NUL\NUL\avpsrlvd\NUL\NUL\NUL\NUL\NUL\NUL\NUL\avpsrlvq\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKvpsrlw\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKvpsubb\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKvpsubd\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKvpsubq\NUL\NUL\NUL\NUL\NUL\NUL\NUL\avpsubsb\NUL\NUL\NUL\NUL\NUL\NUL\NUL\bvpsubsiw\NUL\NUL\NUL\NUL\NUL\NUL\NUL\avpsubsw\NUL\NUL\NUL\NUL\NUL\NUL\NUL\bvpsubusb\NUL\NUL\NUL\NUL\NUL\NUL\NUL\bvpsubusw\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKvpsubw\NUL\NUL\NUL\NUL\NUL\NUL\NUL\avpswapd\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKvptest\NUL\NUL\NUL\NUL\NUL\NUL\NUL\nvpunpckhbw\NUL\NUL\NUL\NUL\NUL\NUL\NUL\nvpunpckhdq\NUL\NUL\NUL\NUL\NUL\NUL\NUL\vvpunpckhqdq\NUL\NUL\NUL\NUL\NUL\NUL\NUL\nvpunpckhwd\NUL\NUL\NUL\NUL\NUL\NUL\NUL\nvpunpcklbw\NUL\NUL\NUL\NUL\NUL\NUL\NUL\nvpunpckldq\NUL\NUL\NUL\NUL\NUL\NUL\NUL\vvpunpcklqdq\NUL\NUL\NUL\NUL\NUL\NUL\NUL\nvpunpcklwd\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQvpxor\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKvrcpps\NUL\NUL\NUL\NUL\NUL\NUL\NUL\bvroundpd\NUL\NUL\NUL\NUL\NUL\NUL\NUL\bvroundps\NUL\NUL\NUL\NUL\NUL\NUL\NUL\bvrsqrtps\NUL\NUL\NUL\NUL\NUL\NUL\NUL\vvscatterdpd\NUL\NUL\NUL\NUL\NUL\NUL\NUL\vvscatterdps\NUL\NUL\NUL\NUL\NUL\NUL\NUL\vvscatterqpd\NUL\NUL\NUL\NUL\NUL\NUL\NUL\vvscatterqps\NUL\NUL\NUL\NUL\NUL\NUL\NUL\avsqrtpd\NUL\NUL\NUL\NUL\NUL\NUL\NUL\avsqrtps\NUL\NUL\NUL\NUL\NUL\NUL\NUL\bvstmxcsr\NUL\NUL\NUL\NUL\NUL\NUL\NUL\avtestpd\NUL\NUL\NUL\NUL\NUL\NUL\NUL\avtestps\NUL\NUL\NUL\NUL\NUL\NUL\NUL\bvzeroall\NUL\NUL\NUL\NUL\NUL\NUL\NUL\nvzeroupper\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTwait\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKwbinvd\NUL\NUL\NUL\NUL\NUL\NUL\NUL\bwrfsbase\NUL\NUL\NUL\NUL\NUL\NUL\NUL\bwrgsbase\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQwrmsr\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKwrmsrq\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQwrshr\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKxabort\NUL\NUL\NUL\NUL\NUL\NUL\NUL\bxacquire\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTxadd\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKxbegin\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTxbts\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTxchg\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTxend\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKxgetbv\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTxlat\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQxlatb\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETXxor\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQxorpd\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQxorps\NUL\NUL\NUL\NUL\NUL\NUL\NUL\bxrelease\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKxrstor\NUL\NUL\NUL\NUL\NUL\NUL\NUL\bxrstor64\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQxsave\NUL\NUL\NUL\NUL\NUL\NUL\NUL\axsave64\NUL\NUL\NUL\NUL\NUL\NUL\NUL\bxsaveopt\NUL\NUL\NUL\NUL\NUL\NUL\NUL\nxsaveopt64\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKxsetbv\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQxtest\NAK\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STX\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DLEIntel x86 (FASM)\NUL\NUL\NUL\NUL\NUL\NUL\NUL\aOperand\a\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\FS\t\n !%&()*+,-./:;<=>?[\\]^{|}~\SOH\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NULE\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTcall\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTiret\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQiretd\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQiretq\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQiretw\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STXja\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETXjae\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STXjb\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETXjbe\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STXjc\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTjcxz\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STXje\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQjecxz\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STXjg\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETXjge\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STXjl\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETXjle\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETXjmp\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETXjna\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTjnae\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETXjnb\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTjnbe\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETXjnc\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETXjne\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETXjng\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTjnge\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETXjnl\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTjnle\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETXjno\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETXjnp\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETXjns\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETXjnz\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STXjo\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STXjp\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETXjpe\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETXjpo\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STXjs\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STXjz\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTloop\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQloopd\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQloope\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKlooped\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKloopew\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKloopne\NUL\NUL\NUL\NUL\NUL\NUL\NUL\aloopned\NUL\NUL\NUL\NUL\NUL\NUL\NUL\aloopnew\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKloopnz\NUL\NUL\NUL\NUL\NUL\NUL\NUL\aloopnzd\NUL\NUL\NUL\NUL\NUL\NUL\NUL\aloopnzw\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQloopw\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQloopz\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKloopzd\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKloopzw\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETXret\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTretd\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTretf\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQretfd\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQretfw\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTretn\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQretnd\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQretnw\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTretw\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETXrsm\NUL\NUL\NUL\NUL\NUL\NUL\NUL\asyscall\NUL\NUL\NUL\NUL\NUL\NUL\NUL\bsyscallq\NUL\NUL\NUL\NUL\NUL\NUL\NUL\bsysenter\NUL\NUL\NUL\NUL\NUL\NUL\NUL\asysexit\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKsysret\NUL\NUL\NUL\NUL\NUL\NUL\NUL\asysretq\DC3\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STX\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DLEIntel x86 (FASM)\NUL\NUL\NUL\NUL\NUL\NUL\NUL\aOperand\a\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\FS\t\n !%&()*+,-./:;<=>?[\\]^{|}~\SOH\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\US\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTbyte\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STXdb\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STXdd\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STXdf\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STXdp\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STXdq\NUL\NUL\NUL\NUL\NUL\NUL\NUL\adqqword\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKdqword\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STXdt\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STXdu\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STXdw\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQdword\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTfile\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQfword\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETXptr\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQpword\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKqqword\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQqword\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STXrb\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STXrd\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STXrf\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STXrp\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STXrq\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STXrt\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STXrw\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQtbyte\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQtword\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTword\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQxword\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQyword\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQzword\SOH\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STX\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DLEIntel x86 (FASM)\NUL\NUL\NUL\NUL\NUL\NUL\NUL\aOperand\a\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\FS\t\n !%&()*+,-./:;<=>?[\\]^{|}~\SOH\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL!\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKappend\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKassert\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STXat\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQbreak\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SIcalminstruction\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKcommon\NUL\NUL\NUL\NUL\NUL\NUL\NUL\adisplay\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTelse\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETXend\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETXequ\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETXerr\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETXfix\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKfoward\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STXif\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETXirp\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTirps\NUL\NUL\NUL\NUL\NUL\NUL\NUL\aiterate\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQlabel\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQlocal\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQmacro\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQmatch\NUL\NUL\NUL\NUL\NUL\NUL\NUL\tnamespace\NUL\NUL\NUL\NUL\NUL\NUL\NUL\bpostpone\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQpurge\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKrepeat\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTrept\NUL\NUL\NUL\NUL\NUL\NUL\NUL\arestore\NUL\NUL\NUL\NUL\NUL\NUL\NUL\arestruc\NUL\NUL\NUL\NUL\NUL\NUL\NUL\areverse\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQstruc\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQtimes\NUL\NUL\NUL\NUL\NUL\NUL\NUL\avirtual\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQwhile\ETB\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STX\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DLEIntel x86 (FASM)\NUL\NUL\NUL\NUL\NUL\NUL\NUL\fPreprocessor\a\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\FS\t\n !%&()*+,-./:;<=>?[\\]^{|}~\SOH\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC4\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQalign\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTdata\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQentry\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQextrn\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKformat\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTfrom\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTheap\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ainclude\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKinvoke\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTload\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETXorg\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTproc\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKpublic\NUL\NUL\NUL\NUL\NUL\NUL\NUL\asection\NUL\NUL\NUL\NUL\NUL\NUL\NUL\asegment\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQstack\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQstore\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQuse16\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQuse32\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQuse64\NAK\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STX\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DLEIntel x86 (FASM)\NUL\NUL\NUL\NUL\NUL\NUL\NUL\aOperand\a\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\FS\t\n !%&()*+,-./:;<=>?[\\]^{|}~\SOH\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQ\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETXrep\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTrepe\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQrepne\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQrepnz\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTrepz\NAK\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC1\RS\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DLEIntel x86 (FASM)\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC2UnknownInstruction\SO\DC4\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STX\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DLEIntel x86 (FASM)\NUL\NUL\NUL\NUL\NUL\NUL\NUL\aOperand\STX\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STX{}\DC4\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKNormal\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKNormal\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DLEIntel x86 (FASM)\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STX\DLE\RS\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACK\NUL\NUL\NUL\NUL\NUL\NUL\NUL:(?:(?:\\.|@@|%%)(?:\\.@)?)?[A-Za-z_][A-Za-z0-9_.]*+:|\\.:|@@:\SOH\DC1\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DLEIntel x86 (FASM)\NUL\NUL\NUL\NUL\NUL\NUL\NUL\vInstruction\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DLEIntel x86 (FASM)\NUL\NUL\NUL\NUL\NUL\NUL\NUL\vInstruction\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKNumber\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKNumber\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DLEIntel x86 (FASM)\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQ\SOH0x\ETX\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STX\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DLEIntel x86 (FASM)\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOT$Hex\SOH0X\ETX\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STX\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DLEIntel x86 (FASM)\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOT$Hex\ACK\NUL\NUL\NUL\NUL\NUL\NUL\NUL>[0-9]++(?:\\.[0-9]*+(?:e[-+]?[0-9]*+)?|(?=f\\b)|e[-+]?[0-9]++\\b)\NUL\EOT\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STX\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DLEIntel x86 (FASM)\NUL\NUL\NUL\NUL\NUL\NUL\NUL\vFloatSuffix\ACK\NUL\NUL\NUL\NUL\NUL\NUL\NULy[01]*+(?:[0-7]*+(?:[0-9a-f]*+(?=h)|(?=[oqh]))|(?=[byoqh]))|[0-7][0-7]*+(?:[0-9a-f]*+(?=h)|(?=[oqh]))|[0-9][0-9a-f]*+(?=h)\NUL\ETX\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STX\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DLEIntel x86 (FASM)\NUL\NUL\NUL\NUL\NUL\NUL\NUL\nBaseSuffix\ACK\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SUB[0-9]*+(?:to[0-9]+|(?=d?))\NUL\STX\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STX\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DLEIntel x86 (FASM)\NUL\NUL\NUL\NUL\NUL\NUL\NUL\fNumberSuffix\STX\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\fNumberSuffix\NUL\NUL\NUL\NUL\NUL\NUL\NUL\fNumberSuffix\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DLEIntel x86 (FASM)\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\STX\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STXDd\ETX\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STX\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DLEIntel x86 (FASM)\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC1CheckNumberSuffix\STX\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STX\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DLEIntel x86 (FASM)\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC1CheckNumberSuffix\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\aOperand\NUL\NUL\NUL\NUL\NUL\NUL\NUL\aOperand\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DLEIntel x86 (FASM)\NUL\NUL\NUL\NUL\NUL\NUL\NUL\r\DLE\RS\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL$\DC4\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DLEIntel x86 (FASM)\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKDollar\SO\DC4\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STX\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SUB!#$%&()*+,-./:<=>?[\\]`{|}~\DC4\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL'\b\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DLEIntel x86 (FASM)\NUL\NUL\NUL\NUL\NUL\NUL\NUL\bSQString\NUL\"\b\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DLEIntel x86 (FASM)\NUL\NUL\NUL\NUL\NUL\NUL\NUL\bDQString\NUL@\DC1\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DLEIntel x86 (FASM)\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACK@Label\NUL;\f\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STX\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DLEIntel x86 (FASM)\NUL\NUL\NUL\NUL\NUL\NUL\NUL\aComment\STX\NUL\NUL\NUL\NUL\NUL\NUL\NUL\n0123456789\STX\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DLEIntel x86 (FASM)\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKNumber\a\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\FS\t\n !%&()*+,-./:;<=>?[\\]^{|}~\SOH\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NULl\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STXah\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STXal\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STXax\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STXbh\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STXbl\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTbnd0\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTbnd1\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTbnd2\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTbnd3\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STXbp\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STXbx\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STXch\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STXcl\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETXcr0\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETXcr2\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETXcr3\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETXcr4\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STXcs\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STXcx\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STXdh\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STXdi\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STXdl\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETXdr0\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETXdr1\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETXdr2\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETXdr3\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETXdr6\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETXdr7\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STXds\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STXdx\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETXeax\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETXebp\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETXebx\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETXecx\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETXedi\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETXedx\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STXes\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETXesi\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETXesp\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STXfs\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STXgs\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STXk0\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STXk1\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STXk2\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STXk3\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STXk4\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STXk5\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STXk6\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STXk7\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETXmm0\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETXmm1\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETXmm2\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETXmm3\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETXmm4\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETXmm5\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETXmm6\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETXmm7\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETXr10\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETXr11\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETXr12\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETXr13\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETXr14\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETXr15\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STXr8\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STXr9\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETXrax\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETXrbp\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETXrbx\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETXrcx\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETXrdi\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETXrdx\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETXrsi\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETXrsp\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STXsi\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STXsp\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STXss\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETXst0\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETXst1\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETXst2\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETXst3\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETXst4\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETXst5\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETXst6\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETXst7\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTxmm0\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTxmm1\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTxmm2\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTxmm3\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTxmm4\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTxmm5\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTxmm6\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTxmm7\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTymm0\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTymm1\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTymm2\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTymm3\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTymm4\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTymm5\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTymm6\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTymm7\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTzmm0\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTzmm1\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTzmm2\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTzmm3\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTzmm4\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTzmm5\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTzmm6\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTzmm7\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\a\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\FS\t\n !%&()*+,-./:;<=>?[\\]^{|}~\SOH\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\US\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTbyte\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STXdb\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STXdd\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STXdf\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STXdp\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STXdq\NUL\NUL\NUL\NUL\NUL\NUL\NUL\adqqword\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKdqword\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STXdt\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STXdu\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STXdw\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQdword\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTfile\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQfword\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETXptr\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQpword\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKqqword\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQqword\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STXrb\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STXrd\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STXrf\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STXrp\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STXrq\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STXrt\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STXrw\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQtbyte\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQtword\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTword\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQxword\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQyword\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQzword\SOH\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\a\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\FS\t\n !%&()*+,-./:;<=>?[\\]^{|}~\SOH\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DLE\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETXand\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETXbsf\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETXbsr\NUL\NUL\NUL\NUL\NUL\NUL\NUL\adefined\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETXfar\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETXmod\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTnear\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETXnot\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STXor\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETXplt\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETXrva\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETXshl\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQshort\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETXshr\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTused\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETXxor\DC4\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC1\RS\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\fPreprocessor\NUL\NUL\NUL\NUL\NUL\NUL\NUL\fPreprocessor\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DLEIntel x86 (FASM)\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOT\ENQ\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETXend\ETB\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STX\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DLEIntel x86 (FASM)\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC3Preprocessor.prefix\ENQ\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTelse\ETB\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STX\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DLEIntel x86 (FASM)\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC3Preprocessor.prefix\ENQ\NUL\NUL\NUL\NUL\NUL\NUL\NUL\avirtual\ETB\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STX\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DLEIntel x86 (FASM)\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC4Preprocessor.virtual\DC1\ETB\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STX\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DLEIntel x86 (FASM)\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC3PreprocessorOperand\ETB\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC3Preprocessor.prefix\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC3Preprocessor.prefix\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DLEIntel x86 (FASM)\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETX\DLE\RS\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\a\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\FS\t\n !%&()*+,-./:;<=>?[\\]^{|}~\SOH\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL!\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKappend\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKassert\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STXat\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQbreak\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SIcalminstruction\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKcommon\NUL\NUL\NUL\NUL\NUL\NUL\NUL\adisplay\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTelse\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETXend\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETXequ\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETXerr\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETXfix\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKfoward\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STXif\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETXirp\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTirps\NUL\NUL\NUL\NUL\NUL\NUL\NUL\aiterate\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQlabel\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQlocal\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQmacro\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQmatch\NUL\NUL\NUL\NUL\NUL\NUL\NUL\tnamespace\NUL\NUL\NUL\NUL\NUL\NUL\NUL\bpostpone\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQpurge\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKrepeat\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTrept\NUL\NUL\NUL\NUL\NUL\NUL\NUL\arestore\NUL\NUL\NUL\NUL\NUL\NUL\NUL\arestruc\NUL\NUL\NUL\NUL\NUL\NUL\NUL\areverse\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQstruc\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQtimes\NUL\NUL\NUL\NUL\NUL\NUL\NUL\avirtual\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQwhile\ETB\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STX\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DLEIntel x86 (FASM)\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC3PreprocessorOperand\DC1\RS\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STX\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DLEIntel x86 (FASM)\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC3PreprocessorOperand\ETB\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STX\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DLEIntel x86 (FASM)\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC3PreprocessorOperand\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC4Preprocessor.virtual\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC4Preprocessor.virtual\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DLEIntel x86 (FASM)\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STX\DLE\RS\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQ\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STXat\ETB\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STX\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DLEIntel x86 (FASM)\NUL\NUL\NUL\NUL\NUL\NUL\NUL\aOperand\ETB\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STX\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DLEIntel x86 (FASM)\NUL\NUL\NUL\NUL\NUL\NUL\NUL\aOperand\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC3PreprocessorOperand\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC3PreprocessorOperand\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DLEIntel x86 (FASM)\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STX\NUL{\DC4\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\SI\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DLEIntel x86 (FASM)\NUL\NUL\NUL\NUL\NUL\NUL\NUL\aOperand\ETB\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETB\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\bSQString\NUL\NUL\NUL\NUL\NUL\NUL\NUL\bSQString\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DLEIntel x86 (FASM)\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STX\SO\DC4\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL'\b\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\b\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC2UnknownInstruction\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC2UnknownInstruction\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DLEIntel x86 (FASM)\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STX\NUL.\DC4\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC1\RS\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STX\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETX\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DLEIntel x86 (FASM)\NUL\NUL\NUL\NUL\NUL\NUL\NUL\aOperand\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NAKrCX (rCX12@yahoo.com)\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH6\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETXGPL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETX\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQ*.asm\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQ*.inc\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACK*.fasm\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKNormal"
