{-# LANGUAGE OverloadedStrings #-}
-- | Automatically generated syntax definition for GNU Assembler.
-- DO NOT EDIT THIS FILE MANUALLY.
-- Instead, modify xml/gnuassembler.xml and 'make bootstrap'.
module Skylighting.Syntax.Gnuassembler (syntax) where

import Skylighting.Types
import Data.Binary

-- | Syntax definition for GNU Assembler.
syntax :: Syntax
syntax = decode "\NUL\NUL\NUL\NUL\NUL\NUL\NUL\rGNU Assembler\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DLEgnuassembler.xml\NUL\NUL\NUL\NUL\NUL\NUL\NUL\fGnuassembler\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOT\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC3branch instructions\NUL\NUL\NUL\NUL\NUL\NUL\NUL5\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTcall\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQcallq\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTiret\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQiretd\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQiretq\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQiretw\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STXja\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETXjae\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STXjb\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETXjbe\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STXjc\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTjcxz\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STXje\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQjecxz\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STXjg\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETXjge\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STXjl\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETXjle\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETXjmp\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTjmpe\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETXjna\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTjnae\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETXjnb\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTjnbe\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETXjnc\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETXjne\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETXjng\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTjnge\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETXjnl\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTjnle\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETXjno\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETXjnp\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETXjns\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETXjnz\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STXjo\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STXjp\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETXjpe\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETXjpo\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQjrcxz\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STXjs\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STXjz\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETXret\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTretd\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTretf\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQretfd\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQretfq\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQretfw\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTretn\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQretnd\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQretnq\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQretnw\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTretq\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTretw\NUL\NUL\NUL\NUL\NUL\NUL\NUL\finstructions\NUL\NUL\NUL\NUL\NUL\NUL\ACK\234\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTlock\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETXrep\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTrepe\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTrepz\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQrepne\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQrepnz\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\axaquire\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\bxrelease\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETXbnd\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQnobnd\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETXaaa\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETXaad\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETXaam\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETXaas\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETXadc\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTaddb\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTaddw\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTaddl\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTaddq\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETXand\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTarpl\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\tbb0_reset\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\tbb1_reset\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQbound\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETXbsf\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETXbsr\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQbswap\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STXbt\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETXbtc\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETXbtr\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETXbts\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETXcbw\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETXcdq\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTcdqe\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETXclc\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETXcld\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETXcli\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTclts\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTcltd\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTcbtw\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTcwtl\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTcwtd\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTcltq\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTcqto\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETXcmc\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTcmpb\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTcmpw\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTcmpl\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTcmpq\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQcmpsb\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQcmpsd\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQcmpsq\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQcmpsw\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\acmpxchg\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ncmpxchg486\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\tcmpxchg8b\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ncmpxchg16b\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQcpuid\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\bcpu_read\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\tcpu_write\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETXcqo\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETXcwd\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTcwde\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETXdaa\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETXdas\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETXdec\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTdecl\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTdecq\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETXdiv\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTdivb\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTdivw\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTdivl\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTdivq\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQdmint\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTemms\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQenter\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETXequ\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQf2xm1\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTfabs\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTfadd\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQfaddp\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTfbld\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQfbstp\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTfchs\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQfclex\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKfcmovb\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\afcmovbe\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKfcmove\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\afcmovnb\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\bfcmovnbe\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\afcmovne\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\afcmovnu\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKfcmovu\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTfcom\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQfcomi\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKfcomip\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQfcomp\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKfcompp\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTfcos\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\afdecstp\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQfdisi\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTfdiv\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQfdivp\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQfdivr\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKfdivrp\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQfemms\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTfeni\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQffree\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKffreep\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQfiadd\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQficom\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKficomp\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQfidiv\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKfidivr\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTfild\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQfimul\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\afincstp\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQfinit\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTfist\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQfistp\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKfisttp\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQfisub\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKfisubr\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETXfld\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTfld1\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQfldcw\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKfldenv\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKfldl2e\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKfldl2t\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKfldlg2\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKfldln2\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQfldpi\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTfldz\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTfmul\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQfmulp\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKfnclex\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKfndisi\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQfneni\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKfninit\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTfnop\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKfnsave\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKfnstcw\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\afnstenv\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKfnstsw\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKfpatan\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQfprem\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKfprem1\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQfptan\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\afrndint\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKfrstor\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQfsave\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKfscale\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKfsetpm\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTfsin\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\afsincos\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQfsqrt\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETXfst\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQfstcw\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKfstenv\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTfstp\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQfstsw\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTfsub\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQfsubp\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQfsubr\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKfsubrp\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTftst\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQfucom\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKfucomi\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\afucomip\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKfucomp\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\afucompp\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTfxam\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTfxch\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\afxtract\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQfyl2x\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\afyl2xp1\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKglobal\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQglobl\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETXhlt\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTibts\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQicebp\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTidiv\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQidivb\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQidivw\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQidivl\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQidivq\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTimul\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQimulb\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQimulw\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQimull\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQimulq\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STXin\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETXinc\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTincl\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTincq\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKincbin\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTinsb\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTinsd\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTinsw\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETXint\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQint01\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTint1\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQint03\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTint3\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTinto\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTinvd\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ainvpcid\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKinvlpg\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ainvlpga\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTiret\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQiretd\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQiretq\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQiretw\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTjcxz\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQjecxz\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQjrcxz\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTlahf\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETXlar\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETXlds\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTleal\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTleaq\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQleave\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETXles\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKlfence\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETXlfs\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTlgdt\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETXlgs\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTlidt\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTlldt\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTlmsw\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\aloadall\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\nloadall286\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQlodsb\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQlodsd\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQlodsq\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQlodsw\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTloop\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQloope\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKloopne\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKloopnz\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQloopz\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETXlsl\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETXlss\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETXltr\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKmfence\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\amonitor\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTmovb\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTmovw\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTmovl\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTmovq\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQmovsb\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQmovsd\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQmovsq\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQmovsw\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQmovsx\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKmovsxd\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQmovzx\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKmovsbw\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKmovsxb\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKmovsbl\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKmovsbq\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKmovswl\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKmovsxw\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKmovswq\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKmovslq\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKmovsxl\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKmovzbw\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKmovzxb\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKmovzbl\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKmovzbq\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKmovzwl\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKmovzxw\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKmovzwq\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETXmul\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTmulb\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTmulw\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTmull\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTmulq\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQmwait\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETXneg\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETXnop\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETXnot\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STXor\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETXout\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQoutsb\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQoutsd\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQoutsw\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\bpackssdw\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\bpacksswb\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\bpackuswb\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQpaddb\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQpaddd\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKpaddsb\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\apaddsiw\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKpaddsw\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\apaddusb\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\apaddusw\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQpaddw\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTpand\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQpandn\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQpause\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQpaveb\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\apavgusb\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\apcmpeqb\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\apcmpeqd\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\apcmpeqw\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\apcmpgtb\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\apcmpgtd\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\apcmpgtw\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\apdistib\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQpf2id\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQpfacc\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQpfadd\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\apfcmpeq\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\apfcmpge\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\apfcmpgt\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQpfmax\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQpfmin\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQpfmul\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQpfrcp\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\bpfrcpit1\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\bpfrcpit2\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\bpfrsqit1\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\apfrsqrt\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQpfsub\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKpfsubr\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQpi2fd\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\bpmachriw\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\apmaddwd\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQpmagw\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\bpmulhriw\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\bpmulhrwa\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\bpmulhrwc\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKpmulhw\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKpmullw\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\apmvgezb\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKpmvlzb\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKpmvnzb\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQpmvzb\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETXpop\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTpopl\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTpopq\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTpopa\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQpopad\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQpopaw\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTpopf\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQpopfd\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQpopfq\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQpopfw\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETXpor\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\bprefetch\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\tprefetchw\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQpslld\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQpsllq\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQpsllw\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQpsrad\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQpsraw\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQpsrld\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQpsrlq\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQpsrlw\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQpsubb\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQpsubd\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKpsubsb\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\apsubsiw\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKpsubsw\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\apsubusb\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\apsubusw\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQpsubw\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\tpunpckhbw\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\tpunpckhdq\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\tpunpckhwd\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\tpunpcklbw\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\tpunpckldq\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\tpunpcklwd\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTpush\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQpusha\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQpushl\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQpushq\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKpushad\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKpushaw\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQpushf\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKpushfd\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKpushfq\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKpushfw\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTpxor\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETXrcl\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETXrcr\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQrdshr\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQrdmsr\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQrdpmc\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQrdtsc\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKrdtscp\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETXret\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTretf\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTretn\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTretq\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETXrol\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETXror\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETXrdm\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTrsdc\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQrsldt\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETXrsm\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTrsts\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTsahf\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETXsal\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTsall\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTsalq\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTsalc\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETXsar\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTsarl\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTsarq\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETXsbb\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQscasb\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQscasd\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQscasq\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQscasw\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKsfence\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTsgdt\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETXshl\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTshll\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQshllq\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTshld\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETXshr\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTshrd\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTsidt\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTsldt\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKskinit\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETXsmi\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQsmint\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\bsmintold\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTsmsw\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETXstc\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETXstd\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETXsti\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQstosb\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQstosd\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQstosq\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQstosw\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETXstr\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETXsub\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTsubw\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTsubl\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTsubq\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTsvdc\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQsvldt\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTsvts\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKswapgs\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\asyscall\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\bsysenter\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\asysexit\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKsysret\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTtest\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQtestl\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQtestq\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETXud0\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETXud1\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTud2b\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETXud2\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTud2a\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTumov\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTverr\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTverw\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQfwait\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKwbinvd\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQwrshr\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQwrmsr\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTxadd\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTxbts\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTxchg\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQxlatb\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTxlat\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETXxor\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTxorl\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTxorq\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQcmove\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQcmovz\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKcmovne\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKcmovnz\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQcmova\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\acmovnbe\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKcmovae\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKcmovnb\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQcmovb\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\acmovnae\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKcmovbe\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKcmovna\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQcmovg\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\acmovnle\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKcmovge\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKcmovnl\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQcmovl\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\acmovnge\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKcmovle\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKcmovng\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQcmovc\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKcmovnc\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQcmovo\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKcmovno\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQcmovs\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKcmovns\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQcmovp\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKcmovpe\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKcmovnp\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKcmovpo\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTsete\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTsetz\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQsetne\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQsetnz\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTseta\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKsetnbe\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQsetae\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQsetnb\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQsetnc\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTsetb\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKsetnae\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\asetcset\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQsetbe\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQsetna\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTsetg\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKsetnle\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQsetge\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQsetnl\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTsetl\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKsetnge\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQsetle\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQsetng\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTsets\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQsetns\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTseto\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQsetno\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQsetpe\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTsetp\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQsetpo\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQsetnp\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQaddps\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQaddss\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKandnps\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQandps\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\acmpeqps\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\acmpeqss\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\acmpleps\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\acmpless\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\acmpltps\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\acmpltss\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\bcmpneqps\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\bcmpneqss\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\bcmpnleps\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\bcmpnless\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\bcmpnltps\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\bcmpnltss\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\bcmpordps\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\bcmpordss\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ncmpunordps\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ncmpunordss\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQcmpps\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQcmpss\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKcomiss\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\bcvtpi2ps\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\bcvtps2pi\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\bcvtsi2ss\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\bcvtss2si\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\tcvttps2pi\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\tcvttss2si\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQdivps\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQdivss\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\aldmxcsr\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQmaxps\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQmaxss\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQminps\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQminss\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKmovaps\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKmovhps\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\amovlhps\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKmovlps\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\amovhlps\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\bmovmskps\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\amovntps\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQmovss\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKmovups\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQmulps\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQmulss\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTorps\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQrcpps\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQrcpss\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\arsqrtps\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\arsqrtss\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKshufps\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKsqrtps\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKsqrtss\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\astmxcsr\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQsubps\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQsubss\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\aucomiss\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\bunpckhps\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\bunpcklps\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQxorps\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\afxrstor\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\tfxrstor64\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKfxsave\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\bfxsave64\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKxgetbv\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKxsetbv\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQxsave\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\axsave64\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\bxsaveopt\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\nxsaveopt64\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKxrstor\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\bxrstor64\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\vprefetchnta\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\nprefetcht0\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\nprefetcht1\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\nprefetcht2\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\bmaskmovq\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKmovntq\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQpavgb\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQpavgw\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKpextrw\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKpinsrw\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKpmaxsw\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKpmaxub\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKpminsw\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKpminub\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\bpmovmskb\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\apmulhuw\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKpsadbw\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKpshufw\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQpf2iw\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKpfnacc\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\apfpnacc\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQpi2fw\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKpswapd\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\nmaskmovdqu\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\aclflush\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\amovntdq\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKmovnti\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\amovntpd\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKmovdqa\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKmovdqu\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\amovdq2q\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\amovq2dq\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQpaddq\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\apmuludq\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKpshufd\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\apshufhw\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\apshuflw\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKpslldq\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKpsrldq\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQpsubq\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\npunpckhqdq\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\npunpcklqdq\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQaddpd\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQaddsd\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKandnpd\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQandpd\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\acmpeqpd\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\acmpeqsd\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\acmplepd\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\acmplesd\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\acmpltpd\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\acmpltsd\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\bcmpneqpd\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\bcmpneqsd\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\bcmpnlepd\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\bcmpnlesd\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\bcmpnltpd\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\bcmpnltsd\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\bcmpordpd\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\bcmpordsd\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ncmpunordpd\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ncmpunordsd\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQcmppd\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKcomisd\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\bcvtdq2pd\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\bcvtdq2ps\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\bcvtpd2dq\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\bcvtpd2pi\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\bcvtpd2ps\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\bcvtpi2pd\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\bcvtps2dq\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\bcvtps2pd\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\bcvtsd2si\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\bcvtsd2ss\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\bcvtsi2sd\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\bcvtss2sd\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\tcvttpd2pi\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\tcvttpd2dq\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\tcvttps2dq\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\tcvttsd2si\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQdivpd\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQdivsd\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQmaxpd\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQmaxsd\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQminpd\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQminsd\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKmovapd\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKmovhpd\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKmovlpd\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\bmovmskpd\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKmovupd\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQmulpd\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQmulsd\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTorpd\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKshufpd\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKsqrtpd\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKsqrtsd\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQsubpd\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQsubsd\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\aucomisd\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\bunpckhpd\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\bunpcklpd\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQxorpd\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\baddsubpd\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\baddsubps\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKhaddpd\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKhaddps\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKhsubpd\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKhsubps\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQlddqu\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\amovddup\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\bmovshdup\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\bmovsldup\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTclgi\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTstgi\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKvmcall\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\avmclear\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKvmfunc\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\bvmlaunch\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKvmload\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\avmmcall\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\avmptrld\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\avmptrst\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKvmread\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\bvmresume\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQvmrun\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKvmsave\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\avmwrite\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKvmxoff\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQvmxon\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKinvept\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ainvvpid\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQpabsb\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQpabsw\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQpabsd\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\apalignr\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKphaddw\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKphaddd\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\aphaddsw\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKphsubw\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKphsubd\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\aphsubsw\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\tpmaddubsw\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\bpmulhrsw\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKpshufb\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKpsignb\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKpsignw\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKpsignd\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQextrq\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ainsertq\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\amovntsd\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\amovntss\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQlzcnt\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ablendpd\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ablendps\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\bblendvpd\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\bblendvps\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTdppd\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTdpps\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\textractps\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\binsertps\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\bmovntdqa\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ampsadbw\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\bpackusdw\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\bpblendvb\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\apblendw\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\apcmpeqq\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKpextrb\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKpextrd\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKpextrq\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\nphminposuw\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKpinsrb\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKpinsrd\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKpinsrq\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKpmaxsb\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKpmaxsd\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKpmaxud\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKpmaxuw\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKpminsb\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKpminsd\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKpminud\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKpminuw\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\bpmovsxbw\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\bpmovsxbd\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\bpmovsxbq\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\bpmovsxwd\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\bpmovsxwq\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\bpmovsxdq\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\bpmovzxbw\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\bpmovzxbd\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\bpmovzxbq\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\bpmovzxwd\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\bpmovzxwq\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\bpmovzxdq\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKpmuldq\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKpmulld\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQptest\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\aroundpd\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\aroundps\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\aroundsd\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\aroundss\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQcrc32\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\tpcmpestri\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\tpcmpestrm\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\tpcmpistri\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\tpcmpistrm\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\apcmpgtq\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKpopcnt\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKgetsec\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKpfrcpv\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\bpfrsqrtv\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQmovbe\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKaesenc\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\naesenclast\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKaesdec\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\naesdeclast\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKaesimc\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SIaeskeygenassist\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\avaesenc\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\vvaesenclast\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\avaesdec\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\vvaesdeclast\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\avaesimc\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DLEvaeskeygenassist\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKvaddpd\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKvaddps\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKvaddsd\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKvaddss\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\tvaddsubpd\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\tvaddsubps\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKvandpd\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKvandps\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\avandnpd\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\avandnps\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\bvblendpd\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\bvblendps\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\tvblendvpd\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\tvblendvps\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\fvbroadcastss\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\fvbroadcastsd\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOvbroadcastf128\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\vvcmpeq_ospd\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\bvcmpeqpd\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\vvcmplt_ospd\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\bvcmpltpd\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\vvcmple_ospd\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\bvcmplepd\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\rvcmpunord_qpd\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\vvcmpunordpd\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\fvcmpneq_uqpd\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\tvcmpneqpd\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\fvcmpnlt_uspd\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\tvcmpnltpd\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\fvcmpnle_uspd\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\tvcmpnlepd\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\vvcmpord_qpd\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\tvcmpordpd\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\vvcmpeq_uqpd\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\fvcmpnge_uspd\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\tvcmpngepd\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\fvcmpngt_uspd\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\tvcmpngtpd\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOvcmpfalse_oqpd\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\vvcmpfalsepd\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\fvcmpneq_oqpd\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\vvcmpge_ospd\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\bvcmpgepd\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\vvcmpgt_ospd\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\bvcmpgtpd\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\rvcmptrue_uqpd\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\nvcmptruepd\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\vvcmplt_oqpd\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\vvcmple_oqpd\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\rvcmpunord_spd\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\fvcmpneq_uspd\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\fvcmpnlt_uqpd\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\fvcmpnle_uqpd\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\vvcmpord_spd\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\vvcmpeq_uspd\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\fvcmpnge_uqpd\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\fvcmpngt_uqpd\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOvcmpfalse_ospd\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\fvcmpneq_ospd\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\vvcmpge_oqpd\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\vvcmpgt_oqpd\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\rvcmptrue_uspd\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKvcmppd\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\vvcmpeq_osps\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\bvcmpeqps\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\vvcmplt_osps\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\bvcmpltps\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\vvcmple_osps\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\bvcmpleps\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\rvcmpunord_qps\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\vvcmpunordps\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\fvcmpneq_uqps\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\tvcmpneqps\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\fvcmpnlt_usps\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\tvcmpnltps\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\fvcmpnle_usps\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\tvcmpnleps\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\vvcmpord_qps\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\tvcmpordps\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\vvcmpeq_uqps\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\fvcmpnge_usps\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\tvcmpngeps\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\fvcmpngt_usps\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\tvcmpngtps\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOvcmpfalse_oqps\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\vvcmpfalseps\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\fvcmpneq_oqps\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\vvcmpge_osps\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\bvcmpgeps\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\vvcmpgt_osps\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\bvcmpgtps\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\rvcmptrue_uqps\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\nvcmptrueps\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\vvcmplt_oqps\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\vvcmple_oqps\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\rvcmpunord_sps\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\fvcmpneq_usps\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\fvcmpnlt_uqps\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\fvcmpnle_uqps\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\vvcmpord_sps\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\vvcmpeq_usps\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\fvcmpnge_uqps\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\fvcmpngt_uqps\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOvcmpfalse_osps\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\fvcmpneq_osps\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\vvcmpge_oqps\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\vvcmpgt_oqps\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\rvcmptrue_usps\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKvcmpps\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\vvcmpeq_ossd\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\bvcmpeqsd\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\vvcmplt_ossd\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\bvcmpltsd\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\vvcmple_ossd\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\bvcmplesd\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\rvcmpunord_qsd\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\vvcmpunordsd\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\fvcmpneq_uqsd\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\tvcmpneqsd\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\fvcmpnlt_ussd\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\tvcmpnltsd\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\fvcmpnle_ussd\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\tvcmpnlesd\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\vvcmpord_qsd\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\tvcmpordsd\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\vvcmpeq_uqsd\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\fvcmpnge_ussd\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\tvcmpngesd\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\fvcmpngt_ussd\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\tvcmpngtsd\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOvcmpfalse_oqsd\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\vvcmpfalsesd\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\fvcmpneq_oqsd\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\vvcmpge_ossd\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\bvcmpgesd\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\vvcmpgt_ossd\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\bvcmpgtsd\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\rvcmptrue_uqsd\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\nvcmptruesd\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\vvcmplt_oqsd\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\vvcmple_oqsd\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\rvcmpunord_ssd\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\fvcmpneq_ussd\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\fvcmpnlt_uqsd\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\fvcmpnle_uqsd\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\vvcmpord_ssd\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\vvcmpeq_ussd\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\fvcmpnge_uqsd\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\fvcmpngt_uqsd\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOvcmpfalse_ossd\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\fvcmpneq_ossd\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\vvcmpge_oqsd\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\vvcmpgt_oqsd\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\rvcmptrue_ussd\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKvcmpsd\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\vvcmpeq_osss\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\bvcmpeqss\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\vvcmplt_osss\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\bvcmpltss\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\vvcmple_osss\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\bvcmpless\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\rvcmpunord_qss\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\vvcmpunordss\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\fvcmpneq_uqss\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\tvcmpneqss\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\fvcmpnlt_usss\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\tvcmpnltss\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\fvcmpnle_usss\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\tvcmpnless\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\vvcmpord_qss\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\tvcmpordss\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\vvcmpeq_uqss\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\fvcmpnge_usss\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\tvcmpngess\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\fvcmpngt_usss\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\tvcmpngtss\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOvcmpfalse_oqss\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\vvcmpfalsess\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\fvcmpneq_oqss\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\vvcmpge_osss\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\bvcmpgess\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\vvcmpgt_osss\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\bvcmpgtss\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\rvcmptrue_uqss\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\nvcmptruess\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\vvcmplt_oqss\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\vvcmple_oqss\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\rvcmpunord_sss\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\fvcmpneq_usss\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\fvcmpnlt_uqss\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\fvcmpnle_uqss\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\vvcmpord_sss\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\vvcmpeq_usss\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\fvcmpnge_uqss\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\fvcmpngt_uqss\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOvcmpfalse_osss\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\fvcmpneq_osss\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\vvcmpge_oqss\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\vvcmpgt_oqss\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\rvcmptrue_usss\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKvcmpss\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\avcomisd\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\avcomiss\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\tvcvtdq2pd\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\tvcvtdq2ps\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\tvcvtpd2dq\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\tvcvtpd2ps\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\tvcvtps2dq\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\tvcvtps2pd\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\tvcvtsd2si\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\tvcvtsd2ss\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\tvcvtsi2sd\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\tvcvtsi2ss\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\tvcvtss2sd\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\tvcvtss2si\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\nvcvttpd2dq\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\nvcvttps2dq\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\nvcvttsd2si\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\nvcvttss2si\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKvdivpd\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKvdivps\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKvdivsd\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKvdivss\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQvdppd\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQvdpps\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\fvextractf128\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\nvextractps\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\avhaddpd\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\avhaddps\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\avhsubpd\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\avhsubps\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\vvinsertf128\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\tvinsertps\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKvlddqu\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKvldqqu\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\bvldmxcsr\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\vvmaskmovdqu\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\nvmaskmovps\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\nvmaskmovpd\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKvmaxpd\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKvmaxps\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKvmaxsd\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKvmaxss\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKvminpd\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKvminps\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKvminsd\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKvminss\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\avmovapd\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\avmovaps\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQvmovd\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQvmovq\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\bvmovddup\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\avmovdqa\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\avmovqqa\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\avmovdqu\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\avmovqqu\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\bvmovhlps\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\avmovhpd\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\avmovhps\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\bvmovlhps\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\avmovlpd\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\avmovlps\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\tvmovmskpd\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\tvmovmskps\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\bvmovntdq\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\bvmovntqq\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\tvmovntdqa\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\bvmovntpd\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\bvmovntps\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKvmovsd\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\tvmovshdup\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\tvmovsldup\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKvmovss\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\avmovupd\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\avmovups\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\bvmpsadbw\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKvmulpd\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKvmulps\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKvmulsd\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKvmulss\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQvorpd\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQvorps\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKvpabsb\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKvpabsw\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKvpabsd\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\tvpacksswb\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\tvpackssdw\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\tvpackuswb\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\tvpackusdw\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKvpaddb\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKvpaddw\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKvpaddd\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKvpaddq\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\avpaddsb\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\avpaddsw\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\bvpaddusb\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\bvpaddusw\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\bvpalignr\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQvpand\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKvpandn\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKvpavgb\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKvpavgw\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\tvpblendvb\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\bvpblendw\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\nvpcmpestri\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\nvpcmpestrm\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\nvpcmpistri\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\nvpcmpistrm\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\bvpcmpeqb\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\bvpcmpeqw\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\bvpcmpeqd\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\bvpcmpeqq\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\bvpcmpgtb\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\bvpcmpgtw\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\bvpcmpgtd\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\bvpcmpgtq\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\tvpermilpd\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\tvpermilps\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\nvperm2f128\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\avpextrb\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\avpextrw\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\avpextrd\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\avpextrq\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\avphaddw\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\avphaddd\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\bvphaddsw\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\vvphminposuw\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\avphsubw\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\avphsubd\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\bvphsubsw\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\avpinsrb\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\avpinsrw\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\avpinsrd\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\avpinsrq\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\bvpmaddwd\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\nvpmaddubsw\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\avpmaxsb\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\avpmaxsw\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\avpmaxsd\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\avpmaxub\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\avpmaxuw\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\avpmaxud\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\avpminsb\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\avpminsw\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\avpminsd\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\avpminub\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\avpminuw\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\avpminud\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\tvpmovmskb\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\tvpmovsxbw\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\tvpmovsxbd\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\tvpmovsxbq\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\tvpmovsxwd\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\tvpmovsxwq\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\tvpmovsxdq\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\tvpmovzxbw\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\tvpmovzxbd\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\tvpmovzxbq\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\tvpmovzxwd\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\tvpmovzxwq\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\tvpmovzxdq\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\bvpmulhuw\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\tvpmulhrsw\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\avpmulhw\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\avpmullw\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\avpmulld\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\bvpmuludq\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\avpmuldq\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTvpor\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\avpsadbw\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\avpshufb\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\avpshufd\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\bvpshufhw\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\bvpshuflw\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\avpsignb\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\avpsignw\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\avpsignd\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\avpslldq\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\avpsrldq\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKvpsllw\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKvpslld\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKvpsllq\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKvpsraw\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKvpsrad\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKvpsrlw\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKvpsrld\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKvpsrlq\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKvptest\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKvpsubb\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKvpsubw\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKvpsubd\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKvpsubq\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\avpsubsb\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\avpsubsw\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\bvpsubusb\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\bvpsubusw\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\nvpunpckhbw\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\nvpunpckhwd\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\nvpunpckhdq\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\vvpunpckhqdq\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\nvpunpcklbw\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\nvpunpcklwd\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\nvpunpckldq\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\vvpunpcklqdq\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQvpxor\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKvrcpps\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKvrcpss\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\bvrsqrtps\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\bvrsqrtss\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\bvroundpd\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\bvroundps\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\bvroundsd\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\bvroundss\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\avshufpd\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\avshufps\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\avsqrtpd\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\avsqrtps\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\avsqrtsd\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\avsqrtss\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\bvstmxcsr\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKvsubpd\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKvsubps\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKvsubsd\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKvsubss\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\avtestps\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\avtestpd\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\bvucomisd\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\bvucomiss\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\tvunpckhpd\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\tvunpckhps\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\tvunpcklpd\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\tvunpcklps\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKvxorpd\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKvxorps\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\bvzeroall\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\nvzeroupper\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\fpclmullqlqdq\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\fpclmulhqlqdq\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\fpclmullqhqdq\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\fpclmulhqhqdq\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\tpclmulqdq\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\rvpclmullqlqdq\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\rvpclmulhqlqdq\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\rvpclmullqhqdq\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\rvpclmulhqhqdq\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\nvpclmulqdq\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\vvfmadd132ps\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\vvfmadd132pd\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\vvfmadd312ps\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\vvfmadd312pd\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\vvfmadd213ps\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\vvfmadd213pd\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\vvfmadd123ps\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\vvfmadd123pd\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\vvfmadd231ps\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\vvfmadd231pd\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\vvfmadd321ps\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\vvfmadd321pd\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOvfmaddsub132ps\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOvfmaddsub132pd\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOvfmaddsub312ps\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOvfmaddsub312pd\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOvfmaddsub213ps\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOvfmaddsub213pd\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOvfmaddsub123ps\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOvfmaddsub123pd\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOvfmaddsub231ps\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOvfmaddsub231pd\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOvfmaddsub321ps\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOvfmaddsub321pd\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\vvfmsub132ps\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\vvfmsub132pd\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\vvfmsub312ps\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\vvfmsub312pd\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\vvfmsub213ps\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\vvfmsub213pd\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\vvfmsub123ps\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\vvfmsub123pd\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\vvfmsub231ps\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\vvfmsub231pd\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\vvfmsub321ps\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\vvfmsub321pd\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOvfmsubadd132ps\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOvfmsubadd132pd\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOvfmsubadd312ps\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOvfmsubadd312pd\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOvfmsubadd213ps\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOvfmsubadd213pd\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOvfmsubadd123ps\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOvfmsubadd123pd\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOvfmsubadd231ps\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOvfmsubadd231pd\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOvfmsubadd321ps\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOvfmsubadd321pd\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\fvfnmadd132ps\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\fvfnmadd132pd\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\fvfnmadd312ps\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\fvfnmadd312pd\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\fvfnmadd213ps\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\fvfnmadd213pd\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\fvfnmadd123ps\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\fvfnmadd123pd\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\fvfnmadd231ps\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\fvfnmadd231pd\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\fvfnmadd321ps\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\fvfnmadd321pd\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\fvfnmsub132ps\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\fvfnmsub132pd\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\fvfnmsub312ps\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\fvfnmsub312pd\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\fvfnmsub213ps\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\fvfnmsub213pd\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\fvfnmsub123ps\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\fvfnmsub123pd\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\fvfnmsub231ps\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\fvfnmsub231pd\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\fvfnmsub321ps\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\fvfnmsub321pd\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\vvfmadd132ss\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\vvfmadd132sd\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\vvfmadd312ss\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\vvfmadd312sd\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\vvfmadd213ss\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\vvfmadd213sd\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\vvfmadd123ss\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\vvfmadd123sd\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\vvfmadd231ss\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\vvfmadd231sd\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\vvfmadd321ss\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\vvfmadd321sd\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\vvfmsub132ss\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\vvfmsub132sd\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\vvfmsub312ss\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\vvfmsub312sd\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\vvfmsub213ss\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\vvfmsub213sd\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\vvfmsub123ss\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\vvfmsub123sd\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\vvfmsub231ss\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\vvfmsub231sd\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\vvfmsub321ss\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\vvfmsub321sd\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\fvfnmadd132ss\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\fvfnmadd132sd\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\fvfnmadd312ss\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\fvfnmadd312sd\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\fvfnmadd213ss\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\fvfnmadd213sd\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\fvfnmadd123ss\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\fvfnmadd123sd\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\fvfnmadd231ss\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\fvfnmadd231sd\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\fvfnmadd321ss\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\fvfnmadd321sd\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\fvfnmsub132ss\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\fvfnmsub132sd\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\fvfnmsub312ss\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\fvfnmsub312sd\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\fvfnmsub213ss\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\fvfnmsub213sd\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\fvfnmsub123ss\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\fvfnmsub123sd\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\fvfnmsub231ss\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\fvfnmsub231sd\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\fvfnmsub321ss\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\fvfnmsub321sd\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\brdfsbase\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\brdgsbase\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKrdrand\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\bwrfsbase\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\bwrgsbase\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\tvcvtph2ps\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\tvcvtps2ph\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTadcx\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTadox\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKrdseed\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTclac\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTstac\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKxstore\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\txcryptecb\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\txcryptcbc\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\txcryptctr\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\txcryptcfb\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\txcryptofb\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\amontmul\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQxsha1\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\axsha256\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKllwpcb\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKslwpcb\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKlwpval\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKlwpins\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\bvfmaddpd\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\bvfmaddps\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\bvfmaddsd\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\bvfmaddss\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\vvfmaddsubpd\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\vvfmaddsubps\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\vvfmsubaddpd\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\vvfmsubaddps\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\bvfmsubpd\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\bvfmsubps\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\bvfmsubsd\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\bvfmsubss\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\tvfnmaddpd\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\tvfnmaddps\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\tvfnmaddsd\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\tvfnmaddss\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\tvfnmsubpd\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\tvfnmsubps\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\tvfnmsubsd\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\tvfnmsubss\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\avfrczpd\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\avfrczps\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\avfrczsd\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\avfrczss\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKvpcmov\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKvpcomb\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKvpcomd\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKvpcomq\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\avpcomub\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\avpcomud\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\avpcomuq\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\avpcomuw\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKvpcomw\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\bvphaddbd\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\bvphaddbq\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\bvphaddbw\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\bvphadddq\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\tvphaddubd\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\tvphaddubq\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\tvphaddubw\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\tvphaddudq\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\tvphadduwd\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\tvphadduwq\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\bvphaddwd\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\bvphaddwq\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\bvphsubbw\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\bvphsubdq\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\bvphsubwd\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\bvpmacsdd\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\tvpmacsdqh\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\tvpmacsdql\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\tvpmacssdd\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\nvpmacssdqh\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\nvpmacssdql\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\tvpmacsswd\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\tvpmacssww\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\bvpmacswd\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\bvpmacsww\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\nvpmadcsswd\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\tvpmadcswd\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKvpperm\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKvprotb\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKvprotd\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKvprotq\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKvprotw\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKvpshab\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKvpshad\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKvpshaq\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKvpshaw\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKvpshlb\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKvpshld\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKvpshlq\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKvpshlw\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOvbroadcasti128\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\bvpblendd\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\fvpbroadcastb\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\fvpbroadcastw\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\fvpbroadcastd\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\fvpbroadcastq\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKvpermd\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\avpermpd\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\avpermps\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKvpermq\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\nvperm2i128\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\fvextracti128\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\vvinserti128\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\nvpmaskmovd\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\nvpmaskmovq\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\avpsllvd\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\avpsllvq\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\avpsravd\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\avpsrlvd\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\avpsrlvq\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\nvgatherdpd\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\nvgatherqpd\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\nvgatherdps\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\nvgatherqps\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\nvpgatherdd\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\nvpgatherqd\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\nvpgatherdq\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\nvpgatherqq\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKxabort\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKxbegin\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTxend\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQxtest\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTandn\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQbextr\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTblci\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQblcic\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTblsi\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQblsic\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ablcfill\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ablsfill\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKblcmsk\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKblsmsk\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTblsr\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTblcs\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTbzhi\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTmulx\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTpdep\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTpext\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTrorx\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTsarx\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTshlx\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTshrx\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQtzcnt\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQtzmsk\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKt1mskc\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\avalignd\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\avalignq\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\tvblendmpd\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\tvblendmps\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SIvbroadcastf32x4\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SIvbroadcastf64x4\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SIvbroadcasti32x4\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SIvbroadcasti64x4\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\vvcompresspd\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\vvcompressps\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\nvcvtpd2udq\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\nvcvtps2udq\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\nvcvtsd2usi\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\nvcvtss2usi\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\vvcvttpd2udq\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\vvcvttps2udq\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\vvcvttsd2usi\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\vvcvttss2usi\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\nvcvtudq2pd\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\nvcvtudq2ps\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\nvcvtusi2sd\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\nvcvtusi2ss\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\tvexpandpd\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\tvexpandps\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\rvextractf32x4\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\rvextractf64x4\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\rvextracti32x4\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\rvextracti64x4\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\vvfixupimmpd\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\vvfixupimmps\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\vvfixupimmsd\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\vvfixupimmss\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\tvgetexppd\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\tvgetexpps\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\tvgetexpsd\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\tvgetexpss\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\nvgetmantpd\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\nvgetmantps\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\nvgetmantsd\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\nvgetmantss\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\fvinsertf32x4\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\fvinsertf64x4\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\fvinserti32x4\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\fvinserti64x4\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\tvmovdqa32\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\tvmovdqa64\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\tvmovdqu32\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\tvmovdqu64\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKvpabsq\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKvpandd\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\avpandnd\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\avpandnq\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKvpandq\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\tvpblendmd\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\tvpblendmq\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\bvpcmpltd\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\bvpcmpled\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\tvpcmpneqd\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\tvpcmpnltd\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\tvpcmpnled\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKvpcmpd\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\bvpcmpltq\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\bvpcmpleq\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\tvpcmpneqq\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\tvpcmpnltq\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\tvpcmpnleq\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKvpcmpq\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\tvpcmpequd\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\tvpcmpltud\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\tvpcmpleud\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\nvpcmpnequd\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\nvpcmpnltud\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\nvpcmpnleud\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\avpcmpud\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\tvpcmpequq\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\tvpcmpltuq\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\tvpcmpleuq\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\nvpcmpnequq\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\nvpcmpnltuq\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\nvpcmpnleuq\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\avpcmpuq\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\vvpcompressd\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\vvpcompressq\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\bvpermi2d\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\tvpermi2pd\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\tvpermi2ps\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\bvpermi2q\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\bvpermt2d\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\tvpermt2pd\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\tvpermt2ps\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\bvpermt2q\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\tvpexpandd\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\tvpexpandq\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\avpmaxsq\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\avpmaxuq\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\avpminsq\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\avpminuq\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\avpmovdb\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\avpmovdw\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\avpmovqb\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\avpmovqd\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\avpmovqw\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\bvpmovsdb\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\bvpmovsdw\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\bvpmovsqb\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\bvpmovsqd\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\bvpmovsqw\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\tvpmovusdb\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\tvpmovusdw\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\tvpmovusqb\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\tvpmovusqd\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\tvpmovusqw\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQvpord\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQvporq\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKvprold\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKvprolq\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\avprolvd\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\avprolvq\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKvprord\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKvprorq\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\avprorvd\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\avprorvq\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\vvpscatterdd\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\vvpscatterdq\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\vvpscatterqd\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\vvpscatterqq\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKvpsraq\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\avpsravq\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\nvpternlogd\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\nvpternlogq\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\bvptestmd\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\bvptestmq\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\tvptestnmd\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\tvptestnmq\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKvpxord\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKvpxorq\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\bvrcp14pd\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\bvrcp14ps\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\bvrcp14sd\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\bvrcp14ss\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\vvrndscalepd\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\vvrndscaleps\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\vvrndscalesd\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\vvrndscaless\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\nvrsqrt14pd\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\nvrsqrt14ps\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\nvrsqrt14sd\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\nvrsqrt14ss\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\tvscalefpd\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\tvscalefps\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\tvscalefsd\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\tvscalefss\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\vvscatterdpd\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\vvscatterdps\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\vvscatterqpd\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\vvscatterqps\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\nvshuff32x4\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\nvshuff64x2\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\nvshufi32x4\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\nvshufi64x2\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKkandnw\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQkandw\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQkmovw\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQknotw\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\bkortestw\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTkorw\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\bkshiftlw\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\bkshiftrw\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\bkunpckbw\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKkxnorw\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQkxorw\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SIvpbroadcastmb2q\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SIvpbroadcastmw2d\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\vvpconflictd\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\vvpconflictq\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\bvplzcntd\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\bvplzcntq\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\avexp2pd\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\avexp2ps\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\bvrcp28pd\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\bvrcp28ps\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\bvrcp28sd\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\bvrcp28ss\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\nvrsqrt28pd\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\nvrsqrt28ps\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\nvrsqrt28sd\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\nvrsqrt28ss\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\rvgatherpf0dpd\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\rvgatherpf0dps\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\rvgatherpf0qpd\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\rvgatherpf0qps\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\rvgatherpf1dpd\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\rvgatherpf1dps\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\rvgatherpf1qpd\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\rvgatherpf1qps\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOvscatterpf0dpd\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOvscatterpf0dps\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOvscatterpf0qpd\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOvscatterpf0qps\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOvscatterpf1dpd\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOvscatterpf1dps\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOvscatterpf1qpd\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOvscatterpf1qps\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\vprefetchwt1\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQbndmk\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQbndcl\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQbndcu\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQbndcn\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKbndmov\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKbndldx\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKbndstx\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\tsha1rnds4\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\tsha1nexte\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\bsha1msg1\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\bsha1msg2\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\vsha256rnds2\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\nsha256msg1\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\nsha256msg2\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\bhint_nop\NUL\NUL\NUL\NUL\NUL\NUL\NUL\bkeywords\NUL\NUL\NUL\NUL\NUL\NUL\NUL\184\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACK.abort\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACK.align\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\t.app-file\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\b.appline\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACK.ascii\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACK.asciz\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\v.att_syntax\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\a.balign\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\b.balignl\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\b.balignw\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQ.byte\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\a.code16\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\a.code32\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQ.comm\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\t.common.s\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\a.common\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQ.data\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQ.dc.b\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQ.dc.d\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQ.dc.l\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQ.dc.s\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQ.dc.w\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQ.dc.x\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETX.dc\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACK.dcb.b\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACK.dcb.d\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACK.dcb.l\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACK.dcb.s\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACK.dcb.w\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACK.dcb.x\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOT.dcb\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACK.debug\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOT.def\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQ.desc\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOT.dim\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\a.double\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQ.ds.b\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQ.ds.d\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQ.ds.l\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQ.ds.p\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQ.ds.s\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQ.ds.w\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQ.ds.x\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETX.ds\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACK.dsect\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACK.eject\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQ.else\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACK.elsec\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\a.elseif\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOT.end\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQ.endc\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACK.endef\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\b.endfunc\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACK.endif\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQ.endm\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQ.endr\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOT.equ\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACK.equiv\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOT.err\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACK.exitm\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\a.extend\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\a.extern\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQ.fail\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQ.file\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQ.fill\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACK.float\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\a.format\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQ.func\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\a.global\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACK.globl\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\a.hidden\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACK.hword\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACK.ident\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETX.if\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOT.ifc\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACK.ifdef\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQ.ifeq\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACK.ifeqs\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQ.ifge\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQ.ifgt\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQ.ifle\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQ.iflt\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQ.ifnc\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\a.ifndef\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQ.ifne\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACK.ifnes\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\t.ifnotdef\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\b.include\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOT.int\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\r.intel_syntax\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\t.internal\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQ.irep\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACK.irepc\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOT.irp\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQ.irpc\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACK.lcomm\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\a.lflags\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQ.line\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\t.linkonce\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQ.list\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQ.llen\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETX.ln\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQ.long\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQ.lsym\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACK.macro\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACK.mexit\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQ.name\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\t.noformat\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\a.nolist\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\a.nopage\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\bnoprefix\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQ.octa\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\a.offset\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOT.org\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\b.p2align\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\t.p2alignl\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\t.p2alignw\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQ.page\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQ.plen\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\v.popsection\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\t.previous\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACK.print\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\n.protected\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACK.psize\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\a.purgem\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\f.pushsection\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQ.quad\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\a.rodata\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOT.rep\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQ.rept\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOT.rva\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACK.sbttl\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOT.scl\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\a.sect.s\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQ.sect\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\n.section.s\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\b.section\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOT.set\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACK.short\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\a.single\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQ.size\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQ.skip\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\b.sleb128\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACK.space\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOT.spc\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACK.stabd\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACK.stabn\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACK.stabs\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\a.string\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\a.struct\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\v.subsection\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\a.symver\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOT.tag\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQ.text\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACK.title\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOT.ttl\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQ.type\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\b.uleb128\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOT.use\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOT.val\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\b.version\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\r.vtable_entry\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SI.vtable_inherit\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQ.weak\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQ.word\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQ.xcom\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQ.xdef\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQ.xref\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\a.xstabs\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQ.zero\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOT.arm\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOT.bss\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQ.code\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQ.even\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\f.force_thumb\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\b.ldouble\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOT.loc\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACK.ltorg\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\a.packed\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQ.pool\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOT.req\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACK.thumb\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\v.thumb_func\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\n.thumb_set\NUL\NUL\NUL\NUL\NUL\NUL\NUL\tregisters\NUL\NUL\NUL\NUL\NUL\NUL\NUL\192\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETXrax\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETXeax\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STXax\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STXah\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STXal\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETXrbx\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETXebx\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STXbx\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STXbh\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STXbl\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETXrcx\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETXecx\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STXcx\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STXch\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STXcl\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETXrdx\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETXedx\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STXdx\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STXdh\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STXdl\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETXrbp\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETXebp\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STXbp\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETXbpl\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETXrsi\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETXesi\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STXsi\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETXsil\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETXrdi\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETXedi\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STXdi\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETXdil\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETXrip\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETXeip\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STXip\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETXrsp\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETXesp\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STXsp\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETXspl\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STXr8\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETXr8d\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETXr8w\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETXr8b\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STXr9\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETXr9d\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETXr9w\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETXr9b\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETXr10\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTr10d\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTr10w\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTr10b\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETXr11\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTr11d\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTr11w\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTr11b\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETXr12\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTr12d\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTr12w\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTr12b\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETXr13\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTr13d\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTr13w\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTr13b\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETXr14\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTr14d\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTr14w\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTr14b\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETXr15\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTr15d\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTr15w\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTr15b\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STXcs\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STXds\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STXes\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STXfs\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STXgs\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STXss\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETXcr0\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETXcr2\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETXcr3\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETXcr4\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETXdr0\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETXdr1\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETXdr2\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETXdr3\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETXdr6\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETXdr7\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STXst\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETXmm0\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETXmm1\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETXmm2\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETXmm3\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETXmm4\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETXmm5\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETXmm6\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETXmm7\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTxmm0\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTxmm1\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTxmm2\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTxmm3\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTxmm4\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTxmm5\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTxmm6\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTxmm7\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTxmm8\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTxmm9\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQxmm10\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQxmm11\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQxmm12\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQxmm13\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQxmm14\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQxmm15\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQxmm16\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQxmm17\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQxmm18\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQxmm19\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQxmm20\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQxmm21\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQxmm22\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQxmm23\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQxmm24\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQxmm25\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQxmm26\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQxmm27\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQxmm28\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQxmm29\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQxmm30\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQxmm31\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTymm0\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTymm1\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTymm2\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTymm3\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTymm4\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTymm5\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTymm6\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTymm7\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTymm8\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTymm9\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQymm10\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQymm11\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQymm12\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQymm13\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQymm14\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQymm15\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQymm16\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQymm17\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQymm18\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQymm19\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQymm20\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQymm21\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQymm22\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQymm23\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQymm24\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQymm25\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQymm26\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQymm27\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQymm28\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQymm29\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQymm30\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQymm31\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTzmm0\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTzmm1\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTzmm2\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTzmm3\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTzmm4\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTzmm5\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTzmm6\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTzmm7\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTzmm8\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTzmm9\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQzmm10\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQzmm11\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQzmm12\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQzmm13\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQzmm14\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQzmm15\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQzmm16\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQzmm17\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQzmm18\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQzmm19\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQzmm20\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQzmm21\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQzmm22\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQzmm23\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQzmm24\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQzmm25\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQzmm26\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQzmm27\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQzmm28\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQzmm29\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQzmm30\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQzmm31\NUL\NUL\NUL\NUL\NUL\NUL\NUL\a\NUL\NUL\NUL\NUL\NUL\NUL\NUL\vCommentar 1\NUL\NUL\NUL\NUL\NUL\NUL\NUL\vCommentar 1\NUL\NUL\NUL\NUL\NUL\NUL\NUL\rGNU Assembler\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETX\SOH*/\f\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\DLE\f\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SI\NUL\NUL\NUL\NUL\NUL\NUL\NUL\bComments\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\f\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\f\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\vCommentar 2\NUL\NUL\NUL\NUL\NUL\NUL\NUL\vCommentar 2\NUL\NUL\NUL\NUL\NUL\NUL\NUL\rGNU Assembler\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STX\DLE\f\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SI\NUL\NUL\NUL\NUL\NUL\NUL\NUL\bComments\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\f\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\f\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKDefine\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKDefine\NUL\NUL\NUL\NUL\NUL\NUL\NUL\rGNU Assembler\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\SO\ETB\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETB\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKNormal\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKNormal\NUL\NUL\NUL\NUL\NUL\NUL\NUL\rGNU Assembler\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SYN\ACK\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC2[\\.]?[_\\w\\d-]*\\s*:\SOH\DC1\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\a\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ESC\t\n !%&()*+,-/:;<=>?[\\]^{|}~\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\184\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACK.abort\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACK.align\NUL\NUL\NUL\NUL\NUL\NUL\NUL\t.app-file\NUL\NUL\NUL\NUL\NUL\NUL\NUL\b.appline\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOT.arm\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACK.ascii\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACK.asciz\NUL\NUL\NUL\NUL\NUL\NUL\NUL\v.att_syntax\NUL\NUL\NUL\NUL\NUL\NUL\NUL\a.balign\NUL\NUL\NUL\NUL\NUL\NUL\NUL\b.balignl\NUL\NUL\NUL\NUL\NUL\NUL\NUL\b.balignw\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOT.bss\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQ.byte\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQ.code\NUL\NUL\NUL\NUL\NUL\NUL\NUL\a.code16\NUL\NUL\NUL\NUL\NUL\NUL\NUL\a.code32\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQ.comm\NUL\NUL\NUL\NUL\NUL\NUL\NUL\a.common\NUL\NUL\NUL\NUL\NUL\NUL\NUL\t.common.s\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQ.data\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETX.dc\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQ.dc.b\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQ.dc.d\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQ.dc.l\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQ.dc.s\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQ.dc.w\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQ.dc.x\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOT.dcb\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACK.dcb.b\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACK.dcb.d\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACK.dcb.l\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACK.dcb.s\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACK.dcb.w\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACK.dcb.x\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACK.debug\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOT.def\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQ.desc\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOT.dim\NUL\NUL\NUL\NUL\NUL\NUL\NUL\a.double\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETX.ds\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQ.ds.b\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQ.ds.d\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQ.ds.l\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQ.ds.p\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQ.ds.s\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQ.ds.w\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQ.ds.x\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACK.dsect\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACK.eject\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQ.else\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACK.elsec\NUL\NUL\NUL\NUL\NUL\NUL\NUL\a.elseif\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOT.end\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQ.endc\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACK.endef\NUL\NUL\NUL\NUL\NUL\NUL\NUL\b.endfunc\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACK.endif\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQ.endm\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQ.endr\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOT.equ\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACK.equiv\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOT.err\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQ.even\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACK.exitm\NUL\NUL\NUL\NUL\NUL\NUL\NUL\a.extend\NUL\NUL\NUL\NUL\NUL\NUL\NUL\a.extern\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQ.fail\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQ.file\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQ.fill\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACK.float\NUL\NUL\NUL\NUL\NUL\NUL\NUL\f.force_thumb\NUL\NUL\NUL\NUL\NUL\NUL\NUL\a.format\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQ.func\NUL\NUL\NUL\NUL\NUL\NUL\NUL\a.global\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACK.globl\NUL\NUL\NUL\NUL\NUL\NUL\NUL\a.hidden\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACK.hword\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACK.ident\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETX.if\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOT.ifc\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACK.ifdef\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQ.ifeq\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACK.ifeqs\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQ.ifge\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQ.ifgt\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQ.ifle\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQ.iflt\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQ.ifnc\NUL\NUL\NUL\NUL\NUL\NUL\NUL\a.ifndef\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQ.ifne\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACK.ifnes\NUL\NUL\NUL\NUL\NUL\NUL\NUL\t.ifnotdef\NUL\NUL\NUL\NUL\NUL\NUL\NUL\b.include\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOT.int\NUL\NUL\NUL\NUL\NUL\NUL\NUL\r.intel_syntax\NUL\NUL\NUL\NUL\NUL\NUL\NUL\t.internal\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQ.irep\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACK.irepc\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOT.irp\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQ.irpc\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACK.lcomm\NUL\NUL\NUL\NUL\NUL\NUL\NUL\b.ldouble\NUL\NUL\NUL\NUL\NUL\NUL\NUL\a.lflags\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQ.line\NUL\NUL\NUL\NUL\NUL\NUL\NUL\t.linkonce\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQ.list\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQ.llen\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETX.ln\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOT.loc\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQ.long\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQ.lsym\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACK.ltorg\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACK.macro\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACK.mexit\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQ.name\NUL\NUL\NUL\NUL\NUL\NUL\NUL\t.noformat\NUL\NUL\NUL\NUL\NUL\NUL\NUL\a.nolist\NUL\NUL\NUL\NUL\NUL\NUL\NUL\a.nopage\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQ.octa\NUL\NUL\NUL\NUL\NUL\NUL\NUL\a.offset\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOT.org\NUL\NUL\NUL\NUL\NUL\NUL\NUL\b.p2align\NUL\NUL\NUL\NUL\NUL\NUL\NUL\t.p2alignl\NUL\NUL\NUL\NUL\NUL\NUL\NUL\t.p2alignw\NUL\NUL\NUL\NUL\NUL\NUL\NUL\a.packed\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQ.page\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQ.plen\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQ.pool\NUL\NUL\NUL\NUL\NUL\NUL\NUL\v.popsection\NUL\NUL\NUL\NUL\NUL\NUL\NUL\t.previous\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACK.print\NUL\NUL\NUL\NUL\NUL\NUL\NUL\n.protected\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACK.psize\NUL\NUL\NUL\NUL\NUL\NUL\NUL\a.purgem\NUL\NUL\NUL\NUL\NUL\NUL\NUL\f.pushsection\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQ.quad\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOT.rep\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQ.rept\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOT.req\NUL\NUL\NUL\NUL\NUL\NUL\NUL\a.rodata\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOT.rva\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACK.sbttl\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOT.scl\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQ.sect\NUL\NUL\NUL\NUL\NUL\NUL\NUL\a.sect.s\NUL\NUL\NUL\NUL\NUL\NUL\NUL\b.section\NUL\NUL\NUL\NUL\NUL\NUL\NUL\n.section.s\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOT.set\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACK.short\NUL\NUL\NUL\NUL\NUL\NUL\NUL\a.single\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQ.size\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQ.skip\NUL\NUL\NUL\NUL\NUL\NUL\NUL\b.sleb128\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACK.space\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOT.spc\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACK.stabd\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACK.stabn\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACK.stabs\NUL\NUL\NUL\NUL\NUL\NUL\NUL\a.string\NUL\NUL\NUL\NUL\NUL\NUL\NUL\a.struct\NUL\NUL\NUL\NUL\NUL\NUL\NUL\v.subsection\NUL\NUL\NUL\NUL\NUL\NUL\NUL\a.symver\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOT.tag\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQ.text\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACK.thumb\NUL\NUL\NUL\NUL\NUL\NUL\NUL\v.thumb_func\NUL\NUL\NUL\NUL\NUL\NUL\NUL\n.thumb_set\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACK.title\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOT.ttl\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQ.type\NUL\NUL\NUL\NUL\NUL\NUL\NUL\b.uleb128\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOT.use\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOT.val\NUL\NUL\NUL\NUL\NUL\NUL\NUL\b.version\NUL\NUL\NUL\NUL\NUL\NUL\NUL\r.vtable_entry\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SI.vtable_inherit\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQ.weak\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQ.word\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQ.xcom\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQ.xdef\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQ.xref\NUL\NUL\NUL\NUL\NUL\NUL\NUL\a.xstabs\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQ.zero\NUL\NUL\NUL\NUL\NUL\NUL\NUL\bnoprefix\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\a\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ESC\t\n !%&()*+,-/:;<=>?[\\]^{|}~\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\192\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STXah\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STXal\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STXax\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STXbh\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STXbl\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STXbp\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETXbpl\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STXbx\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STXch\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STXcl\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETXcr0\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETXcr2\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETXcr3\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETXcr4\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STXcs\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STXcx\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STXdh\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STXdi\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETXdil\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STXdl\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETXdr0\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETXdr1\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETXdr2\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETXdr3\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETXdr6\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETXdr7\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STXds\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STXdx\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETXeax\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETXebp\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETXebx\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETXecx\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETXedi\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETXedx\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETXeip\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STXes\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETXesi\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETXesp\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STXfs\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STXgs\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STXip\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETXmm0\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETXmm1\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETXmm2\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETXmm3\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETXmm4\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETXmm5\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETXmm6\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETXmm7\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETXr10\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTr10b\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTr10d\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTr10w\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETXr11\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTr11b\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTr11d\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTr11w\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETXr12\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTr12b\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTr12d\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTr12w\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETXr13\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTr13b\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTr13d\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTr13w\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETXr14\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTr14b\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTr14d\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTr14w\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETXr15\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTr15b\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTr15d\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTr15w\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STXr8\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETXr8b\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETXr8d\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETXr8w\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STXr9\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETXr9b\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETXr9d\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETXr9w\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETXrax\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETXrbp\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETXrbx\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETXrcx\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETXrdi\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETXrdx\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETXrip\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETXrsi\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETXrsp\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STXsi\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETXsil\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STXsp\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETXspl\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STXss\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STXst\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTxmm0\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTxmm1\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQxmm10\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQxmm11\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQxmm12\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQxmm13\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQxmm14\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQxmm15\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQxmm16\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQxmm17\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQxmm18\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQxmm19\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTxmm2\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQxmm20\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQxmm21\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQxmm22\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQxmm23\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQxmm24\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQxmm25\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQxmm26\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQxmm27\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQxmm28\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQxmm29\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTxmm3\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQxmm30\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQxmm31\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTxmm4\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTxmm5\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTxmm6\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTxmm7\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTxmm8\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTxmm9\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTymm0\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTymm1\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQymm10\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQymm11\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQymm12\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQymm13\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQymm14\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQymm15\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQymm16\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQymm17\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQymm18\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQymm19\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTymm2\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQymm20\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQymm21\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQymm22\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQymm23\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQymm24\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQymm25\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQymm26\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQymm27\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQymm28\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQymm29\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTymm3\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQymm30\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQymm31\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTymm4\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTymm5\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTymm6\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTymm7\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTymm8\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTymm9\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTzmm0\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTzmm1\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQzmm10\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQzmm11\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQzmm12\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQzmm13\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQzmm14\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQzmm15\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQzmm16\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQzmm17\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQzmm18\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQzmm19\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTzmm2\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQzmm20\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQzmm21\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQzmm22\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQzmm23\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQzmm24\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQzmm25\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQzmm26\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQzmm27\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQzmm28\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQzmm29\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTzmm3\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQzmm30\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQzmm31\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTzmm4\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTzmm5\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTzmm6\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTzmm7\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTzmm8\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTzmm9\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\a\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ESC\t\n !%&()*+,-/:;<=>?[\\]^{|}~\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACK\234\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETXaaa\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETXaad\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETXaam\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETXaas\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETXadc\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTadcx\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTaddb\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTaddl\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQaddpd\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQaddps\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTaddq\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQaddsd\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQaddss\NUL\NUL\NUL\NUL\NUL\NUL\NUL\baddsubpd\NUL\NUL\NUL\NUL\NUL\NUL\NUL\baddsubps\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTaddw\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTadox\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKaesdec\NUL\NUL\NUL\NUL\NUL\NUL\NUL\naesdeclast\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKaesenc\NUL\NUL\NUL\NUL\NUL\NUL\NUL\naesenclast\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKaesimc\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SIaeskeygenassist\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETXand\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTandn\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKandnpd\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKandnps\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQandpd\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQandps\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTarpl\NUL\NUL\NUL\NUL\NUL\NUL\NUL\tbb0_reset\NUL\NUL\NUL\NUL\NUL\NUL\NUL\tbb1_reset\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQbextr\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ablcfill\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTblci\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQblcic\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKblcmsk\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTblcs\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ablendpd\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ablendps\NUL\NUL\NUL\NUL\NUL\NUL\NUL\bblendvpd\NUL\NUL\NUL\NUL\NUL\NUL\NUL\bblendvps\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ablsfill\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTblsi\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQblsic\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKblsmsk\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTblsr\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETXbnd\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQbndcl\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQbndcn\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQbndcu\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKbndldx\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQbndmk\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKbndmov\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKbndstx\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQbound\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETXbsf\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETXbsr\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQbswap\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STXbt\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETXbtc\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETXbtr\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETXbts\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTbzhi\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTcbtw\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETXcbw\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETXcdq\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTcdqe\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTclac\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETXclc\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETXcld\NUL\NUL\NUL\NUL\NUL\NUL\NUL\aclflush\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTclgi\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETXcli\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTcltd\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTcltq\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTclts\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETXcmc\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQcmova\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKcmovae\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQcmovb\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKcmovbe\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQcmovc\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQcmove\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQcmovg\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKcmovge\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQcmovl\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKcmovle\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKcmovna\NUL\NUL\NUL\NUL\NUL\NUL\NUL\acmovnae\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKcmovnb\NUL\NUL\NUL\NUL\NUL\NUL\NUL\acmovnbe\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKcmovnc\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKcmovne\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKcmovng\NUL\NUL\NUL\NUL\NUL\NUL\NUL\acmovnge\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKcmovnl\NUL\NUL\NUL\NUL\NUL\NUL\NUL\acmovnle\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKcmovno\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKcmovnp\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKcmovns\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKcmovnz\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQcmovo\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQcmovp\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKcmovpe\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKcmovpo\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQcmovs\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQcmovz\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTcmpb\NUL\NUL\NUL\NUL\NUL\NUL\NUL\acmpeqpd\NUL\NUL\NUL\NUL\NUL\NUL\NUL\acmpeqps\NUL\NUL\NUL\NUL\NUL\NUL\NUL\acmpeqsd\NUL\NUL\NUL\NUL\NUL\NUL\NUL\acmpeqss\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTcmpl\NUL\NUL\NUL\NUL\NUL\NUL\NUL\acmplepd\NUL\NUL\NUL\NUL\NUL\NUL\NUL\acmpleps\NUL\NUL\NUL\NUL\NUL\NUL\NUL\acmplesd\NUL\NUL\NUL\NUL\NUL\NUL\NUL\acmpless\NUL\NUL\NUL\NUL\NUL\NUL\NUL\acmpltpd\NUL\NUL\NUL\NUL\NUL\NUL\NUL\acmpltps\NUL\NUL\NUL\NUL\NUL\NUL\NUL\acmpltsd\NUL\NUL\NUL\NUL\NUL\NUL\NUL\acmpltss\NUL\NUL\NUL\NUL\NUL\NUL\NUL\bcmpneqpd\NUL\NUL\NUL\NUL\NUL\NUL\NUL\bcmpneqps\NUL\NUL\NUL\NUL\NUL\NUL\NUL\bcmpneqsd\NUL\NUL\NUL\NUL\NUL\NUL\NUL\bcmpneqss\NUL\NUL\NUL\NUL\NUL\NUL\NUL\bcmpnlepd\NUL\NUL\NUL\NUL\NUL\NUL\NUL\bcmpnleps\NUL\NUL\NUL\NUL\NUL\NUL\NUL\bcmpnlesd\NUL\NUL\NUL\NUL\NUL\NUL\NUL\bcmpnless\NUL\NUL\NUL\NUL\NUL\NUL\NUL\bcmpnltpd\NUL\NUL\NUL\NUL\NUL\NUL\NUL\bcmpnltps\NUL\NUL\NUL\NUL\NUL\NUL\NUL\bcmpnltsd\NUL\NUL\NUL\NUL\NUL\NUL\NUL\bcmpnltss\NUL\NUL\NUL\NUL\NUL\NUL\NUL\bcmpordpd\NUL\NUL\NUL\NUL\NUL\NUL\NUL\bcmpordps\NUL\NUL\NUL\NUL\NUL\NUL\NUL\bcmpordsd\NUL\NUL\NUL\NUL\NUL\NUL\NUL\bcmpordss\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQcmppd\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQcmpps\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTcmpq\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQcmpsb\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQcmpsd\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQcmpsq\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQcmpss\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQcmpsw\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ncmpunordpd\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ncmpunordps\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ncmpunordsd\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ncmpunordss\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTcmpw\NUL\NUL\NUL\NUL\NUL\NUL\NUL\acmpxchg\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ncmpxchg16b\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ncmpxchg486\NUL\NUL\NUL\NUL\NUL\NUL\NUL\tcmpxchg8b\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKcomisd\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKcomiss\NUL\NUL\NUL\NUL\NUL\NUL\NUL\bcpu_read\NUL\NUL\NUL\NUL\NUL\NUL\NUL\tcpu_write\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQcpuid\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETXcqo\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTcqto\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQcrc32\NUL\NUL\NUL\NUL\NUL\NUL\NUL\bcvtdq2pd\NUL\NUL\NUL\NUL\NUL\NUL\NUL\bcvtdq2ps\NUL\NUL\NUL\NUL\NUL\NUL\NUL\bcvtpd2dq\NUL\NUL\NUL\NUL\NUL\NUL\NUL\bcvtpd2pi\NUL\NUL\NUL\NUL\NUL\NUL\NUL\bcvtpd2ps\NUL\NUL\NUL\NUL\NUL\NUL\NUL\bcvtpi2pd\NUL\NUL\NUL\NUL\NUL\NUL\NUL\bcvtpi2ps\NUL\NUL\NUL\NUL\NUL\NUL\NUL\bcvtps2dq\NUL\NUL\NUL\NUL\NUL\NUL\NUL\bcvtps2pd\NUL\NUL\NUL\NUL\NUL\NUL\NUL\bcvtps2pi\NUL\NUL\NUL\NUL\NUL\NUL\NUL\bcvtsd2si\NUL\NUL\NUL\NUL\NUL\NUL\NUL\bcvtsd2ss\NUL\NUL\NUL\NUL\NUL\NUL\NUL\bcvtsi2sd\NUL\NUL\NUL\NUL\NUL\NUL\NUL\bcvtsi2ss\NUL\NUL\NUL\NUL\NUL\NUL\NUL\bcvtss2sd\NUL\NUL\NUL\NUL\NUL\NUL\NUL\bcvtss2si\NUL\NUL\NUL\NUL\NUL\NUL\NUL\tcvttpd2dq\NUL\NUL\NUL\NUL\NUL\NUL\NUL\tcvttpd2pi\NUL\NUL\NUL\NUL\NUL\NUL\NUL\tcvttps2dq\NUL\NUL\NUL\NUL\NUL\NUL\NUL\tcvttps2pi\NUL\NUL\NUL\NUL\NUL\NUL\NUL\tcvttsd2si\NUL\NUL\NUL\NUL\NUL\NUL\NUL\tcvttss2si\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETXcwd\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTcwde\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTcwtd\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTcwtl\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETXdaa\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETXdas\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETXdec\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTdecl\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTdecq\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETXdiv\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTdivb\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTdivl\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQdivpd\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQdivps\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTdivq\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQdivsd\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQdivss\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTdivw\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQdmint\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTdppd\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTdpps\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTemms\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQenter\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETXequ\NUL\NUL\NUL\NUL\NUL\NUL\NUL\textractps\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQextrq\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQf2xm1\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTfabs\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTfadd\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQfaddp\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTfbld\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQfbstp\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTfchs\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQfclex\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKfcmovb\NUL\NUL\NUL\NUL\NUL\NUL\NUL\afcmovbe\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKfcmove\NUL\NUL\NUL\NUL\NUL\NUL\NUL\afcmovnb\NUL\NUL\NUL\NUL\NUL\NUL\NUL\bfcmovnbe\NUL\NUL\NUL\NUL\NUL\NUL\NUL\afcmovne\NUL\NUL\NUL\NUL\NUL\NUL\NUL\afcmovnu\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKfcmovu\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTfcom\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQfcomi\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKfcomip\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQfcomp\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKfcompp\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTfcos\NUL\NUL\NUL\NUL\NUL\NUL\NUL\afdecstp\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQfdisi\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTfdiv\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQfdivp\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQfdivr\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKfdivrp\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQfemms\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTfeni\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQffree\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKffreep\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQfiadd\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQficom\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKficomp\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQfidiv\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKfidivr\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTfild\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQfimul\NUL\NUL\NUL\NUL\NUL\NUL\NUL\afincstp\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQfinit\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTfist\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQfistp\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKfisttp\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQfisub\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKfisubr\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETXfld\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTfld1\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQfldcw\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKfldenv\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKfldl2e\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKfldl2t\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKfldlg2\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKfldln2\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQfldpi\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTfldz\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTfmul\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQfmulp\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKfnclex\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKfndisi\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQfneni\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKfninit\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTfnop\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKfnsave\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKfnstcw\NUL\NUL\NUL\NUL\NUL\NUL\NUL\afnstenv\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKfnstsw\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKfpatan\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQfprem\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKfprem1\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQfptan\NUL\NUL\NUL\NUL\NUL\NUL\NUL\afrndint\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKfrstor\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQfsave\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKfscale\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKfsetpm\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTfsin\NUL\NUL\NUL\NUL\NUL\NUL\NUL\afsincos\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQfsqrt\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETXfst\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQfstcw\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKfstenv\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTfstp\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQfstsw\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTfsub\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQfsubp\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQfsubr\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKfsubrp\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTftst\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQfucom\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKfucomi\NUL\NUL\NUL\NUL\NUL\NUL\NUL\afucomip\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKfucomp\NUL\NUL\NUL\NUL\NUL\NUL\NUL\afucompp\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQfwait\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTfxam\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTfxch\NUL\NUL\NUL\NUL\NUL\NUL\NUL\afxrstor\NUL\NUL\NUL\NUL\NUL\NUL\NUL\tfxrstor64\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKfxsave\NUL\NUL\NUL\NUL\NUL\NUL\NUL\bfxsave64\NUL\NUL\NUL\NUL\NUL\NUL\NUL\afxtract\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQfyl2x\NUL\NUL\NUL\NUL\NUL\NUL\NUL\afyl2xp1\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKgetsec\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKglobal\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQglobl\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKhaddpd\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKhaddps\NUL\NUL\NUL\NUL\NUL\NUL\NUL\bhint_nop\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETXhlt\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKhsubpd\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKhsubps\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTibts\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQicebp\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTidiv\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQidivb\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQidivl\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQidivq\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQidivw\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTimul\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQimulb\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQimull\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQimulq\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQimulw\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STXin\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETXinc\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKincbin\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTincl\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTincq\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTinsb\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTinsd\NUL\NUL\NUL\NUL\NUL\NUL\NUL\binsertps\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ainsertq\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTinsw\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETXint\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQint01\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQint03\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTint1\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTint3\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTinto\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTinvd\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKinvept\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKinvlpg\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ainvlpga\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ainvpcid\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ainvvpid\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTiret\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQiretd\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQiretq\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQiretw\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTjcxz\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQjecxz\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQjrcxz\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKkandnw\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQkandw\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQkmovw\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQknotw\NUL\NUL\NUL\NUL\NUL\NUL\NUL\bkortestw\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTkorw\NUL\NUL\NUL\NUL\NUL\NUL\NUL\bkshiftlw\NUL\NUL\NUL\NUL\NUL\NUL\NUL\bkshiftrw\NUL\NUL\NUL\NUL\NUL\NUL\NUL\bkunpckbw\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKkxnorw\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQkxorw\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTlahf\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETXlar\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQlddqu\NUL\NUL\NUL\NUL\NUL\NUL\NUL\aldmxcsr\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETXlds\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTleal\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTleaq\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQleave\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETXles\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKlfence\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETXlfs\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTlgdt\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETXlgs\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTlidt\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTlldt\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKllwpcb\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTlmsw\NUL\NUL\NUL\NUL\NUL\NUL\NUL\aloadall\NUL\NUL\NUL\NUL\NUL\NUL\NUL\nloadall286\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTlock\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQlodsb\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQlodsd\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQlodsq\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQlodsw\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTloop\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQloope\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKloopne\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKloopnz\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQloopz\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETXlsl\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETXlss\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETXltr\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKlwpins\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKlwpval\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQlzcnt\NUL\NUL\NUL\NUL\NUL\NUL\NUL\nmaskmovdqu\NUL\NUL\NUL\NUL\NUL\NUL\NUL\bmaskmovq\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQmaxpd\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQmaxps\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQmaxsd\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQmaxss\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKmfence\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQminpd\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQminps\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQminsd\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQminss\NUL\NUL\NUL\NUL\NUL\NUL\NUL\amonitor\NUL\NUL\NUL\NUL\NUL\NUL\NUL\amontmul\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKmovapd\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKmovaps\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTmovb\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQmovbe\NUL\NUL\NUL\NUL\NUL\NUL\NUL\amovddup\NUL\NUL\NUL\NUL\NUL\NUL\NUL\amovdq2q\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKmovdqa\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKmovdqu\NUL\NUL\NUL\NUL\NUL\NUL\NUL\amovhlps\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKmovhpd\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKmovhps\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTmovl\NUL\NUL\NUL\NUL\NUL\NUL\NUL\amovlhps\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKmovlpd\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKmovlps\NUL\NUL\NUL\NUL\NUL\NUL\NUL\bmovmskpd\NUL\NUL\NUL\NUL\NUL\NUL\NUL\bmovmskps\NUL\NUL\NUL\NUL\NUL\NUL\NUL\amovntdq\NUL\NUL\NUL\NUL\NUL\NUL\NUL\bmovntdqa\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKmovnti\NUL\NUL\NUL\NUL\NUL\NUL\NUL\amovntpd\NUL\NUL\NUL\NUL\NUL\NUL\NUL\amovntps\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKmovntq\NUL\NUL\NUL\NUL\NUL\NUL\NUL\amovntsd\NUL\NUL\NUL\NUL\NUL\NUL\NUL\amovntss\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTmovq\NUL\NUL\NUL\NUL\NUL\NUL\NUL\amovq2dq\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQmovsb\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKmovsbl\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKmovsbq\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKmovsbw\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQmovsd\NUL\NUL\NUL\NUL\NUL\NUL\NUL\bmovshdup\NUL\NUL\NUL\NUL\NUL\NUL\NUL\bmovsldup\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKmovslq\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQmovsq\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQmovss\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQmovsw\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKmovswl\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKmovswq\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQmovsx\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKmovsxb\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKmovsxd\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKmovsxl\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKmovsxw\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKmovupd\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKmovups\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTmovw\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKmovzbl\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKmovzbq\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKmovzbw\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKmovzwl\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKmovzwq\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQmovzx\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKmovzxb\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKmovzxw\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ampsadbw\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETXmul\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTmulb\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTmull\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQmulpd\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQmulps\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTmulq\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQmulsd\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQmulss\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTmulw\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTmulx\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQmwait\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETXneg\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQnobnd\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETXnop\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETXnot\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STXor\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTorpd\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTorps\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETXout\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQoutsb\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQoutsd\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQoutsw\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQpabsb\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQpabsd\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQpabsw\NUL\NUL\NUL\NUL\NUL\NUL\NUL\bpackssdw\NUL\NUL\NUL\NUL\NUL\NUL\NUL\bpacksswb\NUL\NUL\NUL\NUL\NUL\NUL\NUL\bpackusdw\NUL\NUL\NUL\NUL\NUL\NUL\NUL\bpackuswb\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQpaddb\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQpaddd\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQpaddq\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKpaddsb\NUL\NUL\NUL\NUL\NUL\NUL\NUL\apaddsiw\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKpaddsw\NUL\NUL\NUL\NUL\NUL\NUL\NUL\apaddusb\NUL\NUL\NUL\NUL\NUL\NUL\NUL\apaddusw\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQpaddw\NUL\NUL\NUL\NUL\NUL\NUL\NUL\apalignr\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTpand\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQpandn\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQpause\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQpaveb\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQpavgb\NUL\NUL\NUL\NUL\NUL\NUL\NUL\apavgusb\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQpavgw\NUL\NUL\NUL\NUL\NUL\NUL\NUL\bpblendvb\NUL\NUL\NUL\NUL\NUL\NUL\NUL\apblendw\NUL\NUL\NUL\NUL\NUL\NUL\NUL\fpclmulhqhqdq\NUL\NUL\NUL\NUL\NUL\NUL\NUL\fpclmulhqlqdq\NUL\NUL\NUL\NUL\NUL\NUL\NUL\fpclmullqhqdq\NUL\NUL\NUL\NUL\NUL\NUL\NUL\fpclmullqlqdq\NUL\NUL\NUL\NUL\NUL\NUL\NUL\tpclmulqdq\NUL\NUL\NUL\NUL\NUL\NUL\NUL\apcmpeqb\NUL\NUL\NUL\NUL\NUL\NUL\NUL\apcmpeqd\NUL\NUL\NUL\NUL\NUL\NUL\NUL\apcmpeqq\NUL\NUL\NUL\NUL\NUL\NUL\NUL\apcmpeqw\NUL\NUL\NUL\NUL\NUL\NUL\NUL\tpcmpestri\NUL\NUL\NUL\NUL\NUL\NUL\NUL\tpcmpestrm\NUL\NUL\NUL\NUL\NUL\NUL\NUL\apcmpgtb\NUL\NUL\NUL\NUL\NUL\NUL\NUL\apcmpgtd\NUL\NUL\NUL\NUL\NUL\NUL\NUL\apcmpgtq\NUL\NUL\NUL\NUL\NUL\NUL\NUL\apcmpgtw\NUL\NUL\NUL\NUL\NUL\NUL\NUL\tpcmpistri\NUL\NUL\NUL\NUL\NUL\NUL\NUL\tpcmpistrm\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTpdep\NUL\NUL\NUL\NUL\NUL\NUL\NUL\apdistib\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTpext\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKpextrb\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKpextrd\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKpextrq\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKpextrw\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQpf2id\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQpf2iw\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQpfacc\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQpfadd\NUL\NUL\NUL\NUL\NUL\NUL\NUL\apfcmpeq\NUL\NUL\NUL\NUL\NUL\NUL\NUL\apfcmpge\NUL\NUL\NUL\NUL\NUL\NUL\NUL\apfcmpgt\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQpfmax\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQpfmin\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQpfmul\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKpfnacc\NUL\NUL\NUL\NUL\NUL\NUL\NUL\apfpnacc\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQpfrcp\NUL\NUL\NUL\NUL\NUL\NUL\NUL\bpfrcpit1\NUL\NUL\NUL\NUL\NUL\NUL\NUL\bpfrcpit2\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKpfrcpv\NUL\NUL\NUL\NUL\NUL\NUL\NUL\bpfrsqit1\NUL\NUL\NUL\NUL\NUL\NUL\NUL\apfrsqrt\NUL\NUL\NUL\NUL\NUL\NUL\NUL\bpfrsqrtv\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQpfsub\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKpfsubr\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKphaddd\NUL\NUL\NUL\NUL\NUL\NUL\NUL\aphaddsw\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKphaddw\NUL\NUL\NUL\NUL\NUL\NUL\NUL\nphminposuw\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKphsubd\NUL\NUL\NUL\NUL\NUL\NUL\NUL\aphsubsw\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKphsubw\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQpi2fd\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQpi2fw\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKpinsrb\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKpinsrd\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKpinsrq\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKpinsrw\NUL\NUL\NUL\NUL\NUL\NUL\NUL\bpmachriw\NUL\NUL\NUL\NUL\NUL\NUL\NUL\tpmaddubsw\NUL\NUL\NUL\NUL\NUL\NUL\NUL\apmaddwd\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQpmagw\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKpmaxsb\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKpmaxsd\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKpmaxsw\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKpmaxub\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKpmaxud\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKpmaxuw\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKpminsb\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKpminsd\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKpminsw\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKpminub\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKpminud\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKpminuw\NUL\NUL\NUL\NUL\NUL\NUL\NUL\bpmovmskb\NUL\NUL\NUL\NUL\NUL\NUL\NUL\bpmovsxbd\NUL\NUL\NUL\NUL\NUL\NUL\NUL\bpmovsxbq\NUL\NUL\NUL\NUL\NUL\NUL\NUL\bpmovsxbw\NUL\NUL\NUL\NUL\NUL\NUL\NUL\bpmovsxdq\NUL\NUL\NUL\NUL\NUL\NUL\NUL\bpmovsxwd\NUL\NUL\NUL\NUL\NUL\NUL\NUL\bpmovsxwq\NUL\NUL\NUL\NUL\NUL\NUL\NUL\bpmovzxbd\NUL\NUL\NUL\NUL\NUL\NUL\NUL\bpmovzxbq\NUL\NUL\NUL\NUL\NUL\NUL\NUL\bpmovzxbw\NUL\NUL\NUL\NUL\NUL\NUL\NUL\bpmovzxdq\NUL\NUL\NUL\NUL\NUL\NUL\NUL\bpmovzxwd\NUL\NUL\NUL\NUL\NUL\NUL\NUL\bpmovzxwq\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKpmuldq\NUL\NUL\NUL\NUL\NUL\NUL\NUL\bpmulhriw\NUL\NUL\NUL\NUL\NUL\NUL\NUL\bpmulhrsw\NUL\NUL\NUL\NUL\NUL\NUL\NUL\bpmulhrwa\NUL\NUL\NUL\NUL\NUL\NUL\NUL\bpmulhrwc\NUL\NUL\NUL\NUL\NUL\NUL\NUL\apmulhuw\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKpmulhw\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKpmulld\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKpmullw\NUL\NUL\NUL\NUL\NUL\NUL\NUL\apmuludq\NUL\NUL\NUL\NUL\NUL\NUL\NUL\apmvgezb\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKpmvlzb\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKpmvnzb\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQpmvzb\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETXpop\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTpopa\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQpopad\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQpopaw\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKpopcnt\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTpopf\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQpopfd\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQpopfq\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQpopfw\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTpopl\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTpopq\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETXpor\NUL\NUL\NUL\NUL\NUL\NUL\NUL\bprefetch\NUL\NUL\NUL\NUL\NUL\NUL\NUL\vprefetchnta\NUL\NUL\NUL\NUL\NUL\NUL\NUL\nprefetcht0\NUL\NUL\NUL\NUL\NUL\NUL\NUL\nprefetcht1\NUL\NUL\NUL\NUL\NUL\NUL\NUL\nprefetcht2\NUL\NUL\NUL\NUL\NUL\NUL\NUL\tprefetchw\NUL\NUL\NUL\NUL\NUL\NUL\NUL\vprefetchwt1\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKpsadbw\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKpshufb\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKpshufd\NUL\NUL\NUL\NUL\NUL\NUL\NUL\apshufhw\NUL\NUL\NUL\NUL\NUL\NUL\NUL\apshuflw\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKpshufw\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKpsignb\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKpsignd\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKpsignw\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQpslld\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKpslldq\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQpsllq\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQpsllw\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQpsrad\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQpsraw\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQpsrld\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKpsrldq\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQpsrlq\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQpsrlw\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQpsubb\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQpsubd\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQpsubq\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKpsubsb\NUL\NUL\NUL\NUL\NUL\NUL\NUL\apsubsiw\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKpsubsw\NUL\NUL\NUL\NUL\NUL\NUL\NUL\apsubusb\NUL\NUL\NUL\NUL\NUL\NUL\NUL\apsubusw\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQpsubw\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKpswapd\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQptest\NUL\NUL\NUL\NUL\NUL\NUL\NUL\tpunpckhbw\NUL\NUL\NUL\NUL\NUL\NUL\NUL\tpunpckhdq\NUL\NUL\NUL\NUL\NUL\NUL\NUL\npunpckhqdq\NUL\NUL\NUL\NUL\NUL\NUL\NUL\tpunpckhwd\NUL\NUL\NUL\NUL\NUL\NUL\NUL\tpunpcklbw\NUL\NUL\NUL\NUL\NUL\NUL\NUL\tpunpckldq\NUL\NUL\NUL\NUL\NUL\NUL\NUL\npunpcklqdq\NUL\NUL\NUL\NUL\NUL\NUL\NUL\tpunpcklwd\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTpush\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQpusha\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKpushad\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKpushaw\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQpushf\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKpushfd\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKpushfq\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKpushfw\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQpushl\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQpushq\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTpxor\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETXrcl\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQrcpps\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQrcpss\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETXrcr\NUL\NUL\NUL\NUL\NUL\NUL\NUL\brdfsbase\NUL\NUL\NUL\NUL\NUL\NUL\NUL\brdgsbase\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETXrdm\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQrdmsr\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQrdpmc\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKrdrand\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKrdseed\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQrdshr\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQrdtsc\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKrdtscp\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETXrep\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTrepe\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQrepne\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQrepnz\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTrepz\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETXret\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTretf\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTretn\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTretq\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETXrol\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETXror\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTrorx\NUL\NUL\NUL\NUL\NUL\NUL\NUL\aroundpd\NUL\NUL\NUL\NUL\NUL\NUL\NUL\aroundps\NUL\NUL\NUL\NUL\NUL\NUL\NUL\aroundsd\NUL\NUL\NUL\NUL\NUL\NUL\NUL\aroundss\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTrsdc\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQrsldt\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETXrsm\NUL\NUL\NUL\NUL\NUL\NUL\NUL\arsqrtps\NUL\NUL\NUL\NUL\NUL\NUL\NUL\arsqrtss\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTrsts\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTsahf\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETXsal\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTsalc\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTsall\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTsalq\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETXsar\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTsarl\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTsarq\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTsarx\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETXsbb\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQscasb\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQscasd\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQscasq\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQscasw\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTseta\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQsetae\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTsetb\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQsetbe\NUL\NUL\NUL\NUL\NUL\NUL\NUL\asetcset\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTsete\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTsetg\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQsetge\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTsetl\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQsetle\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQsetna\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKsetnae\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQsetnb\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKsetnbe\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQsetnc\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQsetne\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQsetng\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKsetnge\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQsetnl\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKsetnle\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQsetno\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQsetnp\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQsetns\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQsetnz\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTseto\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTsetp\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQsetpe\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQsetpo\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTsets\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTsetz\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKsfence\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTsgdt\NUL\NUL\NUL\NUL\NUL\NUL\NUL\bsha1msg1\NUL\NUL\NUL\NUL\NUL\NUL\NUL\bsha1msg2\NUL\NUL\NUL\NUL\NUL\NUL\NUL\tsha1nexte\NUL\NUL\NUL\NUL\NUL\NUL\NUL\tsha1rnds4\NUL\NUL\NUL\NUL\NUL\NUL\NUL\nsha256msg1\NUL\NUL\NUL\NUL\NUL\NUL\NUL\nsha256msg2\NUL\NUL\NUL\NUL\NUL\NUL\NUL\vsha256rnds2\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETXshl\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTshld\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTshll\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQshllq\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTshlx\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETXshr\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTshrd\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTshrx\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKshufpd\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKshufps\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTsidt\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKskinit\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTsldt\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKslwpcb\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETXsmi\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQsmint\NUL\NUL\NUL\NUL\NUL\NUL\NUL\bsmintold\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTsmsw\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKsqrtpd\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKsqrtps\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKsqrtsd\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKsqrtss\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTstac\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETXstc\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETXstd\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTstgi\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETXsti\NUL\NUL\NUL\NUL\NUL\NUL\NUL\astmxcsr\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQstosb\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQstosd\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQstosq\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQstosw\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETXstr\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETXsub\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTsubl\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQsubpd\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQsubps\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTsubq\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQsubsd\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQsubss\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTsubw\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTsvdc\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQsvldt\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTsvts\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKswapgs\NUL\NUL\NUL\NUL\NUL\NUL\NUL\asyscall\NUL\NUL\NUL\NUL\NUL\NUL\NUL\bsysenter\NUL\NUL\NUL\NUL\NUL\NUL\NUL\asysexit\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKsysret\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKt1mskc\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTtest\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQtestl\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQtestq\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQtzcnt\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQtzmsk\NUL\NUL\NUL\NUL\NUL\NUL\NUL\aucomisd\NUL\NUL\NUL\NUL\NUL\NUL\NUL\aucomiss\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETXud0\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETXud1\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETXud2\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTud2a\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTud2b\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTumov\NUL\NUL\NUL\NUL\NUL\NUL\NUL\bunpckhpd\NUL\NUL\NUL\NUL\NUL\NUL\NUL\bunpckhps\NUL\NUL\NUL\NUL\NUL\NUL\NUL\bunpcklpd\NUL\NUL\NUL\NUL\NUL\NUL\NUL\bunpcklps\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKvaddpd\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKvaddps\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKvaddsd\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKvaddss\NUL\NUL\NUL\NUL\NUL\NUL\NUL\tvaddsubpd\NUL\NUL\NUL\NUL\NUL\NUL\NUL\tvaddsubps\NUL\NUL\NUL\NUL\NUL\NUL\NUL\avaesdec\NUL\NUL\NUL\NUL\NUL\NUL\NUL\vvaesdeclast\NUL\NUL\NUL\NUL\NUL\NUL\NUL\avaesenc\NUL\NUL\NUL\NUL\NUL\NUL\NUL\vvaesenclast\NUL\NUL\NUL\NUL\NUL\NUL\NUL\avaesimc\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DLEvaeskeygenassist\NUL\NUL\NUL\NUL\NUL\NUL\NUL\avalignd\NUL\NUL\NUL\NUL\NUL\NUL\NUL\avalignq\NUL\NUL\NUL\NUL\NUL\NUL\NUL\avandnpd\NUL\NUL\NUL\NUL\NUL\NUL\NUL\avandnps\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKvandpd\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKvandps\NUL\NUL\NUL\NUL\NUL\NUL\NUL\tvblendmpd\NUL\NUL\NUL\NUL\NUL\NUL\NUL\tvblendmps\NUL\NUL\NUL\NUL\NUL\NUL\NUL\bvblendpd\NUL\NUL\NUL\NUL\NUL\NUL\NUL\bvblendps\NUL\NUL\NUL\NUL\NUL\NUL\NUL\tvblendvpd\NUL\NUL\NUL\NUL\NUL\NUL\NUL\tvblendvps\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOvbroadcastf128\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SIvbroadcastf32x4\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SIvbroadcastf64x4\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOvbroadcasti128\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SIvbroadcasti32x4\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SIvbroadcasti64x4\NUL\NUL\NUL\NUL\NUL\NUL\NUL\fvbroadcastsd\NUL\NUL\NUL\NUL\NUL\NUL\NUL\fvbroadcastss\NUL\NUL\NUL\NUL\NUL\NUL\NUL\vvcmpeq_ospd\NUL\NUL\NUL\NUL\NUL\NUL\NUL\vvcmpeq_osps\NUL\NUL\NUL\NUL\NUL\NUL\NUL\vvcmpeq_ossd\NUL\NUL\NUL\NUL\NUL\NUL\NUL\vvcmpeq_osss\NUL\NUL\NUL\NUL\NUL\NUL\NUL\vvcmpeq_uqpd\NUL\NUL\NUL\NUL\NUL\NUL\NUL\vvcmpeq_uqps\NUL\NUL\NUL\NUL\NUL\NUL\NUL\vvcmpeq_uqsd\NUL\NUL\NUL\NUL\NUL\NUL\NUL\vvcmpeq_uqss\NUL\NUL\NUL\NUL\NUL\NUL\NUL\vvcmpeq_uspd\NUL\NUL\NUL\NUL\NUL\NUL\NUL\vvcmpeq_usps\NUL\NUL\NUL\NUL\NUL\NUL\NUL\vvcmpeq_ussd\NUL\NUL\NUL\NUL\NUL\NUL\NUL\vvcmpeq_usss\NUL\NUL\NUL\NUL\NUL\NUL\NUL\bvcmpeqpd\NUL\NUL\NUL\NUL\NUL\NUL\NUL\bvcmpeqps\NUL\NUL\NUL\NUL\NUL\NUL\NUL\bvcmpeqsd\NUL\NUL\NUL\NUL\NUL\NUL\NUL\bvcmpeqss\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOvcmpfalse_oqpd\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOvcmpfalse_oqps\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOvcmpfalse_oqsd\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOvcmpfalse_oqss\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOvcmpfalse_ospd\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOvcmpfalse_osps\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOvcmpfalse_ossd\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOvcmpfalse_osss\NUL\NUL\NUL\NUL\NUL\NUL\NUL\vvcmpfalsepd\NUL\NUL\NUL\NUL\NUL\NUL\NUL\vvcmpfalseps\NUL\NUL\NUL\NUL\NUL\NUL\NUL\vvcmpfalsesd\NUL\NUL\NUL\NUL\NUL\NUL\NUL\vvcmpfalsess\NUL\NUL\NUL\NUL\NUL\NUL\NUL\vvcmpge_oqpd\NUL\NUL\NUL\NUL\NUL\NUL\NUL\vvcmpge_oqps\NUL\NUL\NUL\NUL\NUL\NUL\NUL\vvcmpge_oqsd\NUL\NUL\NUL\NUL\NUL\NUL\NUL\vvcmpge_oqss\NUL\NUL\NUL\NUL\NUL\NUL\NUL\vvcmpge_ospd\NUL\NUL\NUL\NUL\NUL\NUL\NUL\vvcmpge_osps\NUL\NUL\NUL\NUL\NUL\NUL\NUL\vvcmpge_ossd\NUL\NUL\NUL\NUL\NUL\NUL\NUL\vvcmpge_osss\NUL\NUL\NUL\NUL\NUL\NUL\NUL\bvcmpgepd\NUL\NUL\NUL\NUL\NUL\NUL\NUL\bvcmpgeps\NUL\NUL\NUL\NUL\NUL\NUL\NUL\bvcmpgesd\NUL\NUL\NUL\NUL\NUL\NUL\NUL\bvcmpgess\NUL\NUL\NUL\NUL\NUL\NUL\NUL\vvcmpgt_oqpd\NUL\NUL\NUL\NUL\NUL\NUL\NUL\vvcmpgt_oqps\NUL\NUL\NUL\NUL\NUL\NUL\NUL\vvcmpgt_oqsd\NUL\NUL\NUL\NUL\NUL\NUL\NUL\vvcmpgt_oqss\NUL\NUL\NUL\NUL\NUL\NUL\NUL\vvcmpgt_ospd\NUL\NUL\NUL\NUL\NUL\NUL\NUL\vvcmpgt_osps\NUL\NUL\NUL\NUL\NUL\NUL\NUL\vvcmpgt_ossd\NUL\NUL\NUL\NUL\NUL\NUL\NUL\vvcmpgt_osss\NUL\NUL\NUL\NUL\NUL\NUL\NUL\bvcmpgtpd\NUL\NUL\NUL\NUL\NUL\NUL\NUL\bvcmpgtps\NUL\NUL\NUL\NUL\NUL\NUL\NUL\bvcmpgtsd\NUL\NUL\NUL\NUL\NUL\NUL\NUL\bvcmpgtss\NUL\NUL\NUL\NUL\NUL\NUL\NUL\vvcmple_oqpd\NUL\NUL\NUL\NUL\NUL\NUL\NUL\vvcmple_oqps\NUL\NUL\NUL\NUL\NUL\NUL\NUL\vvcmple_oqsd\NUL\NUL\NUL\NUL\NUL\NUL\NUL\vvcmple_oqss\NUL\NUL\NUL\NUL\NUL\NUL\NUL\vvcmple_ospd\NUL\NUL\NUL\NUL\NUL\NUL\NUL\vvcmple_osps\NUL\NUL\NUL\NUL\NUL\NUL\NUL\vvcmple_ossd\NUL\NUL\NUL\NUL\NUL\NUL\NUL\vvcmple_osss\NUL\NUL\NUL\NUL\NUL\NUL\NUL\bvcmplepd\NUL\NUL\NUL\NUL\NUL\NUL\NUL\bvcmpleps\NUL\NUL\NUL\NUL\NUL\NUL\NUL\bvcmplesd\NUL\NUL\NUL\NUL\NUL\NUL\NUL\bvcmpless\NUL\NUL\NUL\NUL\NUL\NUL\NUL\vvcmplt_oqpd\NUL\NUL\NUL\NUL\NUL\NUL\NUL\vvcmplt_oqps\NUL\NUL\NUL\NUL\NUL\NUL\NUL\vvcmplt_oqsd\NUL\NUL\NUL\NUL\NUL\NUL\NUL\vvcmplt_oqss\NUL\NUL\NUL\NUL\NUL\NUL\NUL\vvcmplt_ospd\NUL\NUL\NUL\NUL\NUL\NUL\NUL\vvcmplt_osps\NUL\NUL\NUL\NUL\NUL\NUL\NUL\vvcmplt_ossd\NUL\NUL\NUL\NUL\NUL\NUL\NUL\vvcmplt_osss\NUL\NUL\NUL\NUL\NUL\NUL\NUL\bvcmpltpd\NUL\NUL\NUL\NUL\NUL\NUL\NUL\bvcmpltps\NUL\NUL\NUL\NUL\NUL\NUL\NUL\bvcmpltsd\NUL\NUL\NUL\NUL\NUL\NUL\NUL\bvcmpltss\NUL\NUL\NUL\NUL\NUL\NUL\NUL\fvcmpneq_oqpd\NUL\NUL\NUL\NUL\NUL\NUL\NUL\fvcmpneq_oqps\NUL\NUL\NUL\NUL\NUL\NUL\NUL\fvcmpneq_oqsd\NUL\NUL\NUL\NUL\NUL\NUL\NUL\fvcmpneq_oqss\NUL\NUL\NUL\NUL\NUL\NUL\NUL\fvcmpneq_ospd\NUL\NUL\NUL\NUL\NUL\NUL\NUL\fvcmpneq_osps\NUL\NUL\NUL\NUL\NUL\NUL\NUL\fvcmpneq_ossd\NUL\NUL\NUL\NUL\NUL\NUL\NUL\fvcmpneq_osss\NUL\NUL\NUL\NUL\NUL\NUL\NUL\fvcmpneq_uqpd\NUL\NUL\NUL\NUL\NUL\NUL\NUL\fvcmpneq_uqps\NUL\NUL\NUL\NUL\NUL\NUL\NUL\fvcmpneq_uqsd\NUL\NUL\NUL\NUL\NUL\NUL\NUL\fvcmpneq_uqss\NUL\NUL\NUL\NUL\NUL\NUL\NUL\fvcmpneq_uspd\NUL\NUL\NUL\NUL\NUL\NUL\NUL\fvcmpneq_usps\NUL\NUL\NUL\NUL\NUL\NUL\NUL\fvcmpneq_ussd\NUL\NUL\NUL\NUL\NUL\NUL\NUL\fvcmpneq_usss\NUL\NUL\NUL\NUL\NUL\NUL\NUL\tvcmpneqpd\NUL\NUL\NUL\NUL\NUL\NUL\NUL\tvcmpneqps\NUL\NUL\NUL\NUL\NUL\NUL\NUL\tvcmpneqsd\NUL\NUL\NUL\NUL\NUL\NUL\NUL\tvcmpneqss\NUL\NUL\NUL\NUL\NUL\NUL\NUL\fvcmpnge_uqpd\NUL\NUL\NUL\NUL\NUL\NUL\NUL\fvcmpnge_uqps\NUL\NUL\NUL\NUL\NUL\NUL\NUL\fvcmpnge_uqsd\NUL\NUL\NUL\NUL\NUL\NUL\NUL\fvcmpnge_uqss\NUL\NUL\NUL\NUL\NUL\NUL\NUL\fvcmpnge_uspd\NUL\NUL\NUL\NUL\NUL\NUL\NUL\fvcmpnge_usps\NUL\NUL\NUL\NUL\NUL\NUL\NUL\fvcmpnge_ussd\NUL\NUL\NUL\NUL\NUL\NUL\NUL\fvcmpnge_usss\NUL\NUL\NUL\NUL\NUL\NUL\NUL\tvcmpngepd\NUL\NUL\NUL\NUL\NUL\NUL\NUL\tvcmpngeps\NUL\NUL\NUL\NUL\NUL\NUL\NUL\tvcmpngesd\NUL\NUL\NUL\NUL\NUL\NUL\NUL\tvcmpngess\NUL\NUL\NUL\NUL\NUL\NUL\NUL\fvcmpngt_uqpd\NUL\NUL\NUL\NUL\NUL\NUL\NUL\fvcmpngt_uqps\NUL\NUL\NUL\NUL\NUL\NUL\NUL\fvcmpngt_uqsd\NUL\NUL\NUL\NUL\NUL\NUL\NUL\fvcmpngt_uqss\NUL\NUL\NUL\NUL\NUL\NUL\NUL\fvcmpngt_uspd\NUL\NUL\NUL\NUL\NUL\NUL\NUL\fvcmpngt_usps\NUL\NUL\NUL\NUL\NUL\NUL\NUL\fvcmpngt_ussd\NUL\NUL\NUL\NUL\NUL\NUL\NUL\fvcmpngt_usss\NUL\NUL\NUL\NUL\NUL\NUL\NUL\tvcmpngtpd\NUL\NUL\NUL\NUL\NUL\NUL\NUL\tvcmpngtps\NUL\NUL\NUL\NUL\NUL\NUL\NUL\tvcmpngtsd\NUL\NUL\NUL\NUL\NUL\NUL\NUL\tvcmpngtss\NUL\NUL\NUL\NUL\NUL\NUL\NUL\fvcmpnle_uqpd\NUL\NUL\NUL\NUL\NUL\NUL\NUL\fvcmpnle_uqps\NUL\NUL\NUL\NUL\NUL\NUL\NUL\fvcmpnle_uqsd\NUL\NUL\NUL\NUL\NUL\NUL\NUL\fvcmpnle_uqss\NUL\NUL\NUL\NUL\NUL\NUL\NUL\fvcmpnle_uspd\NUL\NUL\NUL\NUL\NUL\NUL\NUL\fvcmpnle_usps\NUL\NUL\NUL\NUL\NUL\NUL\NUL\fvcmpnle_ussd\NUL\NUL\NUL\NUL\NUL\NUL\NUL\fvcmpnle_usss\NUL\NUL\NUL\NUL\NUL\NUL\NUL\tvcmpnlepd\NUL\NUL\NUL\NUL\NUL\NUL\NUL\tvcmpnleps\NUL\NUL\NUL\NUL\NUL\NUL\NUL\tvcmpnlesd\NUL\NUL\NUL\NUL\NUL\NUL\NUL\tvcmpnless\NUL\NUL\NUL\NUL\NUL\NUL\NUL\fvcmpnlt_uqpd\NUL\NUL\NUL\NUL\NUL\NUL\NUL\fvcmpnlt_uqps\NUL\NUL\NUL\NUL\NUL\NUL\NUL\fvcmpnlt_uqsd\NUL\NUL\NUL\NUL\NUL\NUL\NUL\fvcmpnlt_uqss\NUL\NUL\NUL\NUL\NUL\NUL\NUL\fvcmpnlt_uspd\NUL\NUL\NUL\NUL\NUL\NUL\NUL\fvcmpnlt_usps\NUL\NUL\NUL\NUL\NUL\NUL\NUL\fvcmpnlt_ussd\NUL\NUL\NUL\NUL\NUL\NUL\NUL\fvcmpnlt_usss\NUL\NUL\NUL\NUL\NUL\NUL\NUL\tvcmpnltpd\NUL\NUL\NUL\NUL\NUL\NUL\NUL\tvcmpnltps\NUL\NUL\NUL\NUL\NUL\NUL\NUL\tvcmpnltsd\NUL\NUL\NUL\NUL\NUL\NUL\NUL\tvcmpnltss\NUL\NUL\NUL\NUL\NUL\NUL\NUL\vvcmpord_qpd\NUL\NUL\NUL\NUL\NUL\NUL\NUL\vvcmpord_qps\NUL\NUL\NUL\NUL\NUL\NUL\NUL\vvcmpord_qsd\NUL\NUL\NUL\NUL\NUL\NUL\NUL\vvcmpord_qss\NUL\NUL\NUL\NUL\NUL\NUL\NUL\vvcmpord_spd\NUL\NUL\NUL\NUL\NUL\NUL\NUL\vvcmpord_sps\NUL\NUL\NUL\NUL\NUL\NUL\NUL\vvcmpord_ssd\NUL\NUL\NUL\NUL\NUL\NUL\NUL\vvcmpord_sss\NUL\NUL\NUL\NUL\NUL\NUL\NUL\tvcmpordpd\NUL\NUL\NUL\NUL\NUL\NUL\NUL\tvcmpordps\NUL\NUL\NUL\NUL\NUL\NUL\NUL\tvcmpordsd\NUL\NUL\NUL\NUL\NUL\NUL\NUL\tvcmpordss\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKvcmppd\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKvcmpps\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKvcmpsd\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKvcmpss\NUL\NUL\NUL\NUL\NUL\NUL\NUL\rvcmptrue_uqpd\NUL\NUL\NUL\NUL\NUL\NUL\NUL\rvcmptrue_uqps\NUL\NUL\NUL\NUL\NUL\NUL\NUL\rvcmptrue_uqsd\NUL\NUL\NUL\NUL\NUL\NUL\NUL\rvcmptrue_uqss\NUL\NUL\NUL\NUL\NUL\NUL\NUL\rvcmptrue_uspd\NUL\NUL\NUL\NUL\NUL\NUL\NUL\rvcmptrue_usps\NUL\NUL\NUL\NUL\NUL\NUL\NUL\rvcmptrue_ussd\NUL\NUL\NUL\NUL\NUL\NUL\NUL\rvcmptrue_usss\NUL\NUL\NUL\NUL\NUL\NUL\NUL\nvcmptruepd\NUL\NUL\NUL\NUL\NUL\NUL\NUL\nvcmptrueps\NUL\NUL\NUL\NUL\NUL\NUL\NUL\nvcmptruesd\NUL\NUL\NUL\NUL\NUL\NUL\NUL\nvcmptruess\NUL\NUL\NUL\NUL\NUL\NUL\NUL\rvcmpunord_qpd\NUL\NUL\NUL\NUL\NUL\NUL\NUL\rvcmpunord_qps\NUL\NUL\NUL\NUL\NUL\NUL\NUL\rvcmpunord_qsd\NUL\NUL\NUL\NUL\NUL\NUL\NUL\rvcmpunord_qss\NUL\NUL\NUL\NUL\NUL\NUL\NUL\rvcmpunord_spd\NUL\NUL\NUL\NUL\NUL\NUL\NUL\rvcmpunord_sps\NUL\NUL\NUL\NUL\NUL\NUL\NUL\rvcmpunord_ssd\NUL\NUL\NUL\NUL\NUL\NUL\NUL\rvcmpunord_sss\NUL\NUL\NUL\NUL\NUL\NUL\NUL\vvcmpunordpd\NUL\NUL\NUL\NUL\NUL\NUL\NUL\vvcmpunordps\NUL\NUL\NUL\NUL\NUL\NUL\NUL\vvcmpunordsd\NUL\NUL\NUL\NUL\NUL\NUL\NUL\vvcmpunordss\NUL\NUL\NUL\NUL\NUL\NUL\NUL\avcomisd\NUL\NUL\NUL\NUL\NUL\NUL\NUL\avcomiss\NUL\NUL\NUL\NUL\NUL\NUL\NUL\vvcompresspd\NUL\NUL\NUL\NUL\NUL\NUL\NUL\vvcompressps\NUL\NUL\NUL\NUL\NUL\NUL\NUL\tvcvtdq2pd\NUL\NUL\NUL\NUL\NUL\NUL\NUL\tvcvtdq2ps\NUL\NUL\NUL\NUL\NUL\NUL\NUL\tvcvtpd2dq\NUL\NUL\NUL\NUL\NUL\NUL\NUL\tvcvtpd2ps\NUL\NUL\NUL\NUL\NUL\NUL\NUL\nvcvtpd2udq\NUL\NUL\NUL\NUL\NUL\NUL\NUL\tvcvtph2ps\NUL\NUL\NUL\NUL\NUL\NUL\NUL\tvcvtps2dq\NUL\NUL\NUL\NUL\NUL\NUL\NUL\tvcvtps2pd\NUL\NUL\NUL\NUL\NUL\NUL\NUL\tvcvtps2ph\NUL\NUL\NUL\NUL\NUL\NUL\NUL\nvcvtps2udq\NUL\NUL\NUL\NUL\NUL\NUL\NUL\tvcvtsd2si\NUL\NUL\NUL\NUL\NUL\NUL\NUL\tvcvtsd2ss\NUL\NUL\NUL\NUL\NUL\NUL\NUL\nvcvtsd2usi\NUL\NUL\NUL\NUL\NUL\NUL\NUL\tvcvtsi2sd\NUL\NUL\NUL\NUL\NUL\NUL\NUL\tvcvtsi2ss\NUL\NUL\NUL\NUL\NUL\NUL\NUL\tvcvtss2sd\NUL\NUL\NUL\NUL\NUL\NUL\NUL\tvcvtss2si\NUL\NUL\NUL\NUL\NUL\NUL\NUL\nvcvtss2usi\NUL\NUL\NUL\NUL\NUL\NUL\NUL\nvcvttpd2dq\NUL\NUL\NUL\NUL\NUL\NUL\NUL\vvcvttpd2udq\NUL\NUL\NUL\NUL\NUL\NUL\NUL\nvcvttps2dq\NUL\NUL\NUL\NUL\NUL\NUL\NUL\vvcvttps2udq\NUL\NUL\NUL\NUL\NUL\NUL\NUL\nvcvttsd2si\NUL\NUL\NUL\NUL\NUL\NUL\NUL\vvcvttsd2usi\NUL\NUL\NUL\NUL\NUL\NUL\NUL\nvcvttss2si\NUL\NUL\NUL\NUL\NUL\NUL\NUL\vvcvttss2usi\NUL\NUL\NUL\NUL\NUL\NUL\NUL\nvcvtudq2pd\NUL\NUL\NUL\NUL\NUL\NUL\NUL\nvcvtudq2ps\NUL\NUL\NUL\NUL\NUL\NUL\NUL\nvcvtusi2sd\NUL\NUL\NUL\NUL\NUL\NUL\NUL\nvcvtusi2ss\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKvdivpd\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKvdivps\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKvdivsd\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKvdivss\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQvdppd\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQvdpps\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTverr\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTverw\NUL\NUL\NUL\NUL\NUL\NUL\NUL\avexp2pd\NUL\NUL\NUL\NUL\NUL\NUL\NUL\avexp2ps\NUL\NUL\NUL\NUL\NUL\NUL\NUL\tvexpandpd\NUL\NUL\NUL\NUL\NUL\NUL\NUL\tvexpandps\NUL\NUL\NUL\NUL\NUL\NUL\NUL\fvextractf128\NUL\NUL\NUL\NUL\NUL\NUL\NUL\rvextractf32x4\NUL\NUL\NUL\NUL\NUL\NUL\NUL\rvextractf64x4\NUL\NUL\NUL\NUL\NUL\NUL\NUL\fvextracti128\NUL\NUL\NUL\NUL\NUL\NUL\NUL\rvextracti32x4\NUL\NUL\NUL\NUL\NUL\NUL\NUL\rvextracti64x4\NUL\NUL\NUL\NUL\NUL\NUL\NUL\nvextractps\NUL\NUL\NUL\NUL\NUL\NUL\NUL\vvfixupimmpd\NUL\NUL\NUL\NUL\NUL\NUL\NUL\vvfixupimmps\NUL\NUL\NUL\NUL\NUL\NUL\NUL\vvfixupimmsd\NUL\NUL\NUL\NUL\NUL\NUL\NUL\vvfixupimmss\NUL\NUL\NUL\NUL\NUL\NUL\NUL\vvfmadd123pd\NUL\NUL\NUL\NUL\NUL\NUL\NUL\vvfmadd123ps\NUL\NUL\NUL\NUL\NUL\NUL\NUL\vvfmadd123sd\NUL\NUL\NUL\NUL\NUL\NUL\NUL\vvfmadd123ss\NUL\NUL\NUL\NUL\NUL\NUL\NUL\vvfmadd132pd\NUL\NUL\NUL\NUL\NUL\NUL\NUL\vvfmadd132ps\NUL\NUL\NUL\NUL\NUL\NUL\NUL\vvfmadd132sd\NUL\NUL\NUL\NUL\NUL\NUL\NUL\vvfmadd132ss\NUL\NUL\NUL\NUL\NUL\NUL\NUL\vvfmadd213pd\NUL\NUL\NUL\NUL\NUL\NUL\NUL\vvfmadd213ps\NUL\NUL\NUL\NUL\NUL\NUL\NUL\vvfmadd213sd\NUL\NUL\NUL\NUL\NUL\NUL\NUL\vvfmadd213ss\NUL\NUL\NUL\NUL\NUL\NUL\NUL\vvfmadd231pd\NUL\NUL\NUL\NUL\NUL\NUL\NUL\vvfmadd231ps\NUL\NUL\NUL\NUL\NUL\NUL\NUL\vvfmadd231sd\NUL\NUL\NUL\NUL\NUL\NUL\NUL\vvfmadd231ss\NUL\NUL\NUL\NUL\NUL\NUL\NUL\vvfmadd312pd\NUL\NUL\NUL\NUL\NUL\NUL\NUL\vvfmadd312ps\NUL\NUL\NUL\NUL\NUL\NUL\NUL\vvfmadd312sd\NUL\NUL\NUL\NUL\NUL\NUL\NUL\vvfmadd312ss\NUL\NUL\NUL\NUL\NUL\NUL\NUL\vvfmadd321pd\NUL\NUL\NUL\NUL\NUL\NUL\NUL\vvfmadd321ps\NUL\NUL\NUL\NUL\NUL\NUL\NUL\vvfmadd321sd\NUL\NUL\NUL\NUL\NUL\NUL\NUL\vvfmadd321ss\NUL\NUL\NUL\NUL\NUL\NUL\NUL\bvfmaddpd\NUL\NUL\NUL\NUL\NUL\NUL\NUL\bvfmaddps\NUL\NUL\NUL\NUL\NUL\NUL\NUL\bvfmaddsd\NUL\NUL\NUL\NUL\NUL\NUL\NUL\bvfmaddss\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOvfmaddsub123pd\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOvfmaddsub123ps\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOvfmaddsub132pd\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOvfmaddsub132ps\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOvfmaddsub213pd\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOvfmaddsub213ps\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOvfmaddsub231pd\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOvfmaddsub231ps\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOvfmaddsub312pd\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOvfmaddsub312ps\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOvfmaddsub321pd\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOvfmaddsub321ps\NUL\NUL\NUL\NUL\NUL\NUL\NUL\vvfmaddsubpd\NUL\NUL\NUL\NUL\NUL\NUL\NUL\vvfmaddsubps\NUL\NUL\NUL\NUL\NUL\NUL\NUL\vvfmsub123pd\NUL\NUL\NUL\NUL\NUL\NUL\NUL\vvfmsub123ps\NUL\NUL\NUL\NUL\NUL\NUL\NUL\vvfmsub123sd\NUL\NUL\NUL\NUL\NUL\NUL\NUL\vvfmsub123ss\NUL\NUL\NUL\NUL\NUL\NUL\NUL\vvfmsub132pd\NUL\NUL\NUL\NUL\NUL\NUL\NUL\vvfmsub132ps\NUL\NUL\NUL\NUL\NUL\NUL\NUL\vvfmsub132sd\NUL\NUL\NUL\NUL\NUL\NUL\NUL\vvfmsub132ss\NUL\NUL\NUL\NUL\NUL\NUL\NUL\vvfmsub213pd\NUL\NUL\NUL\NUL\NUL\NUL\NUL\vvfmsub213ps\NUL\NUL\NUL\NUL\NUL\NUL\NUL\vvfmsub213sd\NUL\NUL\NUL\NUL\NUL\NUL\NUL\vvfmsub213ss\NUL\NUL\NUL\NUL\NUL\NUL\NUL\vvfmsub231pd\NUL\NUL\NUL\NUL\NUL\NUL\NUL\vvfmsub231ps\NUL\NUL\NUL\NUL\NUL\NUL\NUL\vvfmsub231sd\NUL\NUL\NUL\NUL\NUL\NUL\NUL\vvfmsub231ss\NUL\NUL\NUL\NUL\NUL\NUL\NUL\vvfmsub312pd\NUL\NUL\NUL\NUL\NUL\NUL\NUL\vvfmsub312ps\NUL\NUL\NUL\NUL\NUL\NUL\NUL\vvfmsub312sd\NUL\NUL\NUL\NUL\NUL\NUL\NUL\vvfmsub312ss\NUL\NUL\NUL\NUL\NUL\NUL\NUL\vvfmsub321pd\NUL\NUL\NUL\NUL\NUL\NUL\NUL\vvfmsub321ps\NUL\NUL\NUL\NUL\NUL\NUL\NUL\vvfmsub321sd\NUL\NUL\NUL\NUL\NUL\NUL\NUL\vvfmsub321ss\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOvfmsubadd123pd\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOvfmsubadd123ps\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOvfmsubadd132pd\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOvfmsubadd132ps\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOvfmsubadd213pd\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOvfmsubadd213ps\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOvfmsubadd231pd\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOvfmsubadd231ps\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOvfmsubadd312pd\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOvfmsubadd312ps\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOvfmsubadd321pd\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOvfmsubadd321ps\NUL\NUL\NUL\NUL\NUL\NUL\NUL\vvfmsubaddpd\NUL\NUL\NUL\NUL\NUL\NUL\NUL\vvfmsubaddps\NUL\NUL\NUL\NUL\NUL\NUL\NUL\bvfmsubpd\NUL\NUL\NUL\NUL\NUL\NUL\NUL\bvfmsubps\NUL\NUL\NUL\NUL\NUL\NUL\NUL\bvfmsubsd\NUL\NUL\NUL\NUL\NUL\NUL\NUL\bvfmsubss\NUL\NUL\NUL\NUL\NUL\NUL\NUL\fvfnmadd123pd\NUL\NUL\NUL\NUL\NUL\NUL\NUL\fvfnmadd123ps\NUL\NUL\NUL\NUL\NUL\NUL\NUL\fvfnmadd123sd\NUL\NUL\NUL\NUL\NUL\NUL\NUL\fvfnmadd123ss\NUL\NUL\NUL\NUL\NUL\NUL\NUL\fvfnmadd132pd\NUL\NUL\NUL\NUL\NUL\NUL\NUL\fvfnmadd132ps\NUL\NUL\NUL\NUL\NUL\NUL\NUL\fvfnmadd132sd\NUL\NUL\NUL\NUL\NUL\NUL\NUL\fvfnmadd132ss\NUL\NUL\NUL\NUL\NUL\NUL\NUL\fvfnmadd213pd\NUL\NUL\NUL\NUL\NUL\NUL\NUL\fvfnmadd213ps\NUL\NUL\NUL\NUL\NUL\NUL\NUL\fvfnmadd213sd\NUL\NUL\NUL\NUL\NUL\NUL\NUL\fvfnmadd213ss\NUL\NUL\NUL\NUL\NUL\NUL\NUL\fvfnmadd231pd\NUL\NUL\NUL\NUL\NUL\NUL\NUL\fvfnmadd231ps\NUL\NUL\NUL\NUL\NUL\NUL\NUL\fvfnmadd231sd\NUL\NUL\NUL\NUL\NUL\NUL\NUL\fvfnmadd231ss\NUL\NUL\NUL\NUL\NUL\NUL\NUL\fvfnmadd312pd\NUL\NUL\NUL\NUL\NUL\NUL\NUL\fvfnmadd312ps\NUL\NUL\NUL\NUL\NUL\NUL\NUL\fvfnmadd312sd\NUL\NUL\NUL\NUL\NUL\NUL\NUL\fvfnmadd312ss\NUL\NUL\NUL\NUL\NUL\NUL\NUL\fvfnmadd321pd\NUL\NUL\NUL\NUL\NUL\NUL\NUL\fvfnmadd321ps\NUL\NUL\NUL\NUL\NUL\NUL\NUL\fvfnmadd321sd\NUL\NUL\NUL\NUL\NUL\NUL\NUL\fvfnmadd321ss\NUL\NUL\NUL\NUL\NUL\NUL\NUL\tvfnmaddpd\NUL\NUL\NUL\NUL\NUL\NUL\NUL\tvfnmaddps\NUL\NUL\NUL\NUL\NUL\NUL\NUL\tvfnmaddsd\NUL\NUL\NUL\NUL\NUL\NUL\NUL\tvfnmaddss\NUL\NUL\NUL\NUL\NUL\NUL\NUL\fvfnmsub123pd\NUL\NUL\NUL\NUL\NUL\NUL\NUL\fvfnmsub123ps\NUL\NUL\NUL\NUL\NUL\NUL\NUL\fvfnmsub123sd\NUL\NUL\NUL\NUL\NUL\NUL\NUL\fvfnmsub123ss\NUL\NUL\NUL\NUL\NUL\NUL\NUL\fvfnmsub132pd\NUL\NUL\NUL\NUL\NUL\NUL\NUL\fvfnmsub132ps\NUL\NUL\NUL\NUL\NUL\NUL\NUL\fvfnmsub132sd\NUL\NUL\NUL\NUL\NUL\NUL\NUL\fvfnmsub132ss\NUL\NUL\NUL\NUL\NUL\NUL\NUL\fvfnmsub213pd\NUL\NUL\NUL\NUL\NUL\NUL\NUL\fvfnmsub213ps\NUL\NUL\NUL\NUL\NUL\NUL\NUL\fvfnmsub213sd\NUL\NUL\NUL\NUL\NUL\NUL\NUL\fvfnmsub213ss\NUL\NUL\NUL\NUL\NUL\NUL\NUL\fvfnmsub231pd\NUL\NUL\NUL\NUL\NUL\NUL\NUL\fvfnmsub231ps\NUL\NUL\NUL\NUL\NUL\NUL\NUL\fvfnmsub231sd\NUL\NUL\NUL\NUL\NUL\NUL\NUL\fvfnmsub231ss\NUL\NUL\NUL\NUL\NUL\NUL\NUL\fvfnmsub312pd\NUL\NUL\NUL\NUL\NUL\NUL\NUL\fvfnmsub312ps\NUL\NUL\NUL\NUL\NUL\NUL\NUL\fvfnmsub312sd\NUL\NUL\NUL\NUL\NUL\NUL\NUL\fvfnmsub312ss\NUL\NUL\NUL\NUL\NUL\NUL\NUL\fvfnmsub321pd\NUL\NUL\NUL\NUL\NUL\NUL\NUL\fvfnmsub321ps\NUL\NUL\NUL\NUL\NUL\NUL\NUL\fvfnmsub321sd\NUL\NUL\NUL\NUL\NUL\NUL\NUL\fvfnmsub321ss\NUL\NUL\NUL\NUL\NUL\NUL\NUL\tvfnmsubpd\NUL\NUL\NUL\NUL\NUL\NUL\NUL\tvfnmsubps\NUL\NUL\NUL\NUL\NUL\NUL\NUL\tvfnmsubsd\NUL\NUL\NUL\NUL\NUL\NUL\NUL\tvfnmsubss\NUL\NUL\NUL\NUL\NUL\NUL\NUL\avfrczpd\NUL\NUL\NUL\NUL\NUL\NUL\NUL\avfrczps\NUL\NUL\NUL\NUL\NUL\NUL\NUL\avfrczsd\NUL\NUL\NUL\NUL\NUL\NUL\NUL\avfrczss\NUL\NUL\NUL\NUL\NUL\NUL\NUL\nvgatherdpd\NUL\NUL\NUL\NUL\NUL\NUL\NUL\nvgatherdps\NUL\NUL\NUL\NUL\NUL\NUL\NUL\rvgatherpf0dpd\NUL\NUL\NUL\NUL\NUL\NUL\NUL\rvgatherpf0dps\NUL\NUL\NUL\NUL\NUL\NUL\NUL\rvgatherpf0qpd\NUL\NUL\NUL\NUL\NUL\NUL\NUL\rvgatherpf0qps\NUL\NUL\NUL\NUL\NUL\NUL\NUL\rvgatherpf1dpd\NUL\NUL\NUL\NUL\NUL\NUL\NUL\rvgatherpf1dps\NUL\NUL\NUL\NUL\NUL\NUL\NUL\rvgatherpf1qpd\NUL\NUL\NUL\NUL\NUL\NUL\NUL\rvgatherpf1qps\NUL\NUL\NUL\NUL\NUL\NUL\NUL\nvgatherqpd\NUL\NUL\NUL\NUL\NUL\NUL\NUL\nvgatherqps\NUL\NUL\NUL\NUL\NUL\NUL\NUL\tvgetexppd\NUL\NUL\NUL\NUL\NUL\NUL\NUL\tvgetexpps\NUL\NUL\NUL\NUL\NUL\NUL\NUL\tvgetexpsd\NUL\NUL\NUL\NUL\NUL\NUL\NUL\tvgetexpss\NUL\NUL\NUL\NUL\NUL\NUL\NUL\nvgetmantpd\NUL\NUL\NUL\NUL\NUL\NUL\NUL\nvgetmantps\NUL\NUL\NUL\NUL\NUL\NUL\NUL\nvgetmantsd\NUL\NUL\NUL\NUL\NUL\NUL\NUL\nvgetmantss\NUL\NUL\NUL\NUL\NUL\NUL\NUL\avhaddpd\NUL\NUL\NUL\NUL\NUL\NUL\NUL\avhaddps\NUL\NUL\NUL\NUL\NUL\NUL\NUL\avhsubpd\NUL\NUL\NUL\NUL\NUL\NUL\NUL\avhsubps\NUL\NUL\NUL\NUL\NUL\NUL\NUL\vvinsertf128\NUL\NUL\NUL\NUL\NUL\NUL\NUL\fvinsertf32x4\NUL\NUL\NUL\NUL\NUL\NUL\NUL\fvinsertf64x4\NUL\NUL\NUL\NUL\NUL\NUL\NUL\vvinserti128\NUL\NUL\NUL\NUL\NUL\NUL\NUL\fvinserti32x4\NUL\NUL\NUL\NUL\NUL\NUL\NUL\fvinserti64x4\NUL\NUL\NUL\NUL\NUL\NUL\NUL\tvinsertps\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKvlddqu\NUL\NUL\NUL\NUL\NUL\NUL\NUL\bvldmxcsr\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKvldqqu\NUL\NUL\NUL\NUL\NUL\NUL\NUL\vvmaskmovdqu\NUL\NUL\NUL\NUL\NUL\NUL\NUL\nvmaskmovpd\NUL\NUL\NUL\NUL\NUL\NUL\NUL\nvmaskmovps\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKvmaxpd\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKvmaxps\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKvmaxsd\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKvmaxss\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKvmcall\NUL\NUL\NUL\NUL\NUL\NUL\NUL\avmclear\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKvmfunc\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKvminpd\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKvminps\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKvminsd\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKvminss\NUL\NUL\NUL\NUL\NUL\NUL\NUL\bvmlaunch\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKvmload\NUL\NUL\NUL\NUL\NUL\NUL\NUL\avmmcall\NUL\NUL\NUL\NUL\NUL\NUL\NUL\avmovapd\NUL\NUL\NUL\NUL\NUL\NUL\NUL\avmovaps\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQvmovd\NUL\NUL\NUL\NUL\NUL\NUL\NUL\bvmovddup\NUL\NUL\NUL\NUL\NUL\NUL\NUL\avmovdqa\NUL\NUL\NUL\NUL\NUL\NUL\NUL\tvmovdqa32\NUL\NUL\NUL\NUL\NUL\NUL\NUL\tvmovdqa64\NUL\NUL\NUL\NUL\NUL\NUL\NUL\avmovdqu\NUL\NUL\NUL\NUL\NUL\NUL\NUL\tvmovdqu32\NUL\NUL\NUL\NUL\NUL\NUL\NUL\tvmovdqu64\NUL\NUL\NUL\NUL\NUL\NUL\NUL\bvmovhlps\NUL\NUL\NUL\NUL\NUL\NUL\NUL\avmovhpd\NUL\NUL\NUL\NUL\NUL\NUL\NUL\avmovhps\NUL\NUL\NUL\NUL\NUL\NUL\NUL\bvmovlhps\NUL\NUL\NUL\NUL\NUL\NUL\NUL\avmovlpd\NUL\NUL\NUL\NUL\NUL\NUL\NUL\avmovlps\NUL\NUL\NUL\NUL\NUL\NUL\NUL\tvmovmskpd\NUL\NUL\NUL\NUL\NUL\NUL\NUL\tvmovmskps\NUL\NUL\NUL\NUL\NUL\NUL\NUL\bvmovntdq\NUL\NUL\NUL\NUL\NUL\NUL\NUL\tvmovntdqa\NUL\NUL\NUL\NUL\NUL\NUL\NUL\bvmovntpd\NUL\NUL\NUL\NUL\NUL\NUL\NUL\bvmovntps\NUL\NUL\NUL\NUL\NUL\NUL\NUL\bvmovntqq\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQvmovq\NUL\NUL\NUL\NUL\NUL\NUL\NUL\avmovqqa\NUL\NUL\NUL\NUL\NUL\NUL\NUL\avmovqqu\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKvmovsd\NUL\NUL\NUL\NUL\NUL\NUL\NUL\tvmovshdup\NUL\NUL\NUL\NUL\NUL\NUL\NUL\tvmovsldup\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKvmovss\NUL\NUL\NUL\NUL\NUL\NUL\NUL\avmovupd\NUL\NUL\NUL\NUL\NUL\NUL\NUL\avmovups\NUL\NUL\NUL\NUL\NUL\NUL\NUL\bvmpsadbw\NUL\NUL\NUL\NUL\NUL\NUL\NUL\avmptrld\NUL\NUL\NUL\NUL\NUL\NUL\NUL\avmptrst\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKvmread\NUL\NUL\NUL\NUL\NUL\NUL\NUL\bvmresume\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQvmrun\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKvmsave\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKvmulpd\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKvmulps\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKvmulsd\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKvmulss\NUL\NUL\NUL\NUL\NUL\NUL\NUL\avmwrite\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKvmxoff\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQvmxon\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQvorpd\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQvorps\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKvpabsb\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKvpabsd\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKvpabsq\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKvpabsw\NUL\NUL\NUL\NUL\NUL\NUL\NUL\tvpackssdw\NUL\NUL\NUL\NUL\NUL\NUL\NUL\tvpacksswb\NUL\NUL\NUL\NUL\NUL\NUL\NUL\tvpackusdw\NUL\NUL\NUL\NUL\NUL\NUL\NUL\tvpackuswb\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKvpaddb\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKvpaddd\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKvpaddq\NUL\NUL\NUL\NUL\NUL\NUL\NUL\avpaddsb\NUL\NUL\NUL\NUL\NUL\NUL\NUL\avpaddsw\NUL\NUL\NUL\NUL\NUL\NUL\NUL\bvpaddusb\NUL\NUL\NUL\NUL\NUL\NUL\NUL\bvpaddusw\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKvpaddw\NUL\NUL\NUL\NUL\NUL\NUL\NUL\bvpalignr\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQvpand\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKvpandd\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKvpandn\NUL\NUL\NUL\NUL\NUL\NUL\NUL\avpandnd\NUL\NUL\NUL\NUL\NUL\NUL\NUL\avpandnq\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKvpandq\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKvpavgb\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKvpavgw\NUL\NUL\NUL\NUL\NUL\NUL\NUL\bvpblendd\NUL\NUL\NUL\NUL\NUL\NUL\NUL\tvpblendmd\NUL\NUL\NUL\NUL\NUL\NUL\NUL\tvpblendmq\NUL\NUL\NUL\NUL\NUL\NUL\NUL\tvpblendvb\NUL\NUL\NUL\NUL\NUL\NUL\NUL\bvpblendw\NUL\NUL\NUL\NUL\NUL\NUL\NUL\fvpbroadcastb\NUL\NUL\NUL\NUL\NUL\NUL\NUL\fvpbroadcastd\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SIvpbroadcastmb2q\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SIvpbroadcastmw2d\NUL\NUL\NUL\NUL\NUL\NUL\NUL\fvpbroadcastq\NUL\NUL\NUL\NUL\NUL\NUL\NUL\fvpbroadcastw\NUL\NUL\NUL\NUL\NUL\NUL\NUL\rvpclmulhqhqdq\NUL\NUL\NUL\NUL\NUL\NUL\NUL\rvpclmulhqlqdq\NUL\NUL\NUL\NUL\NUL\NUL\NUL\rvpclmullqhqdq\NUL\NUL\NUL\NUL\NUL\NUL\NUL\rvpclmullqlqdq\NUL\NUL\NUL\NUL\NUL\NUL\NUL\nvpclmulqdq\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKvpcmov\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKvpcmpd\NUL\NUL\NUL\NUL\NUL\NUL\NUL\bvpcmpeqb\NUL\NUL\NUL\NUL\NUL\NUL\NUL\bvpcmpeqd\NUL\NUL\NUL\NUL\NUL\NUL\NUL\bvpcmpeqq\NUL\NUL\NUL\NUL\NUL\NUL\NUL\tvpcmpequd\NUL\NUL\NUL\NUL\NUL\NUL\NUL\tvpcmpequq\NUL\NUL\NUL\NUL\NUL\NUL\NUL\bvpcmpeqw\NUL\NUL\NUL\NUL\NUL\NUL\NUL\nvpcmpestri\NUL\NUL\NUL\NUL\NUL\NUL\NUL\nvpcmpestrm\NUL\NUL\NUL\NUL\NUL\NUL\NUL\bvpcmpgtb\NUL\NUL\NUL\NUL\NUL\NUL\NUL\bvpcmpgtd\NUL\NUL\NUL\NUL\NUL\NUL\NUL\bvpcmpgtq\NUL\NUL\NUL\NUL\NUL\NUL\NUL\bvpcmpgtw\NUL\NUL\NUL\NUL\NUL\NUL\NUL\nvpcmpistri\NUL\NUL\NUL\NUL\NUL\NUL\NUL\nvpcmpistrm\NUL\NUL\NUL\NUL\NUL\NUL\NUL\bvpcmpled\NUL\NUL\NUL\NUL\NUL\NUL\NUL\bvpcmpleq\NUL\NUL\NUL\NUL\NUL\NUL\NUL\tvpcmpleud\NUL\NUL\NUL\NUL\NUL\NUL\NUL\tvpcmpleuq\NUL\NUL\NUL\NUL\NUL\NUL\NUL\bvpcmpltd\NUL\NUL\NUL\NUL\NUL\NUL\NUL\bvpcmpltq\NUL\NUL\NUL\NUL\NUL\NUL\NUL\tvpcmpltud\NUL\NUL\NUL\NUL\NUL\NUL\NUL\tvpcmpltuq\NUL\NUL\NUL\NUL\NUL\NUL\NUL\tvpcmpneqd\NUL\NUL\NUL\NUL\NUL\NUL\NUL\tvpcmpneqq\NUL\NUL\NUL\NUL\NUL\NUL\NUL\nvpcmpnequd\NUL\NUL\NUL\NUL\NUL\NUL\NUL\nvpcmpnequq\NUL\NUL\NUL\NUL\NUL\NUL\NUL\tvpcmpnled\NUL\NUL\NUL\NUL\NUL\NUL\NUL\tvpcmpnleq\NUL\NUL\NUL\NUL\NUL\NUL\NUL\nvpcmpnleud\NUL\NUL\NUL\NUL\NUL\NUL\NUL\nvpcmpnleuq\NUL\NUL\NUL\NUL\NUL\NUL\NUL\tvpcmpnltd\NUL\NUL\NUL\NUL\NUL\NUL\NUL\tvpcmpnltq\NUL\NUL\NUL\NUL\NUL\NUL\NUL\nvpcmpnltud\NUL\NUL\NUL\NUL\NUL\NUL\NUL\nvpcmpnltuq\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKvpcmpq\NUL\NUL\NUL\NUL\NUL\NUL\NUL\avpcmpud\NUL\NUL\NUL\NUL\NUL\NUL\NUL\avpcmpuq\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKvpcomb\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKvpcomd\NUL\NUL\NUL\NUL\NUL\NUL\NUL\vvpcompressd\NUL\NUL\NUL\NUL\NUL\NUL\NUL\vvpcompressq\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKvpcomq\NUL\NUL\NUL\NUL\NUL\NUL\NUL\avpcomub\NUL\NUL\NUL\NUL\NUL\NUL\NUL\avpcomud\NUL\NUL\NUL\NUL\NUL\NUL\NUL\avpcomuq\NUL\NUL\NUL\NUL\NUL\NUL\NUL\avpcomuw\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKvpcomw\NUL\NUL\NUL\NUL\NUL\NUL\NUL\vvpconflictd\NUL\NUL\NUL\NUL\NUL\NUL\NUL\vvpconflictq\NUL\NUL\NUL\NUL\NUL\NUL\NUL\nvperm2f128\NUL\NUL\NUL\NUL\NUL\NUL\NUL\nvperm2i128\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKvpermd\NUL\NUL\NUL\NUL\NUL\NUL\NUL\bvpermi2d\NUL\NUL\NUL\NUL\NUL\NUL\NUL\tvpermi2pd\NUL\NUL\NUL\NUL\NUL\NUL\NUL\tvpermi2ps\NUL\NUL\NUL\NUL\NUL\NUL\NUL\bvpermi2q\NUL\NUL\NUL\NUL\NUL\NUL\NUL\tvpermilpd\NUL\NUL\NUL\NUL\NUL\NUL\NUL\tvpermilps\NUL\NUL\NUL\NUL\NUL\NUL\NUL\avpermpd\NUL\NUL\NUL\NUL\NUL\NUL\NUL\avpermps\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKvpermq\NUL\NUL\NUL\NUL\NUL\NUL\NUL\bvpermt2d\NUL\NUL\NUL\NUL\NUL\NUL\NUL\tvpermt2pd\NUL\NUL\NUL\NUL\NUL\NUL\NUL\tvpermt2ps\NUL\NUL\NUL\NUL\NUL\NUL\NUL\bvpermt2q\NUL\NUL\NUL\NUL\NUL\NUL\NUL\tvpexpandd\NUL\NUL\NUL\NUL\NUL\NUL\NUL\tvpexpandq\NUL\NUL\NUL\NUL\NUL\NUL\NUL\avpextrb\NUL\NUL\NUL\NUL\NUL\NUL\NUL\avpextrd\NUL\NUL\NUL\NUL\NUL\NUL\NUL\avpextrq\NUL\NUL\NUL\NUL\NUL\NUL\NUL\avpextrw\NUL\NUL\NUL\NUL\NUL\NUL\NUL\nvpgatherdd\NUL\NUL\NUL\NUL\NUL\NUL\NUL\nvpgatherdq\NUL\NUL\NUL\NUL\NUL\NUL\NUL\nvpgatherqd\NUL\NUL\NUL\NUL\NUL\NUL\NUL\nvpgatherqq\NUL\NUL\NUL\NUL\NUL\NUL\NUL\bvphaddbd\NUL\NUL\NUL\NUL\NUL\NUL\NUL\bvphaddbq\NUL\NUL\NUL\NUL\NUL\NUL\NUL\bvphaddbw\NUL\NUL\NUL\NUL\NUL\NUL\NUL\avphaddd\NUL\NUL\NUL\NUL\NUL\NUL\NUL\bvphadddq\NUL\NUL\NUL\NUL\NUL\NUL\NUL\bvphaddsw\NUL\NUL\NUL\NUL\NUL\NUL\NUL\tvphaddubd\NUL\NUL\NUL\NUL\NUL\NUL\NUL\tvphaddubq\NUL\NUL\NUL\NUL\NUL\NUL\NUL\tvphaddubw\NUL\NUL\NUL\NUL\NUL\NUL\NUL\tvphaddudq\NUL\NUL\NUL\NUL\NUL\NUL\NUL\tvphadduwd\NUL\NUL\NUL\NUL\NUL\NUL\NUL\tvphadduwq\NUL\NUL\NUL\NUL\NUL\NUL\NUL\avphaddw\NUL\NUL\NUL\NUL\NUL\NUL\NUL\bvphaddwd\NUL\NUL\NUL\NUL\NUL\NUL\NUL\bvphaddwq\NUL\NUL\NUL\NUL\NUL\NUL\NUL\vvphminposuw\NUL\NUL\NUL\NUL\NUL\NUL\NUL\bvphsubbw\NUL\NUL\NUL\NUL\NUL\NUL\NUL\avphsubd\NUL\NUL\NUL\NUL\NUL\NUL\NUL\bvphsubdq\NUL\NUL\NUL\NUL\NUL\NUL\NUL\bvphsubsw\NUL\NUL\NUL\NUL\NUL\NUL\NUL\avphsubw\NUL\NUL\NUL\NUL\NUL\NUL\NUL\bvphsubwd\NUL\NUL\NUL\NUL\NUL\NUL\NUL\avpinsrb\NUL\NUL\NUL\NUL\NUL\NUL\NUL\avpinsrd\NUL\NUL\NUL\NUL\NUL\NUL\NUL\avpinsrq\NUL\NUL\NUL\NUL\NUL\NUL\NUL\avpinsrw\NUL\NUL\NUL\NUL\NUL\NUL\NUL\bvplzcntd\NUL\NUL\NUL\NUL\NUL\NUL\NUL\bvplzcntq\NUL\NUL\NUL\NUL\NUL\NUL\NUL\bvpmacsdd\NUL\NUL\NUL\NUL\NUL\NUL\NUL\tvpmacsdqh\NUL\NUL\NUL\NUL\NUL\NUL\NUL\tvpmacsdql\NUL\NUL\NUL\NUL\NUL\NUL\NUL\tvpmacssdd\NUL\NUL\NUL\NUL\NUL\NUL\NUL\nvpmacssdqh\NUL\NUL\NUL\NUL\NUL\NUL\NUL\nvpmacssdql\NUL\NUL\NUL\NUL\NUL\NUL\NUL\tvpmacsswd\NUL\NUL\NUL\NUL\NUL\NUL\NUL\tvpmacssww\NUL\NUL\NUL\NUL\NUL\NUL\NUL\bvpmacswd\NUL\NUL\NUL\NUL\NUL\NUL\NUL\bvpmacsww\NUL\NUL\NUL\NUL\NUL\NUL\NUL\nvpmadcsswd\NUL\NUL\NUL\NUL\NUL\NUL\NUL\tvpmadcswd\NUL\NUL\NUL\NUL\NUL\NUL\NUL\nvpmaddubsw\NUL\NUL\NUL\NUL\NUL\NUL\NUL\bvpmaddwd\NUL\NUL\NUL\NUL\NUL\NUL\NUL\nvpmaskmovd\NUL\NUL\NUL\NUL\NUL\NUL\NUL\nvpmaskmovq\NUL\NUL\NUL\NUL\NUL\NUL\NUL\avpmaxsb\NUL\NUL\NUL\NUL\NUL\NUL\NUL\avpmaxsd\NUL\NUL\NUL\NUL\NUL\NUL\NUL\avpmaxsq\NUL\NUL\NUL\NUL\NUL\NUL\NUL\avpmaxsw\NUL\NUL\NUL\NUL\NUL\NUL\NUL\avpmaxub\NUL\NUL\NUL\NUL\NUL\NUL\NUL\avpmaxud\NUL\NUL\NUL\NUL\NUL\NUL\NUL\avpmaxuq\NUL\NUL\NUL\NUL\NUL\NUL\NUL\avpmaxuw\NUL\NUL\NUL\NUL\NUL\NUL\NUL\avpminsb\NUL\NUL\NUL\NUL\NUL\NUL\NUL\avpminsd\NUL\NUL\NUL\NUL\NUL\NUL\NUL\avpminsq\NUL\NUL\NUL\NUL\NUL\NUL\NUL\avpminsw\NUL\NUL\NUL\NUL\NUL\NUL\NUL\avpminub\NUL\NUL\NUL\NUL\NUL\NUL\NUL\avpminud\NUL\NUL\NUL\NUL\NUL\NUL\NUL\avpminuq\NUL\NUL\NUL\NUL\NUL\NUL\NUL\avpminuw\NUL\NUL\NUL\NUL\NUL\NUL\NUL\avpmovdb\NUL\NUL\NUL\NUL\NUL\NUL\NUL\avpmovdw\NUL\NUL\NUL\NUL\NUL\NUL\NUL\tvpmovmskb\NUL\NUL\NUL\NUL\NUL\NUL\NUL\avpmovqb\NUL\NUL\NUL\NUL\NUL\NUL\NUL\avpmovqd\NUL\NUL\NUL\NUL\NUL\NUL\NUL\avpmovqw\NUL\NUL\NUL\NUL\NUL\NUL\NUL\bvpmovsdb\NUL\NUL\NUL\NUL\NUL\NUL\NUL\bvpmovsdw\NUL\NUL\NUL\NUL\NUL\NUL\NUL\bvpmovsqb\NUL\NUL\NUL\NUL\NUL\NUL\NUL\bvpmovsqd\NUL\NUL\NUL\NUL\NUL\NUL\NUL\bvpmovsqw\NUL\NUL\NUL\NUL\NUL\NUL\NUL\tvpmovsxbd\NUL\NUL\NUL\NUL\NUL\NUL\NUL\tvpmovsxbq\NUL\NUL\NUL\NUL\NUL\NUL\NUL\tvpmovsxbw\NUL\NUL\NUL\NUL\NUL\NUL\NUL\tvpmovsxdq\NUL\NUL\NUL\NUL\NUL\NUL\NUL\tvpmovsxwd\NUL\NUL\NUL\NUL\NUL\NUL\NUL\tvpmovsxwq\NUL\NUL\NUL\NUL\NUL\NUL\NUL\tvpmovusdb\NUL\NUL\NUL\NUL\NUL\NUL\NUL\tvpmovusdw\NUL\NUL\NUL\NUL\NUL\NUL\NUL\tvpmovusqb\NUL\NUL\NUL\NUL\NUL\NUL\NUL\tvpmovusqd\NUL\NUL\NUL\NUL\NUL\NUL\NUL\tvpmovusqw\NUL\NUL\NUL\NUL\NUL\NUL\NUL\tvpmovzxbd\NUL\NUL\NUL\NUL\NUL\NUL\NUL\tvpmovzxbq\NUL\NUL\NUL\NUL\NUL\NUL\NUL\tvpmovzxbw\NUL\NUL\NUL\NUL\NUL\NUL\NUL\tvpmovzxdq\NUL\NUL\NUL\NUL\NUL\NUL\NUL\tvpmovzxwd\NUL\NUL\NUL\NUL\NUL\NUL\NUL\tvpmovzxwq\NUL\NUL\NUL\NUL\NUL\NUL\NUL\avpmuldq\NUL\NUL\NUL\NUL\NUL\NUL\NUL\tvpmulhrsw\NUL\NUL\NUL\NUL\NUL\NUL\NUL\bvpmulhuw\NUL\NUL\NUL\NUL\NUL\NUL\NUL\avpmulhw\NUL\NUL\NUL\NUL\NUL\NUL\NUL\avpmulld\NUL\NUL\NUL\NUL\NUL\NUL\NUL\avpmullw\NUL\NUL\NUL\NUL\NUL\NUL\NUL\bvpmuludq\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTvpor\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQvpord\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQvporq\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKvpperm\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKvprold\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKvprolq\NUL\NUL\NUL\NUL\NUL\NUL\NUL\avprolvd\NUL\NUL\NUL\NUL\NUL\NUL\NUL\avprolvq\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKvprord\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKvprorq\NUL\NUL\NUL\NUL\NUL\NUL\NUL\avprorvd\NUL\NUL\NUL\NUL\NUL\NUL\NUL\avprorvq\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKvprotb\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKvprotd\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKvprotq\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKvprotw\NUL\NUL\NUL\NUL\NUL\NUL\NUL\avpsadbw\NUL\NUL\NUL\NUL\NUL\NUL\NUL\vvpscatterdd\NUL\NUL\NUL\NUL\NUL\NUL\NUL\vvpscatterdq\NUL\NUL\NUL\NUL\NUL\NUL\NUL\vvpscatterqd\NUL\NUL\NUL\NUL\NUL\NUL\NUL\vvpscatterqq\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKvpshab\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKvpshad\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKvpshaq\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKvpshaw\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKvpshlb\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKvpshld\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKvpshlq\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKvpshlw\NUL\NUL\NUL\NUL\NUL\NUL\NUL\avpshufb\NUL\NUL\NUL\NUL\NUL\NUL\NUL\avpshufd\NUL\NUL\NUL\NUL\NUL\NUL\NUL\bvpshufhw\NUL\NUL\NUL\NUL\NUL\NUL\NUL\bvpshuflw\NUL\NUL\NUL\NUL\NUL\NUL\NUL\avpsignb\NUL\NUL\NUL\NUL\NUL\NUL\NUL\avpsignd\NUL\NUL\NUL\NUL\NUL\NUL\NUL\avpsignw\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKvpslld\NUL\NUL\NUL\NUL\NUL\NUL\NUL\avpslldq\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKvpsllq\NUL\NUL\NUL\NUL\NUL\NUL\NUL\avpsllvd\NUL\NUL\NUL\NUL\NUL\NUL\NUL\avpsllvq\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKvpsllw\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKvpsrad\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKvpsraq\NUL\NUL\NUL\NUL\NUL\NUL\NUL\avpsravd\NUL\NUL\NUL\NUL\NUL\NUL\NUL\avpsravq\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKvpsraw\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKvpsrld\NUL\NUL\NUL\NUL\NUL\NUL\NUL\avpsrldq\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKvpsrlq\NUL\NUL\NUL\NUL\NUL\NUL\NUL\avpsrlvd\NUL\NUL\NUL\NUL\NUL\NUL\NUL\avpsrlvq\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKvpsrlw\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKvpsubb\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKvpsubd\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKvpsubq\NUL\NUL\NUL\NUL\NUL\NUL\NUL\avpsubsb\NUL\NUL\NUL\NUL\NUL\NUL\NUL\avpsubsw\NUL\NUL\NUL\NUL\NUL\NUL\NUL\bvpsubusb\NUL\NUL\NUL\NUL\NUL\NUL\NUL\bvpsubusw\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKvpsubw\NUL\NUL\NUL\NUL\NUL\NUL\NUL\nvpternlogd\NUL\NUL\NUL\NUL\NUL\NUL\NUL\nvpternlogq\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKvptest\NUL\NUL\NUL\NUL\NUL\NUL\NUL\bvptestmd\NUL\NUL\NUL\NUL\NUL\NUL\NUL\bvptestmq\NUL\NUL\NUL\NUL\NUL\NUL\NUL\tvptestnmd\NUL\NUL\NUL\NUL\NUL\NUL\NUL\tvptestnmq\NUL\NUL\NUL\NUL\NUL\NUL\NUL\nvpunpckhbw\NUL\NUL\NUL\NUL\NUL\NUL\NUL\nvpunpckhdq\NUL\NUL\NUL\NUL\NUL\NUL\NUL\vvpunpckhqdq\NUL\NUL\NUL\NUL\NUL\NUL\NUL\nvpunpckhwd\NUL\NUL\NUL\NUL\NUL\NUL\NUL\nvpunpcklbw\NUL\NUL\NUL\NUL\NUL\NUL\NUL\nvpunpckldq\NUL\NUL\NUL\NUL\NUL\NUL\NUL\vvpunpcklqdq\NUL\NUL\NUL\NUL\NUL\NUL\NUL\nvpunpcklwd\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQvpxor\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKvpxord\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKvpxorq\NUL\NUL\NUL\NUL\NUL\NUL\NUL\bvrcp14pd\NUL\NUL\NUL\NUL\NUL\NUL\NUL\bvrcp14ps\NUL\NUL\NUL\NUL\NUL\NUL\NUL\bvrcp14sd\NUL\NUL\NUL\NUL\NUL\NUL\NUL\bvrcp14ss\NUL\NUL\NUL\NUL\NUL\NUL\NUL\bvrcp28pd\NUL\NUL\NUL\NUL\NUL\NUL\NUL\bvrcp28ps\NUL\NUL\NUL\NUL\NUL\NUL\NUL\bvrcp28sd\NUL\NUL\NUL\NUL\NUL\NUL\NUL\bvrcp28ss\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKvrcpps\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKvrcpss\NUL\NUL\NUL\NUL\NUL\NUL\NUL\vvrndscalepd\NUL\NUL\NUL\NUL\NUL\NUL\NUL\vvrndscaleps\NUL\NUL\NUL\NUL\NUL\NUL\NUL\vvrndscalesd\NUL\NUL\NUL\NUL\NUL\NUL\NUL\vvrndscaless\NUL\NUL\NUL\NUL\NUL\NUL\NUL\bvroundpd\NUL\NUL\NUL\NUL\NUL\NUL\NUL\bvroundps\NUL\NUL\NUL\NUL\NUL\NUL\NUL\bvroundsd\NUL\NUL\NUL\NUL\NUL\NUL\NUL\bvroundss\NUL\NUL\NUL\NUL\NUL\NUL\NUL\nvrsqrt14pd\NUL\NUL\NUL\NUL\NUL\NUL\NUL\nvrsqrt14ps\NUL\NUL\NUL\NUL\NUL\NUL\NUL\nvrsqrt14sd\NUL\NUL\NUL\NUL\NUL\NUL\NUL\nvrsqrt14ss\NUL\NUL\NUL\NUL\NUL\NUL\NUL\nvrsqrt28pd\NUL\NUL\NUL\NUL\NUL\NUL\NUL\nvrsqrt28ps\NUL\NUL\NUL\NUL\NUL\NUL\NUL\nvrsqrt28sd\NUL\NUL\NUL\NUL\NUL\NUL\NUL\nvrsqrt28ss\NUL\NUL\NUL\NUL\NUL\NUL\NUL\bvrsqrtps\NUL\NUL\NUL\NUL\NUL\NUL\NUL\bvrsqrtss\NUL\NUL\NUL\NUL\NUL\NUL\NUL\tvscalefpd\NUL\NUL\NUL\NUL\NUL\NUL\NUL\tvscalefps\NUL\NUL\NUL\NUL\NUL\NUL\NUL\tvscalefsd\NUL\NUL\NUL\NUL\NUL\NUL\NUL\tvscalefss\NUL\NUL\NUL\NUL\NUL\NUL\NUL\vvscatterdpd\NUL\NUL\NUL\NUL\NUL\NUL\NUL\vvscatterdps\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOvscatterpf0dpd\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOvscatterpf0dps\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOvscatterpf0qpd\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOvscatterpf0qps\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOvscatterpf1dpd\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOvscatterpf1dps\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOvscatterpf1qpd\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOvscatterpf1qps\NUL\NUL\NUL\NUL\NUL\NUL\NUL\vvscatterqpd\NUL\NUL\NUL\NUL\NUL\NUL\NUL\vvscatterqps\NUL\NUL\NUL\NUL\NUL\NUL\NUL\nvshuff32x4\NUL\NUL\NUL\NUL\NUL\NUL\NUL\nvshuff64x2\NUL\NUL\NUL\NUL\NUL\NUL\NUL\nvshufi32x4\NUL\NUL\NUL\NUL\NUL\NUL\NUL\nvshufi64x2\NUL\NUL\NUL\NUL\NUL\NUL\NUL\avshufpd\NUL\NUL\NUL\NUL\NUL\NUL\NUL\avshufps\NUL\NUL\NUL\NUL\NUL\NUL\NUL\avsqrtpd\NUL\NUL\NUL\NUL\NUL\NUL\NUL\avsqrtps\NUL\NUL\NUL\NUL\NUL\NUL\NUL\avsqrtsd\NUL\NUL\NUL\NUL\NUL\NUL\NUL\avsqrtss\NUL\NUL\NUL\NUL\NUL\NUL\NUL\bvstmxcsr\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKvsubpd\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKvsubps\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKvsubsd\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKvsubss\NUL\NUL\NUL\NUL\NUL\NUL\NUL\avtestpd\NUL\NUL\NUL\NUL\NUL\NUL\NUL\avtestps\NUL\NUL\NUL\NUL\NUL\NUL\NUL\bvucomisd\NUL\NUL\NUL\NUL\NUL\NUL\NUL\bvucomiss\NUL\NUL\NUL\NUL\NUL\NUL\NUL\tvunpckhpd\NUL\NUL\NUL\NUL\NUL\NUL\NUL\tvunpckhps\NUL\NUL\NUL\NUL\NUL\NUL\NUL\tvunpcklpd\NUL\NUL\NUL\NUL\NUL\NUL\NUL\tvunpcklps\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKvxorpd\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKvxorps\NUL\NUL\NUL\NUL\NUL\NUL\NUL\bvzeroall\NUL\NUL\NUL\NUL\NUL\NUL\NUL\nvzeroupper\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKwbinvd\NUL\NUL\NUL\NUL\NUL\NUL\NUL\bwrfsbase\NUL\NUL\NUL\NUL\NUL\NUL\NUL\bwrgsbase\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQwrmsr\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQwrshr\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKxabort\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTxadd\NUL\NUL\NUL\NUL\NUL\NUL\NUL\axaquire\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKxbegin\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTxbts\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTxchg\NUL\NUL\NUL\NUL\NUL\NUL\NUL\txcryptcbc\NUL\NUL\NUL\NUL\NUL\NUL\NUL\txcryptcfb\NUL\NUL\NUL\NUL\NUL\NUL\NUL\txcryptctr\NUL\NUL\NUL\NUL\NUL\NUL\NUL\txcryptecb\NUL\NUL\NUL\NUL\NUL\NUL\NUL\txcryptofb\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTxend\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKxgetbv\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTxlat\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQxlatb\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETXxor\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTxorl\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQxorpd\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQxorps\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTxorq\NUL\NUL\NUL\NUL\NUL\NUL\NUL\bxrelease\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKxrstor\NUL\NUL\NUL\NUL\NUL\NUL\NUL\bxrstor64\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQxsave\NUL\NUL\NUL\NUL\NUL\NUL\NUL\axsave64\NUL\NUL\NUL\NUL\NUL\NUL\NUL\bxsaveopt\NUL\NUL\NUL\NUL\NUL\NUL\NUL\nxsaveopt64\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKxsetbv\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQxsha1\NUL\NUL\NUL\NUL\NUL\NUL\NUL\axsha256\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKxstore\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQxtest\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\a\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ESC\t\n !%&()*+,-/:;<=>?[\\]^{|}~\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL5\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTcall\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQcallq\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTiret\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQiretd\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQiretq\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQiretw\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STXja\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETXjae\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STXjb\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETXjbe\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STXjc\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTjcxz\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STXje\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQjecxz\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STXjg\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETXjge\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STXjl\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETXjle\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETXjmp\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTjmpe\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETXjna\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTjnae\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETXjnb\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTjnbe\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETXjnc\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETXjne\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETXjng\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTjnge\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETXjnl\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTjnle\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETXjno\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETXjnp\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETXjns\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETXjnz\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STXjo\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STXjp\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETXjpe\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETXjpo\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQjrcxz\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STXjs\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STXjz\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETXret\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTretd\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTretf\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQretfd\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQretfq\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQretfw\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTretn\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQretnd\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQretnq\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQretnw\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTretq\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTretw\DC3\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\n\ETX\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\v\ETX\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACK\NUL\NUL\NUL\NUL\NUL\NUL\NUL\n0[bB][01]+\SOH\ETX\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\b\STX\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACK\NUL\NUL\NUL\NUL\NUL\NUL\NUL\b\\$[0-9]+\SOH\STX\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACK\NUL\NUL\NUL\NUL\NUL\NUL\NUL-0[fFeEdD][-+]?[0-9]*\\.?[0-9]*[eE]?[-+]?[0-9]+\SOH\EOT\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACK\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SUB[A-Za-z_.$][A-Za-z0-9_.$]*\SOH\RS\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\r\ACK\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACK\NUL\NUL\NUL\NUL\NUL\NUL\NUL8'(\\\\x[0-9a-fA-F][0-9a-fA-F]?|\\\\[0-7]?[0-7]?[0-7]?|\\\\.|.)\SOH\ACK\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\"\b\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\rGNU Assembler\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKString\ACK\NUL\NUL\NUL\NUL\NUL\NUL\NUL\FS#\\s*if(?:def|ndef)?(?=\\s+\\S)\NUL\ETB\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\rGNU Assembler\NUL\NUL\NUL\NUL\NUL\NUL\NUL\fPreprocessor\ACK\NUL\NUL\NUL\NUL\NUL\NUL\NUL\t#\\s*endif\NUL\ETB\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\rGNU Assembler\NUL\NUL\NUL\NUL\NUL\NUL\NUL\fPreprocessor\ACK\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC4#\\s*define.*((?=\\\\))\NUL\ETB\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\rGNU Assembler\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKDefine\ACK\NUL\NUL\NUL\NUL\NUL\NUL\NULL#\\s*(?:el(?:se|if)|include(?:_next)?|define|undef|line|error|warning|pragma)\SOH\ETB\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\rGNU Assembler\NUL\NUL\NUL\NUL\NUL\NUL\NUL\fPreprocessor\SOH/*\f\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\rGNU Assembler\NUL\NUL\NUL\NUL\NUL\NUL\NUL\vCommentar 1\STX\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETX#;@\f\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\rGNU Assembler\NUL\NUL\NUL\NUL\NUL\NUL\NUL\vCommentar 2\STX\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETB!#%&()*+,-/:<=>?[]^{|}~\DC4\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\fPreprocessor\NUL\NUL\NUL\NUL\NUL\NUL\NUL\fPreprocessor\NUL\NUL\NUL\NUL\NUL\NUL\NUL\rGNU Assembler\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETB\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\fSome Context\NUL\NUL\NUL\NUL\NUL\NUL\NUL\fSome Context\NUL\NUL\NUL\NUL\NUL\NUL\NUL\rGNU Assembler\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKString\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKString\NUL\NUL\NUL\NUL\NUL\NUL\NUL\rGNU Assembler\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETX\SO\b\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\rGNU Assembler\NUL\NUL\NUL\NUL\NUL\NUL\NUL\fSome Context\f\a\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\"\b\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\b\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\144John Zaitseff (J.Zaitseff@zap.org.au), Roland Pabel (roland@pabel.name), Miquel Sabat\195\169 (mikisabate@gmail.com) Waqar Ahmed (waqar.17a@gmail.com)\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH9\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKGPLv2+\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STX\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETX*.s\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETX*.S\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKNormal"
